<?php

/*

 +-----------------------------------------------------------------------+
 | language/am/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Vahan Yerkanian <vahan@arminco.com>                           |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1160 2008-03-01 15:32:44Z yllar $

*/

$labels = array();
$labels['welcome'] = 'Բարի գալուստ $product';
$labels['username'] = 'Օգտվող';
$labels['password'] = 'Գաղտնաբառ';
$labels['server'] = 'Սերվեր';
$labels['login'] = 'Մուտք';
$labels['logout'] = 'Ելք';
$labels['mail'] = 'Էլ–փոստ';
$labels['settings'] = 'Նախասիրություններ';
$labels['addressbook'] = 'Հասցեներ';
$labels['inbox'] = 'Փոստարկղ';
$labels['drafts'] = 'Սևագրեր';
$labels['sent'] = 'Ուղարկված';
$labels['trash'] = 'Աղբարկղ';
$labels['junk'] = 'Թափոն';
$labels['subject'] = 'Վերնագիր';
$labels['from'] = 'Ուղարկող';
$labels['to'] = 'Ստացող';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Reply-To';
$labels['date'] = 'Ամսաթիվ';
$labels['size'] = 'Չափ';
$labels['priority'] = 'Առավելություն';
$labels['organization'] = 'Կազմակերպություն';
$labels['reply-to'] = 'Reply-To';
$labels['mailboxlist'] = 'Դարակներ';
$labels['messagesfromto'] = 'Նամակներ $from–ից $to–ը եղած $count–ից';
$labels['messagenrof'] = 'Նամակ $nr եղած $count–ից';
$labels['moveto'] = 'Տեղափոխել...';
$labels['download'] = 'Քաշել';
$labels['filename'] = 'Ֆայլի անուն';
$labels['filesize'] = 'Ֆայլի չափ';
$labels['preferhtml'] = 'Գերադասել HTML';
$labels['htmlmessage'] = 'HTML նամակ';
$labels['prettydate'] = 'Պարզ ամսաթվեր';
$labels['addtoaddressbook'] = 'Հիշել հասցեն';
$labels['sun'] = 'Կիր';
$labels['mon'] = 'Երկ';
$labels['tue'] = 'Երք';
$labels['wed'] = 'Չրք';
$labels['thu'] = 'Հնգ';
$labels['fri'] = 'Ուրբ';
$labels['sat'] = 'Շբթ';
$labels['sunday'] = 'Կիրակի';
$labels['monday'] = 'Երկուշաբթի';
$labels['tuesday'] = 'Երեքշաբթի';
$labels['wednesday'] = 'Չորեքշաբթի';
$labels['thursday'] = 'Հինգշաբթի';
$labels['friday'] = 'Ուրբաթ';
$labels['saturday'] = 'Շաբաթ';
$labels['today'] = 'Այսօր';
$labels['checkmail'] = 'Ստուգել նոր նամակները';
$labels['writenewmessage'] = 'Նոր նամակ';
$labels['replytomessage'] = 'Պատասխանել նամակին';
$labels['replytoallmessage'] = 'Պատասխանել բոլորին';
$labels['forwardmessage'] = 'Փոխանցել նամակը';
$labels['deletemessage'] = 'Ջնջել նամակը';
$labels['movemessagetotrash'] = 'Գցել աղբարկղը';
$labels['printmessage'] = 'Տպել';
$labels['previousmessage'] = 'Ցուցադրել նախորդ նամակը';
$labels['previousmessages'] = 'Ցուցադրել նախորդ նամակները';
$labels['firstmessage'] = 'Ցուցադրել առաջին նամակը';
$labels['firstmessages'] = 'Ցուցադրել առաջին էջը';
$labels['nextmessage'] = 'Ցուցադրել հաջորդ նամակը';
$labels['nextmessages'] = 'Ցուցադրել հաջորդ նամակները';
$labels['lastmessage'] = 'Ցուցադրել վերջին նամակը';
$labels['lastmessages'] = 'Ցուցադրել վերջին էջը';
$labels['backtolist'] = 'Վերադառնալ նամակների ցուցակ';
$labels['viewsource'] = 'Ցուցադրել նամակի կոդը';
$labels['markmessages'] = 'Նշել նամակները';
$labels['markread'] = 'որպես կարդացած';
$labels['markunread'] = 'որպես չկարդացած';
$labels['select'] = 'Նշել';
$labels['all'] = 'Բոլորը';
$labels['none'] = 'Չնշել';
$labels['unread'] = 'Չկարդացածը';
$labels['compact'] = 'Սեղմել';
$labels['empty'] = 'Դատարկել';
$labels['purge'] = 'Մաքրել';
$labels['quota'] = 'Դիսկային տարածք';
$labels['unknown'] = 'անհայտ';
$labels['unlimited'] = 'անսահմանափակ';
$labels['quicksearch'] = 'Արագ որոնում';
$labels['resetsearch'] = 'Վերսկսել որոնումը';
$labels['compose'] = 'Գրել նամակ';
$labels['savemessage'] = 'Հիշել որպես սևագիր';
$labels['sendmessage'] = 'Ուղարկել';
$labels['addattachment'] = 'Կցել ֆայլ';
$labels['charset'] = 'Տառաշար';
$labels['editortype'] = 'Խմբագրի տիպը';
$labels['returnreceipt'] = 'Ստացման հավաստագիր';
$labels['checkspelling'] = 'Ստուգել ուղագրությունը';
$labels['resumeediting'] = 'Շարունակել խմբագրումը';
$labels['revertto'] = 'Վերականգնել';
$labels['attachments'] = 'Կցումներ';
$labels['upload'] = 'Բեռնել';
$labels['close'] = 'Փակել';
$labels['low'] = 'Ցածր';
$labels['lowest'] = 'Նվազագույն';
$labels['normal'] = 'Նորմալ';
$labels['high'] = 'Կարևոր';
$labels['highest'] = 'Կարևորագույն';
$labels['nosubject'] = '(առանց վերնագրի)';
$labels['showimages'] = 'Ցուցադրել նկարները';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Պարզ տեքստ';
$labels['addcc'] = 'Ավելացնել Cc';
$labels['addbcc'] = 'Ավելացնել Bcc';
$labels['addreplyto'] = 'Ավելացնել Reply-To';
$labels['mdnrequest'] = 'Նամակի հեղինակը խնդրել է նամակը կարդալուն պես տեղեկացնել իրեն։ Ցանկանում էք Տեղեկացնե՞լ։';
$labels['receiptread'] = 'Նամակի ընթերցման ծանուցագիր';
$labels['yourmessage'] = 'Սա Ձեր նամակի ընթերցման ծանուցագիրն է';
$labels['receiptnote'] = 'Նշում՝ Այս ծանուցագիրը ընդամենը տեղեկացնում է, որ նամակը ցուցադրվել է հասցեատիրոջ համակարչով։ Չկա որևիցե երաշխիք, որ հասցեատերը իսկապես կարդացել է նամակը։';
$labels['name'] = 'Մականուն';
$labels['firstname'] = 'Անուն';
$labels['surname'] = 'Ազգանուն';
$labels['email'] = 'Էկ–փոստ';
$labels['addcontact'] = 'Գրանցել նշած հասցեն';
$labels['editcontact'] = 'Խմբագրել հասցեն';
$labels['edit'] = 'Խմբագրել';
$labels['cancel'] = 'Թարգել';
$labels['save'] = 'Հիշել';
$labels['delete'] = 'Ջնջել';
$labels['newcontact'] = 'Ստեղծել նոր հասցեքարտ';
$labels['deletecontact'] = 'Ջնջել նշած նամակները';
$labels['composeto'] = 'Գրել նամակ';
$labels['contactsfromto'] = 'Հասցեներ $from–ից $to–ը եղած $count–ից';
$labels['print'] = 'Տպել';
$labels['export'] = 'Արտահանել';
$labels['previouspage'] = 'Ցուցադրել նախորդ էջը';
$labels['firstpage'] = 'Ցուցադրել առաջին էջը';
$labels['nextpage'] = 'Ցուցադրել հաջորդ էջը';
$labels['lastpage'] = 'Ցուցադրել վերջին էջը';
$labels['groups'] = 'Խմբեր';
$labels['personaladrbook'] = 'Անձնական հասցեներ';
$labels['settingsfor'] = 'Նախասիրություններ';
$labels['preferences'] = 'Ընդհանուր';
$labels['userpreferences'] = 'Օգտվողի նախասիրություններ';
$labels['editpreferences'] = 'Խմբագրել օգտվողի նախասիրությունները';
$labels['identities'] = 'Անձիք';
$labels['manageidentities'] = 'Կարգավորել անձանց';
$labels['newidentity'] = 'Նոր անձ';
$labels['newitem'] = 'Նոր իր';
$labels['edititem'] = 'Խմբագրել իրը';
$labels['setdefault'] = 'Հիմնական';
$labels['language'] = 'Լեզու';
$labels['timezone'] = 'Ժամային գոտի';
$labels['pagesize'] = 'Տողեր առ էջ';
$labels['signature'] = 'Ստորագրություն';
$labels['dstactive'] = 'Ամառային ժամանակ';
$labels['htmleditor'] = 'Ստեղծել HTML նամակներ';
$labels['htmlsignature'] = 'HTML ստորագրություն';
$labels['previewpane'] = 'Ցուցադրել պատուհանը';
$labels['autosavedraft'] = 'Սևագրի ավտոմատ գրանցում';
$labels['everynminutes'] = 'ամեն $n րոպեն';
$labels['never'] = 'երբեք';
$labels['folder'] = 'Դարակ';
$labels['folders'] = 'Դարակներ';
$labels['foldername'] = 'Դարակի անուն';
$labels['subscribed'] = 'Բաժանորդագրված';
$labels['messagecount'] = 'Նամակներ';
$labels['create'] = 'Ստեղծել';
$labels['createfolder'] = 'Բացել նոր դարակ';
$labels['rename'] = 'Վերանվանել';
$labels['renamefolder'] = 'Վերանվանել դարակը';
$labels['deletefolder'] = 'Ջնջել դարակը';
$labels['managefolders'] = 'Կարգավորել դարակները';
$labels['sortby'] = 'Դասավորել';
$labels['sortasc'] = 'ըստ աճման';
$labels['sortdesc'] = 'ըստ նվազման';

?>