<?php

/*

 +-----------------------------------------------------------------------+
 | language/sq_AL/labels.inc                                             |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Dashamir Hoxha <dhoxha@albaniaonline.net>                     |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$labels = array();
$labels['welcome'] = 'Mirëseerdhe te $product';
$labels['username'] = 'Përdoruesi';
$labels['password'] = 'Fjalëkalimi';
$labels['server'] = 'Serveri';
$labels['login'] = 'Hyr';
$labels['logout'] = 'Dil';
$labels['mail'] = 'Mesazhet';
$labels['settings'] = 'Konfigurimi Personal';
$labels['addressbook'] = 'Libri i Adresave';
$labels['inbox'] = 'Ardhjet';
$labels['drafts'] = 'Drafte';
$labels['sent'] = 'Dërguar';
$labels['trash'] = 'Fshirë';
$labels['junk'] = 'Reklama';
$labels['subject'] = 'Tema';
$labels['from'] = 'Dërguesi';
$labels['to'] = 'Marrësi';
$labels['cc'] = 'Kopje';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Reply-To';
$labels['date'] = 'Data';
$labels['size'] = 'Madhësia';
$labels['priority'] = 'Përparësia';
$labels['organization'] = 'Organizata';
$labels['reply-to'] = 'Reply-To';
$labels['mailboxlist'] = 'Dosjet';
$labels['messagesfromto'] = 'Mesazhet $from në $to nga $count';
$labels['messagenrof'] = 'Mesazhi $nr nga $count';
$labels['moveto'] = 'ço te...';
$labels['download'] = 'shkarko';
$labels['filename'] = 'Emër skedari';
$labels['filesize'] = 'Madhësi skedari';
$labels['preferhtml'] = 'Shfaq HTML';
$labels['htmlmessage'] = 'Mesazh HTML';
$labels['prettydate'] = 'Data të këndshme';
$labels['addtoaddressbook'] = 'Shto në librin e adresave';
$labels['sun'] = 'Dje';
$labels['mon'] = 'Hën';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mër';
$labels['thu'] = 'Enj';
$labels['fri'] = 'Pre';
$labels['sat'] = 'Sht';
$labels['sunday'] = 'e djelë';
$labels['monday'] = 'e hënë';
$labels['tuesday'] = 'e martë';
$labels['wednesday'] = 'e mërkurë';
$labels['thursday'] = 'e enjte';
$labels['friday'] = 'e premte';
$labels['saturday'] = 'e shtunë';
$labels['today'] = 'sot';
$labels['checkmail'] = 'Shiko për mesazhe të reja';
$labels['writenewmessage'] = 'Krijo një mesazh të ri';
$labels['replytomessage'] = 'Ktheji përgjigje mesazhit';
$labels['replytoallmessage'] = 'Ktheji përgjigje dërguesit dhe të gjithë marrësve';
$labels['forwardmessage'] = 'Pasoje mesazhin';
$labels['deletemessage'] = 'Fshije mesazhin';
$labels['movemessagetotrash'] = 'Hidhe mesazhin në kosh';
$labels['printmessage'] = 'Shtype këtë mesazh';
$labels['previousmessage'] = 'Shfaq mesazhin e mëparshëm';
$labels['previousmessages'] = 'Shfaq grupin e mëparshëm të mesazheve';
$labels['firstmessage'] = 'Shfaq mesazhin e parë';
$labels['firstmessages'] = 'Shfaq grupin e parë të mesazheve';
$labels['nextmessage'] = 'Shfaq mesazhin pasardhës';
$labels['nextmessages'] = 'Shfaq grupin tjetër të mesazheve';
$labels['lastmessage'] = 'Shfaq mesazhin e fundit';
$labels['lastmessages'] = 'Shfaq grupin e fundit të mesazheve';
$labels['backtolist'] = 'Kthehu te lista e mesazheve';
$labels['viewsource'] = 'Shfaq tekstin';
$labels['markmessages'] = 'Shëno mesazhet';
$labels['markread'] = 'Si të lexuara';
$labels['markunread'] = 'Si të palexuara';
$labels['select'] = 'Zgjidh';
$labels['all'] = 'Të gjitha';
$labels['none'] = 'Asnjë';
$labels['unread'] = 'Palexuar';
$labels['compact'] = 'Zvogëlo';
$labels['empty'] = 'Boshatis';
$labels['purge'] = 'Pastro';
$labels['quota'] = 'Përdorimi i diskut';
$labels['unknown'] = 'i panjohur';
$labels['unlimited'] = 'i pakufizuar';
$labels['quicksearch'] = 'Kërkim i shpejtë';
$labels['resetsearch'] = 'Pastro kërkimin';
$labels['compose'] = 'Shkruaj një mesazh';
$labels['savemessage'] = 'Ruaje si draft';
$labels['sendmessage'] = 'Dërgoje mesazhin tani';
$labels['addattachment'] = 'Bashkangjit një skedar';
$labels['charset'] = 'Bashkësi shkronjash';
$labels['editortype'] = 'Lloj editori';
$labels['returnreceipt'] = 'Njoftim marrje';
$labels['checkspelling'] = 'Kontroll gabimesh';
$labels['resumeediting'] = 'Vazhdo editimin';
$labels['revertto'] = 'Ktheje te';
$labels['attachments'] = 'Bashkangjitjet';
$labels['upload'] = 'Ngarko';
$labels['close'] = 'Mbyll';
$labels['low'] = 'I ulët';
$labels['lowest'] = 'Më i ulëti';
$labels['normal'] = 'Normal';
$labels['high'] = 'I lartë';
$labels['highest'] = 'Më i larti';
$labels['nosubject'] = '(pa subjekt)';
$labels['showimages'] = 'Shfaq imazhet';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'TEXT';
$labels['addcc'] = 'Shto Cc';
$labels['addbcc'] = 'Shto Bcc';
$labels['addreplyto'] = 'Shto Reply-To';
$labels['mdnrequest'] = 'Dërguesi i këtij mesazhi ka kërkuar që të njoftohet kur ju të lexoni këtë mesazh. Dëshironi ta njoftoni dërguesin?';
$labels['receiptread'] = 'Njoftim Leximi';
$labels['yourmessage'] = 'Ky është një njoftim leximi për mesazhin tuaj';
$labels['receiptnote'] = 'Shënim: Ky njoftim tregon vetëm që mesazhi u shfaq në kompjuterin e marrësit. Nuk ka siguri që marrësi e ka lexuar ose e ka kuptuar përmbajtjen e mesazhit.';
$labels['name'] = 'Emri që thirret';
$labels['firstname'] = 'Emri';
$labels['surname'] = 'Mbiemri';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Shto një kontakt të ri';
$labels['editcontact'] = 'Ndrysho kontaktin';
$labels['edit'] = 'Ndrysho';
$labels['cancel'] = 'Anullo';
$labels['save'] = 'Ruaj';
$labels['delete'] = 'Fshi';
$labels['newcontact'] = 'Krijo nje kartë të re kontakti';
$labels['deletecontact'] = 'Fshi kontaktet e zgjedhura';
$labels['composeto'] = 'Shkruaj email për';
$labels['contactsfromto'] = 'Kontaktet $from në $to nga $count';
$labels['print'] = 'Shtyp';
$labels['export'] = 'Eksporto';
$labels['previouspage'] = 'Shfaq grupin e mëparshëm';
$labels['firstpage'] = 'Shfaq grupin e parë';
$labels['nextpage'] = 'Shfaq grupin tjetër';
$labels['lastpage'] = 'Shfaq grupin e fundit';
$labels['groups'] = 'Grupet';
$labels['personaladrbook'] = 'Adresat Personale';
$labels['settingsfor'] = 'Konfigurimet për';
$labels['preferences'] = 'Preferencat';
$labels['userpreferences'] = 'Preferencat e përdoruesit';
$labels['editpreferences'] = 'Ndrysho preferencat e përdoruesit';
$labels['identities'] = 'Identitetet';
$labels['manageidentities'] = 'Manaxho identitetet per këtë llogari';
$labels['newidentity'] = 'Identitet i ri';
$labels['newitem'] = 'Element i ri';
$labels['edititem'] = 'Ndrysho element';
$labels['setdefault'] = 'Bëje identitet kryesor';
$labels['language'] = 'Gjuha';
$labels['timezone'] = 'Brezi orar';
$labels['pagesize'] = 'Rreshtat për faqe';
$labels['signature'] = 'Nënshkrim';
$labels['dstactive'] = 'Ndryshim ore';
$labels['htmleditor'] = 'Shkruaj mesazhe HTML';
$labels['htmlsignature'] = 'Nënshkrimi HTML';
$labels['previewpane'] = 'Shiko si duket';
$labels['autosavedraft'] = 'Ruaje automatikisht si draft';
$labels['everynminutes'] = 'çdo $n minuta';
$labels['never'] = 'kurrë';
$labels['folder'] = 'Kutia';
$labels['folders'] = 'Kutitë';
$labels['foldername'] = 'Emër kutie';
$labels['subscribed'] = 'Regjistruar';
$labels['messagecount'] = 'Mesazhe';
$labels['create'] = 'Krijo';
$labels['createfolder'] = 'Krijo kuti të re';
$labels['rename'] = 'Riemëro';
$labels['renamefolder'] = 'Riemëro kutinë';
$labels['deletefolder'] = 'Fshi kutinë';
$labels['managefolders'] = 'Sistemo kutitë';
$labels['sortby'] = 'Rradhit sipas';
$labels['sortasc'] = 'Rradhitje rritëse';
$labels['sortdesc'] = 'Rradhitje zbritëse';

?>
