<?php

/*
+-----------------------------------------------------------------------+
| language/fa/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Mohammad Ebrahim Mohammadi Panah <mebrahim@gmail.com>         |
|         Anoosh <anoosher2003@yahoo.com>                               |
+-----------------------------------------------------------------------+

@version $Id$

*/

$labels = array();
$labels['welcome'] = 'خوش آمدید $product به';
$labels['username'] = 'نام کاربری';
$labels['password'] = 'گذرواژه';
$labels['server'] = 'سرور';
$labels['login'] = 'ورود';
$labels['logout'] = 'خروج';
$labels['mail'] = 'ایمیل';
$labels['settings'] = 'تنظیمات شخصی';
$labels['addressbook'] = 'دفتر نشانی‌ها';
$labels['inbox'] = 'صندوق';
$labels['drafts'] = 'پیش‌نویس‌ها';
$labels['sent'] = 'فرستاده‌شده‌ها';
$labels['trash'] = 'زباله‌دان';
$labels['junk'] = 'بنجل';
$labels['subject'] = 'موضوع';
$labels['from'] = 'فرستنده';
$labels['to'] = 'گیرنده';
$labels['cc'] = 'رونوشت';
$labels['bcc'] = 'رونوشت مخفی';
$labels['replyto'] = 'پاسخ-به';
$labels['date'] = 'تاریخ';
$labels['size'] = 'حجم';
$labels['priority'] = 'اولویت';
$labels['organization'] = 'سازمان‌دهی';
$labels['reply-to'] = 'پاسخ-به';
$labels['mailboxlist'] = 'پوشه‌ها';
$labels['messagesfromto'] = 'تا $count از $to تا $from پیغام‌های';
$labels['messagenrof'] = 'تا $count پیغام  از $nr';
$labels['moveto'] = '...انتقال به';
$labels['download'] = 'دانلود';
$labels['filename'] = 'نام پرونده';
$labels['filesize'] = 'اندازه‌ی پرونده';
$labels['preferhtml'] = 'HTML نمایش';
$labels['htmlmessage'] = 'HTML پیغام';
$labels['prettydate'] = 'تاریخ‌های زیبا';
$labels['addtoaddressbook'] = 'افزودن به دفتر نشانی‌ها';
$labels['sun'] = 'یکشنبه';
$labels['mon'] = 'دوشنبه';
$labels['tue'] = 'سه‌شنبه';
$labels['wed'] = 'چهارشنبه';
$labels['thu'] = 'پنج‌شنبه';
$labels['fri'] = 'جمعه';
$labels['sat'] = 'شنبه';
$labels['sunday'] = 'یکشنبه';
$labels['monday'] = 'دوشنبه';
$labels['tuesday'] = 'سه‌شنبه';
$labels['wednesday'] = 'چهارشنبه';
$labels['thursday'] = 'پنج‌شنبه';
$labels['friday'] = 'جمعه';
$labels['saturday'] = 'شنبه';
$labels['jan'] = 'ژانویه';
$labels['feb'] = 'فوریه';
$labels['mar'] = 'مارس';
$labels['apr'] = 'آوریل';
$labels['may'] = 'می';
$labels['jun'] = 'ژوئن';
$labels['jul'] = 'جولی';
$labels['aug'] = 'آگوست';
$labels['sep'] = 'سپتامبر';
$labels['oct'] = 'اکتبر';
$labels['nov'] = 'نوامبر';
$labels['dec'] = 'دسامبر';
$labels['longjan'] = 'ژانویه';
$labels['longfeb'] = 'فوریه';
$labels['longmar'] = 'مارس';
$labels['longapr'] = 'آوریل';
$labels['longmay'] = 'می';
$labels['longjun'] = 'ژوئن';
$labels['longjul'] = 'جولی';
$labels['longaug'] = 'آگوست';
$labels['longsep'] = 'سپتامبر';
$labels['longoct'] = 'اکتبر';
$labels['longnov'] = 'نوامبر';
$labels['longdec'] = 'دسامبر';
$labels['today'] = 'امروز';
$labels['checkmail'] = 'بررسی برای پیغام‌های جدید';
$labels['writenewmessage'] = 'ایجاد پیغام جدید';
$labels['replytomessage'] = 'پاسخ به پیغام';
$labels['replytoallmessage'] = 'پاسخ به فرستنده وتمام گیرنده‌ها';
$labels['forwardmessage'] = 'ارجاع پیغام';
$labels['deletemessage'] = 'حذف پیغام';
$labels['movemessagetotrash'] = 'انتقال پیغام به زباله‌دان';
$labels['printmessage'] = 'چاپ این پیغام';
$labels['previousmessage'] = 'نمایش پیغام قبلی';
$labels['previousmessages'] = 'نمایش دسته‌ی قبلی  پیغام‌ها';
$labels['firstmessage'] = 'نمایش اولین  پیغام';
$labels['firstmessages'] = 'نمایش اولین دسته‌ی پیغام‌ها';
$labels['nextmessage'] = 'نمایش پیغام بعدی';
$labels['nextmessages'] = 'نمایش دسته‌ی بعدی  پیغام‌ها';
$labels['lastmessage'] = 'نمایش آخرین پیغام';
$labels['lastmessages'] = 'نمایش آخرین دسته‌ی  پیغام‌ها';
$labels['backtolist'] = 'بازگشت به فهرست پیغام‌ها';
$labels['viewsource'] = 'نمایش منبع';
$labels['markmessages'] = 'علامت‌گذاری پیغام‌ها';
$labels['markread'] = 'به عنوان خوانده‌شده';
$labels['markunread'] = 'به عنوان خوانده‌نشده';
$labels['select'] = 'انتخاب';
$labels['all'] = 'همه';
$labels['none'] = 'هیچ';
$labels['unread'] = 'ناخوانده';
$labels['compact'] = 'فشرده';
$labels['empty'] = 'خالی';
$labels['purge'] = 'خرد کردن';
$labels['quota'] = 'فضای استفاده شده';
$labels['unknown'] = 'ناشناخته';
$labels['unlimited'] = 'نامحدود';
$labels['quicksearch'] = 'جستجوی سریع';
$labels['resetsearch'] = 'شروع مجدد جستجو';
$labels['compose'] = 'نوشتن پیغام';
$labels['savemessage'] = 'ذخیره‌ی این پیش‌نویس';
$labels['sendmessage'] = 'ارسال پیغام';
$labels['addattachment'] = 'پیوست کردن یک پرونده';
$labels['charset'] = 'مجموعه‌نمایه';
$labels['editortype'] = 'نوع ویرایش‌گر';
$labels['returnreceipt'] = 'رسید دریافت';
$labels['checkspelling'] = 'بررسی املایی';
$labels['resumeediting'] = 'ادامه‌ی ویرایش';
$labels['revertto'] = 'برگرداندن به';
$labels['attachments'] = 'پیوست‌ها';
$labels['upload'] = 'بالاگذاری';
$labels['close'] = 'بستن';
$labels['low'] = 'کم';
$labels['lowest'] = 'کم‌ترین';
$labels['normal'] = 'معمولی';
$labels['high'] = 'زیاد';
$labels['highest'] = 'بیش‌ترین';
$labels['nosubject'] = '(بدون موضوع)';
$labels['showimages'] = 'نمایش عکس‌ها';
$labels['alwaysshow'] = 'را نمایش بده $sender همیشه عکسهای دریافتی از  ';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'متن ساده';
$labels['addcc'] = 'افزودن رونوشت';
$labels['addbcc'] = 'افزودن رونوشت مخفی';
$labels['addreplyto'] = 'افزودن پاسخ-به';
$labels['mdnrequest'] = 'فرستندهٔ این پیغام خواسته است که وقتی شما این پیغام را می‌خوانید، آگاه شود. آیا مایلید فرستنده را آگاه کنید؟';
$labels['receiptread'] = '(رسید دریافت (خواندن';
$labels['yourmessage'] = 'این یک رسید دریافت برای پیغام شماست';
$labels['receiptnote'] = 'تذکر: این رسید فقط تصدیق می‌کند که پیغام، روی رایانهٔ گیرنده نمایش داده شده است. هیچ تضمینی نیست که گیرنده، محتوای پیغام را خوانده یا فهمیده باشد.';
$labels['name'] = 'نمایش نام';
$labels['firstname'] = 'نام';
$labels['surname'] = 'نام خانوادگی';
$labels['email'] = 'ایمیل';
$labels['addcontact'] = 'افزودن تماس جدید';
$labels['editcontact'] = 'ویرایش تماس';
$labels['edit'] = 'ویرایش';
$labels['cancel'] = 'لغو';
$labels['save'] = 'ذخیره';
$labels['delete'] = 'حذف';
$labels['newcontact'] = 'ایجاد کارت تماس جدید';
$labels['deletecontact'] = 'حذف تماس‌های انتخاب شده';
$labels['composeto'] = 'نوشتن نامه به';
$labels['contactsfromto'] = ' تا $count از $to تا $from  تماس‌های';
$labels['print'] = 'چاپ';
$labels['export'] = 'صدور';
$labels['previouspage'] = 'نمایش دسته‌ی قبلی';
$labels['firstpage'] = 'نمایش دسته‌ی اول';
$labels['nextpage'] = 'نمایش دسته‌ی بعدی';
$labels['lastpage'] = 'نمایش دسته‌ی آخر';
$labels['groups'] = 'گروه‌ها';
$labels['personaladrbook'] = 'نشانی‌های شخصی';
$labels['settingsfor'] = 'تنظیمات';
$labels['preferences'] = 'ترجیحات';
$labels['userpreferences'] = 'ترجیحات کاربر';
$labels['editpreferences'] = 'ویرایش ترجیحات کاربر';
$labels['identities'] = 'شناسه‌ها';
$labels['manageidentities'] = 'مدیریت شناسه‌ها برای این حساب';
$labels['newidentity'] = 'شناسه جدید';
$labels['newitem'] = 'مورد جدید';
$labels['edititem'] = 'ویرایش مورد';
$labels['setdefault'] = 'پیش‌فرض کن';
$labels['language'] = 'زبان';
$labels['timezone'] = 'محدوده‌ی زمانی';
$labels['pagesize'] = 'سطر در صفحه';
$labels['signature'] = 'امضا';
$labels['dstactive'] = 'ساعت تابستانی';
$labels['htmleditor'] = 'HTML ‌نوشتن پیغام‌های';
$labels['htmlsignature'] = 'HTML امضای';
$labels['previewpane'] = 'نمایش قاب پیش‌نمایش';
$labels['logoutclear'] = 'تمیز کردن زباله دان در هنگام خروچ';
$labels['logoutcompact'] = 'فشرده سازی صندوق در هنگام خروچ';
$labels['uisettings'] = 'محیط کاربری';
$labels['serversettings'] = 'تنظیمات سرور';
$labels['mailboxview'] = 'نمایش صندوق';
$labels['mdnrequests'] = 'تاییدهای فرستنده';
$labels['askuser'] = 'پرسش از کاربر';
$labels['autosend'] = 'ارسال خود به خود';
$labels['ignore'] = 'نادیده گیری';
$labels['readwhendeleted'] = 'در هنگام پاک کردن، پیغام را به عنوان خوانده شده علامت بزن';
$labels['flagfordeletion'] = 'پیغام را بجای پاک کردن، برای پاک شدن آماده کن ';
$labels['showinlineimages'] = 'نمایش عکس های الصاق شده در پایین پیغام';
$labels['autosavedraft'] = 'ذخیره‌ی خودکار پیش‌نویس';
$labels['everynminutes'] = 'دقیقه $n هر';
$labels['never'] = 'هرگز';
$labels['messagesdisplaying'] = 'نمایش داده شدن پیغام ها';
$labels['messagescomposition'] = 'نوشته شدن پیغام ها';
$labels['folder'] = 'پوشه';
$labels['folders'] = 'پوشه‌ها';
$labels['foldername'] = 'نام پوشه';
$labels['subscribed'] = 'مورد اشتراک';
$labels['messagecount'] = 'پیغام‌ها';
$labels['create'] = 'ایجاد';
$labels['createfolder'] = 'ایجاد پوشه‌ی جدید';
$labels['rename'] = 'تغییر نام';
$labels['renamefolder'] = 'تغییر نام پوشه';
$labels['deletefolder'] = 'حذف پوشه';
$labels['managefolders'] = 'مدیریت پوشه‌ها';
$labels['sortby'] = 'مرتب‌سازی بر اساس';
$labels['sortasc'] = 'مرتب‌سازی صعودی';
$labels['sortdesc'] = 'مرتب‌سازی نزولی';

?>
