/***** RoundCube|Mail mail task styles *****/


#messagetoolbar
{
  position: absolute;
  top: 47px;
  left: 200px;
  right: 200px;
  height: 35px;
  white-space: nowrap;
/*  border: 1px solid #cccccc; */
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-400)+'px');
}

#messagetoolbar a
{
  padding-right: 10px;
}

#messagetoolbar select
{
  font-family: "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
  font-size: 11px;
  color: #333333;
}

#messagetoolbar select.mboxlist
{
  position: absolute;
  left: 375px;
  top: 8px;
}

#messagetoolbar select.mboxlist option
{
  padding-left: 15px;
}

#messagetoolbar select.mboxlist option[value="0"]
{
  padding-left: 2px;
}

#markmessagemenu
{
  position: absolute;
  top: 32px;
  left: 90px;
  width: auto;
  visibility: hidden;
  background-color: #F9F9F9;
  border: 1px solid #CCC;
  padding: 1px;
  opacity: 0.9;
  filter:alpha(opacity=90);
  z-index: 240;
}

ul.toolbarmenu
{
  margin: 0;
  padding: 0;
  list-style: none;
}

ul.toolbarmenu li
{
  font-size: 11px;
  white-space: nowrap;
  min-width: 130px;
  width: auto !important;
  width: 130px;
}

ul.toolbarmenu li a
{
  display: block;
  color: #a0a0a0;
  padding: 2px 8px 3px 12px;
  text-decoration: none;
}

ul.toolbarmenu li a.active:hover
{
  background-color: #ddd;
}

#searchfilter
{
  position: absolute;
  right: 18px;
  top: 8px;
  width: 240px;
  text-align: right;
}

#searchfilter label
{
  font-size: 11px;
}

#listcontrols a,
#listcontrols a:active,
#listcontrols a:visited,
#mailboxcontrols a,
#mailboxcontrols a:active,
#mailboxcontrols a:visited,
td.formlinks a,
td.formlinks a:visited
{
  color: #999999;
  font-size: 11px;
  text-decoration: none;
}

#listcontrols a.active,
#listcontrols a.active:active,
#listcontrols a.active:visited,
#mailboxcontrols a.active,
#mailboxcontrols a.active:active,
#mailboxcontrols a.active:visited,
ul.toolbarmenu li a.active,
ul.toolbarmenu li a.active:active,
ul.toolbarmenu li a.active:visited,
td.formlinks a,
td.formlinks a:visited
{
  color: #CC0000;
}

#listcontrols a.active:hover,
#mailboxcontrols a.active:hover
{
  text-decoration: underline;
}

#listcontrols,
#mailboxcontrols
{
  padding-right: 2em;
}

#messagecountbar
{
  position: absolute;
  bottom: 16px;
  right: 20px;
  width: 300px;
  height: 20px;
  text-align: right;
  white-space: nowrap;
}

#messagecountbar span
{
  font-size: 11px;
  color: #333333;
}

#mainscreen 
{
  position: absolute;
  top: 85px;
  right: 20px;
  bottom: 40px;
  left: 20px;
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-40)+'px');
  height: expression((parseInt(document.documentElement.clientHeight)-125)+'px');
}

#mailrightcontainer
{
  position: absolute;
  top: 0px;
  left: 170px;
  bottom: 0px;
  right: 0px;
  /* css hack for IE */
  width: expression((parseInt(this.parentNode.offsetWidth)-170)+'px');
  height: expression(parseInt(this.parentNode.offsetHeight)+'px');
}
	  
#messagepartcontainer
{
  position: absolute;
  top: 80px;
  left: 20px;
  right: 20px;
  bottom: 20px;
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-40)+'px');
  height: expression((parseInt(document.documentElement.clientHeight)-100)+'px');
}

#mailcontframe
{
  position: absolute;
  width: 100%;
  top: 0px;
  bottom: 0px;
  border: 1px solid #999999;
  background-color: #F9F9F9;
  overflow: auto;
  /* css hack for IE */
  height: expression(parseInt(this.parentNode.offsetHeight)+'px');
}

#mailpreviewframe
{
  position: absolute;
  width: 100%;
  top: 205px;
  bottom: 0px;
  border: 1px solid #999999;
  background-color: #F9F9F9;
  /* css hack for IE */
  height: expression((parseInt(this.parentNode.offsetHeight)-205)+'px');
}

#messagecontframe
{
  position: relative;
  top: 0px;
  left: 0px;
  right: 0px;
  bottom: 0px;
  width: 100%;
  height: 100%;
}

#messagepartframe
{
  width: 100%;
  height: 100%;
  border: 1px solid #999999;
  background-color: #F9F9F9;
}


#partheader
{
  position: absolute;
  top: 10px;
  left: 220px;
  right: 20px;
  height: 40px;
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-240)+'px');
}

#partheader table td
{
  padding-left: 2px;
  padding-right: 4px;
  vertical-align: middle;
  font-size: 11px;
}

#partheader table td.title
{
  color: #666666;
  font-weight: bold;
}


/** mailbox list styles */

#mailboxlist-header
{
  display: block;
  height: 12px;
  margin: 0;
  padding: 3px 10px 4px 10px;
  background-color: #EBEBEB;
  background-image: url(images/listheader_aqua.gif); 
  border-bottom: 1px solid #999;
  color: #333333;
  font-size: 11px;
  font-weight: bold;  
}

#mailboxlist-container
{
  position: absolute;
  top: 0px;
  left: 0px;
  width: 160px;
  bottom: 0px;
  border: 1px solid #999;
  background-color: #F9F9F9;
  overflow: auto;
  /* css hack for IE */
  height: expression(parseInt(this.parentNode.offsetHeight)+'px');
}

#mailboxlist
{
  position:relative;
  height: auto;
  margin: 0px;
  padding: 0px;
  list-style-image: none;
  list-style-type: none;
  overflow: hidden;
  white-space: nowrap;
}

#mailboxlist li
{
  display: block;
  position: relative;
  font-size: 11px;
  background: url(images/icons/folder-closed.png) no-repeat;
  background-position: 5px 1px;
  border-bottom: 1px solid #EBEBEB;
}

#mailboxlist li div
{
  position: absolute;
  left: 8px !important;
  left: -16px;
  top: 2px;
  width: 14px;
  height: 16px;
}

#mailboxlist li div.collapsed,
#mailboxlist li div.expanded
{
  cursor: pointer;
}

#mailboxlist li div.collapsed
{
  background: url(images/icons/collapsed.png) bottom right no-repeat;
}

#mailboxlist li div.expanded
{
  background: url(images/icons/expanded.png) bottom right no-repeat;
}

#mailboxlist li.inbox
{
  background-image: url(images/icons/folder-inbox.png);
}

#mailboxlist li.drafts
{
  background-image: url(images/icons/folder-drafts.png);
}

#mailboxlist li.sent
{
  background-image: url(images/icons/folder-sent.png);
}

#mailboxlist li.junk
{
  background-image: url(images/icons/folder-junk.png);
}

#mailboxlist li.trash
{
  background-image: url(images/icons/folder-trash.png);
}

#mailboxlist li a
{
  cursor: default;
  display: block;
  position: relative;
  padding-left: 25px;
  padding-top: 2px;
  padding-bottom: 2px;
  text-decoration: none;
}

#mailboxlist li.unread
{
  font-weight: bold;
}

#mailboxlist li.virtual > a
{
  color: #666;
}

#mailboxlist li.selected,
#mailboxlist li.droptarget li.selected
{
  background-color: #929292;
}

#mailboxlist li.selected > a,
#mailboxlist li.droptarget li.selected a
{
  color: #FFF;
  font-weight: bold;
}

#mailboxlist li.droptarget
{
  background-color: #FFFFA6;
}

/* styles for nested folders */
#mailboxlist ul {
  list-style: none;
  padding: 0;
  margin:0;
  border-top: 1px solid #EBEBEB;  
  padding-left: 15px;
  background-position: 25px 1px;
  background-color: #F9F9F9;
  color: blue;
  font-weight: normal;
}


#mailfooter
{
  position: absolute;
  left: 20px;
  right: 20px;
  bottom: 18px;
  height: 20px;
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-40)+'px');
}

#mailfooter table tr td
{
  white-space: nowrap;
  vertical-align: bottom;
}

#mailboxcontrols,
#listcontrols,
#countcontrols,
#quotabox
{
  white-space: nowrap;
  font-size: 11px;
}


/** message list styles */

body.messagelist
{
  margin: 0px;
  background-color: #F9F9F9;
}

#messagelist
{
  width: 100%;
  display: table;
  table-layout: fixed;
  /* css hack for IE */
  width: expression('auto');
}

#messagelist thead tr td
{
  height: 20px;
  padding-top: 0px;
  padding-bottom: 0px;
  padding-left: 2px;
  padding-right: 4px;
  vertical-align: middle;
  border-bottom: 1px solid #999999;
  color: #333333;
  background-color: #EBEBEB;
  background-image: url(images/listheader_aqua.gif); 
  font-size: 11px;
  font-weight: bold;
}

#messagelist thead tr td.sortedASC,
#messagelist thead tr td.sortedDESC
{
  background-image: url(images/listheader_dark.gif); 
}

#messagelist thead tr td.sortedASC a
{
  background: url(images/sort_asc.gif) top right no-repeat;
}

#messagelist thead tr td.sortedDESC a
{
  background: url(images/sort_desc.gif) top right no-repeat;
}

#messagelist thead tr td a
{
  display: block;
  width: auto !important;
  width: 100%;
  color: #333333;
  text-decoration: none;
}

#messagelist tbody tr td
{
  height: 16px;
  padding: 2px;
  padding-right: 4px;
  font-size: 11px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  border-bottom: 1px solid #EBEBEB;
  cursor: default;
}

#messagelist tbody tr td a
{
  color: #000;
  text-decoration: none;
  white-space: nowrap;
  cursor: inherit;
}

#messagelist tbody tr td.subject a
{
  cursor: default;
}

#messagelist col
{
  display: table-column;
  text-align: left;
  vertical-align: middle;
}

#messagelist tr td.icon,
#messagelist tr td.flag
{
  width: 16px;
  vertical-align: middle;
  cursor: pointer;
}

#messagelist tbody tr td.flag img:hover,
#messagelist thead tr td.flag img
{
  background: url(images/icons/unflagged.png) center no-repeat;
}

#messagelist tr td.subject
{
  overflow: hidden;
  vertical-align: middle;
}

#messagelist tr td.size
{
  width: 70px;
  text-align: right;
  vertical-align: middle;
}

#messagelist thead tr td.size
{
  text-align: left;
}

#messagelist tr td.from,
#messagelist tr td.to
{
  width: 180px;
  vertical-align: middle;
}

#messagelist tr td.date
{
  width: 118px;
  vertical-align: middle;
}

#messagelist tr.message
{
  background-color: #FFFFFF;
}

/*
#messagelist tr.odd
{
  background-color: #F9F9F9;
}
*/

#messagelist tr.unread
{
  font-weight: bold;
  background-color: #FFFFFF;
}

#messagelist tr.flagged td,
#messagelist tr.flagged td a
{
  color: #CC0000;
}

#messagelist tr.selected td
{
  color: #FFFFFF;
  background-color: #CC3333;
}

#messagelist tr.unfocused td
{
  color: #FFFFFF;
  background-color: #929292;
}

#messagelist tr.selected td a
{
  color: #FFFFFF;
}

#messagelist tr.unfocused td a
{
  color: #FFFFFF;
}

#messagelist tr.deleted td,
#messagelist tr.deleted td a
{
  color: #CCCCCC;
}

/* safari hacks \*/
html>body*#messagelist[id$="messagelist"]:not([class="none"]) { width: 99.8%; }
html>body*#messagelist[id$="messagelist"]:not([class="none"]) tr td.flag,
html>body*#messagelist[id$="messagelist"]:not([class="none"]) tr td.icon { width: 20px; }
html>body*input[type$="file"]:not([class="none"]) { background-color: transparent; border: 0; }
/**/

#quotadisplay
{
  color: #666666;
  font-size: 11px;
}

#quotadisplay img
{
  vertical-align: middle;
  margin-left: 4px;
  border: 1px solid #999;
}


/** message view styles */

#messageframe
{
  position: absolute;
  top: 0px;
  left: 170px;
  right: 0px;
  bottom: 0px;
  border: 1px solid #999;
  background-color: #FFF;
  overflow: auto;
  /* css hack for IE */
  width: expression((parseInt(this.parentNode.offsetWidth)-170)+'px');
  height: expression((parseInt(this.parentNode.offsetHeight))+'px');
}

#messagecanvas 
{
  /* css hack for IE */
  width: expression((parseInt(this.parentNode.offsetWidth)-20)+'px');
}

#printmessageframe
{
  position: absolute;
  top: 0px;
  left: 0px;
  right: 0px;
  bottom: 0px;
  border: 1px solid #999;
  background-color: #FFF;
  overflow: auto;
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-220)+'px');
  height: expression((parseInt(document.documentElement.clientHeight)-125)+'px');
}

div.messageheaderbox
{
  margin: 6px 8px 0px 8px;
  border: 1px solid #ccc;
}

table.headers-table
{
  width: 100%;
  background-color: #EBEBEB;
  table-layout: fixed;
}

#messagebody table.headers-table
{
  width: auto;
  margin: 6px 8px;
  background-color: #F4F4F4;
  border: 1px solid #ccc;
}

#messageframe table.headers-table
{
  border-bottom: 1px solid #ccc;
}

table.headers-table tr td
{
  font-size: 11px;
  border-bottom:1px solid #FFFFFF;
}

table.headers-table td.header-title
{
  width: 80px;
  color: #666666;
  font-weight: bold;
  text-align: right;
  white-space: nowrap;
  padding-right: 4px;
}

table.headers-table tr td.subject
{
  width: 90%;
  font-weight: bold;
}

table.headers-table tr td.all
{
  width: 100%;
  color: #666666;
  text-align: left;
  padding-right: 10px;
  vertical-align: center;
  text-align: center;
}

#attachment-list
{
  margin: 0px;
  padding: 0px 0px 0px 72px;
  min-height: 16px;
  list-style-image: none;
  list-style-type: none;
  background: url(images/icons/attachment.png) 60px 2px no-repeat #DFDFDF;
  /* IE6 hack */    
  _height: expression(Math.min(16, parseInt(document.documentElement.clientHeight))+'px');
}

#attachment-list:after
{
  content: ".";
  display: block;
  height: 0;
  font-size: 0;
  clear: both;
  visibility: hidden;
}

#attachment-list li
{
  float: left;
  height: 18px;
  font-size: 11px;
  padding: 2px 0px 0px 15px;
  white-space: nowrap;
}

#attachment-list li a
{
  text-decoration: none;
}

#attachment-list li a:hover
{
  text-decoration: underline;
}

#messagebody
{
  position:relative;
  padding-bottom: 10px;
  background-color: #FFFFFF;
}

div.message-part
{
  padding: 10px 8px;
  border-top: 1px solid #ccc;
/*  overflow: hidden; */
}

#messagebody div:first-child
{
  border-top: 0;
}

div.message-part a,
div.message-htmlpart a
{
  color: #0000CC;
}

div.message-part pre,
div.message-part div.pre
{
  margin: 0px;
  padding: 0px;
  font-family: monospace;
  white-space: -moz-pre-wrap !important;
  white-space: -o-pre-wrap !important;
  white-space: pre-wrap !important;
  white-space: pre;
  word-wrap: break-word; /* IE (and Safari) */
}

div.message-part blockquote
{
  color: blue;
  border-left: 2px solid blue;
  border-right: 2px solid blue;
  background-color: #F6F6F6;
  margin: 2px 0px 2px 0px;
  padding: 1px 8px 1px 10px;
}

div.message-part blockquote blockquote
{
  color: green;
  border-left: 2px solid green;
  border-right: 2px solid green;
}

div.message-part blockquote blockquote blockquote
{
  color: #990000;
  border-left: 2px solid #bb0000;
  border-right: 2px solid #bb0000;
}

body.iframe 
{
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth))+'px');
}

body.iframe div.message-htmlpart
{
  margin: 8px;
}

div.message-htmlpart div.rcmBody
{
  margin: 8px;
}

#remote-objects-message
{
  display: none;
  margin: 8px;
  min-height: 20px;
  padding: 10px 10px 6px 46px;
}

#remote-objects-message a
{
  color: #666666;
  padding-left: 10px;
}

#remote-objects-message a:hover
{
  color: #333333;
}

#messageviewlink
{
  position: absolute;
  top: 8px;
  right: 10px;
  width: 15px;
  height: 15px;
  border: 0;
}

/** message compose styles */

#compose-toolbar
{
  white-space: nowrap;
}

#priority-selector,
#receipt-selector
{
  padding-left: 30px;
}

#compose-container
{
  position: absolute;
  top: 90px;
  left: 200px;
  right: 25px;
  bottom: 30px;
  margin: 0px;
  /* css hack for IE */
  width: expression((parseInt(document.documentElement.clientWidth)-220)+'px');
  height: expression((parseInt(document.documentElement.clientHeight)-120)+'px');
}

#compose-div
{
  position: absolute;
  top: 110px;
  bottom: 40px;
  width: 100%;
  vertical-align: top;
}

#compose-headers
{
  width: 100%;
}

#compose-headers td.top
{
  vertical-align: top;
}

#compose-headers td.title,
#compose-subject td.title
{
  width: 80px !important;
  color: #666666;
  font-size: 11px;
  font-weight: bold;
  padding-right: 10px;
  white-space: nowrap;
}

#compose-body,
#compose-headers td textarea,
#compose-headers td input
{
  width: 100%;
  width: expression('99%');
}

#compose-headers td textarea
{
  height: 38px;
}

#compose-cc,
#compose-bcc,
#compose-replyto
{
  display: none;
}

#compose-body
{
  min-height: 100px;
  height: 100%;
  font-size: 9pt;
  font-family: "Courier New", Courier, monospace;
}

#compose-attachments
{
  position: absolute;
  top: 100px;
  left: 20px;
  width: 160px;
}

#compose-attachments ul
{
  margin: 0px;
  padding: 0px;
  border: 1px solid #CCCCCC;
  background-color: #F9F9F9;
  list-style-image: none;
  list-style-type: none;
}

#compose-attachments ul li
{
  height: 18px;
  font-size: 11px;
  padding-left: 2px;
  padding-top: 2px;
  padding-right: 4px;
  border-bottom: 1px solid #EBEBEB;
  white-space: nowrap;
  overflow: hidden;
}

#attachment-title
{
  background: url(images/icons/attachment.png) top left no-repeat;
  padding: 0px 0px 3px 22px;
}

#attachment-form
{
  position: absolute;
  top: 150px;
  left: 20px;
  z-index: 200;
  padding: 6px;
  visibility: hidden;
  border: 1px solid #CCCCCC;
  background-color: #F9F9F9;
}

#attachment-form div
{
  padding: 2px;
}

#attachment-form div.buttons
{
  margin-top: 4px;
}

table.headers-table tr td.more-headers
{
  cursor: pointer;
  width: 100%;
  height: 8px;
  border-bottom: 0;
}

table.headers-table tr td.all
{
  padding: 2px 6px 4px 6px;
  border-bottom: 0;
}

td.show-headers
{
  background: url(images/icons/down_small.gif) no-repeat center;
}

td.hide-headers
{
  background: url(images/icons/up_small.gif) no-repeat center;
}

#all-headers
{
  height: 150px;
  display: none;
}

#headers-source
{
  margin: 0 5px;
  padding: 0.5em;
  height: 145px;
  background: white;
  overflow: auto;
  font-size: 11px;
  white-space: nowrap;
  border: 1px solid #999999;
  display: none;
  text-align: left;
  color: #333;
}

font.bold
{
  font-weight: bold;
}
