<?php

/*

+-----------------------------------------------------------------------+
| language/hu_HU/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Levente Farkas <lfarkas at lfarkas dot org>                   |
|         Ervin Hegedüs <airween@damson.hu>                             |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Üdvözli a $product';
$labels['username'] = 'Felhasználónév';
$labels['password'] = 'Jelszó';
$labels['server'] = 'Szerver';
$labels['login'] = 'Belépés';
$labels['logout'] = 'Kijelentkezés';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Egyéni beállítások';
$labels['addressbook'] = 'Címjegyzék';
$labels['inbox'] = 'Érkezett levelek';
$labels['drafts'] = 'Piszkozatok';
$labels['sent'] = 'Küldött levelek';
$labels['trash'] = 'Törölt elemek';
$labels['junk'] = 'Szemetes';
$labels['subject'] = 'Tárgy';
$labels['from'] = 'Feladó';
$labels['to'] = 'Címzett';
$labels['cc'] = 'Másolat';
$labels['bcc'] = 'Titkos másolat';
$labels['replyto'] = 'Válaszcím';
$labels['date'] = 'Dátum';
$labels['size'] = 'Méret';
$labels['priority'] = 'Sürgősség';
$labels['organization'] = 'Szervezet';
$labels['reply-to'] = 'Válaszcím';
$labels['mailboxlist'] = 'Mappák';
$labels['messagesfromto'] = 'Üzenetek: $from - $to / $count';
$labels['messagenrof'] = '$nr / $count üzenet';
$labels['moveto'] = 'áthelyezés...';
$labels['download'] = 'letöltés';
$labels['filename'] = 'File neve';
$labels['filesize'] = 'File mérete';
$labels['preferhtml'] = 'HTML megjelenítés';
$labels['htmlmessage'] = 'HTML üzenet';
$labels['prettydate'] = 'Rövid dátumok';
$labels['addtoaddressbook'] = 'Hozzáadás a címjegyzékhez';
$labels['sun'] = 'Vas';
$labels['mon'] = 'Hét';
$labels['tue'] = 'Kedd';
$labels['wed'] = 'Szer';
$labels['thu'] = 'Csüt';
$labels['fri'] = 'Pén';
$labels['sat'] = 'Szom';
$labels['sunday'] = 'Vasárnap';
$labels['monday'] = 'Hétfő';
$labels['tuesday'] = 'Kedd';
$labels['wednesday'] = 'Szerda';
$labels['thursday'] = 'Csütörtök';
$labels['friday'] = 'Péntek';
$labels['saturday'] = 'Szombat';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Febr';
$labels['mar'] = 'Márc';
$labels['apr'] = 'Ápr';
$labels['may'] = 'Máj';
$labels['jun'] = 'Jún';
$labels['jul'] = 'Júl';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Szept';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Január';
$labels['longfeb'] = 'Február';
$labels['longmar'] = 'Március';
$labels['longapr'] = 'Április';
$labels['longmay'] = 'Május';
$labels['longjun'] = 'Június';
$labels['longjul'] = 'Július';
$labels['longaug'] = 'Augusztus';
$labels['longsep'] = 'Szeptember';
$labels['longoct'] = 'Október';
$labels['longnov'] = 'November';
$labels['longdec'] = 'December';
$labels['today'] = 'Ma';
$labels['checkmail'] = 'Új üzenetek ellenőrzése';
$labels['writenewmessage'] = 'Új üzenet';
$labels['replytomessage'] = 'Válasz';
$labels['replytoallmessage'] = 'Válasz a feladónak és az összes címzettnek';
$labels['forwardmessage'] = 'Továbbítás';
$labels['deletemessage'] = 'Törlés';
$labels['movemessagetotrash'] = 'Üzenet törlése';
$labels['printmessage'] = 'Nyomtatás';
$labels['previousmessage'] = 'Előző levél mutatása';
$labels['previousmessages'] = 'Előző rész mutatása';
$labels['firstmessage'] = 'Első levél mutatása';
$labels['firstmessages'] = 'Első rész mutatása';
$labels['nextmessage'] = 'Következő levél mutatása';
$labels['nextmessages'] = 'Következő rész mutatása';
$labels['lastmessage'] = 'Utolsó levél mutatása';
$labels['lastmessages'] = 'Utolsó rész mutatása';
$labels['backtolist'] = 'Vissza az üzenetekhez';
$labels['viewsource'] = 'Forrás megtekintése';
$labels['markmessages'] = 'Üzenetek megjelölése';
$labels['markread'] = 'Olvasottként';
$labels['markunread'] = 'Olvasatlanként';
$labels['markflagged'] = 'Jelöltként';
$labels['markunflagged'] = 'Jelöletlenként';
$labels['select'] = 'Kijelölés';
$labels['all'] = 'Összes';
$labels['none'] = 'Nincs';
$labels['unread'] = 'Olvasatlan';
$labels['compact'] = 'Tömörítés';
$labels['empty'] = 'Ürítés';
$labels['purge'] = 'Tisztítás';
$labels['quota'] = 'Diszk használat';
$labels['unknown'] = 'ismeretlen';
$labels['unlimited'] = 'korlátlan';
$labels['quicksearch'] = 'Gyorskeresés';
$labels['resetsearch'] = 'Alapállapot';
$labels['compose'] = 'Üzenet létrehozása';
$labels['savemessage'] = 'Vázlat mentése';
$labels['sendmessage'] = 'Üzenet azonnali küldése';
$labels['addattachment'] = 'File csatolása';
$labels['charset'] = 'Karakterkészlet';
$labels['editortype'] = 'Szerkesztő típusa';
$labels['returnreceipt'] = 'Értesítés';
$labels['checkspelling'] = 'Helyesírás-ellenőrzés';
$labels['resumeediting'] = 'Helyesírás kész';
$labels['revertto'] = 'Vissza erre:';
$labels['attachments'] = 'Csatolások';
$labels['upload'] = 'Feltöltés';
$labels['close'] = 'Bezárás';
$labels['low'] = 'Alacsony';
$labels['lowest'] = 'Legkisebb';
$labels['normal'] = 'Normál';
$labels['high'] = 'Magas';
$labels['highest'] = 'Legmagasabb';
$labels['nosubject'] = '(nincs tárgy)';
$labels['showimages'] = 'Képek megjelenítése';
$labels['alwaysshow'] = 'Képek megjelenítése mindíg ha a feladó $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Egyszerű szöveg';
$labels['addcc'] = 'Cc (Másolati cím) hozzáadása';
$labels['addbcc'] = 'Bcc (Titkos másolati cím) hozzáadása';
$labels['addreplyto'] = 'Válaszcím hozzáadása';
$labels['mdnrequest'] = 'Az üzenet küldője értesítést kér arról hogy elolvastad a levelet. Elküdjük az Olvasási Értesítést?';
$labels['receiptread'] = 'Olvasási Értesítés (olvasott)';
$labels['yourmessage'] = 'Ez az üzeneted Olvasási Értesítése';
$labels['receiptnote'] = 'Megjegyzés: Ez az Olvasási Értesítés csak azt igazolja, hogy az üzenet megjelenítésre került a címzett számítógépén. Nincs rá garancia, hogy a címzett elolvasta volna az üzenetet illetve megértette volna annak tartalmát.';
$labels['name'] = 'Megjelenített név';
$labels['firstname'] = 'Keresztnév';
$labels['surname'] = 'Vezetéknév';
$labels['email'] = 'E-mail cím';
$labels['addcontact'] = 'Új kapcsolat hozzáadása';
$labels['editcontact'] = 'Kapcsolat szerkesztése';
$labels['edit'] = 'Szerkesztés';
$labels['cancel'] = 'Mégsem';
$labels['save'] = 'Mentés';
$labels['delete'] = 'Törlés';
$labels['newcontact'] = 'Új névjegykártya létrehozása';
$labels['deletecontact'] = 'Kijelölt kapcsolatok törlése';
$labels['composeto'] = 'E-mail küldése erre a címre';
$labels['contactsfromto'] = 'Kapcsolatok: $from - $to / $count';
$labels['print'] = 'Nyomtatás';
$labels['export'] = 'Exportálás';
$labels['previouspage'] = 'Előző lap';
$labels['firstpage'] = 'Első lap';
$labels['nextpage'] = 'Következő lap';
$labels['lastpage'] = 'Utolsó lap';
$labels['groups'] = 'Csoportok';
$labels['personaladrbook'] = 'Személyes címjegyzék';
$labels['settingsfor'] = 'Beállítás';
$labels['preferences'] = 'Beállítások';
$labels['userpreferences'] = 'Felhasználói beállítások';
$labels['editpreferences'] = 'Felhasználói beállítások szerkesztése';
$labels['identities'] = 'Azonosítók';
$labels['manageidentities'] = 'Hozzáférés azonosítóinak kezelése';
$labels['newidentity'] = 'Új azonosító';
$labels['newitem'] = 'Új elem';
$labels['edititem'] = 'Elem szerkesztése';
$labels['setdefault'] = 'Beállítás alapértelmezettnek';
$labels['language'] = 'Nyelv';
$labels['timezone'] = 'Időzóna';
$labels['pagesize'] = 'Sorok száma egy oldalon';
$labels['signature'] = 'Aláírás';
$labels['dstactive'] = 'Nyári időszámítás';
$labels['htmleditor'] = 'HTML üzenet írása';
$labels['htmlsignature'] = 'HTML aláírás';
$labels['previewpane'] = 'Előnézeti kép';
$labels['skin'] = 'Smink';
$labels['logoutclear'] = 'Törölt elemek mappa ürítése kilépéskor';
$labels['logoutcompact'] = 'Beérkezett üzenetek mappa tömörítése kilépéskor';
$labels['uisettings'] = 'Felhasználói felület';
$labels['serversettings'] = 'Szerverbeállítások';
$labels['mailboxview'] = 'Postafiók nézet';
$labels['mdnrequests'] = 'Olvasási értesítés küldése';
$labels['askuser'] = 'kérdezzen rá';
$labels['autosend'] = 'automatikus küldés';
$labels['ignore'] = 'hagyja figyelmen kívül';
$labels['readwhendeleted'] = 'Üzenet olvasottként jelölése törléskor';
$labels['flagfordeletion'] = 'Üzenet törlendőnek jelölése törlés helyett ';
$labels['showinlineimages'] = 'Csatolt képek megjelenítése az üzenet alatt';
$labels['autosavedraft'] = 'Automatikus piszkozat mentés';
$labels['everynminutes'] = 'minden $n percben';
$labels['never'] = 'soha';
$labels['messagesdisplaying'] = 'Üzenetek megjelenítése';
$labels['messagescomposition'] = 'Üzenetek írása';
$labels['folder'] = 'Mappa';
$labels['folders'] = 'Mappák';
$labels['foldername'] = 'Mappa neve';
$labels['subscribed'] = 'Feliratkozás';
$labels['messagecount'] = 'Üzenet';
$labels['create'] = 'Létrehozás';
$labels['createfolder'] = 'Új mappa létrehozása';
$labels['rename'] = 'Átnevezés';
$labels['renamefolder'] = 'Mappa átnevezése';
$labels['deletefolder'] = 'Mappa törlése';
$labels['managefolders'] = 'Mappák kezelése';
$labels['sortby'] = 'Rendezés';
$labels['sortasc'] = 'növekvő';
$labels['sortdesc'] = 'csökkenő';

?>
