<?php

/*
 +-----------------------------------------------------------------------+
 | language/ga/messages.inc                                              |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author:   Noel Bourke  (cros13)                                       |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$messages = array();
$messages['loginfailed'] = 'Theip an iarraidh chun logáil tú isteach';
$messages['cookiesdisabled'] = 'Níor glac do sracléitheoir an fianán seisiúin';
$messages['sessionerror'] = 'Tá an seisiúin neamhbhailí nó as feidhm';
$messages['imaperror'] = 'Theip an iarraidh chun nasc go dtí an freastalaí Prótacal Rochtana Teachtaireachtaí Idirlín (IMAP)';
$messages['nomessagesfound'] = 'Ní bhfuair mé aon teachtaireacht i bosca postas seo';
$messages['loggedout'] = 'D\'éirigh tú logáil amach. Slán Leat!';
$messages['mailboxempty'] = 'Tá an bosca postas folamh';
$messages['loading'] = 'Fan nóiméad, ag lódáil...';
$messages['loadingdata'] = 'Ag lódáil sonraí...';
$messages['checkingmail'] = 'Ag seiceáil chun teachtaireacht nua...';
$messages['sendingmessage'] = 'Ag seol mo teachtaireacht láithreach bonn...';
$messages['messagesent'] = 'Sheol mé an teachtaireacht';
$messages['savingmessage'] = 'Ag sábháil an teachtaireacht...';
$messages['messagesaved'] = 'Sábháil mé an teachtaireacht i dréachtaí';
$messages['successfullysaved'] = 'D\'éirigh mé agus sábháil mé';
$messages['addedsuccessfully'] = 'D\'éirigh mé agus shábháil mé duine nua go dtí an Leabhair Seoltaí';
$messages['contactexists'] = 'Tá duine i do Leabhair Seoltaí agus tá an seoladh ríomhphost seo aige';
$messages['blockedimages'] = 'Chun do príobháide a cosain, choiscinn na híomhánna san teachtaireacht seo ';
$messages['encryptedmessage'] = 'Tá an teachtaireacht seo i criptiúchán, Níl an cumas agam chun é a tionscail';
$messages['nocontactsfound'] = 'Ní raibh aon buine san Leabhair Seoltaí seo';
$messages['contactnotfound'] = 'Ní bhfuair mé an duine seo';
$messages['sendingfailed'] = 'Theip an iarraidh chun an teachtaireacht a seol';
$messages['errorsaving'] = 'Theip mé agus ní shábháil';
$messages['errormoving'] = 'Theip mé agus ní bog an teachtaireacht';
$messages['errordeleting'] = 'Theip mé agus níor scrios me an teachtaireacht';
$messages['deletecontactconfirm'] = 'Ar mhaith leat scrios na daoine seo?';
$messages['deletemessagesconfirm'] = 'Ar mhaith leat scrios na teachtaireacht seo?';
$messages['deletefolderconfirm'] = 'Ar mhaith leat scrios an fillteán seo?';
$messages['purgefolderconfirm'] = 'Ar mhaith leat scrios gach teachtaireacht san fillteán seo?';
$messages['formincomplete'] = 'Níor chríochnaigh tú an foirm';
$messages['noemailwarning'] = 'Abair liom seoladh ríomhphost nach bfhuil neamhbhaillí';
$messages['nonamewarning'] = 'Abair liom do ainm';
$messages['nopagesizewarning'] = 'Abair liom saghas leathanaigh';
$messages['norecipientwarning'] = 'Abair liom faighteoir amhain ar a laghad';
$messages['nosubjectwarning'] = 'Níl aon ábhair ar an teachtaireacht, ba mhaith tú déarfaidh mé ábair?';
$messages['nobodywarning'] = 'Níl aon teacs san teachtaireacht, ba mhaith tú déarfaidh mé teachtaireacht ar bith?';
$messages['notsentwarning'] = 'Theip an iarraidh chun an teachtaireacht a seo. ba mhaith tú scrios do teachtaireacht?';
$messages['noldapserver'] = 'Abair liom eolaire LDAP chun é a cuardaigh';
$messages['nocontactsreturned'] = 'Ní bhfuair mé aon duine as an ceist seo';
$messages['nosearchname'] = 'Abair liom ainm duine nó seoladh ríomhphost';
$messages['searchsuccessful'] = 'Fuair mé $n teachtaireacht';
$messages['searchnomatch'] = 'Ní bhfuair mé aon rud as an ceist seo';
$messages['searching'] = 'Ag tástáil...';
$messages['checking'] = 'Bím ag dhéanamh na mhaoirseachtí...';
$messages['nospellerrors'] = 'Ní bhfuair mé aon earráidí i teachtaireacht seo';
$messages['folderdeleted'] = 'D\'éirigh mé, Scrios mé an fillteán';
$messages['deletedsuccessfully'] = 'D\'éirigh mé, Scrios mé';
$messages['converting'] = 'Scrios mé formáidithe as an teachtaireacht seo';
$messages['messageopenerror'] = 'Theip orm chun an teachtaireacht seo a tarrtháil as an freastalaí';
$messages['fileuploaderror'] = 'Theip an suas-luchtú';
$messages['filesizeerror'] = 'Beigh an comhad ró-mhor. Is ea $size uas-saghas chun admháil léite';
$messages['copysuccess'] = 'D\'éirigh mé agus chuir mé $nr seolagh i do Leabhair Seoltaí';
$messages['copyerror'] = 'Theip mé agus níor dfhag mé aon seolagh';
$messages['sourceisreadonly'] = 'Tá an foinse seolaigh seo inléite amháin';
$messages['errorsavingcontact'] = 'Theip mé, Níl an cumas agam an seolagh seo a sábháil';

?>