<?php

/*
+-----------------------------------------------------------------------+
| language/eu_ES/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Bicyus <bicyus@tenkanet.com>                                  |
|         Bihar <gaurdabihar@gmail.com>                                 |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Ongietorri Roundcube|Mail-era';
$labels['username'] = 'Erabiltzailea';
$labels['password'] = 'Pasahitza';
$labels['server'] = 'Zerbitzaria';
$labels['login'] = 'Saio hasiera';
$labels['logout'] = 'Irten';
$labels['mail'] = 'ePosta';
$labels['settings'] = 'Ezarpen Pertsonalak';
$labels['addressbook'] = 'Helbide Liburua';
$labels['inbox'] = 'Sarrera';
$labels['drafts'] = 'Zirriborroak';
$labels['sent'] = 'Bidalitakoak';
$labels['trash'] = 'Zakarrontzia';
$labels['junk'] = 'Zabor-posta';
$labels['subject'] = 'Gaia';
$labels['from'] = 'Nork';
$labels['to'] = 'Nori';
$labels['cc'] = 'Kopia';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Erantzun-Honi';
$labels['date'] = 'Data';
$labels['size'] = 'Tamaina';
$labels['priority'] = 'Lehentasuna';
$labels['organization'] = 'Erakundea';
$labels['reply-to'] = 'Erantzun-Honi';
$labels['mailboxlist'] = 'Karpetak';
$labels['messagesfromto'] = '$from -tik $to -ra $count mezuetatik';
$labels['messagenrof'] = '$nr mezua $count -tik';
$labels['moveto'] = 'mugitu hona...';
$labels['download'] = 'deskargatu';
$labels['filename'] = 'Fitxategi Izena';
$labels['filesize'] = 'Fitxategi Tamaina';
$labels['preferhtml'] = 'HTML nahiago';
$labels['htmlmessage'] = 'HTML Mezua';
$labels['prettydate'] = 'Data politak';
$labels['addtoaddressbook'] = 'Helbide liburura gehitu';
$labels['sun'] = 'Iga';
$labels['mon'] = 'Al';
$labels['tue'] = 'As';
$labels['wed'] = 'Azt';
$labels['thu'] = 'Og';
$labels['fri'] = 'Or';
$labels['sat'] = 'Lar';
$labels['sunday'] = 'Igandea';
$labels['monday'] = 'Astelehena';
$labels['tuesday'] = 'Asteartea';
$labels['wednesday'] = 'Asteazkena';
$labels['thursday'] = 'Osteguna';
$labels['friday'] = 'Ostirala';
$labels['saturday'] = 'Larunbata';
$labels['jan'] = 'Urt';
$labels['feb'] = 'Ots';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Api';
$labels['may'] = 'Mai';
$labels['jun'] = 'Eka';
$labels['jul'] = 'Uzt';
$labels['aug'] = 'Abu';
$labels['sep'] = 'Ira';
$labels['oct'] = 'Urr';
$labels['nov'] = 'Aza';
$labels['dec'] = 'Abe';
$labels['longjan'] = 'Urtarrila';
$labels['longfeb'] = 'Otsaila';
$labels['longmar'] = 'Martxoa';
$labels['longapr'] = 'Apirila';
$labels['longmay'] = 'Maiatza';
$labels['longjun'] = 'Ekaina';
$labels['longjul'] = 'Uztaila';
$labels['longaug'] = 'Abuztua';
$labels['longsep'] = 'Iraila';
$labels['longoct'] = 'Urria';
$labels['longnov'] = 'Azaroa';
$labels['longdec'] = 'Abendua';
$labels['today'] = 'Gaur';
$labels['checkmail'] = 'Mezu berrien bila arakatu';
$labels['writenewmessage'] = 'Mezu berri bat sortu';
$labels['replytomessage'] = 'Mezuari erantzun';
$labels['replytoallmessage'] = 'Bidaltzaile eta hartzaile guztiei erantzun';
$labels['forwardmessage'] = 'Mezua Birbidali';
$labels['deletemessage'] = 'Mezua ezabatu';
$labels['movemessagetotrash'] = 'Mezua zakarrontzira mugitu';
$labels['printmessage'] = 'Mezu hau inprimatu';
$labels['previousmessage'] = 'Aurreko mezua ikusi';
$labels['previousmessages'] = 'Aurreko mezuak ikusi';
$labels['firstmessage'] = 'Lehenengo mezua ikusi';
$labels['firstmessages'] = 'Lehenengo mezu sorta ikusi';
$labels['nextmessage'] = 'Hurrengo mezua ikusi';
$labels['nextmessages'] = 'Hurrengo mezu sorta ikusi';
$labels['lastmessage'] = 'Azken mezua ikusi';
$labels['lastmessages'] = 'Azken mezu sorta ikusi';
$labels['backtolist'] = 'Mezu zerrendara itzuli';
$labels['viewsource'] = 'Jatorria bistarazi';
$labels['markmessages'] = 'Markatu mezuak';
$labels['markread'] = 'Irakurria bezala';
$labels['markunread'] = 'Ez-irakurria bezala';
$labels['markflagged'] = 'Markatua bezala';
$labels['markunflagged'] = 'Ez-markatua bezala';
$labels['select'] = 'Hautatu';
$labels['all'] = 'Denak';
$labels['none'] = 'Batez';
$labels['unread'] = 'Irakurri gabeak';
$labels['compact'] = 'Trinkotu';
$labels['empty'] = 'Hustu';
$labels['purge'] = 'Garbitu';
$labels['quota'] = 'Disko erabilera';
$labels['unknown'] = 'ezezaguna';
$labels['unlimited'] = 'mugagabea';
$labels['quicksearch'] = 'Bilaketa azkarra';
$labels['resetsearch'] = 'Bilaketa berrabiarazi';
$labels['compose'] = 'Mezu bat sortu';
$labels['savemessage'] = 'Zirriborro hau gorde';
$labels['sendmessage'] = 'Mezua orain bidali';
$labels['addattachment'] = 'Fitxategia erantsi';
$labels['charset'] = 'Karaktere jokoa';
$labels['editortype'] = 'Editore mota';
$labels['returnreceipt'] = 'Bidaltzaileari itzuli';
$labels['checkspelling'] = 'Egiaztaketa ortografikoa';
$labels['resumeediting'] = 'Editatzen jarraitu';
$labels['revertto'] = 'Itzuli hona';
$labels['attachments'] = 'Eranskinak';
$labels['upload'] = 'Igo';
$labels['close'] = 'Itxi';
$labels['low'] = 'Baxua';
$labels['lowest'] = 'Baxuena';
$labels['normal'] = 'Normala';
$labels['high'] = 'Altua';
$labels['highest'] = 'Altuena';
$labels['nosubject'] = '(gairik gabea)';
$labels['showimages'] = 'Irudiak bistarazi';
$labels['alwaysshow'] = 'Beti ikusi $sender -en irudiak';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Testu laua';
$labels['savesentmessagein'] = 'Gorde mezua hemen';
$labels['dontsave'] = 'ez gorde';
$labels['addcc'] = 'Gehitu Cc (kopia)';
$labels['addbcc'] = 'Gehitu Bcc (kopia ezkutua)';
$labels['addreplyto'] = 'Gehitu erantzun-honi';
$labels['mdnrequest'] = 'Mezu honen bidaltzaileak mezua irakurtzen duzunean jakinaraztea eskatu du. Bidaltzailea ohartu nahi duzu?';
$labels['receiptread'] = 'Itzulketa agiria (irakurria)';
$labels['yourmessage'] = 'Hau zure mezuaren Itzulketa Agiria da';
$labels['receiptnote'] = 'Oharra: Agiri honek hartzailearen ordenagailuan mezua ikusi dala adierazten du besterik gabe. Honek ez du esan nahi hartzaileak mezua irakurri edo/eta ulertu duenik:';
$labels['name'] = 'Izena bistarazi';
$labels['firstname'] = 'Izena';
$labels['surname'] = 'Abizena';
$labels['email'] = 'ePosta';
$labels['addcontact'] = 'Txartel berria gehitu';
$labels['editcontact'] = 'Txartela editatu';
$labels['edit'] = 'Editatu';
$labels['cancel'] = 'Utzi';
$labels['save'] = 'Gorde';
$labels['delete'] = 'Ezabatu';
$labels['newcontact'] = 'Helbide liburu txartel berria sortu';
$labels['deletecontact'] = 'Aukeraturiko txartelak ezabatu';
$labels['composeto'] = 'Bidali mezua honi: ';
$labels['contactsfromto'] = '$from -tik $to -ra $count txarteletatik';
$labels['print'] = 'Inprimatu';
$labels['export'] = 'Esportatu';
$labels['previouspage'] = 'Aurreko sorta ikusi';
$labels['firstpage'] = 'Lehenengo sorta ikusi';
$labels['nextpage'] = 'Hurrengo sorta ikusi';
$labels['lastpage'] = 'Azken sorta ikusi';
$labels['groups'] = 'Taldeak';
$labels['personaladrbook'] = 'Helbide pertsonalak';
$labels['settingsfor'] = 'Honen ezarpenak:';
$labels['preferences'] = 'Hobespenak';
$labels['userpreferences'] = 'Erabiltzaile hobespenak';
$labels['editpreferences'] = 'Erabiltzaile hobespenak editatu';
$labels['identities'] = 'Identitateak';
$labels['manageidentities'] = 'Kontu honetako identitateak kudeatu';
$labels['newidentity'] = 'Identitate berria';
$labels['newitem'] = 'Elementu berria';
$labels['edititem'] = 'Elementua Editatu';
$labels['setdefault'] = 'Lehenespenak ezarri';
$labels['language'] = 'Hizkuntza';
$labels['timezone'] = 'Ordu zonaldea';
$labels['pagesize'] = 'Lerro orrialdeko';
$labels['signature'] = 'Sinadura';
$labels['dstactive'] = 'Eguneko gordeketak';
$labels['htmleditor'] = 'HTML mezuak sortu';
$labels['htmlsignature'] = 'HTML sinadura';
$labels['previewpane'] = 'Aurrebista panela ikusi';
$labels['skin'] = 'Azal-interfazea';
$labels['logoutclear'] = 'Garbitu Zakarronzia irtetean';
$labels['logoutcompact'] = 'Trinkotu Sarrera irtetean';
$labels['uisettings'] = 'Erabiltzaile-interfazea';
$labels['serversettings'] = 'Zerbitzariaren ezarpenak';
$labels['mailboxview'] = 'Postakutxatilaren ikuspegia';
$labels['mdnrequests'] = 'Bidaltzailearen jakinarazpena';
$labels['askuser'] = 'galdetu erabiltzaileari';
$labels['autosend'] = 'bidali automatikoki';
$labels['ignore'] = 'ezikusi';
$labels['readwhendeleted'] = 'Markatu mezua irakurrita bezala ezabatzerakoan';
$labels['flagfordeletion'] = 'Markatu mezua ezabatzeko ezabatu beharrean';
$labels['showinlineimages'] = 'Erakutsi erantzitako irudiak mezuaren azpian';
$labels['autosavedraft'] = 'Zirriborroa automatikoki gorde';
$labels['everynminutes'] = '$n minuturo';
$labels['never'] = 'inoiz ez';
$labels['messagesdisplaying'] = 'Mezuak ikusi';
$labels['messagescomposition'] = 'Mezuak sortu';
$labels['folder'] = 'Karpeta';
$labels['folders'] = 'Karpetak';
$labels['foldername'] = 'Karpeta izena';
$labels['subscribed'] = 'Harpideturik';
$labels['messagecount'] = 'Mezuak';
$labels['create'] = 'Sortu';
$labels['createfolder'] = 'Karpeta berria sortu';
$labels['rename'] = 'Berrizendatu';
$labels['renamefolder'] = 'Karpeta berrizendatu';
$labels['deletefolder'] = 'Karpeta ezabatu';
$labels['managefolders'] = 'Karpeta kudeaketa';
$labels['specialfolders'] = 'Karpeta bereziak';
$labels['sortby'] = 'Honela ordenatu';
$labels['sortasc'] = 'Goraka ordenatu';
$labels['sortdesc'] = 'Beheraka ordenatu';

?>
