<?php

/*

 +-----------------------------------------------------------------------+
 | language/pl_PL/labels.inc                                             |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Tomasz Pajor        <t.pajor@kei.pl>                          |
 |         Sławomir Cichoń     <slawek.cichon@gmail.com>                 |
 |         Janusz Zamecki      <janusz@zamecki.eu>                       |
 |         Mariusz Szulerecki  <nob@force.eu.org>                        |
 |         Wojciech Szczepucha <donkoyote@gmail.com>                     |
 |         Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1404 2008-05-19 08:12:54Z alec $

*/

$labels = array();
$labels['welcome'] = 'Witamy w $product';
$labels['username'] = 'Nazwa';
$labels['password'] = 'Hasło';
$labels['server'] = 'Serwer';
$labels['login'] = 'Zaloguj';
$labels['logout'] = 'Wyloguj';
$labels['mail'] = 'Poczta';
$labels['settings'] = 'Ustawienia';
$labels['addressbook'] = 'Książka adresowa';
$labels['inbox'] = 'Odebrane';
$labels['drafts'] = 'Kopie robocze';
$labels['sent'] = 'Wysłane';
$labels['trash'] = 'Kosz';
$labels['junk'] = 'Spam';
$labels['subject'] = 'Temat';
$labels['from'] = 'Nadawca';
$labels['to'] = 'Odbiorca';
$labels['cc'] = 'Kopia';
$labels['bcc'] = 'Ukryta kopia';
$labels['replyto'] = 'Odp. do';
$labels['date'] = 'Data';
$labels['size'] = 'Rozmiar';
$labels['priority'] = 'Priorytet';
$labels['organization'] = 'Organizacja';
$labels['reply-to'] = 'Odpowiedz do';
$labels['mailboxlist'] = 'Foldery';
$labels['messagesfromto'] = 'Wiadomości od $from do $to z $count';
$labels['messagenrof'] = 'Wiadomość $nr z $count';
$labels['moveto'] = 'Przenieś do...';
$labels['download'] = 'Pobierz';
$labels['filename'] = 'Nazwa pliku';
$labels['filesize'] = 'Rozmiar pliku';
$labels['preferhtml'] = 'Domyślny HTML';
$labels['htmlmessage'] = 'Wiadomość HTML';
$labels['showremoteimages'] = 'Wyświetlaj obrazki w wiadomościach';
$labels['fromknownsenders'] = 'od znanych nadawców';
$labels['always'] = 'zawsze';
$labels['prettydate'] = 'Ładne daty';
$labels['showinlineimages'] = 'Wyświetlaj załączone obrazki pod treścią wiadomości';
$labels['messagesdisplaying'] = 'Wyświetlanie wiadomości';
$labels['messagescomposition'] = 'Tworzenie wiadomości';
$labels['addtoaddressbook'] = 'Dodaj do książki adresowej ';
$labels['sun'] = 'Nd';
$labels['mon'] = 'Pn';
$labels['tue'] = 'Wt';
$labels['wed'] = 'Śr';
$labels['thu'] = 'Czw';
$labels['fri'] = 'Pt';
$labels['sat'] = 'Sb';
$labels['sunday'] = 'Niedziela';
$labels['monday'] = 'Poniedziałek';
$labels['tuesday'] = 'Wtorek';
$labels['wednesday'] = 'Środa';
$labels['thursday'] = 'Czwartek';
$labels['friday'] = 'Piątek';
$labels['saturday'] = 'Sobota';
$labels['jan'] = 'sty';
$labels['feb'] = 'lut';
$labels['mar'] = 'mar';
$labels['apr'] = 'kwi';
$labels['may'] = 'maj';
$labels['jun'] = 'cze';
$labels['jul'] = 'lip';
$labels['aug'] = 'sie';
$labels['sep'] = 'wrz';
$labels['oct'] = 'paź';
$labels['nov'] = 'lis';
$labels['dec'] = 'gru';
$labels['longjan'] = 'styczeń';
$labels['longfeb'] = 'luty';
$labels['longmar'] = 'marzec';
$labels['longapr'] = 'kwiecień';
$labels['longmay'] = 'maj';
$labels['longjun'] = 'czerwiec';
$labels['longjul'] = 'lipiec';
$labels['longaug'] = 'sierpień';
$labels['longsep'] = 'wrzesień';
$labels['longoct'] = 'październik';
$labels['longnov'] = 'listopad';
$labels['longdec'] = 'grudzień';
$labels['today'] = 'Dzisiaj';
$labels['checkmail'] = 'Sprawdź skrzynkę';
$labels['writenewmessage'] = 'Utwórz nową wiadomość';
$labels['replytomessage'] = 'Odpowiedz nadawcy';
$labels['replytoallmessage'] = 'Odpowiedz wszystkim';
$labels['forwardmessage'] = 'Prześlij dalej';
$labels['deletemessage'] = 'Usuń';
$labels['movemessagetotrash'] = 'Przenieś do Kosza';
$labels['printmessage'] = 'Drukuj';
$labels['previousmessage'] = 'Pokaż poprzednią';
$labels['previousmessages'] = 'Pokaż poprzednie';
$labels['firstmessage'] = 'Pokaż pierwszą';
$labels['firstmessages'] = 'Pokaż pierwsze';
$labels['nextmessage'] = 'Pokaż następną';
$labels['nextmessages'] = 'Pokaż następne';
$labels['lastmessage'] = 'Pokaż ostatnią';
$labels['lastmessages'] = 'Pokaż ostatnie';
$labels['backtolist'] = 'Pokaż listę wiadomości';
$labels['viewsource'] = 'Pokaż źródło';
$labels['markmessages'] = 'Oznacz wiadomość';
$labels['markread'] = 'Jako przeczytaną';
$labels['markunread'] = 'Jako nieprzeczytaną';
$labels['markflagged'] = 'Jako oflagowaną';
$labels['markunflagged'] = 'Jako nieoflagowaną';
$labels['select'] = 'Zaznacz';
$labels['all'] = 'Wszystkie';
$labels['none'] = 'Anuluj';
$labels['unread'] = 'Nieprzeczytane';
$labels['flagged'] = 'Oznaczone';
$labels['unanswered'] = 'Bez odpowiedzi';
$labels['filter'] = 'Filtr';
$labels['compact'] = 'Porządkuj';
$labels['empty'] = 'Opróżnij';
$labels['purge'] = 'Oczyść';
$labels['quota'] = 'Użyte miejsce';
$labels['unknown'] = 'nieznane';
$labels['unlimited'] = 'bez limitu';
$labels['quicksearch'] = 'Szybkie wyszukiwanie';
$labels['resetsearch'] = 'Wyczyść filtr';
$labels['openinextwin'] = 'Otwórz w nowym oknie';
$labels['compose'] = 'Utwórz wiadomość';
$labels['savemessage'] = 'Zapisz kopię roboczą';
$labels['sendmessage'] = 'Wyślij teraz';
$labels['addattachment'] = 'Dołącz plik';
$labels['charset'] = 'Kodowanie znaków';
$labels['editortype'] = 'Typ edytora';
$labels['returnreceipt'] = 'Potwierdzenie odbioru';
$labels['checkspelling'] = 'Sprawdź pisownię';
$labels['resumeediting'] = 'Zakończ sprawdzanie pisowni';
$labels['revertto'] = 'Powróć do';
$labels['attachments'] = 'Załączniki';
$labels['upload'] = 'Wyślij';
$labels['close'] = 'Zamknij';
$labels['low'] = 'Bardzo niski';
$labels['lowest'] = 'Niski';
$labels['normal'] = 'Normalny';
$labels['high'] = 'Wysoki';
$labels['highest'] = 'Bardzo wysoki';
$labels['nosubject'] = '(brak tematu)';
$labels['showimages'] = 'Wyświetl obrazki';
$labels['alwaysshow'] = 'Zawsze wyświetlaj obrazki od $sender'; 
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Zwykły tekst';
$labels['savesentmessagein'] = 'Zapisz wiadomość w'; 
$labels['dontsave'] = 'nie zapisuj';
$labels['addcc'] = 'Dodaj Cc';
$labels['addbcc'] = 'Dodaj Bcc';
$labels['addreplyto'] = 'Dodaj Reply-To';
$labels['mdnrequest'] = 'Nadawca zażądał potwierdzenia przeczytania tej wiadomości. Czy chcesz go powiadomić?';
$labels['receiptread'] = 'Potwierdzenie otrzymania';
$labels['yourmessage'] = 'To jest potwierdzenie dostarczenia Twojej wiadomości';
$labels['receiptnote'] = 'Uwaga: To potwierdzenie dostarczenia wiadomości oznacza tylko, że wiadomość została wyświetlona na komputerze adresata. Nie ma żadnej gwarancji, że odbiorca przeczytał czy też zrozumiał treść wiadomości.';
$labels['name'] = 'Nazwa';
$labels['firstname'] = 'Imię';
$labels['surname'] = 'Nazwisko';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Dodaj nowy kontakt do książki adresowej';
$labels['editcontact'] = 'Edytuj kontakt';
$labels['edit'] = 'Edytuj';
$labels['cancel'] = 'Anuluj';
$labels['save'] = 'Zapisz';
$labels['delete'] = 'Usuń';
$labels['newcontact'] = 'Dodaj nowy kontakt';
$labels['deletecontact'] = 'Usuń zaznaczone kontakty';
$labels['composeto'] = 'Utwórz wiadomość dla wybranych kontaktów';
$labels['contactsfromto'] = 'Kontakty od $from do $to z $count';
$labels['print'] = 'Drukuj';
$labels['export'] = 'Eksportuj';
$labels['previouspage'] = 'poprzednia strona';
$labels['firstpage'] = 'pierwsza strona';
$labels['nextpage'] = 'następna strona';
$labels['lastpage'] = 'ostatnia strona';
$labels['groups'] = 'Grupy';
$labels['personaladrbook'] = 'Książka adresowa';
$labels['settingsfor'] = 'Ustawienia dla';
$labels['preferences'] = 'Preferencje';
$labels['userpreferences'] = 'Preferencje użytkownika';
$labels['editpreferences'] = 'Edytuj preferencje';
$labels['identities'] = 'Tożsamości';
$labels['manageidentities'] = 'Zarządzaj tożsamościami';
$labels['newidentity'] = 'Nowa tożsamość';
$labels['newitem'] = 'Nowy';
$labels['edititem'] = 'Edytuj';
$labels['setdefault'] = 'Domyślna';
$labels['language'] = 'Język';
$labels['timezone'] = 'Strefa czasowa';
$labels['pagesize'] = 'Wierszy na stronie';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Czas letni';
$labels['htmleditor'] = 'Twórz wiadomości HTML';
$labels['htmlsignature'] = 'Podpis w HTML';
$labels['previewpane'] = 'Pokaż podgląd wiadomości';
$labels['skin'] = 'Wygląd interfejsu';
$labels['logoutclear'] = 'Przy wylogowaniu opróżnij Kosz';
$labels['logoutcompact'] = 'Przy wylogowaniu porządkuj folder Odebrane';
$labels['uisettings'] = 'Interfejs użytkownika';
$labels['serversettings'] = 'Ustawienia serwera';
$labels['mailboxview'] = 'Widok skrzynki pocztowej';
$labels['mdnrequests'] = 'Potwierdzenia odbioru';
$labels['askuser'] = 'spytaj użytkownika';
$labels['autosend'] = 'wyślij automatycznie';
$labels['ignore'] = 'ignoruj';
$labels['mimeparamfolding'] = 'Nazwy załączników';
$labels['2231folding'] = 'zgodne z RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'zgodne z RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'zgodne z RFC 2047 (inne)';
$labels['advancedoptions'] = 'opcje zaawansowane';
$labels['readwhendeleted'] = 'Podczas usuwania oznacz wiadomość jako przeczytaną';
$labels['flagfordeletion'] = 'Oznacz wiadomość do usunięcia zamiast ją usuwać';
$labels['skipdeleted'] = 'Ukryj wiadomości oznaczone do usunięcia';
$labels['autosavedraft'] = 'Automatyczny zapis tworzonej wiadomości';
$labels['everynminutes'] = 'co $n minut(y)';
$labels['keepalive']  = 'Sprawdzaj czy nadeszły nowe wiadomości';
$labels['keepaliveevery']  = 'co $n minut(y)';
$labels['never'] = 'nigdy';
$labels['focusonnewmessage'] = 'Informuj przeglądarkę o nowej wiadomości';
$labels['folder'] = 'Folder';
$labels['folders'] = 'Foldery';
$labels['foldername'] = 'Nazwa folderu';
$labels['subscribed'] = 'Zasubskrybowany';
$labels['messagecount'] = 'Wiadomości';
$labels['create'] = 'Utwórz';
$labels['createfolder'] = 'Utwórz nowy folder';
$labels['rename'] = 'Zmień nazwę';
$labels['renamefolder'] = 'Zmień nazwę folderu';
$labels['deletefolder'] = 'Usuń folder';
$labels['managefolders'] = 'Zarządzaj folderami';
$labels['specialfolders'] = 'Foldery specjalne';
$labels['sortby'] = 'Sortuj wg';
$labels['sortasc'] = 'Rosnąco';
$labels['sortdesc'] = 'Malejąco';
$labels['import'] = 'Importuj'; 
$labels['importcontacts'] = 'Import kontaktów'; 
$labels['importfromfile'] = 'Import z pliku:'; 
$labels['importreplace'] = 'Zastąp całą książkę adresową'; 
$labels['importtext'] = 'Możesz dodać kontakty z istniejącej książki adresowej.<br/>Aktualnie możliwy jest import kontaktów w formacie <a href="http://en.wikipedia.org/wiki/VCard">vCard</a>.'; 
$labels['done'] = 'Wykonane';
$labels['autodetect'] = '- wybór automatyczny -';
$labels['maxuploadsize'] = 'Maksymalny rozmiar pliku to $size';
$labels['exportvcards'] = 'Eksport kontaktów w formacie vCard';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['checkallfolders'] = 'Sprawdzaj czy nadeszły nowe wiadomości we wszystkich folderach';

?>
