<?php

/*
 +-----------------------------------------------------------------------+
 | language/ga/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author:   Noel Bourke  (cros13)                                       |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$labels = array();
$labels['welcome'] = 'Fáilte go $product';
$labels['username'] = 'Úsáideoir';
$labels['password'] = 'Pasfhocal';
$labels['server'] = 'Freastalaí';
$labels['login'] = 'Logáil isteach';
$labels['logout'] = 'Logáil amach';
$labels['mail'] = 'Postas';
$labels['settings'] = 'Socruithe Pearsanta';
$labels['addressbook'] = 'Leabhair Seoltaí';
$labels['inbox'] = 'Isteach';
$labels['drafts'] = 'Dréachtaí';
$labels['sent'] = 'Amach';
$labels['trash'] = 'Bosca bruscair';
$labels['junk'] = 'Dramhaíl';
$labels['subject'] = 'Ábhair';
$labels['from'] = 'Seolaí';
$labels['to'] = 'Faighteoir';
$labels['cc'] = 'Cóipeáil';
$labels['bcc'] = 'Cóip cheilte';
$labels['replyto'] = 'Freagair go';
$labels['date'] = 'Dáta';
$labels['size'] = 'Méid';
$labels['priority'] = 'Tosaíocht';
$labels['organization'] = 'Eagraíocht';
$labels['reply-to'] = 'Freagair go';
$labels['mailboxlist'] = 'Fillteán';
$labels['messagesfromto'] = 'Teachtaireachta as $from go $to as $count';
$labels['messagenrof'] = 'Teachtaireacht $nr as $count';
$labels['moveto'] = 'bog go...';
$labels['download'] = 'síos-luchtú';
$labels['filename'] = 'Comhad';
$labels['filesize'] = 'Toirt';
$labels['preferhtml'] = 'Taispeáin an HTML';
$labels['htmlmessage'] = 'Teachtaireacht HTML';
$labels['prettydate'] = 'Dátaí Dheas';
$labels['addtoaddressbook'] = 'Sábháil i mo leabhair seoltaí';
$labels['sun'] = 'Do';
$labels['mon'] = 'Lu';
$labels['tue'] = 'Mh';
$labels['wed'] = 'Ch';
$labels['thu'] = 'Dé';
$labels['fri'] = 'Ao';
$labels['sat'] = 'Sa';
$labels['sunday'] = 'Domhnach';
$labels['monday'] = 'An Luan';
$labels['tuesday'] = 'An Mháirt';
$labels['wednesday'] = 'An Chéadaoin';
$labels['thursday'] = 'An Déardaoin';
$labels['friday'] = 'Aoine';
$labels['saturday'] = 'An Satharn';
$labels['today'] = 'Inniu';
$labels['checkmail'] = 'Seiceáil chun teachtaireacht nua';
$labels['writenewmessage'] = 'Scríobh teachtaireacht nua';
$labels['replytomessage'] = 'Scríobh freagra chun an seolaí';
$labels['replytoallmessage'] = 'Scríobh freagra chun an seolaí agus na faighteoir';
$labels['forwardmessage'] = 'Seol ar aghaidh an teachtaireacht';
$labels['deletemessage'] = 'Chuir an teachtaireacht i mo bosca bruscair';
$labels['printmessage'] = 'Priontáil an teachtaireacht seo';
$labels['previousmessage'] = 'Taispeáin an teachtaireacht roimhe seo';
$labels['previousmessages'] = 'Taispeáin an foireann roimhe seo';
$labels['firstmessage'] = 'Taispeáin an cead teachtaireacht';
$labels['firstmessages'] = 'Taispeáin an cead foireann';
$labels['nextmessage'] = 'Taispeáin an teachtaireacht ina dhiaidh sin';
$labels['nextmessages'] = 'Taispeáin an foireann ina dhiaidh sin';
$labels['lastmessage'] = 'Taispeáin an teachtaireacht deireanach';
$labels['lastmessages'] = 'Taispeáin an foireann deireanach';
$labels['backtolist'] = 'Téigh ar ais go dtí an liosta teachtaireachta';
$labels['viewsource'] = 'Éiriú bunchód';
$labels['select'] = 'Togh';
$labels['all'] = 'An uile';
$labels['none'] = 'Aon cheann';
$labels['unread'] = 'Na rudaí nach bhuil corraithe';
$labels['compact'] = 'Comhbhrúigh';
$labels['empty'] = 'Folmhaigh';
$labels['purge'] = 'Purgaigh';
$labels['quota'] = 'Toilleadh diosca atá athláimhe';
$labels['unknown'] = 'gan aithne';
$labels['unlimited'] = 'gan teorainn';
$labels['quicksearch'] = 'Mearcuardaigh';
$labels['resetsearch'] = 'Athshocraigh an cuardach';
$labels['compose'] = 'Scríobh teachtaireacht';
$labels['sendmessage'] = 'Seol mo teachtaireacht láithreach bonn';
$labels['savemessage'] = 'Sábháil an dréachta seo';
$labels['addattachment'] = 'Suimigh Iatán';
$labels['charset'] = 'Foireann carachtar';
$labels['editortype'] = 'Sort eagarthóir';
$labels['returnreceipt'] = 'Admháil léite';
$labels['checkspelling'] = 'Fiosrú ar mo litriú';
$labels['resumeediting'] = 'Athdhúisigh eagarthóireacht';
$labels['revertto'] = 'Filleadh ar';
$labels['attachments'] = 'Iatání';
$labels['upload'] = 'Aistriú suas';
$labels['close'] = 'Dún';
$labels['low'] = 'Íseal';
$labels['lowest'] = 'Is Ísle';
$labels['normal'] = 'Gnách';
$labels['high'] = 'Ard';
$labels['highest'] = 'Is Airde';
$labels['nosubject'] = '(Níl aon Ábhair)';
$labels['showimages'] = 'Taispeáin na híomhánna';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Téacs amháin';
$labels['name'] = 'Leasainm';
$labels['firstname'] = 'Ainm baiste';
$labels['surname'] = 'Sloinne';
$labels['email'] = 'Ríomhphost';
$labels['addcontact'] = 'Sábháil duine nua';
$labels['editcontact'] = 'Chuir chara in eagar';
$labels['edit'] = 'Athraigh';
$labels['cancel'] = 'Cealaigh';
$labels['save'] = 'Sábháil';
$labels['delete'] = 'Scrios';
$labels['newcontact'] = 'Scríobh carta teagmháil nua';
$labels['deletecontact'] = 'Scrios na daoine seo';
$labels['composeto'] = 'Scríobh teachtaireacht go';
$labels['contactsfromto'] = 'Daoine as $from to $to as $count';
$labels['print'] = 'Priontáil';
$labels['export'] = 'Easportáil';
$labels['previouspage'] = 'Taispeáin an foireann roimhe seo';
$labels['firstpage'] = 'Taispeáin an céad foireann';
$labels['nextpage'] = 'Taispeáin an foireann ina dhiaidh sin';
$labels['lastpage'] = 'Taispeáin an foireann deireanach';
$labels['groups'] = 'Grúpaí';
$labels['personaladrbook'] = 'Seoltaí Pearsanta';
$labels['settingsfor'] = 'Socruithe chun';
$labels['preferences'] = 'Tosaíocht';
$labels['userpreferences'] = 'Tosaíocht Pearsanta';
$labels['editpreferences'] = 'Athraigh tosaíocht pearsanta';
$labels['identities'] = 'Céannachtaí';
$labels['manageidentities'] = 'Stiúir céannachtaí i cuntas seo';
$labels['newidentity'] = 'Céannacht nua';
$labels['newitem'] = 'Mír nua';
$labels['edititem'] = 'Athraigh mhír';
$labels['setdefault'] = 'Socraigh an réamhshocraithe';
$labels['language'] = 'Teanga';
$labels['timezone'] = 'Crios ama';
$labels['pagesize'] = 'Rónna in aghaidh gach leathanach';
$labels['signature'] = 'Mana clabhsúir';
$labels['dstactive'] = 'Laethúil um shamhradh';
$labels['htmleditor'] = 'Scríobh teachtaireachta HTML';
$labels['htmlsignature'] = 'Mana clabhsúir HTML';
$labels['previewpane'] = 'Taispeáin an pána réamhamharc';
$labels['autosavedraft'] = 'Sábháil dréachta go huathoibríoch';
$labels['everynminutes'] = ' i gceann gach $n nóiméad';
$labels['never'] = 'riamh';
$labels['folder'] = 'Fillteán';
$labels['folders'] = 'Fillteán';
$labels['foldername'] = 'Ainm fillteán';
$labels['subscribed'] = 'Síntiú';
$labels['create'] = 'Cruthaigh';
$labels['createfolder'] = 'Cruthaigh fillteán nua';
$labels['rename'] = 'Ainmnigh arís';
$labels['renamefolder'] = 'Ainmnigh fillteán arís';
$labels['deletefolder'] = 'Scrios fillteán';
$labels['managefolders'] = 'Stiúir na fillteán';
$labels['sortby'] = 'Sórtáil trí';
$labels['sortasc'] = 'Sórtáil in ord méadaitheach';
$labels['sortdesc'] = 'Sórtáil in ord neartaitheach';

?>