<?php

/*

+-----------------------------------------------------------------------+
| language/cs_CZ/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Martin Mrajca <martin@moonlake.cz>                            |
|        joe <joe@humlak.cz>                                            |
|        Jiri Kaderavek <jiri.kaderavek@webstep.net>                    |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Vítejte v $product';
$labels['username'] = 'Uživatel';
$labels['password'] = 'Heslo';
$labels['server'] = 'Server';
$labels['login'] = 'Přihlásit';
$labels['logout'] = 'Odhlásit';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Osobní nastavení';
$labels['addressbook'] = 'Adresář';
$labels['inbox'] = 'Příchozí pošta';
$labels['drafts'] = 'Rozepsané';
$labels['sent'] = 'Odeslané';
$labels['trash'] = 'Koš';
$labels['junk'] = 'Nevyžádaná pošta';
$labels['subject'] = 'Předmět';
$labels['from'] = 'Odesílatel';
$labels['to'] = 'Adresát';
$labels['cc'] = 'Kopie';
$labels['bcc'] = 'Slepá';
$labels['replyto'] = 'Odpověď na';
$labels['date'] = 'Datum';
$labels['size'] = 'Velikost';
$labels['priority'] = 'Priorita';
$labels['organization'] = 'Organizace';
$labels['reply-to'] = 'Odpověď na';
$labels['mailboxlist'] = 'Složky';
$labels['messagesfromto'] = 'Zprávy $from až $to z celkem $count';
$labels['messagenrof'] = 'Zpráva $nr z $count';
$labels['moveto'] = 'přesunout do...';
$labels['download'] = 'stáhnout';
$labels['filename'] = 'Jméno přílohy';
$labels['filesize'] = 'Velikost přílohy';
$labels['preferhtml'] = 'Upřednostňovat HTML zobrazení';
$labels['htmlmessage'] = 'HTML zpráva';
$labels['prettydate'] = 'Hezčí datum';
$labels['addtoaddressbook'] = 'Přidat do adresáře';
$labels['sun'] = 'Ne';
$labels['mon'] = 'Po';
$labels['tue'] = 'Út';
$labels['wed'] = 'St';
$labels['thu'] = 'Čt';
$labels['fri'] = 'Pá';
$labels['sat'] = 'So';
$labels['sunday'] = 'Neděle';
$labels['monday'] = 'Pondělí';
$labels['tuesday'] = 'Úterý';
$labels['wednesday'] = 'Středa';
$labels['thursday'] = 'Čtvrtek';
$labels['friday'] = 'Pátek';
$labels['saturday'] = 'Sobota';
$labels['jan'] = 'Led';
$labels['feb'] = 'Úno';
$labels['mar'] = 'Bře';
$labels['apr'] = 'Dub';
$labels['may'] = 'Kvě';
$labels['jun'] = 'Čer';
$labels['jul'] = 'Čec';
$labels['aug'] = 'Srp';
$labels['sep'] = 'Zář';
$labels['oct'] = 'Říj';
$labels['nov'] = 'Lis';
$labels['dec'] = 'Pro';
$labels['longjan'] = 'Leden';
$labels['longfeb'] = 'Únor';
$labels['longmar'] = 'Březen';
$labels['longapr'] = 'Duben';
$labels['longmay'] = 'Květen';
$labels['longjun'] = 'Červen';
$labels['longjul'] = 'Červenec';
$labels['longaug'] = 'Srpen';
$labels['longsep'] = 'Září';
$labels['longoct'] = 'Říjen';
$labels['longnov'] = 'Listopad';
$labels['longdec'] = 'Prosinec';
$labels['today'] = 'Dnes';
$labels['checkmail'] = 'Zkontrolovat nové zprávy';
$labels['writenewmessage'] = 'Vytvořit novou zprávu';
$labels['replytomessage'] = 'Odpovědět odesílateli';
$labels['replytoallmessage'] = 'Odpovědět všem';
$labels['forwardmessage'] = 'Předat zprávu';
$labels['deletemessage'] = 'Přesunout do koše';
$labels['movemessagetotrash'] = 'Přesunout zprávu do koše';
$labels['printmessage'] = 'Vytisknout zprávu';
$labels['previousmessage'] = 'Zobrazit předchozí zprávu';
$labels['previousmessages'] = 'Zobrazit předchozí zprávy';
$labels['firstmessage'] = 'Zobrazit první zprávu';
$labels['firstmessages'] = 'Zobrazit první zprávy';
$labels['nextmessage'] = 'Zobrazit další zprávu';
$labels['nextmessages'] = 'Zobrazit další zprávy';
$labels['lastmessage'] = 'Zobrazit poslední zprávu';
$labels['lastmessages'] = 'Zobrazit poslední zprávy';
$labels['backtolist'] = 'Zpět do seznamu zpráv';
$labels['viewsource'] = 'Zobrazit zdroj';
$labels['markmessages'] = 'Označ zprávy';
$labels['markread'] = 'Jako přečtené';
$labels['markunread'] = 'Jako nepřečtené';
$labels['markflagged'] = 'Jako označené';
$labels['markunflagged'] = 'Jako neoznačené';
$labels['select'] = 'Vybrat';
$labels['all'] = 'Vše';
$labels['none'] = 'Nic';
$labels['unread'] = 'Nepřečtené';
$labels['compact'] = 'Zmenšit';
$labels['empty'] = 'Vymazat';
$labels['purge'] = 'Vyprázdnit';
$labels['quota'] = 'Využití schránky';
$labels['unknown'] = 'neznámý';
$labels['unlimited'] = 'neomezený';
$labels['quicksearch'] = 'Rychlé vyhledávání';
$labels['resetsearch'] = 'Zrušit vyhledávání';
$labels['openinextwin'] = 'Otevřít v novém okně';
$labels['compose'] = 'Napsat zprávu';
$labels['savemessage'] = 'Uložit do rozepsaných';
$labels['sendmessage'] = 'Odeslat zprávu nyní';
$labels['addattachment'] = 'Přidat přílohu';
$labels['charset'] = 'Znaková sada';
$labels['editortype'] = 'Typ editoru zpráv';
$labels['returnreceipt'] = 'Doručenka';
$labels['checkspelling'] = 'Zkontrolovat pravopis';
$labels['resumeediting'] = 'Pokračovat v úpravách';
$labels['revertto'] = 'Přejít na';
$labels['attachments'] = 'Přílohy';
$labels['upload'] = 'Nahrát';
$labels['close'] = 'Zavřít';
$labels['low'] = 'Nízká';
$labels['lowest'] = 'Nejnižší';
$labels['normal'] = 'Normální';
$labels['high'] = 'Vysoká';
$labels['highest'] = 'Nejvyšší';
$labels['nosubject'] = '(bez predmetu)';
$labels['showimages'] = 'Zobrazit obrázky';
$labels['alwaysshow'] = 'Vždy ukazovat obrázky od $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Prostý text';
$labels['savesentmessagein'] = 'Ukládat odeslané zprávy v';
$labels['dontsave'] = 'neukládat';
$labels['maxuploadsize'] = 'Maximální povolená velikost souboru je $size';
$labels['addcc'] = 'Přidat pole \"Kopie\"';
$labels['addbcc'] = 'Přidat pole \"Skrytá Kopie\"';
$labels['addreplyto'] = 'Přidat pole \"Odpověď\"';
$labels['mdnrequest'] = 'Odesílatel této zprávy si přeje být upozorněn na to, že jste zprávu obdrželi. Chcete přijetí zprávy potvrdit?';
$labels['receiptread'] = 'Potvrzení o přijetí zprávy';
$labels['yourmessage'] = 'Toto je potvrzení o přijetí Vaší zprávy';
$labels['receiptnote'] = 'Poznámka: Toto potvrzení negarantuje, že zpráva byla příjemce přečtena a že porozuměl jejímu obsahu.';
$labels['name'] = 'Zobrazit jméno';
$labels['firstname'] = 'Jméno';
$labels['surname'] = 'Příjmení';
$labels['email'] = 'E-mail';
$labels['addcontact'] = 'Přidat kontakt';
$labels['editcontact'] = 'Upravit kontakt';
$labels['edit'] = 'Upravit';
$labels['cancel'] = 'Konec';
$labels['save'] = 'Uložit';
$labels['delete'] = 'Smazat';
$labels['newcontact'] = 'Vytvořit nový kontakt';
$labels['deletecontact'] = 'Smazat vybrané kontakty';
$labels['composeto'] = 'Poslat e-mail';
$labels['contactsfromto'] = 'Kontakty $from až $to z celkem $count';
$labels['print'] = 'Tisk';
$labels['export'] = 'Export';
$labels['exportvcards'] = 'Exportovat kontakty ve formátu vCard';
$labels['previouspage'] = 'Předchozí';
$labels['firstpage'] = 'Zobrazit první zprávy';
$labels['nextpage'] = 'Další';
$labels['lastpage'] = 'Zobrazit poslední zprávy';
$labels['groups'] = 'Skupiny';
$labels['personaladrbook'] = 'Osobní kontakty';
$labels['import'] = 'Import';
$labels['importcontacts'] = 'Importovat kontakty';
$labels['importfromfile'] = 'Importovat ze souboru';
$labels['importreplace'] = 'Nahradit celý seznam kontaktů';
$labels['importtext'] = 'Můžete nahrát kontakty z existujícího seznamu kontaktů.Podporujeme formát vCard';
$labels['done'] = 'Hotovo';
$labels['settingsfor'] = 'Nastavení pro';
$labels['preferences'] = 'Vlastnosti';
$labels['userpreferences'] = 'Vlastnosti uživatele';
$labels['editpreferences'] = 'Upravit vlastnosti uživatele';
$labels['identities'] = 'Profily';
$labels['manageidentities'] = 'Spravovat profily u tohoto účtu';
$labels['newidentity'] = 'Nový profil';
$labels['newitem'] = 'Nová položka';
$labels['edititem'] = 'Upravit položku';
$labels['setdefault'] = 'Nastavit výchozí';
$labels['autodetect'] = 'Automaticky';
$labels['language'] = 'Jazyk';
$labels['timezone'] = 'Časová zóna';
$labels['pagesize'] = 'Řádků na stránku';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Letní čas';
$labels['htmleditor'] = 'Vytvářet HTML zprávy';
$labels['htmlsignature'] = 'HTML podpis';
$labels['previewpane'] = 'Zobrazit panel náhledu';
$labels['skin'] = 'Vzhled';
$labels['logoutclear'] = 'Vyprázdnit koš při odhlášení';
$labels['logoutcompact'] = 'Provést údržbu schránky při odhlášení';
$labels['uisettings'] = 'Uživatelské rozhraní';
$labels['serversettings'] = 'Nastavení serveru';
$labels['mailboxview'] = 'Zobrazení schránky';
$labels['mdnrequests'] = 'Oznámení o doručení';
$labels['askuser'] = 'zeptat se';
$labels['autosend'] = 'poslat automaticky';
$labels['ignore'] = 'ignorovat';
$labels['readwhendeleted'] = 'Při odstranění označit zprávu jako přečtenou';
$labels['flagfordeletion'] = 'Zprávu nemazat, pouze označit pro odstranění';
$labels['showinlineimages'] = 'Zobrazovat připojené obrázky pod textem';
$labels['autosavedraft'] = 'Automaticky uložit rozepsané zprávy';
$labels['everynminutes'] = 'každých $n minut';
$labels['never'] = 'nikdy';
$labels['messagesdisplaying'] = 'Zobrazování zpráv';
$labels['messagescomposition'] = 'Psaní zpráv';
$labels['folder'] = 'Složka';
$labels['folders'] = 'Složky';
$labels['foldername'] = 'Jméno složky';
$labels['subscribed'] = 'Vybráno';
$labels['messagecount'] = 'Počet zpráv';
$labels['create'] = 'Vytvořit';
$labels['createfolder'] = 'Vytvořit novou složku';
$labels['rename'] = 'Přejmenovat';
$labels['renamefolder'] = 'Přejmenovat složku';
$labels['deletefolder'] = 'Smazat složku';
$labels['managefolders'] = 'Spravovat složky';
$labels['specialfolders'] = 'Speciální složky';
$labels['sortby'] = 'Seřadit podle';
$labels['sortasc'] = 'Seřadit vzestupně';
$labels['sortdesc'] = 'Seřadit sestupně';

?>