<?php

/*

+-----------------------------------------------------------------------+
| language/pt_PT/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Authors: Sergio Rocha <sergio.rocha@makeitsimple.pt>                  |
|          João Vale <jpvale@gmail.com>                                 |
|          Fernando Silva <fernando.silva@openquest.pt>                 |
|          Nuno Costa <nuno@criacaoweb.net>                             |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Bem-vindo ao $product';
$labels['username'] = 'Utilizador';
$labels['password'] = 'Senha';
$labels['server'] = 'Servidor';
$labels['login'] = 'Entrar';
$labels['logout'] = 'Sair';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Configurações pessoais';
$labels['addressbook'] = 'Lista de Contactos';
$labels['inbox'] = 'Caixa de entrada';
$labels['drafts'] = 'Rascunhos';
$labels['sent'] = 'Enviados';
$labels['trash'] = 'Lixeira';
$labels['junk'] = 'Junk';
$labels['subject'] = 'Assunto';
$labels['from'] = 'Remetente';
$labels['to'] = 'Para';
$labels['cc'] = 'Cópia';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Responder para';
$labels['date'] = 'Data';
$labels['size'] = 'Tamanho';
$labels['priority'] = 'Prioridade';
$labels['organization'] = 'Organização';
$labels['reply-to'] = 'Responder para';
$labels['mailboxlist'] = 'Pastas';
$labels['messagesfromto'] = 'Mensagens $from - $to de $count';
$labels['messagenrof'] = 'Mensagem $nr de $count';
$labels['moveto'] = 'mover para...';
$labels['download'] = 'descarregar';
$labels['filename'] = 'Ficheiro';
$labels['filesize'] = 'Tamanho';
$labels['preferhtml'] = 'Prefere HTML';
$labels['htmlmessage'] = 'Mensagem HTML';
$labels['prettydate'] = 'Formatar datas';
$labels['addtoaddressbook'] = 'Adicionar à lista de contactos';
$labels['sun'] = 'Dom';
$labels['mon'] = 'Seg';
$labels['tue'] = 'Ter';
$labels['wed'] = 'Qua';
$labels['thu'] = 'Qui';
$labels['fri'] = 'Sex';
$labels['sat'] = 'Sáb';
$labels['sunday'] = 'Domingo';
$labels['monday'] = 'Segunda-feira';
$labels['tuesday'] = 'Terça-feira';
$labels['wednesday'] = 'Quarta-feira';
$labels['thursday'] = 'Quinta-feira';
$labels['friday'] = 'Sexta-feira';
$labels['saturday'] = 'Sábado';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Fev';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Abr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Ago';
$labels['sep'] = 'Set';
$labels['oct'] = 'Out';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dez';
$labels['longjan'] = 'Janeiro';
$labels['longfeb'] = 'Fevereiro';
$labels['longmar'] = 'Março';
$labels['longapr'] = 'Abril';
$labels['longmay'] = 'Maio';
$labels['longjun'] = 'Junho';
$labels['longjul'] = 'Julho';
$labels['longaug'] = 'Agosto';
$labels['longsep'] = 'Setembro';
$labels['longoct'] = 'Outubro';
$labels['longnov'] = 'Novembro';
$labels['longdec'] = 'Dezembro';
$labels['today'] = 'Hoje';
$labels['checkmail'] = 'Verificar novas mensagens';
$labels['writenewmessage'] = 'Criar nova mensagem';
$labels['replytomessage'] = 'Responder';
$labels['replytoallmessage'] = 'Responder a todos';
$labels['forwardmessage'] = 'Reencaminhar';
$labels['deletemessage'] = 'Apagar';
$labels['movemessagetotrash'] = 'Mover para lixeira';
$labels['printmessage'] = 'Imprimir';
$labels['previousmessage'] = 'Mensagem anterior';
$labels['previousmessages'] = 'Página anterior';
$labels['firstmessage'] = 'Primeira mensagem';
$labels['firstmessages'] = 'Primeira página';
$labels['nextmessage'] = 'Próxima mensagem';
$labels['nextmessages'] = 'Próxima página';
$labels['lastmessage'] = 'Última mensagem';
$labels['lastmessages'] = 'Última página';
$labels['backtolist'] = 'Voltar';
$labels['viewsource'] = 'Mostrar código fonte';
$labels['markmessages'] = 'Marcar mensagens';
$labels['markread'] = 'Como lidas';
$labels['markunread'] = 'Como não lidas';
$labels['markflagged'] = 'Com sinalização';
$labels['markunflagged'] = 'Sem sinalização';
$labels['select'] = 'Seleccionar';
$labels['all'] = 'Todas';
$labels['none'] = 'Nenhuma';
$labels['unread'] = 'Não lidas';
$labels['compact'] = 'Compactar';
$labels['empty'] = 'Vazio';
$labels['purge'] = 'Apagar';
$labels['quota'] = 'Utilização';
$labels['unknown'] = 'desconhecido';
$labels['unlimited'] = 'ilimitado';
$labels['quicksearch'] = 'Pesquisa rápida';
$labels['resetsearch'] = 'Limpar pesquisa';
$labels['openinextwin'] = 'Abrir numa nova janela';
$labels['compose'] = 'Escrever mensagem';
$labels['savemessage'] = 'Salvar rascunho';
$labels['sendmessage'] = 'Enviar';
$labels['addattachment'] = 'Anexar';
$labels['charset'] = 'Charset';
$labels['editortype'] = 'Tipo de editor';
$labels['returnreceipt'] = 'Confirmação de leitura';
$labels['checkspelling'] = 'Verificar ortografia';
$labels['resumeediting'] = 'Continuar a edição';
$labels['revertto'] = 'Reverter para';
$labels['attachments'] = 'Anexos';
$labels['upload'] = 'Puxar';
$labels['close'] = 'Fechar';
$labels['low'] = 'Baixa';
$labels['lowest'] = 'Mais baixa';
$labels['normal'] = 'Normal';
$labels['high'] = 'Alta';
$labels['highest'] = 'Mais alta';
$labels['nosubject'] = '(sem assunto)';
$labels['showimages'] = 'Exibir imagens';
$labels['alwaysshow'] = 'Mostrar sempre imagens a partir de  $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Texto simples';
$labels['savesentmessagein'] = 'Salvar mensagem enviada em';
$labels['dontsave'] = 'não salvar';
$labels['maxuploadsize'] = 'Tamanho máximo permitido do ficheiro é $size';
$labels['addcc'] = 'Adicionar Cc';
$labels['addbcc'] = 'Adicionar Bcc';
$labels['addreplyto'] = 'Adicionar "Responder para"';
$labels['mdnrequest'] = 'O remetente desta mensagem pediu para ser notificado quando esta fosse lida. Deseja enviar uma notificação?';
$labels['receiptread'] = 'Recibo de leitura';
$labels['yourmessage'] = 'Isto é um recibo de leitura da sua mensagem';
$labels['receiptnote'] = 'Nota: este recibo apenas indica que a mensagem foi aberta pelo destinatário. Não garante que a mensagem foi lida ou compreendida.';
$labels['name'] = 'Nome completo';
$labels['firstname'] = 'Primeiro nome';
$labels['surname'] = 'Apelido';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Criar novo contacto';
$labels['editcontact'] = 'Editar contacto';
$labels['edit'] = 'Editar';
$labels['cancel'] = 'Cancelar';
$labels['save'] = 'Gravar';
$labels['delete'] = 'Apagar';
$labels['newcontact'] = 'Criar novo contacto';
$labels['deletecontact'] = 'Apagar contactos selecionados';
$labels['composeto'] = 'Escrever mensagem para';
$labels['contactsfromto'] = 'Contactos $from - $to of $count';
$labels['print'] = 'Imprimir';
$labels['export'] = 'Exportar';
$labels['exportvcards'] = 'Exportar contactos no formato vCard';
$labels['previouspage'] = 'Exibir página anterior';
$labels['firstpage'] = 'Exibir primeira página';
$labels['nextpage'] = 'Exibir próxima página';
$labels['lastpage'] = 'Exibir última página';
$labels['groups'] = 'Grupos';
$labels['personaladrbook'] = 'Endereços pessoais';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contactos';
$labels['importfromfile'] = 'Importar do ficheiro:';
$labels['importreplace'] = 'Substituir todo o livro de endereços';
$labels['importtext'] = 'Pode submeter contactos a partir de um livro de endereços.Actualmente suportamos importação de endereços no formato vCard.';
$labels['done'] = 'Terminado';
$labels['settingsfor'] = 'Configurações para';
$labels['preferences'] = 'Preferências';
$labels['userpreferences'] = 'Preferências do utilizador';
$labels['editpreferences'] = 'Editar preferências do utilizador';
$labels['identities'] = 'Identidades';
$labels['manageidentities'] = 'Gerir identidades para esta conta';
$labels['newidentity'] = 'Nova identidade';
$labels['newitem'] = 'Novo item';
$labels['edititem'] = 'Editar item';
$labels['setdefault'] = 'Marcar por omissão';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Idioma';
$labels['timezone'] = 'Fuso horário';
$labels['pagesize'] = 'Linhas por página';
$labels['signature'] = 'Assinatura';
$labels['dstactive'] = 'Horário de verão';
$labels['htmleditor'] = 'Escrever mensagens em HTML';
$labels['htmlsignature'] = 'Assinatura em HTML';
$labels['previewpane'] = 'Mostrar pré-visualização';
$labels['skin'] = 'Interface skin [tema]';
$labels['logoutclear'] = 'Limpar a Lixeira após sair';
$labels['logoutcompact'] = 'Compactar Caixa de Entrada após sair';
$labels['uisettings'] = 'Interface de Utilizador';
$labels['serversettings'] = 'Definições do Servidor';
$labels['mailboxview'] = 'Visualizar caixa de Entrada';
$labels['mdnrequests'] = 'Enviar Notificações';
$labels['askuser'] = 'Perguntar ao ultilizador';
$labels['autosend'] = 'enviar automáticamente';
$labels['ignore'] = 'ignorar';
$labels['readwhendeleted'] = 'Marcar a mensagem como lida ao excluir';
$labels['flagfordeletion'] = 'Marcar a mensagem de eliminação, em vez de a excluir';
$labels['skipdeleted'] = 'Não mostrar mensagens apagadas';
$labels['showinlineimages'] = 'Mostrar imagens anexadas abaixo da mensagem';
$labels['autosavedraft'] = 'Salvar rascunho automaticamente';
$labels['everynminutes'] = 'a cada $n minutos';
$labels['keepaliveevery'] = 'cada $n minuto(s)';
$labels['keepalive'] = 'Verificar novas mensagens em';
$labels['never'] = 'nunca';
$labels['messagesdisplaying'] = 'A exibir mensagens';
$labels['messagescomposition'] = 'Composição de mensagens ';
$labels['mimeparamfolding'] = 'Nomes de anexos';
$labels['2231folding'] = 'Total RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Total RFC 2047 (outro)';
$labels['advancedoptions'] = 'Opções avançadas';
$labels['focusonnewmessage'] = 'Focar janela de navegador na nova mensagem';
$labels['folder'] = 'Pasta';
$labels['folders'] = 'Pastas';
$labels['foldername'] = 'Nome da pasta';
$labels['subscribed'] = 'Subscrito';
$labels['messagecount'] = 'Mensagens';
$labels['create'] = 'Criar';
$labels['createfolder'] = 'Criar nova pasta';
$labels['rename'] = 'Renomear';
$labels['renamefolder'] = 'Renomear pasta';
$labels['deletefolder'] = 'Apagar pasta';
$labels['managefolders'] = 'Gerir pastas';
$labels['specialfolders'] = 'Pastas especiais';
$labels['sortby'] = 'Ordenado por';
$labels['sortasc'] = 'Ascendente';
$labels['sortdesc'] = 'Descendente';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
