<?php

/*

 +-----------------------------------------------------------------------+
 | language/nb_NO/labels.inc                                             |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Kjetil Waage - Nextline AS <kjetil@nextline.no>               |
 | Author: Tor Erik Linnerud - JKLM <tel@jklm.no>                        |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1335 2008-04-27 15:18:13Z alec $

*/

$labels = array();
$labels['welcome'] = 'Velkommen til $product';
$labels['username'] = 'Brukernavn:';
$labels['password'] = 'Passord:';
$labels['server'] = 'Server';
$labels['login'] = 'Logg på';
$labels['logout'] = 'Logg ut';
$labels['mail'] = 'E-post';
$labels['settings'] = 'Personlige innstillinger';
$labels['addressbook'] = 'Adressebok';
$labels['inbox'] = 'Innboks';
$labels['drafts'] = 'Kladder';
$labels['sent'] = 'Sendt';
$labels['trash'] = 'Søppel';
$labels['junk'] = 'Spam';
$labels['subject'] = 'Emne';
$labels['from'] = 'Avsender';
$labels['to'] = 'Mottaker';
$labels['cc'] = 'Kopi til';
$labels['bcc'] = 'BCC';
$labels['replyto'] = 'Svar til';
$labels['date'] = 'Dato';
$labels['size'] = 'Størrelse';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organisasjon';
$labels['reply-to'] = 'Svar til';
$labels['mailboxlist'] = 'Mapper';
$labels['messagesfromto'] = 'Meldinger $from til $to av $count';
$labels['messagenrof'] = 'Meldinger $nr av $count';
$labels['moveto'] = 'flytt til...';
$labels['download'] = 'last ned';
$labels['filename'] = 'Filnavn';
$labels['filesize'] = 'Filstørrelse';
$labels['preferhtml'] = 'Foretrekk HTML';
$labels['htmlmessage'] = 'HTML-beskjed';
$labels['prettydate'] = 'Pen datovisning';
$labels['addtoaddressbook'] = 'Tilføy til adresseboken';
$labels['sun'] = 'Søn';
$labels['mon'] = 'Man';
$labels['tue'] = 'Tir';
$labels['wed'] = 'Ons';
$labels['thu'] = 'Tor';
$labels['fri'] = 'Fre';
$labels['sat'] = 'Lør';
$labels['sunday'] = 'Søndag';
$labels['monday'] = 'Mandag';
$labels['tuesday'] = 'Tirsdag';
$labels['wednesday'] = 'Onsdag';
$labels['thursday'] = 'Torsdag';
$labels['friday'] = 'Fredag';
$labels['saturday'] = 'Lørdag';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Des';
$labels['longjan'] = 'Januar';
$labels['longfeb'] = 'Februar';
$labels['longmar'] = 'Marsj';
$labels['longapr'] = 'April';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'Juli';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Oktober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'Desember';
$labels['today'] = 'I dag';
$labels['checkmail'] = 'Sjekk for nye beskjeder';
$labels['writenewmessage'] = 'Opprett en ny e-post';
$labels['replytomessage'] = 'Svar på denne e-posten';
$labels['replytoallmessage'] = 'Svar til alle mottakere';
$labels['forwardmessage'] = 'Videresend denne e-posten';
$labels['deletemessage'] = 'Slett e-posten';
$labels['movemessagetotrash'] = 'Flytt e-posten til søppel';
$labels['printmessage'] = 'Skriv ut denne e-posten';
$labels['previousmessage'] = 'Vis forrige melding';
$labels['previousmessages'] = 'Vis forrige side';
$labels['firstmessage'] = 'Vis første melding';
$labels['firstmessages'] = 'Vis første side med meldinger';
$labels['nextmessage'] = 'Vis neste melding';
$labels['nextmessages'] = 'Vis neste side';
$labels['lastmessage'] = 'Vis siste melding';
$labels['lastmessages'] = 'Vis siste side med meldinger';
$labels['backtolist'] = 'Tilbake til e-postlisten';
$labels['viewsource'] = 'Vis kilde';
$labels['markmessages'] = 'Merk e-postene';
$labels['markread'] = 'som lest';
$labels['markunread'] = 'som ulest';
$labels['select'] = 'Velg';
$labels['all'] = 'Alle';
$labels['none'] = 'Ingen';
$labels['unread'] = 'Uleste';
$labels['compact'] = 'Rydd opp';
$labels['empty'] = 'Tøm';
$labels['purge'] = 'Tøm';
$labels['quota'] = 'Plassforbruk';
$labels['unknown'] = 'ukjent';
$labels['unlimited'] = 'ubegrenset';
$labels['quicksearch'] = 'Hurtigsøk';
$labels['resetsearch'] = 'Nullstill søk';
$labels['compose'] = 'Skriv ny e-post';
$labels['savemessage'] = 'Lagre kladd';
$labels['sendmessage'] = 'Send e-posten';
$labels['addattachment'] = 'Vedlegg';
$labels['charset'] = 'Tegnsett';
$labels['editortype'] = 'Format';
$labels['returnreceipt'] = 'Be om kvittering';
$labels['checkspelling'] = 'Stavekontroll';
$labels['resumeediting'] = 'Fortsett redigering';
$labels['revertto'] = 'Tilbake til';
$labels['attachments'] = 'Vedlegg';
$labels['upload'] = 'Last opp';
$labels['close'] = 'Lukk';
$labels['low'] = 'Lav';
$labels['lowest'] = 'Lavest';
$labels['normal'] = 'Normal';
$labels['high'] = 'Høy';
$labels['highest'] = 'Høyest';
$labels['nosubject'] = '(intet emne)';
$labels['showimages'] = 'Vis bilder';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Ren tekst';
$labels['addcc'] = 'Legg til Cc';
$labels['addbcc'] = 'Legg til Bcc';
$labels['addreplyto'] = 'Legg til Reply-To';
$labels['mdnrequest'] = 'Senderen av denne meldingen har bedt om å bli gjort oppmerksom på at denne meldingen er lest. Ønsker du å sende denne bekreftelsen?';
$labels['receiptread'] = 'Kvittering (lest)';
$labels['yourmessage'] = 'Dette er en kvittering for at din e-post er mottatt';
$labels['receiptnote'] = 'Merknad: Denne kvitteringen bekrefter bare at e-posten ble vist hos mottakeren. Det er ingen garanti for at mottakeren har lest eller forstått innholdet i e-posten.';
$labels['name'] = 'Visningsnavn';
$labels['firstname'] = 'Fornavn';
$labels['surname'] = 'Etternavn';
$labels['email'] = 'E-post';
$labels['addcontact'] = 'Legg til en ny kontakt';
$labels['editcontact'] = 'Rediger kontakt';
$labels['edit'] = 'Rediger';
$labels['cancel'] = 'Avbryt';
$labels['save'] = 'Lagre';
$labels['delete'] = 'Slett';
$labels['newcontact'] = 'Opprett ny kontakt';
$labels['deletecontact'] = 'Slett valgte kontakter';
$labels['composeto'] = 'Skriv e-post til';
$labels['contactsfromto'] = 'Kontakter $from til $to av $count';
$labels['print'] = 'Skriv ut';
$labels['export'] = 'Eksportere';
$labels['previouspage'] = 'Vis forrige sett';
$labels['firstpage'] = 'Vis første sett';
$labels['nextpage'] = 'Vis neste sett';
$labels['lastpage'] = 'Vis siste sett';
$labels['groups'] = 'Grupper';
$labels['personaladrbook'] = 'Egne adresser';
$labels['settingsfor'] = 'Innstillinger for';
$labels['preferences'] = 'Oppsett';
$labels['userpreferences'] = 'Brukeroppsett';
$labels['editpreferences'] = 'Rediger brukeroppsett';
$labels['identities'] = 'Identiteter';
$labels['manageidentities'] = 'Administrer identitetene for denne kontoen';
$labels['newidentity'] = 'Ny identitet';
$labels['newitem'] = 'Nytt punkt';
$labels['edititem'] = 'Rediger punkt';
$labels['setdefault'] = 'Sett som standard';
$labels['language'] = 'Språk';
$labels['timezone'] = 'Tidssone';
$labels['pagesize'] = 'Linjer per side';
$labels['signature'] = 'Signatur';
$labels['dstactive'] = 'Sommertid';
$labels['htmleditor'] = 'Bruk HTML-editor';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['previewpane'] = 'Forhåndsvisning';
$labels['logoutclear'] = 'Tøm søpel ved utlogging';
$labels['logoutcompact'] = 'Kompakt innboksen ved utlogging';
$labels['uisettings'] = 'Brukergrensesnitt';
$labels['serversettings'] = 'Serverinnstillinger';
$labels['autosavedraft'] = 'Autolagring av utkast';
$labels['everynminutes'] = 'Hvert $n. minutt';
$labels['never'] = 'Aldri';
$labels['folder'] = 'Mappe';
$labels['folders'] = 'Mapper';
$labels['foldername'] = 'Mappenavn';
$labels['subscribed'] = 'Abonnere';
$labels['messagecount'] = 'Meldinger';
$labels['create'] = 'Opprett';
$labels['createfolder'] = 'Lag ny mappe';
$labels['rename'] = 'Endre navn';
$labels['renamefolder'] = 'Endre navn på mappe';
$labels['deletefolder'] = 'Slett mappe';
$labels['managefolders'] = 'Rediger mapper';
$labels['sortby'] = 'Sorter etter';
$labels['sortasc'] = 'Eldste først';
$labels['sortdesc'] = 'Nyeste først';

?>