<?php

/*

 +-----------------------------------------------------------------------+
 | language/nb_NO/messages.inc                                           |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Kjetil Waage - Nextline AS <kjetil@nextline.no>               |
 | Author: Tor Erik Linnerud - JKLM <tel@jklm.no>                        |
 +-----------------------------------------------------------------------+

 @version $Id: messages.inc 1093 2008-02-16 11:40:18Z tomekp $

*/

$messages = array();
$messages['loginfailed'] = 'Pålogging mislyktes';
$messages['cookiesdisabled'] = 'Din nettleser aksepterer ikke cookies';
$messages['sessionerror'] = 'Din session er ugyldig eller utløpt';
$messages['imaperror'] = 'Forbindelsen til IMAP serveren sviktet';
$messages['nomessagesfound'] = 'Det ble ikke funnet noen beskjeder i denne innboksen';
$messages['loggedout'] = 'Du er logget av webmail. Ha det bra!';
$messages['mailboxempty'] = 'Postkassen er tom!';
$messages['loading'] = 'Laster...';
$messages['loadingdata'] = 'Laster data...';
$messages['checkingmail'] = 'Sjekker for nye beskjeder...';
$messages['sendingmessage'] = 'Sender beskjed...';
$messages['messagesent'] = 'Beskjeden ble sendt uten feil';
$messages['savingmessage'] = 'Lagrer beskjed...';
$messages['messagesaved'] = 'Beskjed er lagret i "kladder" mappen';
$messages['successfullysaved'] = 'Lagret';
$messages['addedsuccessfully'] = 'Kontakten ble tilføyd i adresseboken';
$messages['contactexists'] = 'Der er allerede en kontakt med denne e-postadressen';
$messages['blockedimages'] = 'Bilder fra eksterne servere er blokkert i denne e-posten.';
$messages['encryptedmessage'] = 'Dette er en krypteret beskjed og kan ikke vises. Beklager!';
$messages['nocontactsfound'] = 'Ingen kontakter ble funnet';
$messages['contactnotfound'] = 'Den forespurte kontakten ble ikke funnet';
$messages['sendingfailed'] = 'Kunne ikke sende e-posten';
$messages['errorsaving'] = 'Det oppstod en feil ved lagring av data';
$messages['errormoving'] = 'Kunne ikke flytte beskjeden';
$messages['errordeleting'] = 'Kunne ikke slette beskjeden';
$messages['deletecontactconfirm'] = 'Vil du virkelig slette valgte kontakt(er)?';
$messages['deletemessagesconfirm'] = 'Vil du virkelig slette de valgte meldingen(e)?';
$messages['deletefolderconfirm'] = 'Vil du virkelig slette denne mappen?';
$messages['purgefolderconfirm'] = 'Vil du virkelig slette alle meldingene i denne mappen?';
$messages['formincomplete'] = 'Skjemaet var ikke fullstendig fylt ut';
$messages['noemailwarning'] = 'Skriv inn en gyldig e-post adresse';
$messages['nonamewarning'] = 'Angi et navn';
$messages['nopagesizewarning'] = 'Angi sidestørrelsen';
$messages['norecipientwarning'] = 'Skriv inn minst en mottaker';
$messages['nosubjectwarning'] = '"Emne" feltet er tomt. Vil du skrive det inn nå?';
$messages['nobodywarning'] = 'Send denne e-post uten tekst?';
$messages['notsentwarning'] = 'E-posten ble ikke sendt. Vil du slette meldingen?';
$messages['noldapserver'] = 'Venligst velg hvilken LDAP server det skal søkes i';
$messages['nocontactsreturned'] = 'Ingen kontakter ble funnet';
$messages['nosearchname'] = 'Venligst skriv inn kontaktens navn eller e-postadresse';
$messages['searchsuccessful'] = '$nr meldinger funnet';
$messages['searchnomatch'] = 'Søket ga ingen resultater';
$messages['searching'] = 'Søker...';
$messages['checking'] = 'Sjekker...';
$messages['nospellerrors'] = 'Ingen stavefeil funnet';
$messages['folderdeleted'] = 'Mappe slettet';
$messages['deletedsuccessfully'] = 'Slettet';
$messages['converting'] = 'Fjerner formatering fra meldingen...';
$messages['messageopenerror'] = 'Kunne ikke laste meldingen fra server';
$messages['fileuploaderror'] = 'Opplasting feilet';
$messages['filesizeerror'] = 'Filen overstiger maksimum tillatt filstørrelse ($size)';
$messages['copysuccess'] = '$nr adresser ble kopiert';
$messages['copyerror'] = 'Kunne ikke kopiere';
$messages['sourceisreadonly'] = 'Denne adressekilden er skrivebeskyttet';
$messages['errorsavingcontact'] = 'Kunne ikke lagre adressen';
$messages['movingmessage'] = 'Flytter e-post...';
$messages['receiptsent'] = 'Kvittering har blitt sent';
$messages['errorsendingreceipt'] = 'Kunne ikke sende kvittering';
$messages['nodeletelastidentity'] = 'Du kan ikke slette denne identiteten, det er din siste.';
$messages['addsubfolderhint'] = 'Mappen vil bli opprettet som en undermappe av den nåværende valgte mappe';

?>