<?php

/*

+-----------------------------------------------------------------------+
| language/fi/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Ville Alatalo <ville@alatalo.org>                             |
|         Veljo Velling <veve@utu.fi>                                   |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Tervetuloa $product -käyttäjäksi';
$labels['username'] = 'Käyttäjätunnus';
$labels['password'] = 'Salasana';
$labels['server'] = 'Palvelin';
$labels['login'] = 'Kirjaudu';
$labels['logout'] = 'Kirjaudu ulos';
$labels['mail'] = 'Sähköposti';
$labels['settings'] = 'Omat asetukset';
$labels['addressbook'] = 'Osoitekirja';
$labels['inbox'] = 'Saapuneet';
$labels['drafts'] = 'Luonnokset';
$labels['sent'] = 'Lähetetyt';
$labels['trash'] = 'Roskakori';
$labels['junk'] = 'Roskaposti';
$labels['subject'] = 'Aihe';
$labels['from'] = 'Lähettäjä';
$labels['to'] = 'Vastaanottaja';
$labels['cc'] = 'Kopio';
$labels['bcc'] = 'Piilokopio';
$labels['replyto'] = 'Vastaus osoitteeseen';
$labels['date'] = 'Päiväys';
$labels['size'] = 'Koko';
$labels['priority'] = 'Tärkeys';
$labels['organization'] = 'Organisaatio';
$labels['reply-to'] = 'Vastaus osoitteeseen';
$labels['mailboxlist'] = 'Kansiot';
$labels['messagesfromto'] = 'Viestit $from-$to/$count';
$labels['messagenrof'] = 'Viesti $nr/$count';
$labels['moveto'] = 'siirrä kansioon...';
$labels['download'] = 'lataa';
$labels['filename'] = 'Tiedoston nimi';
$labels['filesize'] = 'Tiedoston koko';
$labels['preferhtml'] = 'Käytä HTML:aa';
$labels['htmlmessage'] = 'HTML-viesti';
$labels['prettydate'] = 'Nätit päiväykset';
$labels['addtoaddressbook'] = 'Lisää osoitekirjaan';
$labels['sun'] = 'Su';
$labels['mon'] = 'Ma';
$labels['tue'] = 'Ti';
$labels['wed'] = 'Ke';
$labels['thu'] = 'To';
$labels['fri'] = 'Pe';
$labels['sat'] = 'La';
$labels['sunday'] = 'Sunnuntai';
$labels['monday'] = 'Maanantai';
$labels['tuesday'] = 'Tiistai';
$labels['wednesday'] = 'Keskiviikko';
$labels['thursday'] = 'Torstai';
$labels['friday'] = 'Perjantai';
$labels['saturday'] = 'Lauantai';
$labels['jan'] = 'Tammi';
$labels['feb'] = 'Helmi';
$labels['mar'] = 'Maalis';
$labels['apr'] = 'Huhti';
$labels['may'] = 'Touko';
$labels['jun'] = 'Kesä';
$labels['jul'] = 'Heinä';
$labels['aug'] = 'Elo';
$labels['sep'] = 'Syys';
$labels['oct'] = 'Loka';
$labels['nov'] = 'Marras';
$labels['dec'] = 'Joulu';
$labels['longjan'] = 'Tammikuu';
$labels['longfeb'] = 'Helmikuu';
$labels['longmar'] = 'Maaliskuu';
$labels['longapr'] = 'Huhtikuu';
$labels['longmay'] = 'Toukokuu';
$labels['longjun'] = 'Kesäkuu';
$labels['longjul'] = 'Heinäkuu';
$labels['longaug'] = 'Elokuu';
$labels['longsep'] = 'Syyskuu';
$labels['longoct'] = 'Lokakuu';
$labels['longnov'] = 'Marraskuu';
$labels['longdec'] = 'Joulukuu';
$labels['today'] = 'Tänään';
$labels['checkmail'] = 'Tarkista saapuneet viestit';
$labels['writenewmessage'] = 'Kirjoita uusi viesti';
$labels['replytomessage'] = 'Vastaa viestiin';
$labels['replytoallmessage'] = 'Vastaa kaikille';
$labels['forwardmessage'] = 'Välitä viesti';
$labels['deletemessage'] = 'Poista viesti';
$labels['movemessagetotrash'] = 'Siirrä viesti roskakoriin';
$labels['printmessage'] = 'Tulosta viesti';
$labels['previousmessage'] = 'Näytä edellinen viesti';
$labels['previousmessages'] = 'Näytä edelliset viestit';
$labels['firstmessage'] = 'Näytä ensimmäinen viesti';
$labels['firstmessages'] = 'Näytä ensimmäinen viestiluettelo';
$labels['nextmessage'] = 'Näytä edellinen viesti';
$labels['nextmessages'] = 'Näytä seuraavat viestit';
$labels['lastmessage'] = 'Näytä viimeinen viesti';
$labels['lastmessages'] = 'Näytä viimeinen viestiluettelo';
$labels['backtolist'] = 'Takaisin viesteihin';
$labels['viewsource'] = 'Näytä lähdekoodi';
$labels['markmessages'] = 'Merkitse viestit';
$labels['markread'] = 'luetuiksi';
$labels['markunread'] = 'ei-luetuiksi';
$labels['markflagged'] = 'korostetuiksi';
$labels['markunflagged'] = 'ei-korostetuiksi';
$labels['select'] = 'Valitse';
$labels['all'] = 'Kaikki';
$labels['none'] = 'Ei mitään';
$labels['unread'] = 'Lukemattomat';
$labels['compact'] = 'Tiivistä';
$labels['empty'] = 'Tyhjennä';
$labels['purge'] = 'Puhdista';
$labels['quota'] = 'Levytila';
$labels['unknown'] = 'tuntematon';
$labels['unlimited'] = 'rajoittamaton';
$labels['quicksearch'] = 'Pikahaku';
$labels['resetsearch'] = 'Nollaa haku';
$labels['openinextwin'] = 'Avaa uudessa ikkunassa';
$labels['compose'] = 'Viestin kirjoitus';
$labels['savemessage'] = 'Tallenna tämä luonnos';
$labels['sendmessage'] = 'Lähetä viesti';
$labels['addattachment'] = 'Liitetiedosto';
$labels['charset'] = 'Merkistö';
$labels['editortype'] = 'Editorin tyyppi';
$labels['returnreceipt'] = 'Perillesaapumisilmoitus';
$labels['checkspelling'] = 'Tarkista oikeinkirjoitus';
$labels['resumeediting'] = 'Jatka muokkausta';
$labels['revertto'] = 'Muuta takaisin';
$labels['attachments'] = 'Liitetiedostot';
$labels['upload'] = 'Lisää';
$labels['close'] = 'Sulje';
$labels['low'] = 'Matala';
$labels['lowest'] = 'Matalin';
$labels['normal'] = 'Normaali';
$labels['high'] = 'Korkea';
$labels['highest'] = 'Korkein';
$labels['nosubject'] = '(ei otsikkoa)';
$labels['showimages'] = 'Näytä kuvat';
$labels['alwaysshow'] = 'Näytä aina lähettäjältä $sender saapuneet kuvat';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Tavallinen teksti';
$labels['savesentmessagein'] = 'Tallenna lähetetty viesti kansioon';
$labels['dontsave'] = 'Älä tallenna';
$labels['maxuploadsize'] = 'Suurin sallittu tiedostokoko on $size';
$labels['addcc'] = 'Lisää kopio';
$labels['addbcc'] = 'Lisää piilokopio';
$labels['addreplyto'] = 'Lisää vastausosoite';
$labels['mdnrequest'] = 'Viestin lähettäjä on pyytänyt kuittauksen siitä että olet lukenut viestin. Haluatko lähettää kuittauksen?';
$labels['receiptread'] = 'Lukukuittaus';
$labels['yourmessage'] = 'Tämä viesti on kuittaus lähettämällesi viestille';
$labels['receiptnote'] = 'Huom! Kuittaus tarkoittaa vain sitä, että viesti on avattu vastaanottajan tietokoneella. Se ei tarkoita että vastaanottaja on myös lukenut tai ymmärtänyt viestin.';
$labels['name'] = 'Näkyvä nimi';
$labels['firstname'] = 'Etunimi';
$labels['surname'] = 'Sukunimi';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Lisää valittu kontakti osoitekirjaan';
$labels['editcontact'] = 'Muokkaa kontaktia';
$labels['edit'] = 'Muokkaa';
$labels['cancel'] = 'Peruuta';
$labels['save'] = 'Tallenna';
$labels['delete'] = 'Poista';
$labels['newcontact'] = 'Luo uusi kontakti';
$labels['deletecontact'] = 'Poista valitut kontaktit';
$labels['composeto'] = 'Kirjoita viesti kontaktille';
$labels['contactsfromto'] = 'Kontaktit $from-$to/$count';
$labels['print'] = 'Tulosta';
$labels['export'] = 'Vie (export)';
$labels['exportvcards'] = 'Vie kontaktit vCard-muodossa';
$labels['previouspage'] = 'Näytä edellinen luettelo';
$labels['firstpage'] = 'Näytä ensimmäinen luettelo';
$labels['nextpage'] = 'Näytä seuraava luettelo';
$labels['lastpage'] = 'Näytä viimeinen luettelo';
$labels['groups'] = 'Ryhmät';
$labels['personaladrbook'] = 'Henkilökohtaiset osoitteet';
$labels['import'] = 'Tuo';
$labels['importcontacts'] = 'Tuo yhteystiedot';
$labels['importfromfile'] = 'Tuo tiedostosta:';
$labels['importreplace'] = 'Korvaa koko osoitekirja';
$labels['importtext'] = 'Voit lähettää yhteystietoja muista osoitekirjoistna.Kontaktien tuomine on hetkellä mahdollista vCard-muodossa.';
$labels['done'] = 'Valmis';
$labels['settingsfor'] = 'Asetukset';
$labels['preferences'] = 'Asetukset';
$labels['userpreferences'] = 'Käyttäjän asetukset';
$labels['editpreferences'] = 'Muokkaa käyttäjän asetuksia';
$labels['identities'] = 'Identiteetit';
$labels['manageidentities'] = 'Muokkaa tunnuksen identiteettejä';
$labels['newidentity'] = 'Uusi identiteetti';
$labels['newitem'] = 'Uusi';
$labels['edititem'] = 'Muokkaa';
$labels['setdefault'] = 'Aseta vakioksi';
$labels['autodetect'] = 'Automaattinen';
$labels['language'] = 'Kieli';
$labels['timezone'] = 'Aikavyöhyke';
$labels['pagesize'] = 'Rivejä sivulla';
$labels['signature'] = 'Allekirjoitus';
$labels['dstactive'] = 'Kesäaika';
$labels['htmleditor'] = 'Kirjoita HTML-muodossa';
$labels['htmlsignature'] = 'HTML-allekirjoitus';
$labels['previewpane'] = 'Näytä esikatselulehti';
$labels['skin'] = 'Käyttöliittymän teema';
$labels['logoutclear'] = 'Tyhjennä roskakori ulos kirjautuessa';
$labels['logoutcompact'] = 'Tiivistä kansiot ulos kirjautuessa';
$labels['uisettings'] = 'Käyttöliittymä';
$labels['serversettings'] = 'Palvelinasetukset';
$labels['mailboxview'] = 'Postilaatikkonäkymä';
$labels['mdnrequests'] = 'Lähettäjän kuittaukset';
$labels['askuser'] = 'kysy käyttäjältä';
$labels['autosend'] = 'lähetä automaattisesti';
$labels['ignore'] = 'jätä huomiotta';
$labels['readwhendeleted'] = 'Merkitse poistettavat viestit luetuiksi';
$labels['flagfordeletion'] = 'Poistamisen sijaan, merkitse viestit poistettavaksi';
$labels['skipdeleted'] = 'Älä näytä poistettuja viestejä';
$labels['showinlineimages'] = 'Näytä liitekuvat viestin jälkeen';
$labels['autosavedraft'] = 'Tallenna luonnos automaattisesti';
$labels['everynminutes'] = '$n minuutin välein';
$labels['never'] = 'ei koskaan';
$labels['messagesdisplaying'] = 'Viestien näyttäminen';
$labels['messagescomposition'] = 'Viestien kirjoittaminen';
$labels['mimeparamfolding'] = 'Liitetiedostojen nimet';
$labels['2231folding'] = 'Täysin RFC 2231 mukainen (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 mukainen (MS Outlook)';
$labels['2047folding'] = 'Täysin RFC 2047 mukainen (muut)';
$labels['advancedoptions'] = 'Lisäasetukset';
$labels['folder'] = 'Kansio';
$labels['folders'] = 'Kansiot';
$labels['foldername'] = 'Kansion nimi';
$labels['subscribed'] = 'Näytetään';
$labels['messagecount'] = 'Viestejä';
$labels['create'] = 'Luo uusi';
$labels['createfolder'] = 'Luo uusi kansio';
$labels['rename'] = 'Nimeä uudelleen';
$labels['renamefolder'] = 'Nimeä kansio uudelleen';
$labels['deletefolder'] = 'Poista kansio';
$labels['managefolders'] = 'Kansioiden hallinta';
$labels['specialfolders'] = 'Erikoiskansiot';
$labels['sortby'] = 'Järjestä';
$labels['sortasc'] = 'Järjestä nousevasti (a-ö)';
$labels['sortdesc'] = 'Järjestä laskevasti (ö-a)';
$labels['B'] = 't';
$labels['KB'] = 'Kt';
$labels['MB'] = 'Mt';
$labels['GB'] = 'Gt';

?>
