<?php

/*

+-----------------------------------------------------------------------+
| language/da/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Martin Moeller <martin@liga.dk>                               |
|         Jesper R. Meyer <jrm@upthere.dk>                              |
|         Søren Aggeboe <soren@aggeboe.dk>                              |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Velkommen til $product';
$labels['username'] = 'Brugernavn';
$labels['password'] = 'Adgangskode';
$labels['server'] = 'Server';
$labels['login'] = 'Log på';
$labels['logout'] = 'Log af';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Personlige indstillinger';
$labels['addressbook'] = 'Adressebog';
$labels['inbox'] = 'Indbakke';
$labels['drafts'] = 'Kladder';
$labels['sent'] = 'Sendt post';
$labels['trash'] = 'Skrald';
$labels['junk'] = 'Ragelse';
$labels['subject'] = 'Emne';
$labels['from'] = 'Afsender';
$labels['to'] = 'Modtager';
$labels['cc'] = 'Kopi til';
$labels['bcc'] = 'BCC';
$labels['replyto'] = 'Svar til';
$labels['date'] = 'Dato';
$labels['size'] = 'Størrelse';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organisation';
$labels['reply-to'] = 'Svar til';
$labels['mailboxlist'] = 'Mapper';
$labels['messagesfromto'] = 'Beskeder $from til $to af $count';
$labels['messagenrof'] = 'Besked $nr af $count';
$labels['moveto'] = 'flyt til...';
$labels['download'] = 'download';
$labels['filename'] = 'Filnavn';
$labels['filesize'] = 'Filstørrelse';
$labels['preferhtml'] = 'Foretræk HTML';
$labels['htmlmessage'] = 'HTML-besked';
$labels['prettydate'] = 'Pæn datovisning';
$labels['addtoaddressbook'] = 'Tilføj til adressebogen';
$labels['sun'] = 'Søn';
$labels['mon'] = 'Man';
$labels['tue'] = 'Tir';
$labels['wed'] = 'Ons';
$labels['thu'] = 'Tor';
$labels['fri'] = 'Fre';
$labels['sat'] = 'Lør';
$labels['sunday'] = 'Søndag';
$labels['monday'] = 'Mandag';
$labels['tuesday'] = 'Tirsdag';
$labels['wednesday'] = 'Onsdag';
$labels['thursday'] = 'Torsdag';
$labels['friday'] = 'Fredag';
$labels['saturday'] = 'Lørdag';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Maj';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Januar';
$labels['longfeb'] = 'Februar';
$labels['longmar'] = 'Marts';
$labels['longapr'] = 'April';
$labels['longmay'] = 'Maj';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'Juli';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Oktober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'December';
$labels['today'] = 'I dag';
$labels['checkmail'] = 'Se efter nye beskeder';
$labels['writenewmessage'] = 'Skriv en ny besked';
$labels['replytomessage'] = 'Svar på denne besked';
$labels['replytoallmessage'] = 'Svar til alle modtagere';
$labels['forwardmessage'] = 'Videresend denne besked';
$labels['deletemessage'] = 'Slet besked';
$labels['movemessagetotrash'] = 'Flyt besked til skrald';
$labels['printmessage'] = 'Udskriv denne besked';
$labels['previousmessage'] = 'Vis forrige besked';
$labels['previousmessages'] = 'Vis forrige sæt beskeder';
$labels['firstmessage'] = 'Vis første besked';
$labels['firstmessages'] = 'Vis første sæt beskeder';
$labels['nextmessage'] = 'Vis næste besked';
$labels['nextmessages'] = 'Vis næste sæt beskeder';
$labels['lastmessage'] = 'Vis sidste besked';
$labels['lastmessages'] = 'Vis sidste sæt beskeder';
$labels['backtolist'] = 'Tilbage til beskedlisten';
$labels['viewsource'] = 'Vis rå besked';
$labels['markmessages'] = 'Markér beskeder';
$labels['markread'] = 'Som læst';
$labels['markunread'] = 'Som ulæst';
$labels['markflagged'] = 'Som markeret';
$labels['markunflagged'] = 'Som umarkeret';
$labels['select'] = 'Vælg';
$labels['all'] = 'Alle';
$labels['none'] = 'Ingen';
$labels['unread'] = 'Ulæste';
$labels['compact'] = 'Ryd op';
$labels['empty'] = 'Tøm';
$labels['purge'] = 'Udrens';
$labels['quota'] = 'Disk forbrug';
$labels['unknown'] = 'ukendt';
$labels['unlimited'] = 'ubegrænset';
$labels['quicksearch'] = 'Hurtigsøgning';
$labels['resetsearch'] = 'Nulstil søgning';
$labels['openinextwin'] = 'Åbn i nyt vindue';
$labels['compose'] = 'Forfat en besked';
$labels['savemessage'] = 'Gem denne kladde';
$labels['sendmessage'] = 'Send beskeden nu';
$labels['addattachment'] = 'Vedhæft en fil';
$labels['charset'] = 'Tegnsæt';
$labels['editortype'] = 'Tekstbehandler';
$labels['returnreceipt'] = 'Anmod om kvittering';
$labels['checkspelling'] = 'Stavekontrol';
$labels['resumeediting'] = 'Genoptag redigering';
$labels['revertto'] = 'Vend tilbage til';
$labels['attachments'] = 'Vedhæftninger';
$labels['upload'] = 'Upload';
$labels['close'] = 'Luk';
$labels['low'] = 'Lav';
$labels['lowest'] = 'Lavest';
$labels['normal'] = 'Normal';
$labels['high'] = 'Høj';
$labels['highest'] = 'Højest';
$labels['nosubject'] = '(intet emne)';
$labels['showimages'] = 'Vis billeder';
$labels['alwaysshow'] = 'Vis altid billeder fra $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Almindelig tekst';
$labels['savesentmessagein'] = 'Gem afsendt besked i';
$labels['dontsave'] = 'gem ikke';
$labels['maxuploadsize'] = 'Maksimale tilladte filstørrelse er $size';
$labels['addcc'] = 'Tilføj Cc';
$labels['addbcc'] = 'Tilføj Bcc';
$labels['addreplyto'] = 'Tilføj Svar-Til adresse';
$labels['mdnrequest'] = 'Afsenderen af denne besked har bedt om at modtage en bekræftelse når du læser beskeden. Vil du sende kvittering for læsning?';
$labels['receiptread'] = 'Send kvittering for læsning';
$labels['yourmessage'] = 'Dette er en kvittering for at din besked er blevet vist';
$labels['receiptnote'] = 'Bemærk: Denne kvittering bekræfter udelukkende at beskeden blev vist på modtagerens computer. Der er ingen garanti for at modtageren har læst eller forstået beskedens indhold.';
$labels['name'] = 'Vist navn';
$labels['firstname'] = 'Fornavn';
$labels['surname'] = 'Efternavn';
$labels['email'] = 'E-mail';
$labels['addcontact'] = 'Tilføj en ny kontakt';
$labels['editcontact'] = 'Redigér kontakt';
$labels['edit'] = 'Redigér';
$labels['cancel'] = 'Afbryd';
$labels['save'] = 'Gem';
$labels['delete'] = 'Slet';
$labels['newcontact'] = 'Opret nyt kontaktkort';
$labels['deletecontact'] = 'Slet valgte kontakter';
$labels['composeto'] = 'Skriv brev til';
$labels['contactsfromto'] = 'Kontakter $from til $to af $count';
$labels['print'] = 'Print';
$labels['export'] = 'Eksport';
$labels['exportvcards'] = 'Eksportér kontakter i vCard format';
$labels['previouspage'] = 'Vis forrige sæt';
$labels['firstpage'] = 'Vis første sæt';
$labels['nextpage'] = 'Vis næste sæt';
$labels['lastpage'] = 'Vis sidste sæt';
$labels['groups'] = 'Grupper';
$labels['personaladrbook'] = 'Personlige Adresser';
$labels['import'] = 'Importér';
$labels['importcontacts'] = 'Importér kontakter';
$labels['importfromfile'] = 'Importér fra fil:';
$labels['importreplace'] = 'Overskriv hele adressebogen';
$labels['importtext'] = 'Du kan uploade kontakter fra en eksisterende adressebog.Vi understøtter i øjeblikket import af adresser i vCard formatet.';
$labels['done'] = 'Færdig';
$labels['settingsfor'] = 'Indstillinger for';
$labels['preferences'] = 'Præferencer';
$labels['userpreferences'] = 'Brugerpræferencer';
$labels['editpreferences'] = 'Redigér brugerpræferencer';
$labels['identities'] = 'Identiteter';
$labels['manageidentities'] = 'Styr identiteterne for denne konto';
$labels['newidentity'] = 'Ny identitet';
$labels['newitem'] = 'Nyt punkt';
$labels['edititem'] = 'Redigér punkt';
$labels['setdefault'] = 'Sæt standard';
$labels['autodetect'] = 'Automatisk';
$labels['language'] = 'Sprog';
$labels['timezone'] = 'Tidszone';
$labels['pagesize'] = 'Rækker per side';
$labels['signature'] = 'Signatur';
$labels['dstactive'] = 'Sommertid';
$labels['htmleditor'] = 'Skriv HTML-besked';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['previewpane'] = 'Forhåndsvisning';
$labels['skin'] = 'Interface skin';
$labels['logoutclear'] = 'Tøm Skrald når jeg logger af';
$labels['logoutcompact'] = 'Komprimér Indbakke når jeg logger af';
$labels['uisettings'] = 'Brugerinterface';
$labels['serversettings'] = 'Serverindstillinger';
$labels['askuser'] = 'spørg brugeren';
$labels['autosend'] = 'send automatisk';
$labels['ignore'] = 'ignorér';
$labels['readwhendeleted'] = 'Markér beskeden som læst ved sletning';
$labels['skipdeleted'] = 'Skjul slettede beskeder';
$labels['showinlineimages'] = 'Vis vedhæftede billeder under beskeden';
$labels['autosavedraft'] = 'Gem kladde automatisk';
$labels['everynminutes'] = 'hver $n. minut';
$labels['never'] = 'aldrig';
$labels['messagesdisplaying'] = 'Viser beskeder';
$labels['messagescomposition'] = 'Skriver nye beskeder';
$labels['mimeparamfolding'] = 'Navne på vedhæftninger';
$labels['2231folding'] = 'Fuld RFC 2231 understøttelse (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 understøttelse (MS Outlook)';
$labels['2047folding'] = 'Fuld RFC 2047 understøttelse (andre)';
$labels['advancedoptions'] = 'Advancerede muligheder';
$labels['folder'] = 'Mappe';
$labels['folders'] = 'Mapper';
$labels['foldername'] = 'Mappenavn';
$labels['subscribed'] = 'Abonneret';
$labels['messagecount'] = 'Beskeder';
$labels['create'] = 'Opret';
$labels['createfolder'] = 'Opret ny mappe';
$labels['rename'] = 'Omdøb';
$labels['renamefolder'] = 'Omdøb mappe';
$labels['deletefolder'] = 'Slet mappe';
$labels['managefolders'] = 'Administrér mapper';
$labels['specialfolders'] = 'Specielle mapper';
$labels['sortby'] = 'Sortér efter';
$labels['sortasc'] = 'Ældste først';
$labels['sortdesc'] = 'Nyeste først';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
