<?php

/*

 +-----------------------------------------------------------------------+
 | language/uk/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Natali Stasyuk <natali@onlineua.net>                          |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$labels = array();
$labels['welcome'] = 'Ласкаво просимо в $product!';
$labels['username'] = 'Ім`я користувача';
$labels['password'] = 'Пароль';
$labels['server'] = 'Сервер';
$labels['login'] = 'Увійти';
$labels['logout'] = 'Вийти';
$labels['mail'] = 'Пошта';
$labels['settings'] = 'Налаштування';
$labels['addressbook'] = 'Контакти';
$labels['inbox'] = 'Вхідні';
$labels['drafts'] = 'Чернетки';
$labels['sent'] = 'Відправлені';
$labels['trash'] = 'Смітник';
$labels['junk'] = 'Спам';
$labels['subject'] = 'Тема';
$labels['from'] = 'Від';
$labels['to'] = 'Кому';
$labels['cc'] = 'Копія';
$labels['bcc'] = 'Прихована';
$labels['replyto'] = 'Зворотня адреса';
$labels['date'] = 'Дата';
$labels['size'] = 'Розмір';
$labels['priority'] = 'Пріоритет';
$labels['organization'] = 'Організація';
$labels['reply-to'] = 'Зворотня адреса';
$labels['mailboxlist'] = 'Теки';
$labels['messagesfromto'] = 'Повідомлення з $from по $to із $count';
$labels['messagenrof'] = 'Повідомлення $nr із $count';
$labels['moveto'] = 'Перемістити у...';
$labels['download'] = 'Завантажити';
$labels['filename'] = 'Ім`я файлу';
$labels['filesize'] = 'Розмір файлу';
$labels['preferhtml'] = 'Переважно HTML';
$labels['htmlmessage'] = 'Повідомлення HTML';
$labels['prettydate'] = 'Красиві дати';
$labels['addtoaddressbook'] = 'Додати до контактів';
$labels['sun'] = 'Нд';
$labels['mon'] = 'Пн';
$labels['tue'] = 'Вт';
$labels['wed'] = 'Ср';
$labels['thu'] = 'Чт';
$labels['fri'] = 'Пт';
$labels['sat'] = 'Сб';
$labels['sunday'] = 'Неділя';
$labels['monday'] = 'Понеділок';
$labels['tuesday'] = 'Вівторок';
$labels['wednesday'] = 'Середа';
$labels['thursday'] = 'Четвер';
$labels['friday'] = 'П`ятниця';
$labels['saturday'] = 'Субота';
$labels['today'] = 'Сьогодні';
$labels['checkmail'] = 'Перевірити пошту';
$labels['writenewmessage'] = 'Нове повідомлення';
$labels['replytomessage'] = 'Відповісти';
$labels['replytoallmessage'] = 'Відповісти усім';
$labels['forwardmessage'] = 'Переслати';
$labels['deletemessage'] = 'У смітник';
$labels['movemessagetotrash'] = 'Перемістити повідомлення у смітник';
$labels['printmessage'] = 'Друкувати';
$labels['previousmessage'] = 'Показати попереднє повідомлення';
$labels['previousmessages'] = 'Попередня сторінка повідомлень';
$labels['firstmessage'] = 'Показати перше повідомлення';
$labels['firstmessages'] = 'Перша сторінка повідомлень';
$labels['nextmessage'] = 'Показати наступне повідомлення';
$labels['nextmessages'] = 'Наступна сторінка повідомлень';
$labels['lastmessage'] = 'Показати останнє повідомлення';
$labels['lastmessages'] = 'Остання сторінка повідомлень';
$labels['backtolist'] = 'До переліку повідомлень';
$labels['viewsource'] = 'Вихідний текст';
$labels['select'] = 'Вибрати';
$labels['all'] = 'Все';
$labels['none'] = 'Нічого';
$labels['unread'] = 'Непрочитані';
$labels['compact'] = 'Стиснути';
$labels['empty'] = 'Спустошити';
$labels['purge'] = 'Очистити';
$labels['quota'] = 'Квота';
$labels['unknown'] = 'невідомо';
$labels['unlimited'] = 'без обмеження';
$labels['quicksearch'] = 'Швидкий пошук';
$labels['resetsearch'] = 'Очистити пошук';
$labels['compose'] = 'Написати повідомлення';
$labels['savemessage'] = 'Зберегти чернетку';
$labels['sendmessage'] = 'Відіслати зараз';
$labels['addattachment'] = 'Додати вкладення';
$labels['charset'] = 'Набір символів';
$labels['editortype'] = 'Редактор';
$labels['returnreceipt'] = 'Запит відповіді';
$labels['checkspelling'] = 'Перевірити орфографію';
$labels['resumeediting'] = 'Продовжити редагування';
$labels['revertto'] = 'Відмінити правки';
$labels['attachments'] = 'Вкладення';
$labels['upload'] = 'Завантажити';
$labels['close'] = 'Закрити';
$labels['low'] = 'Низький';
$labels['lowest'] = 'Найнижчий';
$labels['normal'] = 'Нормальний';
$labels['high'] = 'Високий';
$labels['highest'] = 'Найвищий';
$labels['nosubject'] = '(без теми)';
$labels['showimages'] = 'Показати зображення';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Звичайний текст';
$labels['addcc'] = 'Додати Cc';
$labels['addbcc'] = 'Додати Bcc';
$labels['addreplyto'] = 'Додати Reply-To';
$labels['name'] = 'Відображуване ім`я';
$labels['firstname'] = 'Ім`я';
$labels['surname'] = 'Прізвище';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Додати вибрані контакти до списку контактів';
$labels['editcontact'] = 'Редагувати контакт';
$labels['edit'] = 'Правка';
$labels['cancel'] = 'Відміна';
$labels['save'] = 'Зберегти';
$labels['delete'] = 'Видалити';
$labels['newcontact'] = 'Створити новий контакт';
$labels['deletecontact'] = 'Видалити вибрані контакти';
$labels['composeto'] = 'Створити повідомлення для вибранних контактів';
$labels['contactsfromto'] = 'Контакти з $from по $to з $count';
$labels['print'] = 'Друкувати';
$labels['export'] = 'Експортувати';
$labels['previouspage'] = 'Показати попередній';
$labels['firstpage'] = 'Показати перший';
$labels['nextpage'] = 'Показати наступний';
$labels['lastpage'] = 'Показати останній';
$labels['groups'] = 'Групи';
$labels['personaladrbook'] = 'Персональні адреси';
$labels['settingsfor'] = 'Налаштування для';
$labels['preferences'] = 'Уподобання';
$labels['userpreferences'] = 'Уподобання користувача';
$labels['editpreferences'] = 'Редагувати уподобання користувача';
$labels['identities'] = 'Профілі';
$labels['manageidentities'] = 'Керування профілями';
$labels['newidentity'] = 'Новий профіль';
$labels['newitem'] = 'Новий';
$labels['edititem'] = 'Правка';
$labels['setdefault'] = 'Використовувати типово';
$labels['language'] = 'Мова';
$labels['timezone'] = 'Часовий пояс';
$labels['pagesize'] = 'Рядків на сторінці';
$labels['signature'] = 'Підпис';
$labels['dstactive'] = 'Літній/зимовий час';
$labels['htmleditor'] = 'Створювати повідомлення в HTML';
$labels['htmlsignature'] = 'Підпис в HTML';
$labels['previewpane'] = 'Показати панель перегляду';
$labels['autosavedraft'] = 'Автозбереження чернетки';
$labels['everynminutes'] = 'кожні $n хвилин';
$labels['never'] = 'ніколи';
$labels['folder'] = 'Тека';
$labels['folders'] = 'Теки';
$labels['foldername'] = 'Назва теки';
$labels['subscribed'] = 'Підписані';
$labels['create'] = 'Створити';
$labels['createfolder'] = 'Створити нову теку';
$labels['rename'] = 'Перейменувати';
$labels['renamefolder'] = 'Перейменувати теку';
$labels['deletefolder'] = 'Видалити теку';
$labels['managefolders'] = 'Керування теками';
$labels['sortby'] = 'Відсортувати за';
$labels['sortasc'] = 'Сортувати за зростанням';
$labels['sortdesc'] = 'Сортувати за спаданням';

?>