<?php

/*

+-----------------------------------------------------------------------+
| language/ar_SA/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Ossama Khayat <okhayat@yahoo.com>                             |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'مرحباً بكم في $product';
$labels['username'] = 'اسم المستخدم';
$labels['password'] = 'كلمة المرور';
$labels['server'] = 'الخادم';
$labels['login'] = 'تسجيل الدخول';
$labels['logout'] = 'تسجيل الخروج';
$labels['mail'] = 'البريد';
$labels['settings'] = 'الإعدادات الشخصية';
$labels['addressbook'] = 'دفتر العناوين';
$labels['inbox'] = 'الوارد';
$labels['drafts'] = 'المسودات';
$labels['sent'] = 'المرسل';
$labels['trash'] = 'المهملات';
$labels['junk'] = 'غير المرغوب';
$labels['subject'] = 'الموضوع';
$labels['from'] = 'المرسل';
$labels['to'] = 'المستقبل';
$labels['cc'] = 'نسخة';
$labels['bcc'] = 'نسخة مخفية';
$labels['replyto'] = 'الرد إلى';
$labels['date'] = 'التاريخ';
$labels['size'] = 'الحجم';
$labels['priority'] = 'الأولوية';
$labels['organization'] = 'المنظمة';
$labels['reply-to'] = 'الرد إلى';
$labels['mailboxlist'] = 'المجلدات';
$labels['messagesfromto'] = 'الرسالة $from إلى $to من $count';
$labels['messagenrof'] = 'الرسالة $nr من $count';
$labels['moveto'] = 'نقل إلى...';
$labels['download'] = 'تنزيل';
$labels['filename'] = 'اسم الملف';
$labels['filesize'] = 'حجم الملف';
$labels['preferhtml'] = 'تفضيل صيغة HTML';
$labels['htmlmessage'] = 'رسالة بنسق HTML';
$labels['prettydate'] = 'تواريخ منمقة';
$labels['addtoaddressbook'] = 'إضافة إلى دفتر العناوين';
$labels['sun'] = 'أح';
$labels['mon'] = 'إث';
$labels['tue'] = 'ثل';
$labels['wed'] = 'أر';
$labels['thu'] = 'خم';
$labels['fri'] = 'جم';
$labels['sat'] = 'سب';
$labels['sunday'] = 'الأحد';
$labels['monday'] = 'الإثنين';
$labels['tuesday'] = 'الثلاثاء';
$labels['wednesday'] = 'الأربعاء';
$labels['thursday'] = 'الخميس';
$labels['friday'] = 'الجمعة';
$labels['saturday'] = 'السبت';
$labels['jan'] = 'ينا';
$labels['feb'] = 'فبر';
$labels['mar'] = 'مار';
$labels['apr'] = 'أبر';
$labels['may'] = 'ماي';
$labels['jun'] = 'يون';
$labels['jul'] = 'يول';
$labels['aug'] = 'أغس';
$labels['sep'] = 'سبت';
$labels['oct'] = 'أكت';
$labels['nov'] = 'نوف';
$labels['dec'] = 'ديس';
$labels['longjan'] = 'يناير';
$labels['longfeb'] = 'فبراير';
$labels['longmar'] = 'مارس';
$labels['longapr'] = 'أبريل';
$labels['longmay'] = 'مايو';
$labels['longjun'] = 'يونيو';
$labels['longjul'] = 'يوليو';
$labels['longaug'] = 'أغسطس';
$labels['longsep'] = 'سبتمبر';
$labels['longoct'] = 'أكتوبر';
$labels['longnov'] = 'نوفمبر';
$labels['longdec'] = 'ديسمبر';
$labels['today'] = 'اليوم';
$labels['checkmail'] = 'التحقق من وجود رسائل جديدة';
$labels['writenewmessage'] = 'إنشاء رسالة جديدة';
$labels['replytomessage'] = 'الرد على الرسالة';
$labels['replytoallmessage'] = 'الرد على المرسل وجميع مستقبلي الرسالة';
$labels['forwardmessage'] = 'تمرير الرسالة';
$labels['deletemessage'] = 'حذف الرسالة إلى المهملات';
$labels['movemessagetotrash'] = 'انقل الرسالة إلى سلة المهملات';
$labels['printmessage'] = 'طباعة هذه الرسالة';
$labels['previousmessage'] = 'عرض الرسالة السابقة';
$labels['previousmessages'] = 'عرض المجموعة السابقة من الرسائل';
$labels['firstmessage'] = 'عرض الرسالة الأولى';
$labels['firstmessages'] = 'عرض مجموعة الرسائل الأولى';
$labels['nextmessage'] = 'عرض الرسالة التالية';
$labels['nextmessages'] = 'عرض المجموعة التالية من الرسائل';
$labels['lastmessage'] = 'عرض الرسالة الأخيرة';
$labels['lastmessages'] = 'عرض مجموعة الرسائل الأخيرة';
$labels['backtolist'] = 'العودة إلى لائحة الرسائل';
$labels['viewsource'] = 'إظهار المصدر';
$labels['markmessages'] = 'وسم الرسالة';
$labels['markread'] = 'كمقروءة';
$labels['markunread'] = 'كغير مقروءة';
$labels['markflagged'] = 'كموْسومة';
$labels['markunflagged'] = 'كغير موْسومة';
$labels['select'] = 'تحديد';
$labels['all'] = 'الكل';
$labels['none'] = 'لا شيء';
$labels['unread'] = 'غير المقروءة';
$labels['compact'] = 'ضغط';
$labels['empty'] = 'تفريغ';
$labels['purge'] = 'إزالة';
$labels['quota'] = 'المساحة المستخدمة';
$labels['unknown'] = 'مجهول';
$labels['unlimited'] = 'غير محدود';
$labels['quicksearch'] = 'البحث السريع';
$labels['resetsearch'] = 'استعادة البحث للافتراضي';
$labels['openinextwin'] = 'افتح في نافذة جديدة';
$labels['compose'] = 'إنشاء رسالة';
$labels['savemessage'] = 'حفظ هذه المسودة';
$labels['sendmessage'] = 'إرسال الرسالة الآن';
$labels['addattachment'] = 'إرفاق ملف';
$labels['charset'] = 'مجموعة المحارف';
$labels['editortype'] = 'نوع المُحرّر';
$labels['returnreceipt'] = 'ايصال استلام';
$labels['checkspelling'] = 'التدقيق الإملائي';
$labels['resumeediting'] = 'متابعة التحرير';
$labels['revertto'] = 'استعادة إلى';
$labels['attachments'] = 'مرفقات';
$labels['upload'] = 'تحميل';
$labels['close'] = 'إغلاق';
$labels['low'] = 'منخض';
$labels['lowest'] = 'الأقل';
$labels['normal'] = 'عادي';
$labels['high'] = 'مرتفع';
$labels['highest'] = 'الأعلى';
$labels['nosubject'] = '(دون موضوع)';
$labels['showimages'] = 'إظهار الصور';
$labels['alwaysshow'] = 'دائماً أظهر الصّور القادمة من $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'نص مجرد';
$labels['savesentmessagein'] = 'احفظ الرسالة المُرسلة في';
$labels['dontsave'] = 'لا تحفظها';
$labels['maxuploadsize'] = 'أقصى حجم للملف هو $size';
$labels['addcc'] = 'أضف CC';
$labels['addbcc'] = 'أضف BCC';
$labels['addreplyto'] = 'أضيف Reply-To';
$labels['mdnrequest'] = 'طلب المرسل إعلامه عند قراءتك لرسالته. هل تود إعلام المرسل؟';
$labels['receiptread'] = 'إيصال الاستلام )بالقراءة)';
$labels['yourmessage'] = 'هذا إيصال بقراءة رسالتك';
$labels['receiptnote'] = 'ملاحظة: يُعلمك هذا الإيصال بأن رسالتك قد ظهرت على جهاز المستقبِل. ليست هناك أية ضمانات أن المستقبل قد قرأ أو فهم محتويات الرسالة.';
$labels['name'] = 'اسم العرض';
$labels['firstname'] = 'الإسم الأول';
$labels['surname'] = 'الإسم الأخير';
$labels['email'] = 'البريد الإلكتروني';
$labels['addcontact'] = 'إضافة المراسل المحدد إلى دفتر عناويني';
$labels['editcontact'] = 'تحرير بيانات المراسل';
$labels['edit'] = 'تحرير';
$labels['cancel'] = 'إلغاء';
$labels['save'] = 'حفظ';
$labels['delete'] = 'حذف';
$labels['newcontact'] = 'إنشاء بطاقة مراسل جديدة';
$labels['deletecontact'] = 'حذف المراسلين المحددين';
$labels['composeto'] = 'إنشاء رسالة إليه';
$labels['contactsfromto'] = 'المراسلون $from إلى $to من $count';
$labels['print'] = 'طباعة';
$labels['export'] = 'تصدير';
$labels['exportvcards'] = 'صدّر المراسلين بنسق vCard';
$labels['previouspage'] = 'عرض المجموعة السابقة';
$labels['firstpage'] = 'عرض المجموعة الأولى';
$labels['nextpage'] = 'عرض المجموعة التالية';
$labels['lastpage'] = 'عرض المجموعة الأخيرة';
$labels['groups'] = 'المجموعات';
$labels['personaladrbook'] = 'العناوين الشخصية';
$labels['import'] = 'استورد';
$labels['importcontacts'] = 'استورد المراسلين';
$labels['importfromfile'] = 'استورد من ملف:';
$labels['importreplace'] = 'استبدل دفتر العناوين بأكمله';
$labels['importtext'] = 'يمكنك رفع قائمة المراسلين من دفتر عناوين موجود.<br/>ندعم حالياً استيراد العناوين من نسق بيانات <a href="http://en.wikipedia.org/wiki/VCard">vCard</a>.';
$labels['done'] = 'تم';
$labels['settingsfor'] = 'إعدادات';
$labels['preferences'] = 'التفضيلات';
$labels['userpreferences'] = 'تفضيلات المستخدم';
$labels['editpreferences'] = 'تحرير تفضيلات المستخدم';
$labels['identities'] = 'الهويات';
$labels['manageidentities'] = 'إدارة هويات هذا الحساب';
$labels['newidentity'] = 'هوية جديدة';
$labels['newitem'] = 'عنصر جديد';
$labels['edititem'] = 'تحرير عنصر';
$labels['setdefault'] = 'تعيين كإفتراضي';
$labels['autodetect'] = 'آلي';
$labels['language'] = 'اللغة';
$labels['timezone'] = 'المنطقة الزمنية';
$labels['pagesize'] = 'أسطر في الصفحة';
$labels['signature'] = 'التوقيع';
$labels['dstactive'] = 'التوقيت الصيفي';
$labels['htmleditor'] = 'إنشاء رسائل بنسق HTML';
$labels['htmlsignature'] = 'توقيع HTML';
$labels['previewpane'] = 'إظهار قسم المعاينة';
$labels['skin'] = 'شكل الواجهة';
$labels['logoutclear'] = 'أفرغ المحذوفات عند الخروج';
$labels['logoutcompact'] = 'اضغط الوارد عن الخروج';
$labels['uisettings'] = 'واجهة المستخدم';
$labels['serversettings'] = 'إعدادات الخادم';
$labels['mailboxview'] = 'مظهر صندوق البريد';
$labels['mdnrequests'] = 'تنويهات المُرسِل';
$labels['askuser'] = 'اسأل المستخدم';
$labels['autosend'] = 'أأرسلها تلقائياً';
$labels['ignore'] = 'تجاهلها';
$labels['readwhendeleted'] = 'حدد الرسالة كمقروءة عند حذفها';
$labels['flagfordeletion'] = 'ضع علامة على الرسالة لحذفها بدلاً من حذفها';
$labels['skipdeleted'] = 'لا تظهر الرسائل المحذوفة';
$labels['showinlineimages'] = 'أظهر الصّور المرفقة أسفل الرسالة';
$labels['autosavedraft'] = 'حفظ المسودة تلقائياً';
$labels['everynminutes'] = 'كل $n دقيقة';
$labels['keepaliveevery'] = 'كل $n دقيقة';
$labels['keepalive'] = 'تحقق من وجود رسائل جديدة عند';
$labels['never'] = 'أبداً';
$labels['messagesdisplaying'] = 'إظهار الرسائل';
$labels['messagescomposition'] = 'إنشاء الرسائل';
$labels['mimeparamfolding'] = 'أسماء الملفات المرفقة';
$labels['2231folding'] = 'RFC 2231 بأكملها (ثندربيرد)';
$labels['miscfolding'] = 'RFC 2047/2231 (ميكروسوفت آوتلوك)';
$labels['2047folding'] = 'RFC 2047 بأكملها (غيرها)';
$labels['advancedoptions'] = 'خيارات متقدّمة';
$labels['focusonnewmessage'] = 'وجّه نافذة المتصفح عند وجود رسالة جديدة';
$labels['folder'] = 'مجلد';
$labels['folders'] = 'مجلدات';
$labels['foldername'] = 'اسم المجلد';
$labels['subscribed'] = 'مشترك';
$labels['messagecount'] = 'الرسائل';
$labels['create'] = 'أنشئ';
$labels['createfolder'] = 'أنشئ مجلد جديد';
$labels['rename'] = 'إعادة التسمية';
$labels['renamefolder'] = 'إعادة تسمية المجلد';
$labels['deletefolder'] = 'احذف المجلد';
$labels['managefolders'] = 'إدارة المجلدات';
$labels['specialfolders'] = 'المجلّدات المُميّزة';
$labels['sortby'] = 'ترتيب بحسب';
$labels['sortasc'] = 'ترتيب تصاعدي';
$labels['sortdesc'] = 'ترتيب تنازلي';
$labels['B'] = 'ب';
$labels['KB'] = 'ك.ب';
$labels['MB'] = 'م.ب';
$labels['GB'] = 'ج.ب';

?>
