<?php

/*

 +-----------------------------------------------------------------------+
 | language/nl_BE/messages.inc                                           |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Dennis Heeren <dennis.heeren@gmail.com>                       |
 +-----------------------------------------------------------------------+

 @version $Id: messages.inc 1108 2008-02-17 20:08:44Z thomasb $

*/

$messages = array();
$messages['loginfailed'] = 'Aanmelden mislukt...';
$messages['cookiesdisabled'] = 'Uw browser accepteert geen cookies...';
$messages['sessionerror'] = 'Sessie is reeds beëindigd of is ongeldig...';
$messages['imaperror'] = 'Kon geen verbinding maken met de IMAP server...';
$messages['nomessagesfound'] = 'Er zijn geen berichten in deze map...';
$messages['loggedout'] = 'U bent nu afgemeld. Tot ziens!';
$messages['mailboxempty'] = 'Mailbox is leeg...';
$messages['loading'] = 'Bezig met ophalen gegevens...';
$messages['loadingdata'] = 'Bezig met gegevens ophalen...';
$messages['checkingmail'] = 'Controleer op nieuwe berichten...';
$messages['sendingmessage'] = 'Bericht wordt verstuurd...';
$messages['messagesent'] = 'Het bericht is verzonden...';
$messages['savingmessage'] = 'Bericht wordt bewaard...';
$messages['messagesaved'] = 'Bericht bewaard in Concepten';
$messages['successfullysaved'] = 'Succesvol opgeslagen...';
$messages['addedsuccessfully'] = 'Contactpersoon is toegevoegd...';
$messages['contactexists'] = 'Er bestaat reeds een contactpersoon met dit e-mailadres...';
$messages['blockedimages'] = 'Om uw privacy te beschermen worden de afbeeldingen in dit bericht niet getoond...';
$messages['encryptedmessage'] = 'Dit bericht is geëncrypteerd en kan niet worden weergegeven, sorry...';
$messages['nocontactsfound'] = 'Geen contactpersonen gevonden...';
$messages['contactnotfound'] = 'De gevraagde contactpersoon was niet gevonden';
$messages['sendingfailed'] = 'Kon het bericht niet versturen...';
$messages['errorsaving'] = 'Er is een fout opgetreden bij het opslaan van het bericht...';
$messages['errormoving'] = 'Kon het bericht niet verplaatsen...';
$messages['errordeleting'] = 'Kon het bericht niet verwijderen...';
$messages['deletecontactconfirm'] = 'Bent u zeker dat u de geselecteerde contactpers(o)on(en) wilt verwijderen?';
$messages['deletemessagesconfirm'] = 'Bent u zeker dat u de geselecteerde bericht(en) wilt verwijderen?';
$messages['deletefolderconfirm'] = 'Weet u zeker dat u deze map wilt verwijderen?';
$messages['purgefolderconfirm'] = 'Bent u zeker dat u alle berichten in deze map wilt verwijderen?';
$messages['formincomplete'] = 'Het formulier is niet volledig ingevuld...';
$messages['noemailwarning'] = 'Geef een geldig e-mailadres op...';
$messages['nonamewarning'] = 'Geef een naam op...';
$messages['nopagesizewarning'] = 'Geef een geldig aantal berichten per pagina op...';
$messages['norecipientwarning'] = 'Geef minstens één bestemmeling op...';
$messages['nosubjectwarning'] = 'Geen onderwerp opgegeven. Wenst u alsnog een onderwerp te geven?';
$messages['nobodywarning'] = 'Wilt u dit lege bericht versturen?';
$messages['notsentwarning'] = 'Het bericht is niet verzonden. Wilt u het bericht verwijderen?';
$messages['noldapserver'] = 'Kies een LDAP server waarop gezocht moet worden...';
$messages['nocontactsreturned'] = 'Geen contactpersonen gevonden';
$messages['nosearchname'] = 'Geen een contacpersoon of e-mailadres op...';
$messages['searchsuccessful'] = '$nr berichten gevonden';
$messages['searchnomatch'] = 'Zoekopdracht leverde geen resultaten';
$messages['searching'] = 'Bezig met zoeken...';
$messages['checking'] = 'Bezig met controleren...';
$messages['nospellerrors'] = 'Geen spelfouten gevonden';
$messages['folderdeleted'] = 'Mappen met succes verwijderd';
$messages['deletedsuccessfully'] = 'Succesvol verwijderd';
$messages['converting'] = 'Opmaak van het bericht wordt gewist...';
$messages['messageopenerror'] = 'Kon het bericht niet ophalen van de server';
$messages['fileuploaderror'] = 'Bestandupload mislukt';
$messages['filesizeerror'] = 'Het bestand overschrijdt de maximum grootte van $size';
$messages['copysuccess'] = '$nr adressen met succes gekopiëerd';
$messages['copyerror'] = 'Kon de adressen niet kopiëren';
$messages['sourceisreadonly'] = 'Het adres kan niet worden opgeslagen';
$messages['errorsavingcontact'] = 'Kon de contactpersoon niet bewaren';
$messages['movingmessage'] = 'Bericht wordt verplaatst...';
$messages['receiptsent'] = 'Ontvangstbevestiging verstuurd';
$messages['errorsendingreceipt'] = 'Kon de ontvangstbevestigign niet versturen';
$messages['nodeletelastidentity'] = 'U kunt dit laatste afzendadres niet verwijderen.';
$messages['addsubfolderhint'] = 'De map wordt aangemaakt als submap van de geselecteerde map.';

?>
