<?php

/*

+-----------------------------------------------------------------------+
| language/ca_ES/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Miguel Canteras i Cañizares <miguel@canteras.org>             |
|         Simo <sim6@graciasensefils.net>                               |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2142 2008-12-10 19:22:22Z yllar $

*/

$labels = array();
$labels['welcome'] = 'Benvingut a $product';
$labels['username'] = 'Nom d\'usuari';
$labels['password'] = 'Contrasenya';
$labels['server'] = 'Servidor';
$labels['login'] = 'Entrar';
$labels['logout'] = 'Tancar sessió';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Configuració';
$labels['addressbook'] = 'Contactes';
$labels['inbox'] = 'Entrada';
$labels['drafts'] = 'Esborranys';
$labels['sent'] = 'Enviats';
$labels['trash'] = 'Paperera';
$labels['junk'] = 'Correu brossa';
$labels['subject'] = 'Assumpte';
$labels['from'] = 'Remitent';
$labels['to'] = 'Destinatari';
$labels['cc'] = 'CC';
$labels['bcc'] = 'BCC';
$labels['replyto'] = 'Respondre a';
$labels['date'] = 'Data';
$labels['size'] = 'Grandària';
$labels['priority'] = 'Prioritat';
$labels['organization'] = 'Organització';
$labels['reply-to'] = 'Respondre a';
$labels['mailboxlist'] = 'Carpetes';
$labels['messagesfromto'] = 'Missatges des de $from a $to de $count';
$labels['messagenrof'] = 'Missatge $nr de $count';
$labels['moveto'] = 'moure a...';
$labels['download'] = 'descarregar';
$labels['filename'] = 'Nom del fitxer';
$labels['filesize'] = 'Grandària de fitxer';
$labels['preferhtml'] = 'Preferisc HTML';
$labels['htmlmessage'] = 'Missatge HTML';
$labels['prettydate'] = 'Dates curtes';
$labels['addtoaddressbook'] = 'Afegir a contactes';
$labels['sun'] = 'DG';
$labels['mon'] = 'DL';
$labels['tue'] = 'DM';
$labels['wed'] = 'DC';
$labels['thu'] = 'DJ';
$labels['fri'] = 'DV';
$labels['sat'] = 'DS';
$labels['sunday'] = 'Diumenge';
$labels['monday'] = 'Dilluns';
$labels['tuesday'] = 'Dimarts';
$labels['wednesday'] = 'Dimecres';
$labels['thursday'] = 'Dijous';
$labels['friday'] = 'Divendres';
$labels['saturday'] = 'Dissabte';
$labels['jan'] = 'gen';
$labels['feb'] = 'feb';
$labels['mar'] = 'mar';
$labels['apr'] = 'abr';
$labels['may'] = 'mai';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'ago';
$labels['sep'] = 'set';
$labels['oct'] = 'oct';
$labels['nov'] = 'nov';
$labels['dec'] = 'des';
$labels['longjan'] = 'gener';
$labels['longfeb'] = 'febrer';
$labels['longmar'] = 'març';
$labels['longapr'] = 'abril';
$labels['longmay'] = 'maig';
$labels['longjun'] = 'juny';
$labels['longjul'] = 'juliol';
$labels['longaug'] = 'agost';
$labels['longsep'] = 'setembre';
$labels['longoct'] = 'octubre';
$labels['longnov'] = 'novembre';
$labels['longdec'] = 'desembre';
$labels['today'] = 'Avui';
$labels['checkmail'] = 'Recupera missatges nous';
$labels['writenewmessage'] = 'Crear nou missatge';
$labels['replytomessage'] = 'Respondre al missatge';
$labels['replytoallmessage'] = 'Respondre al remitent i a tots els destinataris';
$labels['forwardmessage'] = 'Reenviar missatge';
$labels['deletemessage'] = 'Eliminar missatge';
$labels['movemessagetotrash'] = 'Moure missatge a la paperera';
$labels['printmessage'] = 'Imprimir aquest missatge';
$labels['previousmessage'] = 'Mostrar el missatge anterior';
$labels['previousmessages'] = 'Mostrar missatges anteriors';
$labels['firstmessage'] = 'Mostrar el primer missatge';
$labels['firstmessages'] = 'Mostrar els primers missatges';
$labels['nextmessage'] = 'Mostrar el missatge següent';
$labels['nextmessages'] = 'Mostrar missatges següents';
$labels['lastmessage'] = 'Mostrar l\'últim missatge';
$labels['lastmessages'] = 'Mostrar els últims missatges';
$labels['backtolist'] = 'Tornar a la llista de missatges';
$labels['viewsource'] = 'Visualitza el codi font';
$labels['markmessages'] = 'Marca missatges';
$labels['markread'] = 'Com a llegits';
$labels['markunread'] = 'Com a no llegits';
$labels['markflagged'] = 'Com marcat';
$labels['markunflagged'] = 'Com no marcat';
$labels['select'] = 'Seleccionar';
$labels['all'] = 'Tots';
$labels['none'] = 'Cap';
$labels['unread'] = 'No llegits';
$labels['flagged'] = 'Marcat';
$labels['unanswered'] = 'No respost';
$labels['filter'] = 'Filtre';
$labels['compact'] = 'Compacta';
$labels['empty'] = 'Buida';
$labels['purge'] = 'Purga';
$labels['quota'] = 'Utilització de disc';
$labels['unknown'] = 'desconegut';
$labels['unlimited'] = 'il·limitat';
$labels['quicksearch'] = 'Cerca ràpida';
$labels['resetsearch'] = 'Neteja cerca';
$labels['openinextwin'] = 'Obrir a una nova finestra';
$labels['compose'] = 'Escriure un missatge';
$labels['savemessage'] = 'Desa aquest esborrany';
$labels['sendmessage'] = 'Enviar ara el missatge';
$labels['addattachment'] = 'Afegir un fitxer';
$labels['charset'] = 'Codificació de caràcters';
$labels['editortype'] = 'Tipus d\'editor';
$labels['returnreceipt'] = 'Confirmació de recepció';
$labels['checkspelling'] = 'Comprova l\'ortografia';
$labels['resumeediting'] = 'Continua l\'edició';
$labels['revertto'] = 'Tornar a';
$labels['attachments'] = 'Adjunts';
$labels['upload'] = 'Afegir';
$labels['close'] = 'Cancel·lar';
$labels['low'] = 'Baixa';
$labels['lowest'] = 'Molt baixa';
$labels['normal'] = 'Normal';
$labels['high'] = 'Alta';
$labels['highest'] = 'Molt alta';
$labels['nosubject'] = '(sense assumpte)';
$labels['showimages'] = 'Mostra imatges';
$labels['alwaysshow'] = 'Sempre mostrar imatges de $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Text pla';
$labels['savesentmessagein'] = 'Desar el missatge enviat a';
$labels['dontsave'] = 'no deseu';
$labels['maxuploadsize'] = 'El tamany màxim de fitxer és $size';
$labels['addcc'] = 'Afegir Cc';
$labels['addbcc'] = 'Afegir Bcc';
$labels['addreplyto'] = 'Afegir Reply-To';
$labels['mdnrequest'] = 'El remitent d\'aquest missatge ha demanat ser notificat quan llegeixis aquest missatge. Vols notificar al remitent?';
$labels['receiptread'] = 'Confirmació de recepció';
$labels['yourmessage'] = 'Aquesta és una confirmació de recepció per al teu missatge';
$labels['receiptnote'] = 'Nota: Aquesta confirmació solament indica que el missatge ha estat mostrat a l\'ordinador del destinatari. No hi ha garantia que el destinatari hagi llegit o entès el contingut del missatge.';
$labels['name'] = 'Nom a mostrar';
$labels['firstname'] = 'Nom';
$labels['surname'] = 'Cognom';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Afegir nou contacte';
$labels['editcontact'] = 'Editar contacte';
$labels['edit'] = 'Editar';
$labels['cancel'] = 'Cancel·lar';
$labels['save'] = 'Desar';
$labels['delete'] = 'Suprimir';
$labels['newcontact'] = 'Crear nou contacte';
$labels['deletecontact'] = 'Suprimir contactes seleccionats';
$labels['composeto'] = 'Redactar correu per a';
$labels['contactsfromto'] = 'Contactes $from a $to de $count';
$labels['print'] = 'Imprimeix';
$labels['export'] = 'Exportar';
$labels['exportvcards'] = 'Exportar contactes en format vCard';
$labels['previouspage'] = 'Mostrar anteriors';
$labels['firstpage'] = 'Mostrar primers';
$labels['nextpage'] = 'Mostrar següents';
$labels['lastpage'] = 'Mostrar últims';
$labels['groups'] = 'Grups';
$labels['personaladrbook'] = 'Llibreta d\'adreces';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contactes';
$labels['importfromfile'] = 'Importar des d\'un fitxer:';
$labels['importreplace'] = 'Reemplaçar la llibreta d\'adreçes sencera';
$labels['importtext'] = 'Podeu importar contactes des d\'una llibreta d\'adreces existent.<br/>Actualment suportem l\'importació d\'adreces amb el format <a href="http://en.wikipedia.org/wiki/VCard">vCard</a>.';
$labels['done'] = 'Fet';
$labels['settingsfor'] = 'Configuració per a';
$labels['preferences'] = 'Preferències';
$labels['userpreferences'] = 'Preferències d\'usuari';
$labels['editpreferences'] = 'Editar preferències d\'usuari';
$labels['identities'] = 'Identitats';
$labels['manageidentities'] = 'Gestionar identitats per a aquest compte';
$labels['newidentity'] = 'Nova identitat';
$labels['newitem'] = 'Nou';
$labels['edititem'] = 'Editar';
$labels['setdefault'] = 'Seleccionar opció per defecte';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Idioma';
$labels['timezone'] = 'Zona horària';
$labels['pagesize'] = 'Files per pàgina';
$labels['signature'] = 'Signatura';
$labels['dstactive'] = 'Horari d\'estiu';
$labels['htmleditor'] = 'Escriure missatges HTML';
$labels['htmlsignature'] = 'Signatura HTML';
$labels['previewpane'] = 'Mostrar el panell de previsualització';
$labels['skin'] = 'Aparença d\'interfície';
$labels['logoutclear'] = 'Esborrar la paperera al tancar sessió';
$labels['logoutcompact'] = 'Compactar la safata d\'entrada al tancar sessió';
$labels['uisettings'] = 'Interfície d\'usuari';
$labels['serversettings'] = 'Configuració del servidor';
$labels['mailboxview'] = 'Vista de la bústia';
$labels['mdnrequests'] = 'Notificacions de recepció';
$labels['askuser'] = 'Pregunta-ho a l\'usuari';
$labels['autosend'] = 'Envia-les automàticament';
$labels['ignore'] = 'Ignora-les';
$labels['readwhendeleted'] = 'Marca el missatge com a llegit quan s\'esborri';
$labels['flagfordeletion'] = 'Afegeix marca d\'esborrat en comptes d\'esborrar-lo';
$labels['skipdeleted'] = 'No mostrar els missatges esborrats';
$labels['showremoteimages'] = 'Mostrar imatges remotes sota el missatge';
$labels['fromknownsenders'] = 'de remitent conegut';
$labels['always'] = 'sempre';
$labels['showinlineimages'] = 'Mostra les imatges adjuntes sota el missatge';
$labels['autosavedraft'] = 'Desar esborrany automàticament';
$labels['everynminutes'] = 'cada $n minuts';
$labels['keepaliveevery'] = 'cada $n minut(s)';
$labels['keepalive'] = 'Comprovar nous missatges a';
$labels['never'] = 'mai';
$labels['messagesdisplaying'] = 'Vista de missatges';
$labels['messagescomposition'] = 'Composició de missatges';
$labels['mimeparamfolding'] = 'Noms dels adjunts';
$labels['2231folding'] = 'Complet RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Complet RFC 2047 (un altre)';
$labels['advancedoptions'] = 'Opcions avançades';
$labels['focusonnewmessage'] = 'Enviar el focus al navegador quan hi hagi un nou missatge';
$labels['checkallfolders'] = 'Comprovar totes les carpetes per missatges nous';
$labels['folder'] = 'Carpeta';
$labels['folders'] = 'Carpetes';
$labels['foldername'] = 'Nom de carpeta';
$labels['subscribed'] = 'Subscriure\'s';
$labels['messagecount'] = 'Missatges';
$labels['create'] = 'Crear';
$labels['createfolder'] = 'Crear nova carpeta';
$labels['rename'] = 'Canvia el nom';
$labels['renamefolder'] = 'Canvia el nom de la carpeta';
$labels['deletefolder'] = 'Suprimir carpeta';
$labels['managefolders'] = 'Gestionar carpetes';
$labels['specialfolders'] = 'Carpetes Especials';
$labels['sortby'] = 'Ordena per';
$labels['sortasc'] = 'Ordena ascendentment';
$labels['sortdesc'] = 'Ordena descendentment';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>