<?php

/*

 +-----------------------------------------------------------------------+
 | language/lv/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Rudolfs Osins <dev.random@gmail.com>                          |
 |         Mikelis Zalais <mik@prog.lv>                                  |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1093 2008-02-16 11:40:18Z tomekp $

*/

$labels = array();
$labels['welcome'] = 'Esiet laipni lūgti $product';
$labels['username'] = 'Lietotājvārds';
$labels['password'] = 'Parole';
$labels['server'] = 'Serveris';
$labels['login'] = 'Pieslēgties';
$labels['logout'] = 'Atslēgties';
$labels['mail'] = 'E-pasts';
$labels['settings'] = 'Personīgie iestatījumi';
$labels['addressbook'] = 'Adrešu grāmata';
$labels['inbox'] = 'Ienākošās';
$labels['drafts'] = 'Uzmetumi';
$labels['sent'] = 'Nosūtītās';
$labels['trash'] = 'Miskaste';
$labels['junk'] = 'Mēstules';
$labels['subject'] = 'Temats';
$labels['from'] = 'No';
$labels['to'] = 'Kam';
$labels['cc'] = 'Kopija';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Atbildēt uz';
$labels['date'] = 'Datums';
$labels['size'] = 'Izmērs';
$labels['priority'] = 'Prioritāte';
$labels['organization'] = 'Organizācija';
$labels['reply-to'] = 'Atbildēt uz';
$labels['mailboxlist'] = 'Mapes';
$labels['messagesfromto'] = 'Vēstules $from līdz $to no $count';
$labels['messagenrof'] = '$nr. vēstule  no $count';
$labels['moveto'] = 'pārvietot uz...';
$labels['download'] = 'lejupielādēt';
$labels['filename'] = 'Faila nosaukums';
$labels['filesize'] = 'Faila izmērs';
$labels['preferhtml'] = 'Dot priekšroku HTML';
$labels['htmlmessage'] = 'HTML vēstule';
$labels['prettydate'] = '"Skaists" datums';
$labels['addtoaddressbook'] = 'Pievienot adrešu grāmatai';
$labels['sun'] = 'Sv';
$labels['mon'] = 'P';
$labels['tue'] = 'O';
$labels['wed'] = 'T';
$labels['thu'] = 'C';
$labels['fri'] = 'P';
$labels['sat'] = 'Se';
$labels['sunday'] = 'Svētdiena';
$labels['monday'] = 'Pirmdiena';
$labels['tuesday'] = 'Otrdiena';
$labels['wednesday'] = 'Trešdiena';
$labels['thursday'] = 'Ceturtdiena';
$labels['friday'] = 'Piektdiena';
$labels['saturday'] = 'Sestdiena';
$labels['today'] = 'Šodien';
$labels['checkmail'] = 'Pārbaudīt pastu';
$labels['writenewmessage'] = 'Rakstīt jaunu vēstuli';
$labels['replytomessage'] = 'Atbildēt uz vēstuli';
$labels['replytoallmessage'] = 'Atbildēt sūtītājam un visiem saņēmējiem';
$labels['forwardmessage'] = 'Pārsūtīt vēstuli';
$labels['deletemessage'] = 'Dzēst vēstuli';
$labels['movemessagetotrash'] = 'Pārvietot vēstuli uz miskasti';
$labels['printmessage'] = 'Izdrukāt šo vēstuli';
$labels['previousmessage'] = 'Parādīt iepriekšējo vēstuli';
$labels['previousmessages'] = 'Parādīt iepriekšējo vēstuļu kopu';
$labels['firstmessage'] = 'Parādīt pirmo vēstuli';
$labels['firstmessages'] = 'Parādīt pirmo vēstuļu kopu';
$labels['nextmessage'] = 'Parādīt nākamo vēstuli';
$labels['nextmessages'] = 'Parādīt nākamo vēstuļu kopu';
$labels['lastmessage'] = 'Parādīt pēdējo vēstuli';
$labels['lastmessages'] = 'Parādīt pēdējo vēstuļu kopu';
$labels['backtolist'] = 'Atpakaļ uz vēstuļu sarakstu';
$labels['viewsource'] = 'Rādīt pirmtekstu';
$labels['markmessages'] = 'Atzīmēt vēstules';
$labels['markread'] = 'Kā lasītas';
$labels['markunread'] = 'Kā nelasītas';
$labels['select'] = 'Iezīmēt';
$labels['all'] = 'Visas';
$labels['none'] = 'Nevienu';
$labels['unread'] = 'Nelasītās';
$labels['compact'] = 'Saspiest';
$labels['empty'] = 'Iztukšot';
$labels['purge'] = 'Iztīrīt';
$labels['quota'] = 'Kvota';
$labels['unknown'] = 'nezināms';
$labels['unlimited'] = 'neierobežots';
$labels['quicksearch'] = 'Ārtā meklēšana';
$labels['resetsearch'] = 'Atstatīt meklēšanu';
$labels['compose'] = 'Rakstīt vēstuli';
$labels['savemessage'] = 'Saglabāt uzmetumu';
$labels['sendmessage'] = 'Sūtīt vēstuli';
$labels['addattachment'] = 'Pievienot failu';
$labels['charset'] = 'Rakstzīmju kopa';
$labels['editortype'] = 'Redaktora tips';
$labels['returnreceipt'] = 'Saņemšanas apstiprinājums';
$labels['checkspelling'] = 'Pārbaudīt pareizrakstību';
$labels['resumeediting'] = 'Turpināt rediģēšanu';
$labels['revertto'] = 'Atgriezt uz';
$labels['attachments'] = 'Pielikumi';
$labels['upload'] = 'Augšupielādēt';
$labels['close'] = 'Aizvērt';
$labels['low'] = 'Zema';
$labels['lowest'] = 'Zemākā';
$labels['normal'] = 'Normāla';
$labels['high'] = 'Augsta';
$labels['highest'] = 'Augstākā';
$labels['nosubject'] = '(no subject)';
$labels['showimages'] = 'Rādīt attēlus';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Vienkāršs teksts';
$labels['addcc'] = 'Pievienot Cc';
$labels['addbcc'] = 'Pievienot Bcc';
$labels['addreplyto'] = 'Pievienot Reply-To';
$labels['mdnrequest'] = 'Šīs vēstules sūtītājs vēlas redzēt vēstules saņemšanas apstiprinājumu. Vai jūs vēlaties nosūtīt apstiprinājumu?';
$labels['receiptread'] = 'Saņemšanas apstiprinājums';
$labels['yourmessage'] = 'Šīs ir jūsu vēstules saņemšanas apstiprinājums';
$labels['receiptnote'] = 'Piezīme: Šīs apsiprinājums nozīmē tikai to, ka vēstule tika parādīta uz saņēmāja datora. Tas nenozīmē, ka saņēmējs ir izlasījis vai izpratis vēstules saturu.';
$labels['name'] = 'Uzrādītais vārds';
$labels['firstname'] = 'Vārds';
$labels['surname'] = 'Uzvārds';
$labels['email'] = 'E-pasts';
$labels['addcontact'] = 'Pievienot iezīmēto ierakstu adrešu grāmatai';
$labels['editcontact'] = 'Rediģēt adrešu grāmatas ierakstu';
$labels['edit'] = 'Rediģēt';
$labels['cancel'] = 'Atcelt';
$labels['save'] = 'Saglabāt';
$labels['delete'] = 'Dzēst';
$labels['newcontact'] = 'Izveidot jaunu ierakstu adrešu grāmatā';
$labels['deletecontact'] = 'Dzēst iezīmētos ierakstus';
$labels['composeto'] = 'Rakstīt vēstuli';
$labels['contactsfromto'] = 'Ieraksti $from līdz $to no $count';
$labels['print'] = 'Drukāt';
$labels['export'] = 'Eksportēt';
$labels['previouspage'] = 'Parādīt iepriekšējo kopu';
$labels['firstpage'] = 'Parādīt pirmo kopu';
$labels['nextpage'] = 'Parādīt nākamo kopu';
$labels['lastpage'] = 'Parādīt pēdējo kopu';
$labels['groups'] = 'Grupas';
$labels['personaladrbook'] = 'Personīgās adreses';
$labels['settingsfor'] = 'Iestatījumi';
$labels['preferences'] = 'Preferences';
$labels['userpreferences'] = 'Lietotāja preferences';
$labels['editpreferences'] = 'Rediģēt lietotāja preferences';
$labels['identities'] = 'Identitātes';
$labels['manageidentities'] = 'Rediģēt šī konta identitātes';
$labels['newidentity'] = 'Jauna identitāte';
$labels['newitem'] = 'Jauns';
$labels['edititem'] = 'Rediģēt';
$labels['setdefault'] = 'Uzlikt kā noklusēto';
$labels['language'] = 'Valoda';
$labels['timezone'] = 'Laika zona';
$labels['pagesize'] = 'Rindas lapā';
$labels['signature'] = 'Paraksts';
$labels['dstactive'] = 'Vasaras/ziemas laiks';
$labels['htmleditor'] = 'Rakstīt HTML vēstules';
$labels['htmlsignature'] = 'HTML paraksts';
$labels['previewpane'] = 'Rādīt priekšskatījuma paneli';
$labels['autosavedraft'] = 'Automātiski saglabāt uzmetumu';
$labels['everynminutes'] = 'katras $n minūtes';
$labels['never'] = 'nekad';
$labels['folder'] = 'Mape';
$labels['folders'] = 'Mapes';
$labels['foldername'] = 'Mapes nosaukums';
$labels['subscribed'] = 'Abonētās';
$labels['messagecount'] = 'Vēstules';
$labels['create'] = 'Izveidot';
$labels['createfolder'] = 'Izveidot jaunu mapi';
$labels['rename'] = 'Pārsaukt';
$labels['renamefolder'] = 'Pārsaukt mapi';
$labels['deletefolder'] = 'Dzēst mapi';
$labels['managefolders'] = 'Rediģēt mapes';
$labels['sortby'] = 'Kārtot pēc';
$labels['sortasc'] = 'Kārtot augošā secībā';
$labels['sortdesc'] = 'Kārtot dilstošā secībā';

?>