<?php

/*

 +-----------------------------------------------------------------------+
 | language/se/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Fredrik Nygren <f.nygren@gmail.com>                           |
 |         Andreas Henriksson <andreas@fatal.se>						 |
 |		   Jonas Näsholm <hostmaster@bitfuse.net>                        |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1191 2008-03-13 08:10:49Z yllar $

*/

$labels = array();
$labels['welcome'] = 'Välkommen till $product';
$labels['username'] = 'Användarnamn';
$labels['password'] = 'Lösenord';
$labels['server'] = 'Server';
$labels['login'] = 'Logga in';
$labels['logout'] = 'Logga ut';
$labels['mail'] = 'Meddelanden';
$labels['settings'] = 'Personliga inställningar';
$labels['addressbook'] = 'Adressbok';
$labels['inbox'] = 'Inkorg';
$labels['drafts'] = 'Utkast';
$labels['sent'] = 'Skickat';
$labels['trash'] = 'Papperskorg';
$labels['junk'] = 'Skräp';
$labels['subject'] = 'Ämne';
$labels['from'] = 'Avsändare';
$labels['to'] = 'Mottagare';
$labels['cc'] = 'Kopia';
$labels['bcc'] = 'Hemlig kopia';
$labels['replyto'] = 'Svara till';
$labels['date'] = 'Datum';
$labels['size'] = 'Storlek';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organisation';
$labels['reply-to'] = 'Svara till';
$labels['mailboxlist'] = 'Mappar';
$labels['messagesfromto'] = 'Meddelande $from till $to av $count';
$labels['messagenrof'] = 'Meddelande $nr av $count';
$labels['moveto'] = 'flytta till...';
$labels['download'] = 'ladda ner';
$labels['filename'] = 'Filnamn';
$labels['filesize'] = 'Filstorlek';
$labels['preferhtml'] = 'Visa HTML';
$labels['htmlmessage'] = 'HTML-meddelande';
$labels['prettydate'] = 'Fina datum';
$labels['addtoaddressbook'] = 'Lägg till i adressbok';
$labels['sun'] = 'Sön';
$labels['mon'] = 'Mån';
$labels['tue'] = 'Tis';
$labels['wed'] = 'Ons';
$labels['thu'] = 'Tor';
$labels['fri'] = 'Fre';
$labels['sat'] = 'Lör';
$labels['sunday'] = 'Söndag';
$labels['monday'] = 'Måndag';
$labels['tuesday'] = 'Tisdag';
$labels['wednesday'] = 'Onsdag';
$labels['thursday'] = 'Torsdag';
$labels['friday'] = 'Fredag';
$labels['saturday'] = 'Lördag';
$labels['today'] = 'Idag';
$labels['checkmail'] = 'Hämta nya meddelanden';
$labels['writenewmessage'] = 'Skapa nytt meddelande';
$labels['replytomessage'] = 'Svara avsändaren';
$labels['replytoallmessage'] = 'Svara avsändaren och alla mottagare';
$labels['forwardmessage'] = 'Vidarebefordra meddelande';
$labels['deletemessage'] = 'Radera meddelande';
$labels['movemessagetotrash'] = 'Flytta meddelande till papperskorgen';
$labels['printmessage'] = 'Skriv ut';
$labels['previousmessage'] = 'Visa föregående meddelande';
$labels['previousmessages'] = 'Visa tidigare grupp av meddelanden';
$labels['firstmessage'] = 'Visa första meddelandet';
$labels['firstmessages'] = 'Visa första gruppen av meddelanden';
$labels['nextmessage'] = 'Visa nästa meddelande';
$labels['nextmessages'] = 'Visa nästa grupp av meddelanden';
$labels['lastmessage'] = 'Visa sista meddelandet';
$labels['lastmessages'] = 'Visa sista gruppen av meddelanden';
$labels['backtolist'] = 'Tillbaka till meddelandelistan';
$labels['viewsource'] = 'Visa källa';
$labels['markmessages'] = 'Markera meddelande';
$labels['markread'] = 'Som läst';
$labels['markunread'] = 'Som oläst';
$labels['select'] = 'Välj';
$labels['all'] = 'Alla';
$labels['none'] = 'Ingen';
$labels['unread'] = 'Olästa';
$labels['compact'] = 'Packa';
$labels['empty'] = 'Töm';
$labels['purge'] = 'Rensa';
$labels['quota'] = 'Diskutrymme';
$labels['unknown'] = 'okänd';
$labels['unlimited'] = 'obegränsad';
$labels['quicksearch'] = 'Snabbsök';
$labels['resetsearch'] = 'Återställ sökning';
$labels['compose'] = 'Skapa nytt meddelande';
$labels['savemessage'] = 'Spara utkast';
$labels['sendmessage'] = 'Skicka meddelande';
$labels['addattachment'] = 'Bifoga fil';
$labels['charset'] = 'Teckenkodning';
$labels['editortype'] = 'Typ av redigerare';
$labels['returnreceipt'] = 'Mottagarkvitto';
$labels['checkspelling'] = 'Kontrollera stavning';
$labels['resumeediting'] = 'Återuppta redigering';
$labels['revertto'] = 'Återgå till';
$labels['attachments'] = 'Bilagor';
$labels['upload'] = 'Bifoga';
$labels['close'] = 'Stäng';
$labels['low'] = 'Låg';
$labels['lowest'] = 'Lägst';
$labels['normal'] = 'Normal';
$labels['high'] = 'Hög';
$labels['highest'] = 'Högst';
$labels['nosubject'] = '(inget ämne)';
$labels['showimages'] = 'Visa bilder';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Oformaterad text';
$labels['addcc'] = 'Kopia';
$labels['addbcc'] = 'Hemlig kopia';
$labels['addreplyto'] = 'Svara till';
$labels['mdnrequest'] = 'Avsändaren har bett om att bli uppmärksammad när du läst det här meddelandet. Vill du skicka uppmärksamma avsändaren?';
$labels['receiptread'] = 'Svarskvitto (läst)';
$labels['yourmessage'] = 'Det här är ett svarskvitto för ditt meddelande';
$labels['receiptnote'] = 'Notera: Det här kvittot berättar bara att meddelandet visats på mottagarens dator. Det finns ingen garanti att mottagaren har läst och förstått innehållet i meddelandet';
$labels['name'] = 'Visa namn';
$labels['firstname'] = 'Förnamn';
$labels['surname'] = 'Efternamn';
$labels['email'] = 'E-post';
$labels['addcontact'] = 'Lägg till ny kontakt';
$labels['editcontact'] = 'Redigera kontakt';
$labels['edit'] = 'Redigera';
$labels['cancel'] = 'Avbryt';
$labels['save'] = 'Spara';
$labels['delete'] = 'Radera';
$labels['newcontact'] = 'Skapa nytt kontaktkort';
$labels['deletecontact'] = 'Radera valda kontakter';
$labels['composeto'] = 'Skriv meddelande till';
$labels['contactsfromto'] = 'Kontakter $from till $to av $count';
$labels['print'] = 'Skriv ut';
$labels['export'] = 'Exportera';
$labels['previouspage'] = 'Visa föregående grupp';
$labels['firstpage'] = 'Visa första gruppen';
$labels['nextpage'] = 'Visa nästa grupp';
$labels['lastpage'] = 'Visa sista gruppen';
$labels['groups'] = 'Grupper';
$labels['personaladrbook'] = 'Personliga adresser';
$labels['settingsfor'] = 'Inställningar för';
$labels['preferences'] = 'Inställningar';
$labels['userpreferences'] = 'Användarinställningar';
$labels['editpreferences'] = 'Ändra användarinställningar';
$labels['identities'] = 'Profiler';
$labels['manageidentities'] = 'Hantera profiler för detta konto';
$labels['newidentity'] = 'Ny profil';
$labels['newitem'] = 'Ny post';
$labels['edititem'] = 'Ändra post';
$labels['setdefault'] = 'Sätt som standard';
$labels['language'] = 'Språk';
$labels['timezone'] = 'Tidszon';
$labels['pagesize'] = 'Rader per sida';
$labels['signature'] = 'Signatur';
$labels['dstactive'] = 'Sommartid';
$labels['htmleditor'] = 'Skriv HTML-meddelanden';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['previewpane'] = 'Visa delad vy i inbox';
$labels['autosavedraft'] = 'Spara utkast automatiskt';
$labels['everynminutes'] = 'var $n minut';
$labels['never'] = 'aldrig';
$labels['folder'] = 'Mapp';
$labels['folders'] = 'Mappar';
$labels['foldername'] = 'Mappnamn';
$labels['subscribed'] = 'Ansluten';
$labels['messagecount'] = 'Meddelanden';
$labels['create'] = 'Skapa';
$labels['createfolder'] = 'Skapa ny mapp';
$labels['rename'] = 'Byt namn';
$labels['renamefolder'] = 'Byt mappnamn';
$labels['deletefolder'] = 'Radera mapp';
$labels['managefolders'] = 'Hantera mappar';
$labels['sortby'] = 'Sortera på';
$labels['sortasc'] = 'Sortera stigande';
$labels['sortdesc'] = 'Sortera fallande';

?>
