<?php

/*

 +-----------------------------------------------------------------------+
 | language/vn/messages.inc                                              |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Vinh Bui <bqvinh@buivinh.info>                                |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$messages = array();
$messages['loginfailed']  = 'Không đăng nhập được';
$messages['cookiesdisabled'] = 'Trình duyệt không hỗ trợ cookies';
$messages['sessionerror'] = 'Phiên làm việc không hợp lệ hoặc đã hết hạn';
$messages['imaperror'] = 'Không kết nối được với máy chủ IMAP';
$messages['nomessagesfound'] = 'Không có thư trong hòm thư này';
$messages['loggedout'] = 'Phiên làm việc đã kết thúc. Hẹn gặp lại!';
$messages['mailboxempty'] = 'Hộp thư rỗng';
$messages['loading'] = 'Vui lòng chờ trong giây lát...';
$messages['loadingdata'] = 'Đang nạp dữ liệu...';
$messages['checkingmail'] = 'Kiểm tra thư mới...';
$messages['sendingmessage'] = 'Đang gửi thư...';
$messages['messagesent'] = 'Thư đã được gửi';
$messages['savingmessage'] = 'Đang lưu thư...';
$messages['messagesaved'] = 'Thư đã được gửi vào ngăn Drafts';
$messages['successfullysaved'] = 'Đã lưu thành công';
$messages['addedsuccessfully'] = 'Địa chỉ liên hệ đã được lưu';
$messages['contactexists'] = 'Địa chỉ liên hệ với e-mail này đã được lưu trước đây';
$messages['blockedimages'] = 'Để bảo vệ tính riêng tư, chức năng hiện ảnh từ xa bị cấm trong thư này.';
$messages['encryptedmessage'] = 'Thư này được mã hóa, không thể xem. Rất tiếc!';
$messages['nocontactsfound'] = 'Không tìm thấy địa chỉ liên hệ';
$messages['sendingfailed'] = 'Không gửi được thư';
$messages['errorsaving'] = 'Lỗi khi lưu';
$messages['errormoving'] = 'Không thể chuyển được thư';
$messages['errordeleting'] = 'Không thể xóa được thư';
$messages['deletecontactconfirm']  = 'Xóa bỏ các địa chỉ được chọn?';
$messages['deletefolderconfirm']  = 'Xóa bỏ thư mục này?';
$messages['purgefolderconfirm']  = 'Xóa toàn bộ thư trong thư mục nào?';
$messages['formincomplete'] = 'Mẫu chưa được điền xong';
$messages['noemailwarning'] = 'Nhập địa chỉ email';
$messages['nonamewarning']  = 'Nhập tên';
$messages['nopagesizewarning'] = 'Nhập kích cỡ của trang';
$messages['norecipientwarning'] = 'Thư cần có it nhất 1 người nhận';
$messages['nosubjectwarning']  = 'Mục "Tiêu đề" chưa có. Điền tiêu đề ?';
$messages['nobodywarning'] = 'Thư không nội dung, vẫn tiếp tục gửi?';
$messages['notsentwarning'] = 'Thư chưa được gửi. Bỏ qua thư đang soạn?';
$messages['noldapserver'] = 'Chọn máy chủ ldap server để tìm';
$messages['nocontactsreturned'] = 'Không tìm thấy địa chỉ';
$messages['nosearchname'] = 'Nhập địa chỉ hoặc email';
$messages['searchsuccessful'] = '$nr messages found';
$messages['searchnomatch'] = 'Không tìm thấy';
$messages['searching'] = 'Tìm kiếm...';
$messages['checking'] = 'Kiểm tra...';
$messages['nospellerrors'] = 'Không có lỗi chính tả';
$messages['folderdeleted'] = 'Thư mục đã được xóa';

?>