<?php

/*

+-----------------------------------------------------------------------+
| language/lt_LT/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Martynas Bendorius <martynas@evanet.lt>                       |
+-----------------------------------------------------------------------+'

@version $Id: labels.inc 2184 2008-12-21 09:30:25Z yllar $

*/

$labels = array();
$labels['welcome'] = 'Sveiki atvykę į $product';
$labels['username'] = 'Vartotojas';
$labels['password'] = 'Slaptažodis';
$labels['server'] = 'Serveris';
$labels['login'] = 'Prisijungti';
$labels['logout'] = 'Atsijungti';
$labels['mail'] = 'El. paštas';
$labels['settings'] = 'Nustatymai';
$labels['addressbook'] = 'Adresų knyga';
$labels['inbox'] = 'Gauti';
$labels['drafts'] = 'Juodraščiai';
$labels['sent'] = 'Išsiųsti';
$labels['trash'] = 'Šiukšliadėžė';
$labels['junk'] = 'Nereikalingi';
$labels['subject'] = 'Tema';
$labels['from'] = 'Siuntėjas';
$labels['to'] = 'Gavėjas';
$labels['cc'] = 'Kopija';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Atsakyti į';
$labels['date'] = 'Data';
$labels['size'] = 'Dydis';
$labels['priority'] = 'Svarbumas';
$labels['organization'] = 'Organizacija';
$labels['reply-to'] = 'Atsakyti į';
$labels['mailboxlist'] = 'Aplankai';
$labels['messagesfromto'] = 'Laiškai nuo $from iki $to iš $count';
$labels['messagenrof'] = 'Laiškas $nr iš $count';
$labels['moveto'] = 'perkelti į ...';
$labels['download'] = 'parsisiųsti';
$labels['filename'] = 'Bylos vardas';
$labels['filesize'] = 'Bylos dydis';
$labels['preferhtml'] = 'Rodyti HTML';
$labels['htmlmessage'] = 'HTML Laiškas';
$labels['prettydate'] = 'Gražios datos';
$labels['addtoaddressbook'] = 'Įtraukti į adresų knygą';
$labels['sun'] = 'Sek';
$labels['mon'] = 'Pir';
$labels['tue'] = 'Ant';
$labels['wed'] = 'Tre';
$labels['thu'] = 'Ket';
$labels['fri'] = 'Pen';
$labels['sat'] = 'Šeš';
$labels['sunday'] = 'Sekmadienis';
$labels['monday'] = 'Pirmadienis';
$labels['tuesday'] = 'Antradienis';
$labels['wednesday'] = 'Trečiadienis';
$labels['thursday'] = 'Ketvirtadienis';
$labels['friday'] = 'Penktadienis';
$labels['saturday'] = 'Šeštadienis';
$labels['jan'] = 'Sau';
$labels['feb'] = 'Vas';
$labels['mar'] = 'Kov';
$labels['apr'] = 'Bal';
$labels['may'] = 'Geg';
$labels['jun'] = 'Bir';
$labels['jul'] = 'Lie';
$labels['aug'] = 'Rugp';
$labels['sep'] = 'Rugs';
$labels['oct'] = 'Spa';
$labels['nov'] = 'Lap';
$labels['dec'] = 'Gruo';
$labels['longjan'] = 'Sausis';
$labels['longfeb'] = 'Vasaris';
$labels['longmar'] = 'Kovas';
$labels['longapr'] = 'Balandis';
$labels['longmay'] = 'Gegužė';
$labels['longjun'] = 'Biržėlis';
$labels['longjul'] = 'Liepa';
$labels['longaug'] = 'Rugpjūtis';
$labels['longsep'] = 'Rugsėjis';
$labels['longoct'] = 'Spalis';
$labels['longnov'] = 'Lapkritis';
$labels['longdec'] = 'Gruodis';
$labels['today'] = 'Šiandien';
$labels['checkmail'] = 'Tikrinti ar nėra naujų laiškų';
$labels['writenewmessage'] = 'Rašyti naują laišką';
$labels['replytomessage'] = 'Atsakyti į lašką';
$labels['replytoallmessage'] = 'Atsakyti visiems';
$labels['forwardmessage'] = 'Persiųsti laišką';
$labels['deletemessage'] = 'Ištrinti laišką';
$labels['movemessagetotrash'] = 'Perkelti laišką į šiukšliadėžę';
$labels['printmessage'] = 'Atspausdinti laišką';
$labels['previousmessage'] = 'Rodyti ankstesnį laišką';
$labels['previousmessages'] = 'Rodyti ankstesius laiškus';
$labels['firstmessage'] = 'Rodyti pirmąjį laišką';
$labels['firstmessages'] = 'Rodyti pirmuosius laiškus';
$labels['nextmessage'] = 'Rodyti tolesnį laišką';
$labels['nextmessages'] = 'Rodyti tolesnius laiškus';
$labels['lastmessage'] = 'Rodyti paskutinį laišką';
$labels['lastmessages'] = 'Rodyti paskutinius laiškus';
$labels['backtolist'] = 'Grižti į laiškų sarašą';
$labels['viewsource'] = 'Rodyti šaltinį';
$labels['markmessages'] = 'Pažymėti laiškus';
$labels['markread'] = 'Kaip perskaitytus';
$labels['markunread'] = 'Kaip neperskaitytus';
$labels['markflagged'] = 'Kaip pažymėtą';
$labels['markunflagged'] = 'Kaip nepažymėtą';
$labels['select'] = 'Pažymėti';
$labels['all'] = 'Visus';
$labels['none'] = 'Nieko';
$labels['unread'] = 'Neskaitytas';
$labels['flagged'] = 'Pažymėtas';
$labels['unanswered'] = 'Neatsakytas';
$labels['filter'] = 'Filtruoti';
$labels['compact'] = 'Suspausti';
$labels['empty'] = 'Ištuštinti';
$labels['purge'] = 'Išvalyti';
$labels['quota'] = 'Disko naudojimas';
$labels['unknown'] = 'nežinomas';
$labels['unlimited'] = 'neribotas';
$labels['quicksearch'] = 'Greita paieška';
$labels['resetsearch'] = 'Atšaukti paiešką';
$labels['openinextwin'] = 'Atidaryti naujame lange';
$labels['compose'] = 'Rašyti nauja laiška';
$labels['savemessage'] = 'Išsaugoti šį juodraštį';
$labels['sendmessage'] = 'Išsiųsti laiską';
$labels['addattachment'] = 'Prisegti bylą';
$labels['charset'] = 'Koduotė';
$labels['editortype'] = 'Redagavimo tipas';
$labels['returnreceipt'] = 'Atgalinis gavėjas';
$labels['checkspelling'] = 'Tikrinti rašybą';
$labels['resumeediting'] = 'Tęsti redagavimą';
$labels['revertto'] = 'Atstatyti į';
$labels['attachments'] = 'Prisegtos bylos';
$labels['upload'] = 'Įkelti';
$labels['close'] = 'Uždaryti';
$labels['low'] = 'Žemas';
$labels['lowest'] = 'Žemiausias';
$labels['normal'] = 'Normalus';
$labels['high'] = 'Aukštas';
$labels['highest'] = 'Aukščiausias';
$labels['nosubject'] = '(nėra temos)';
$labels['showimages'] = 'Rodyti paveikslėlius';
$labels['alwaysshow'] = 'Visada rodyti paveikslėlius gautus iš $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Paprastas tekstas';
$labels['savesentmessagein'] = 'Išsaugoti išsiųstus laiškus į';
$labels['dontsave'] = 'neišsaugoti';
$labels['maxuploadsize'] = 'Maksimalus leistinas bylos dydis yra $size';
$labels['addcc'] = 'Pridėti Cc';
$labels['addbcc'] = 'Pridėti Bcc';
$labels['addreplyto'] = 'Pridėti Reply-To';
$labels['mdnrequest'] = 'Žinutės siuntėjas paprašė patvirtinti, kad jūs ją perskaitėte. Ar norite išsiųsti patvirtinimą?';
$labels['receiptread'] = 'Patvirtinimas (skaitymo)';
$labels['yourmessage'] = 'Jūsų laiško perskaitymo patvirtinimas';
$labels['receiptnote'] = 'Pastaba: šis laiško perskaitymo patvirtinimas nurodo, jog laiškas buvo atidarytas gavėjo kompiuteryje, tačiau negarantuoja, jog gavėjas perskaitė ir suprato laiško turinį.';
$labels['name'] = 'Rodomas vardas';
$labels['firstname'] = 'Vardas';
$labels['surname'] = 'Pavardė';
$labels['email'] = 'El. paštas';
$labels['addcontact'] = 'Pridėti kontaktą';
$labels['editcontact'] = 'Redaguoti kontaktą';
$labels['edit'] = 'Redaguoti';
$labels['cancel'] = 'Atšaukti';
$labels['save'] = 'Išsaugoti';
$labels['delete'] = 'Ištrinti';
$labels['newcontact'] = 'Sukurti naują kontaktą';
$labels['deletecontact'] = 'Ištrinti pažymėtus kontaktus';
$labels['composeto'] = 'Rašyti laišką';
$labels['contactsfromto'] = 'Kontaktai nuo $from iki $to iš $count';
$labels['print'] = 'Atspausdinti';
$labels['export'] = 'Eksportuoti';
$labels['exportvcards'] = 'Eksportuoti kontaktus vCard formatu';
$labels['previouspage'] = 'Rodyti ankstesnį puslapį';
$labels['firstpage'] = 'Rodyti pirmąjį puslapį';
$labels['nextpage'] = 'Rodyti tolesnį puslapį';
$labels['lastpage'] = 'Rodyti paskutinį puslapį';
$labels['groups'] = 'Grupės';
$labels['personaladrbook'] = 'Asmeniniai adresai';
$labels['import'] = 'Importuoti';
$labels['importcontacts'] = 'Importuoti kontaktus';
$labels['importfromfile'] = 'Importuoti iš bylos:';
$labels['importreplace'] = 'Pakeisti visą adresų knygą';
$labels['importtext'] = 'Jūs galite įkelti kontaktus iš egzistuojančios adresų knygos.Mes šiuo metu palaikome adresų importavimą vCard duomenų formatu. ';
$labels['done'] = 'Baigta';
$labels['settingsfor'] = 'Nustatymai';
$labels['preferences'] = 'Nustatymai';
$labels['userpreferences'] = 'Vartotojo nustatymai';
$labels['editpreferences'] = 'Redaguoti vartotojo nustatymus';
$labels['identities'] = 'Tapatybės';
$labels['manageidentities'] = 'Tvarkyti tapatybes šiai sąskaitai';
$labels['newidentity'] = 'Nauja tapatybė';
$labels['newitem'] = 'Naujas įrašas';
$labels['edititem'] = 'Redaguoti įrašą';
$labels['setdefault'] = 'Nustatyti pagrindiniu';
$labels['autodetect'] = 'Automatiškai';
$labels['language'] = 'Kalba';
$labels['timezone'] = 'Laiko juosta';
$labels['pagesize'] = 'Eilučių skaičius puslapyje';
$labels['signature'] = 'Parašas';
$labels['dstactive'] = 'Vasaros/Žiemos laikas';
$labels['htmleditor'] = 'Kurti HTML laiškus';
$labels['htmlsignature'] = 'HTML parašas';
$labels['previewpane'] = 'Rodyti peržiūros lauką';
$labels['skin'] = 'Aplinkos stilius';
$labels['logoutclear'] = 'Išvalyti šiukšliadėžę atsijungiant';
$labels['logoutcompact'] = 'Suspausti Gautus atsijungiant';
$labels['uisettings'] = 'Vartotojo Aplinka';
$labels['serversettings'] = 'Serverio Nuostatos';
$labels['mailboxview'] = 'Pašto Dėžutės Peržiūra';
$labels['mdnrequests'] = 'Siuntėjo perspėjimai';
$labels['askuser'] = 'prašyti vartotojo';
$labels['autosend'] = 'siųsti automatiškai';
$labels['ignore'] = 'ignoruoti';
$labels['readwhendeleted'] = 'Pažymėti laišką kaip perskaitytu trinant';
$labels['flagfordeletion'] = 'Pažymėti laišką trynimui vietoje ištrynimo';
$labels['skipdeleted'] = 'Nerodyti ištrintų laiškų';
$labels['showremoteimages'] = 'Rodyti paveikslėlius';
$labels['fromknownsenders'] = 'iš žinomų siuntėjų';
$labels['always'] = 'visada';
$labels['showinlineimages'] = 'Rodyti prisegtus paveikslėlius žemiau laiško';
$labels['autosavedraft'] = 'Automatiškai išsaugoti juodraščius';
$labels['everynminutes'] = 'kas $n minutes(-čių)';
$labels['keepaliveevery'] = 'kas $n minutę(-čių)';
$labels['keepalive'] = 'Tikrinti ar nėra naujų pranešimus';
$labels['never'] = 'niekada';
$labels['messagesdisplaying'] = 'Laiškų rodymas';
$labels['messagescomposition'] = 'Laiškų struktūra';
$labels['mimeparamfolding'] = 'Prisegtų bylų vardai';
$labels['2231folding'] = 'Pilnas RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Pilnas RFC 2047 (kita)';
$labels['advancedoptions'] = 'Papildomi nustatymai';
$labels['focusonnewmessage'] = 'Fokusuoti naršyklės langą gavus naują laišką';
$labels['checkallfolders'] = 'Tikrinti ar nėra naujų laiškų visuose aplankuose';
$labels['folder'] = 'Aplankas';
$labels['folders'] = 'Aplankai';
$labels['foldername'] = 'Aplanko vardas';
$labels['subscribed'] = 'Užsakytas';
$labels['messagecount'] = 'Laiškai';
$labels['create'] = 'Sukurti';
$labels['createfolder'] = 'Sukurti naują aplanką';
$labels['rename'] = 'Pervadinti';
$labels['renamefolder'] = 'Pervadinti aplanką';
$labels['deletefolder'] = 'Ištrinti aplanką';
$labels['managefolders'] = 'Tvarkyti aplankus';
$labels['specialfolders'] = 'Specialūs aplankai';
$labels['sortby'] = 'Rikiuoti pagal';
$labels['sortasc'] = 'Rikiuoti didėjančia tvarka';
$labels['sortdesc'] = 'Rikiuoti mažėjančia tvarka';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
