<?php

/*
+-----------------------------------------------------------------------+
| language/mk_MK/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author:  Ivan Mishev - mishevivan@gmail.com                           |
+-----------------------------------------------------------------------+

@version $Id$

*/

$labels = array();
$labels['welcome'] = 'Добредојдовте во $product';
$labels['username'] = 'Корисничко Име';
$labels['password'] = 'Лозинка';
$labels['server'] = 'Сервер';
$labels['login'] = 'Логирај Се';
$labels['logout'] = 'Одлогирај Се';
$labels['mail'] = 'Е-Маил';
$labels['settings'] = 'Подесувања';
$labels['addressbook'] = 'Именик';
$labels['inbox'] = 'Пошта';
$labels['drafts'] = 'Непратени';
$labels['sent'] = 'Пратени';
$labels['trash'] = 'Корпа';
$labels['junk'] = 'Ѓубре';
$labels['subject'] = 'Наслов';
$labels['from'] = 'Праќач';
$labels['to'] = 'Примач';
$labels['cc'] = 'Копирај';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Препрати на';
$labels['date'] = 'Дата';
$labels['size'] = 'Големина';
$labels['priority'] = 'Приоритет';
$labels['organization'] = 'Организација';
$labels['reply-to'] = 'Препрати на';
$labels['mailboxlist'] = 'Папки';
$labels['messagesfromto'] = '$count пораки од $from';
$labels['messagenrof'] = '$nr порака од $count';
$labels['moveto'] = 'Премести во...';
$labels['download'] = 'сними';
$labels['filename'] = 'Име на датотеката';
$labels['filesize'] = 'Големина на датотеката';
$labels['preferhtml'] = 'Прикажи во HTML';
$labels['htmlmessage'] = 'HTML Порака';
$labels['prettydate'] = 'Убави дати';
$labels['addtoaddressbook'] = 'Додади во именик';
$labels['sun'] = 'Нед';
$labels['mon'] = 'Пон';
$labels['tue'] = 'Вто';
$labels['wed'] = 'Сре';
$labels['thu'] = 'Чет';
$labels['fri'] = 'Пет';
$labels['sat'] = 'Саб';
$labels['sunday'] = 'Недела';
$labels['monday'] = 'Понеделник';
$labels['tuesday'] = 'Вторник';
$labels['wednesday'] = 'Среда';
$labels['thursday'] = 'Четврток';
$labels['friday'] = 'Петок';
$labels['saturday'] = 'Сабота';
$labels['jan'] = 'Јан';
$labels['feb'] = 'Фев';
$labels['mar'] = 'Мар';
$labels['apr'] = 'Апр';
$labels['may'] = 'Мај';
$labels['jun'] = 'Јун';
$labels['jul'] = 'Јул';
$labels['aug'] = 'Авг';
$labels['sep'] = 'Сеп';
$labels['oct'] = 'Окт';
$labels['nov'] = 'Ное';
$labels['dec'] = 'Дек';
$labels['longjan'] = 'Јануари';
$labels['longfeb'] = 'Февруари';
$labels['longmar'] = 'Март';
$labels['longapr'] = 'Април';
$labels['longmay'] = 'Мај';
$labels['longjun'] = 'Јуни';
$labels['longjul'] = 'Јули';
$labels['longaug'] = 'Август';
$labels['longsep'] = 'Септември';
$labels['longoct'] = 'Октомври';
$labels['longnov'] = 'Ноември';
$labels['longdec'] = 'Декември';
$labels['today'] = 'Денес';
$labels['checkmail'] = 'Провери пошта';
$labels['writenewmessage'] = 'Нова порака';
$labels['replytomessage'] = 'Одговори на пораката';
$labels['replytoallmessage'] = 'Одговори на сите';
$labels['forwardmessage'] = 'Препрати ја пораката';
$labels['deletemessage'] = 'Премести ја пораката во Корпа';
$labels['movemessagetotrash'] = 'Премести ги пораките во Канта';
$labels['printmessage'] = 'За печатење';
$labels['previousmessage'] = 'Прикажи ја претходната порака';
$labels['previousmessages'] = 'Прикажи ги претходните пораки';
$labels['firstmessage'] = 'Прикажи ја првата порака';
$labels['firstmessages'] = 'Прикажи ги првите пораки';
$labels['nextmessage'] = 'Прикажи ја наредната порака';
$labels['nextmessages'] = 'Прикажи ги следните пораки';
$labels['lastmessage'] = 'Прикажи ја последната порака';
$labels['lastmessages'] = 'Прикажи ги последните пораки';
$labels['backtolist'] = 'Врати се во поштенското сандаче';
$labels['viewsource'] = 'Покажи го изворот на пракање';
$labels['markmessages'] = 'Обележи ги пораките';
$labels['markread'] = 'Како прочитани';
$labels['markunread'] = 'Како непрочитани';
$labels['markflagged'] = 'Како обележана';
$labels['markunflagged'] = 'Како необележана';
$labels['select'] = 'Одбележи';
$labels['all'] = 'Сите';
$labels['none'] = 'Никоја';
$labels['unread'] = 'Непрочитани';
$labels['compact'] = 'Уредно';
$labels['empty'] = 'Испразни';
$labels['purge'] = 'Чистење';
$labels['quota'] = 'Искористен простор';
$labels['unknown'] = 'непознато';
$labels['unlimited'] = 'неограничено';
$labels['quicksearch'] = 'Брзо претражување';
$labels['resetsearch'] = 'Ново претражување';
$labels['compose'] = 'Нова порака';
$labels['savemessage'] = 'Снимај ја пораката во Непратени';
$labels['sendmessage'] = 'Прати ја пораката';
$labels['addattachment'] = 'Прикачи фајл';
$labels['charset'] = 'Charset';
$labels['editortype'] = 'Тип на едитор';
$labels['returnreceipt'] = 'Врати ';
$labels['checkspelling'] = 'Провери спелување';
$labels['resumeediting'] = 'Продолжи со уредување';
$labels['revertto'] = 'Обрати се на';
$labels['attachments'] = 'Прикачено';
$labels['upload'] = 'Прикачи';
$labels['close'] = 'Затвори';
$labels['low'] = 'Низок';
$labels['lowest'] = 'Најнизок';
$labels['normal'] = 'Нормален';
$labels['high'] = 'Висок';
$labels['highest'] = 'Највисок';
$labels['nosubject'] = '(нема тема)';
$labels['showimages'] = 'Прикажи ги сликите';
$labels['alwaysshow'] = 'Секогаш прикажувај ги сликите од $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Обичен текст';
$labels['addcc'] = 'Додај Cc';
$labels['addbcc'] = 'Додај Bcc';
$labels['addreplyto'] = 'Додај Одговори-На';
$labels['mdnrequest'] = 'Праќачот на оваа порака сака да добие известување кога ќе ја прочитате пораката. Дали сакате да го известите?';
$labels['receiptread'] = 'Извести (читај)';
$labels['yourmessage'] = 'Ова е известување за вашата порака';
$labels['receiptnote'] = 'Забелешка: Ова известување само потврдува дека пораката која сте ја пратиле е отворена. Не е гаранција дека примачот ја прочитал или ја разбрал истата.';
$labels['name'] = 'Прикажано име';
$labels['firstname'] = 'Име';
$labels['surname'] = 'Презиме';
$labels['email'] = 'Е-маил';
$labels['addcontact'] = 'Додади го контактот';
$labels['editcontact'] = 'Промени го контактот';
$labels['edit'] = 'Промени';
$labels['cancel'] = 'Откажи';
$labels['save'] = 'Сними';
$labels['delete'] = 'Избриши';
$labels['newcontact'] = 'Додади ново име';
$labels['deletecontact'] = 'Избриши ги следните имиња';
$labels['composeto'] = 'Напиши порака';
$labels['contactsfromto'] = '$count имиња $from до $to';
$labels['print'] = 'Испечати';
$labels['export'] = 'Извади како';
$labels['previouspage'] = 'Прикажи претходна страна';
$labels['firstpage'] = 'Прикажи ја првата страна';
$labels['nextpage'] = 'Прикажи ја следната страна';
$labels['lastpage'] = 'Прикажи ја последната страна';
$labels['groups'] = 'Групи';
$labels['personaladrbook'] = 'Адреси';
$labels['settingsfor'] = 'Подесувања за';
$labels['preferences'] = 'Подесувања';
$labels['userpreferences'] = 'Кориснички подесувања';
$labels['editpreferences'] = 'Промени ги корисничките подесувања';
$labels['identities'] = 'Идентитети';
$labels['manageidentities'] = 'Организирај ги идентитетите за овој корисник';
$labels['newidentity'] = 'Нов идентитет';
$labels['newitem'] = 'Нов објект';
$labels['edititem'] = 'Промени објект';
$labels['setdefault'] = 'Одбери за основно';
$labels['language'] = 'Јазик';
$labels['timezone'] = 'Временска зона';
$labels['pagesize'] = 'Редови прикажани на страна';
$labels['signature'] = 'Потпис';
$labels['dstactive'] = 'Промени на времето';
$labels['htmleditor'] = 'Создади HTML порака';
$labels['htmlsignature'] = 'HTML потпис';
$labels['previewpane'] = 'Прикажи го претходниот панел';
$labels['skin'] = 'Модел на изгледот';
$labels['logoutclear'] = 'Очисти ја Кантата при излез';
$labels['logoutcompact'] = 'Подреди ја поштата при излез';
$labels['uisettings'] = 'Кориснички изглед';
$labels['serversettings'] = 'Подесувања на серверот';
$labels['mailboxview'] = 'Приказ на поштенското сандаче';
$labels['mdnrequests'] = 'Најави за праќачот';
$labels['askuser'] = 'прашај го корисникот';
$labels['autosend'] = 'автоматски испрати';
$labels['ignore'] = 'игнорирање';
$labels['readwhendeleted'] = 'Обележи ја пораката како прочитана при бришење';
$labels['flagfordeletion'] = 'Обележи ја пораката за бришење наместо да ја избришеш';
$labels['showinlineimages'] = 'Прикажи ги прикачените слики под пораката';
$labels['autosavedraft'] = 'Авоматски снимај во Непратени';
$labels['everynminutes'] = 'секои $n минути';
$labels['never'] = 'никогаш';
$labels['messagesdisplaying'] = 'Прикажување на порака';
$labels['messagescomposition'] = 'Пишување на порака';
$labels['folder'] = 'Папка';
$labels['folders'] = 'Папки';
$labels['foldername'] = 'Име на папката';
$labels['subscribed'] = 'Претплатен';
$labels['messagecount'] = 'Пораки';
$labels['create'] = 'Креирај';
$labels['createfolder'] = 'Креирај нова папка';
$labels['rename'] = 'Преименувај';
$labels['renamefolder'] = 'Преименувај ја папката';
$labels['deletefolder'] = 'Избриши ја папката';
$labels['managefolders'] = 'Организирање на папки';
$labels['sortby'] = 'Уреди по';
$labels['sortasc'] = 'Уреди по азбучен ред';
$labels['sortdesc'] = 'Уреди опаѓачки';

?>
