<?php

/*

 +-----------------------------------------------------------------------+
 | language/sr_cyrillic/messages.inc                                     |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Branko Kokanovic <branko.kokanovic@gmail.com>                 |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$messages = array();
$messages['loginfailed'] = 'Неуспешно пријављивање';
$messages['cookiesdisabled'] = 'Ваш интернет прегледач не подржава колачиће';
$messages['sessionerror'] = 'Сесија није валидна или је истекла';
$messages['imaperror'] = 'Неуспешна конекција на IMAP сервер';
$messages['nomessagesfound'] = 'Немате порука у сандучету';
$messages['loggedout'] = 'Успешно сте се одјавили.';
$messages['mailboxempty'] = 'Сандуче је празно';
$messages['loading'] = 'Учитавање...';
$messages['loadingdata'] = 'Учитавање података...';
$messages['checkingmail'] = 'Провера нових порука у току...';
$messages['sendingmessage'] = 'Порука се шаље...';
$messages['messagesent'] = 'Порука је успешно послата';
$messages['savingmessage'] = 'Порука се снима...';
$messages['messagesaved'] = 'Порука успешно сачувана у Снимљене';
$messages['successfullysaved'] = 'Снимање успешно обављено';
$messages['addedsuccessfully'] = 'Контакт успешно додат у именик';
$messages['contactexists'] = 'Контакт са овом е-мејл адресом већ постоји у именику';
$messages['blockedimages'] = 'Због заштите приватности, слике са удаљених сервера су блокиране';
$messages['encryptedmessage'] = 'Ова порука је шифрована, па се не може приказати';
$messages['nocontactsfound'] = 'Није пронађен ниједан контакт';
$messages['contactnotfound'] = 'Жељени контакт није нађен';
$messages['sendingfailed'] = 'Грешка при слању поруке';
$messages['errorsaving'] = 'Грешка при снимању поруке';
$messages['errormoving'] = 'Грешка при премештању поруке';
$messages['errordeleting'] = 'Грешка при брисању поруке';
$messages['deletecontactconfirm'] = 'Да ли стварно желите да обришете изабране контакте?';
$messages['deletemessagesconfirm'] = 'Да ли стварно желите да обришете изабране поруке?';
$messages['deletefolderconfirm'] = 'Да ли заиста желите да обришете изабрану фасциклу?';
$messages['purgefolderconfirm'] = 'Да ли заиста желите да обришете све поруке у фасцикли?';
$messages['formincomplete'] = 'Формулар није у целости попуњен';
$messages['noemailwarning'] = 'Унесите валидну е-мејл адресу';
$messages['nonamewarning'] = 'Унесите име';
$messages['nopagesizewarning'] = 'Унесите величину странице';
$messages['norecipientwarning'] = 'Унесите примаоца/примаоце (За)';
$messages['nosubjectwarning'] = 'Поље \'Наслов\' је празно. Желите ли да унесете наслов?';
$messages['nobodywarning'] = 'Да ли желите да пошаљете поруку без текста?';
$messages['notsentwarning'] = 'Порука није послата. Да ли желите да одбаците ову поруку?';
$messages['noldapserver'] = 'Унесите LDAP сервер за претрагу';
$messages['nocontactsreturned'] = 'Није пронађен ниједан контакт';
$messages['nosearchname'] = 'Унесите име или е-мејл адресу';
$messages['searchsuccessful'] = 'Број пронађених порука: $nr';
$messages['searchnomatch'] = 'Тражена фраза није пронађена ни у једној поруци';
$messages['searching'] = 'Претрага у току...';
$messages['checking'] = 'Провера у току...';
$messages['nospellerrors'] = 'Није пронађена ниједна правописна грешка';
$messages['folderdeleted'] = 'Фасцикла успешно обрисана';
$messages['deletedsuccessfully'] = 'Брисање успешно';
$messages['converting'] = 'Уклањање форматирања из поруке...';
$messages['messageopenerror'] = 'Порука се не може учитати са сервера';
$messages['fileuploaderror'] = 'Слање датотеке неуспешно';
$messages['filesizeerror'] = 'Послата датотека не може да прекорачи величину од $size';
$messages['copysuccess'] = 'Успешно копирано $nr адреса';
$messages['copyerror'] = 'Немогуће је ископирати иједну адресу';
$messages['sourceisreadonly'] = 'Овај извор адресе је само за читање';
$messages['errorsavingcontact'] = 'Неуспело снимање адресе контакта';
$messages['movingmessage'] = 'Премештам поруку...';
$messages['receiptsent'] = 'Успешно послато обавештење о приспећу';
$messages['errorsendingreceipt'] = 'Неуспело слање обавештења о приспећу';
$messages['nodeletelastidentity'] = 'Не можете обрисати овај идентитет, он Вам је последњи.';
$messages['addsubfolderhint'] = 'Ова фасцикла ће бити креирана као подфасцикла тренутне';

?>
