<?php

/*
 +-----------------------------------------------------------------------+
 | language/si/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Melanga Dissanayake <Melanga.Dissanayake@pabcbank.com>        |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$labels = array();
$labels['welcome'] = '$product ආයුබොවන්';
$labels['username'] = 'නම';
$labels['password'] = 'මුරපදය';
$labels['server'] = 'පද්ධතිය';
$labels['login'] = 'අතුල්වීම';
$labels['logout'] = 'පිටවීම';
$labels['mail'] = 'විද්යුත් තැපෑල';
$labels['settings'] = 'පොද්ගලික කට්ටල අංග';
$labels['addressbook'] = 'ලිපින පොත';
$labels['inbox'] = 'ඇතුල්වීම්';
$labels['drafts'] = 'කටු සටහන්';
$labels['sent'] = 'පිටවුම්';
$labels['trash'] = 'ලටපට';
$labels['junk'] = 'සුන්බුන්';
$labels['subject'] = 'මාතෘකාව';
$labels['from'] = 'යවන්නා';
$labels['to'] = 'ලබන්නා';
$labels['cc'] = 'පිටපත් කිරීම්';
$labels['bcc'] = 'අඳ පිටපත් කිරීම්';
$labels['replyto'] = 'පිළිතුරු සඳහා';
$labels['date'] = 'දිනය';
$labels['size'] = 'ප්රමාණය';
$labels['priority'] = 'ප්රමුඛතාව';
$labels['organization'] = 'සංවිධානය';
$labels['reply-to'] = 'පිළිතුරු සඳහා';
$labels['mailboxlist'] = 'ෆෝල්ඩරය';
$labels['messagesfromto'] = '$from ගෙන් $to පනිවුඩ $count';
$labels['messagenrof'] = 'පනිවුඩය $count න් $nr ';
$labels['moveto'] = 'ගෙනයෑම...';
$labels['download'] = 'බාගතකිරීම';
$labels['filename'] = 'ගොනුවේ නම';
$labels['filesize'] = 'ගොනුවේ ප්රමාණය';
$labels['preferhtml'] = 'HTML විදහා පෙන්වීම';
$labels['htmlmessage'] = 'HTML පනිවුඩය';
$labels['prettydate'] = 'සුරුබුහුටි දින';
$labels['addtoaddressbook'] = 'ලිපින පොතට එකතු කරන්න';
$labels['sun'] = 'ඉරිදා';
$labels['mon'] = 'සඳුදා';
$labels['tue'] = 'අගහ';
$labels['wed'] = 'බදාදා';
$labels['thu'] = 'බ්රහස්';
$labels['fri'] = 'සිකුරා';
$labels['sat'] = 'සෙනසු';
$labels['sunday'] = 'ඉරිදා';
$labels['monday'] = 'සඳුදා';
$labels['tuesday'] = 'අගහරුවාදා';
$labels['wednesday'] = 'බදාදා';
$labels['thursday'] = 'බ්රහස්පතිනිදා';
$labels['friday'] = 'සිකුරාදා';
$labels['saturday'] = 'සෙනසුරාදා';
$labels['today'] = 'අද';
$labels['checkmail'] = 'අඵත් පනිවුඩ සඳහා පිරික්සීම';
$labels['writenewmessage'] = 'අඵත් පනිවුඩක්';
$labels['replytomessage'] = 'පනිවුඩයට පිළිතුරු';
$labels['replytoallmessage'] = 'එවන්නාට සහ සැමට පිළිතුරු';
$labels['forwardmessage'] = 'පනිවුඩය ඉදිරියට';
$labels['deletemessage'] = 'පනිවුඩය ලටපට තුලට ගෙනයන්න';
$labels['movemessagetotrash'] = 'පණිවුඩය ලටපට වෙත ගෙන යන්න';
$labels['printmessage'] = 'පනිවුඩය මුද්රනය කරන්න';
$labels['previousmessage'] = 'කලින් පනිවුඩය පෙන්නන්න';
$labels['previousmessages'] = 'කලින් පනිවුඩ කට්ටලය පෙන්නන්න';
$labels['firstmessage'] = 'පළමුවන පනිවුඩය පෙන්නන්න';
$labels['firstmessages'] = 'පළමුවන පනිවුඩ කට්ටලය පෙන්නන්න';
$labels['nextmessage'] = 'මීළඟ පනිවුඩය පෙන්නන්න';
$labels['nextmessages'] = 'මීළඟ පනිවුඩ කට්ටලය පෙන්නන්න';
$labels['lastmessage'] = 'අවසාන පනිවුඩය පෙන්නන්න';
$labels['lastmessages'] = 'අවසාන පනිවුඩ කට්ටලය පෙන්නන්න';
$labels['backtolist'] = 'නැවතත් පනිවුඩ ලැයිස්තුවට';
$labels['viewsource'] = 'මූලාශ්රය පෙන්නන්න';
$labels['markmessages'] = 'පණිවුඩ';
$labels['markread'] = 'කියවු ලෙස සළකුණු කරන්න';
$labels['markunread'] = 'නොකියවු ලෙස සළකුණු කරන්න';
$labels['select'] = 'තෝරාගන්න';
$labels['all'] = 'සියලු';
$labels['none'] = 'තෝරානොගත්';
$labels['unread'] = 'නොකියවූ';
$labels['compact'] = 'සංයුක්ත';
$labels['empty'] = 'රික්ත';
$labels['purge'] = 'විරේචන';
$labels['quota'] = 'භාවිතය';
$labels['unknown'] = 'නාඳුනන';
$labels['unlimited'] = 'අසීමිත';
$labels['quicksearch'] = 'ඉක්මන් සෙවුම';
$labels['resetsearch'] = 'සෙවුම යලි පිහිටවීම';
$labels['compose'] = 'පනිවුඩයක් සෑදීම';
$labels['savemessage'] = 'කටු සටහනේ තැන්පත කරන්න';
$labels['sendmessage'] = 'පනිවුඩය දැන් යවන්න';
$labels['addattachment'] = 'ගොනුවක් ඇතුලත් කිරීම';
$labels['charset'] = 'අකුරැ කට්ටලය';
$labels['editortype'] = 'සම්පාදන ආකාරය';
$labels['returnreceipt'] = 'නැවත ලබන්නා';
$labels['checkspelling'] = 'වචන පරීක්ෂාව';
$labels['resumeediting'] = 'සම්පාදන නැවත ඇරඹීම';
$labels['revertto'] = 'ආපසු ඒම';
$labels['attachments'] = 'ගොනු';
$labels['upload'] = 'ඇතුල් කරීම';
$labels['close'] = 'වැසීම';
$labels['low'] = 'අඩු';
$labels['lowest'] = 'අඩුම';
$labels['normal'] = 'සමක';
$labels['high'] = 'ඉහළ';
$labels['highest'] = 'ඉහළම';
$labels['nosubject'] = '(මාතෘකාව නොමැති)';
$labels['showimages'] = 'රූප පෙන්නන්න';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'පැහැදිලි අකුරු';
$labels['addcc'] = 'Cc එක් කරන්න';
$labels['addbcc'] = 'Bcc එක් කරන්න';
$labels['addreplyto'] = '\'පිළිතුරු සඳහා\' එක් කරන්න';
$labels['mdnrequest'] = 'මෙම පණිවුඩය එවන්නා ඔබ එය කියවු බව අසයි. එය දැන්වීමට ඔබ කැමතිද?';
$labels['receiptread'] = 'ලැබීම් ලදුපත (කියවීම)';
$labels['yourmessage'] = 'මෙය ඔබගේ පණිවුඩයේ ලැබීම් ලදුපතයි';
$labels['receiptnote'] = 'සටහන: ලැබීම් ලදුපත මගින් මෙම පණිවුඩය කියවූ බව හෝ තේරුම් ගත් බව ගම්‍ය නොවේ. පණිවුඩය ලබන්නාට පෙන්නුම් කල බවටට සාක්ෂියක් පමණි';
$labels['name'] = 'නම පෙන්නන්න';
$labels['firstname'] = 'පළමු නම';
$labels['surname'] = 'අවසාන නම';
$labels['email'] = 'ද්යුත් තැපෑල';
$labels['addcontact'] = 'ලිපින පොතට එකතු කරන්න';
$labels['editcontact'] = 'ලිපිනය වෙනස් කිරීම';
$labels['edit'] = 'වෙනස් කිරීම';
$labels['cancel'] = 'අවලංගු කරීම';
$labels['save'] = 'තැන්පත් කිරීම';
$labels['delete'] = 'මකා දැමීම';
$labels['newcontact'] = 'අඵත් ලිපින පතක් සෑදීම';
$labels['deletecontact'] = 'තෝරාගත් ලිපින මකා දැමන්න';
$labels['composeto'] = 'පනිවුඩයක් සෑදීම';
$labels['contactsfromto'] = '$from ගෙන් $to ලිපින $count';
$labels['print'] = 'මුද්රණය';
$labels['export'] = 'නිර්යාත';
$labels['previouspage'] = 'කලින් කට්ටලය පෙන්නන්න';
$labels['firstpage'] = 'පළමුවන කට්ටලය පෙන්නන්න';
$labels['nextpage'] = 'මීළඟ කට්ටලය පෙන්නන්න';
$labels['lastpage'] = 'අවසාන කට්ටලය පෙන්නන්න';
$labels['groups'] = 'කණ්ඩායම්';
$labels['personaladrbook'] = 'පොද්ගලික ලිපිනය';
$labels['settingsfor'] = 'සඳහා කට්ටල අංග';
$labels['preferences'] = 'අභිමතය';
$labels['userpreferences'] = 'පරිශීලක අභිමතය';
$labels['editpreferences'] = 'පරිශීලක අභිමතය වෙනස් කිරීම්';
$labels['identities'] = 'අනන්නයතාව';
$labels['manageidentities'] = 'මෙම ගිණුමෙ අනන්නයතාව හැසිරවීම';
$labels['newidentity'] = 'අඵත් අනන්නයතාව';
$labels['newitem'] = 'අඵත් අයිතම';
$labels['edititem'] = 'අයිතම වෙනස් කිරීම්';
$labels['setdefault'] = 'පළමු තත්වයට';
$labels['language'] = 'භාෂාව';
$labels['timezone'] = 'කාල කලාපය';
$labels['pagesize'] = 'පිටුවකටඅ පේළි';
$labels['signature'] = 'අත්සන';
$labels['dstactive'] = 'දිවා එළිය ඉතිරි කිරීම';
$labels['htmleditor'] = 'HTML පනිවුඩයක් සෑදීම';
$labels['htmlsignature'] = 'HTML අත්සන';
$labels['previewpane'] = 'පූර්වදර්ශන කොටස පෙන්නන්න';
$labels['autosavedraft'] = 'ස්වයංක්රීයව කටු සටහනේ තැන්පත් කරන්න';
$labels['everynminutes'] = 'සෑම මිනිත්තු $n';
$labels['never'] = 'කිසි විටෙකත් නැති';
$labels['folder'] = 'ෆෝල්ඩරය';
$labels['folders'] = 'ෆෝල්ඩර';
$labels['foldername'] = 'ෆෝල්ඩරයේ නම';
$labels['subscribed'] = 'සාමාජික';
$labels['messagecount'] = 'පනිවුඩ';
$labels['create'] = 'සෑදීම';
$labels['createfolder'] = 'අඵත් ෆෝල්ඩරයක් සෑදීම';
$labels['rename'] = 'නැවත නම් කිරීම';
$labels['renamefolder'] = 'ෆෝල්ඩරය නැවත නම් කිරීම';
$labels['deletefolder'] = 'ෆෝල්ඩරය මකා දැමීම';
$labels['managefolders'] = 'හැසිරවීම හැසිරවීම';
$labels['sortby'] = 'චිසින් වර්ග කිරීම';
$labels['sortasc'] = 'ආරෝහණ වර්ග කිරීම';
$labels['sortdesc'] = 'අවරෝහණ වර්ග කිරීම';

?>