<?php

/*

+-----------------------------------------------------------------------+
| language/sl/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Andrej Sossi <asossi@dotcom.ts.it>                            |
|         Andrej Mocilnik <amocilnik@dotcom.ts.it>                      |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 1109 2008-02-17 20:22:05Z thomasb $

*/

$labels = array();
$labels['welcome'] = 'Dobrodošel v $product';
$labels['username'] = 'Uporabniško ime';
$labels['password'] = 'Geslo';
$labels['server'] = 'Strežnik';
$labels['login'] = 'Prijava';
$labels['logout'] = 'Odjava';
$labels['mail'] = 'E-Pošta';
$labels['settings'] = 'Osebne nastavitve';
$labels['addressbook'] = 'Stiki';
$labels['inbox'] = 'Prejeto';
$labels['drafts'] = 'Osnutki';
$labels['sent'] = 'Poslano';
$labels['trash'] = 'Smeti';
$labels['junk'] = 'Nezaželena  sporočila';
$labels['subject'] = 'Zadeva';
$labels['from'] = 'Pošiljatelj';
$labels['to'] = 'Prejemnik';
$labels['cc'] = 'Kp';
$labels['bcc'] = 'Skp';
$labels['replyto'] = 'Odgovor na';
$labels['date'] = 'Datum';
$labels['size'] = 'Velikost';
$labels['priority'] = 'Prioriteta';
$labels['organization'] = 'Organizacija';
$labels['reply-to'] = 'Odgovor na';
$labels['mailboxlist'] = 'Mape';
$labels['messagesfromto'] = 'Sporočila $from do $to od $count';
$labels['messagenrof'] = 'Sporočilo $nr od $count';
$labels['moveto'] = 'premakni v...';
$labels['download'] = 'prenesi';
$labels['filename'] = 'Ime datoteke';
$labels['filesize'] = 'Velikost datoteke';
$labels['preferhtml'] = 'Prednostno HTML';
$labels['htmlmessage'] = 'HTML sporočilo';
$labels['prettydate'] = 'Bolj čitljivi datumi';
$labels['addtoaddressbook'] = 'Dodaj v stike';
$labels['sun'] = 'Ned';
$labels['mon'] = 'Pon';
$labels['tue'] = 'Tor';
$labels['wed'] = 'Sre';
$labels['thu'] = 'Čet';
$labels['fri'] = 'Pet';
$labels['sat'] = 'Sob';
$labels['sunday'] = 'Nedelja';
$labels['monday'] = 'Ponedeljek';
$labels['tuesday'] = 'Torek';
$labels['wednesday'] = 'Sreda';
$labels['thursday'] = 'Četrtek';
$labels['friday'] = 'Petek';
$labels['saturday'] = 'Sobota';
$labels['today'] = 'Danes';
$labels['checkmail'] = 'Preglej nova sporočila';
$labels['writenewmessage'] = 'Novo sporočilo';
$labels['replytomessage'] = 'Odgovori na sporočilo';
$labels['replytoallmessage'] = 'Odgovori pošiljatelju in vsem prejemnikom';
$labels['forwardmessage'] = 'Posreduj sporočilo';
$labels['deletemessage'] = 'Premakni sporočilo v smeti';
$labels['movemessagetotrash'] = 'Premakni v smetnjak';
$labels['printmessage'] = 'Natisni to sporočilo';
$labels['previousmessage'] = 'Prikaži prejšnje sporočilo';
$labels['previousmessages'] = 'Prikaži prejšnja sporočila';
$labels['firstmessage'] = 'Prikaži prvo sporočilo';
$labels['firstmessages'] = 'Prikaži prva sporočila';
$labels['nextmessage'] = 'Prikaži naslednjo sporočilo';
$labels['nextmessages'] = 'Prikaži naslednja sporočila';
$labels['lastmessage'] = 'Prikaži zadnjo sporočilo';
$labels['lastmessages'] = 'Prikaži zadnja sporočila';
$labels['backtolist'] = 'Nazaj na seznam sporočil';
$labels['viewsource'] = 'Prikaži izvirno kodo';
$labels['markmessages'] = 'Označi sporočilo';
$labels['markread'] = 'Kot prebrano';
$labels['markunread'] = 'Kot neprebrano';
$labels['select'] = 'Izberi';
$labels['all'] = 'Vse';
$labels['none'] = 'Nobenih';
$labels['unread'] = 'Neprebrano';
$labels['compact'] = 'Stisni';
$labels['empty'] = 'Izprazni';
$labels['purge'] = 'Počisti';
$labels['quota'] = 'Poraba diska';
$labels['unknown'] = 'neznana';
$labels['unlimited'] = 'neomejena';
$labels['quicksearch'] = 'Hitri iskalnik';
$labels['resetsearch'] = 'Prekliči iskanje';
$labels['compose'] = 'Sestavi sporočilo';
$labels['savemessage'] = 'Shrani kot osnutek';
$labels['sendmessage'] = 'Pošlji sporočilo zdaj';
$labels['addattachment'] = 'Pripni datoteko';
$labels['charset'] = 'Nabor znakov';
$labels['editortype'] = 'Vrsta urejevalnika';
$labels['returnreceipt'] = 'Potrdilo prejemnika';
$labels['checkspelling'] = 'Preglej pravopis';
$labels['resumeediting'] = 'Nadaljuj z urejanjem';
$labels['revertto'] = 'Razveljavi';
$labels['attachments'] = 'Priponke';
$labels['upload'] = 'Naloži';
$labels['close'] = 'Zapri';
$labels['low'] = 'Nizka';
$labels['lowest'] = 'Najnižja';
$labels['normal'] = 'Normalna';
$labels['high'] = 'Visoka';
$labels['highest'] = 'Najvišja';
$labels['nosubject'] = '(brez naslova)';
$labels['showimages'] = 'Prikaži slike';
$labels['htmltoggle'] = 'Obogateno besedilo (HTML)';
$labels['plaintoggle'] = 'Samo besedilo';
$labels['addcc'] = 'Dodaj Kp';
$labels['addbcc'] = 'Dodaj Skp';
$labels['addreplyto'] = 'Dodaj naslov za odgovor';
$labels['mdnrequest'] = 'Pošiljatelj tega sporočila je zaprosil za portdilo, ko vi preberete to sporočilo. Hočete poslati obvestilo?';
$labels['receiptread'] = 'Potrdilo o prebranem sporočilu';
$labels['yourmessage'] = 'To je potrdilo, da je bilo vaše sporočilo prebrano';
$labels['receiptnote'] = 'Pozor: to je samo potrdilo, da vaše sporočilo je bilo prikazano na prejemnikovem računalniku. To še ne pomeni, da je prejemnik prebral ali razumel vsebino vašega sporočila.';
$labels['name'] = 'Ime za prikaz';
$labels['firstname'] = 'Ime';
$labels['surname'] = 'Priimek';
$labels['email'] = 'E-Pošta';
$labels['addcontact'] = 'Dodaj izbrane stike v imenik';
$labels['editcontact'] = 'Uredi vizitko';
$labels['edit'] = 'Uredi';
$labels['cancel'] = 'Prekliči';
$labels['save'] = 'Shrani';
$labels['delete'] = 'Briši';
$labels['newcontact'] = 'Dodaj vizitko';
$labels['deletecontact'] = 'Izbriši izbrane vizitke';
$labels['composeto'] = 'Sestavi sporočilo za';
$labels['contactsfromto'] = 'Vizitke $from od $to do $count';
$labels['print'] = 'Natisni';
$labels['export'] = 'Izvozi';
$labels['previouspage'] = 'Prejšnja stran';
$labels['firstpage'] = 'Prva stran';
$labels['nextpage'] = 'Naslednja stran';
$labels['lastpage'] = 'Zadnja stran';
$labels['groups'] = 'Skupine';
$labels['personaladrbook'] = 'Osebni Stiki';
$labels['settingsfor'] = 'Nastavitve za';
$labels['preferences'] = 'Nastavitve';
$labels['userpreferences'] = 'Uporabniške nastavitve';
$labels['editpreferences'] = 'Uredi uporabniške nastavitve';
$labels['identities'] = 'Identitete';
$labels['manageidentities'] = 'Upravljaj identitete za ta račun';
$labels['newidentity'] = 'Nova identiteta';
$labels['newitem'] = 'Nov predmet';
$labels['edititem'] = 'Uredi predmet';
$labels['setdefault'] = 'Nastavi privzeto';
$labels['language'] = 'Jezik';
$labels['timezone'] = 'Časovni pas';
$labels['pagesize'] = 'Vrstic na stran';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Avtomatična nastavitev sončne/legalne ure';
$labels['htmleditor'] = 'Sestavi sporočila z obogatenim besedilom';
$labels['htmlsignature'] = 'Podpis z obogatenim besedilom';
$labels['previewpane'] = 'Prikaži predogled';
$labels['autosavedraft'] = 'Avtomatično shrani osnutke';
$labels['everynminutes'] = 'vsakih $n minut';
$labels['never'] = 'nikoli';
$labels['folder'] = 'Mapa';
$labels['folders'] = 'Mape';
$labels['foldername'] = 'Ime mape';
$labels['subscribed'] = 'Vpisan';
$labels['messagecount'] = 'Sporočila';
$labels['create'] = 'Ustvari';
$labels['createfolder'] = 'Ustvari novo mapo';
$labels['rename'] = 'Preimenuj';
$labels['renamefolder'] = 'Preimenuj mapo';
$labels['deletefolder'] = 'Izbriši mapo';
$labels['managefolders'] = 'Urejaj mape';
$labels['sortby'] = 'Uredi po';
$labels['sortasc'] = 'Uredi naraščajoče';
$labels['sortdesc'] = 'Uredi padajoče';

?>
