<?php

/*

+-----------------------------------------------------------------------+
| language/az_AZ/messages.inc                                           |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Orkhan Guliyev, OUR Technology, LLC.<office@ourtechnology.net>|
+-----------------------------------------------------------------------+

*/

$messages = array();
$messages['loginfailed'] = 'Giriş uğursuz oldu';
$messages['cookiesdisabled'] = 'Darayıcınız cookiləri kəbul etmir';
$messages['sessionerror'] = 'Sessiyanız sona çatmışdır və ya xətalıdır';
$messages['imaperror'] = 'IMAP Serverləə əlaqə yaratmaq mümkün olmadı';
$messages['nomessagesfound'] = 'Poçt qutusunda məktub tapılmadı';
$messages['loggedout'] = 'Çıxış uğurlu oldu. Gülə-gülə!';
$messages['mailboxempty'] = 'Poçt qutusu boşdur';
$messages['loading'] = 'Yüklənir...';
$messages['loadingdata'] = 'Verilənlər yüklənir...';
$messages['checkingmail'] = 'Yeni məktub olub-olmadığı yoxlanılır...';
$messages['sendingmessage'] = 'Məktub göndərilir...';
$messages['messagesent'] = 'Məktub göndərildi';
$messages['savingmessage'] = 'Poçt yaddaşa salınır...';
$messages['messagesaved'] = 'Məktub yaddaşa salındı';
$messages['successfullysaved'] = 'Yaddaşda saxlanıldı';
$messages['addedsuccessfully'] = 'Əlaqə ünvan kitabçasına əlavə olundu';
$messages['contactexists'] = 'Ünvan kitabçasında bu e-poçt ünvanı mövcuddur';
$messages['blockedimages'] = 'Gizliliyinizi qorumaq məqsədilə məktubdakı qrafiklər blok edildi.';
$messages['encryptedmessage'] = 'Bu şifrələnmiş bir məktubdur və bu səbəbə görə göstərilməsi mümkün deyil. Üzr istəyirik!';
$messages['nocontactsfound'] = 'Əlaqə tapılmadı';
$messages['contactnotfound'] = 'İstənən bağlantı tapılmadı';
$messages['sendingfailed'] = 'Məktub göndəriləmədi';
$messages['senttooquickly'] = 'Zəhmət olmasa, bu məktubu göndərməzdən əvvəl $sec gözləyin';
$messages['errorsavingsent'] = 'Məktub saxlanılan zaman xəta baş verdi';
$messages['errorsaving'] = 'Yaddaşda saxlanılarkən bir problem baş verdi';
$messages['errormoving'] = 'Məktubun yerini dəyişmək mümkün olmadı';
$messages['errordeleting'] = 'Məktubu silmək mümkün olmadı';
$messages['deletecontactconfirm'] = 'Seçilən əlaqələri silməyə əminsinizmi?';
$messages['deletemessagesconfirm'] = 'Seçilən mesajları silmək istəyirsiz?';
$messages['deletefolderconfirm'] = 'Bu qovluğu silməyə əminmisiniz?';
$messages['purgefolderconfirm'] = 'Bu qovluqdakı bütün məktubları silməyə əminmisiniz?';
$messages['foldercreating'] = 'Qovluğun yaradılması...';
$messages['folderdeleting'] = 'Qovluğun silinməsi...';
$messages['folderrenaming'] = 'Qovluğun adının dəyişdirilməsi...';
$messages['foldermoving'] = 'Qovluq köçürülür...';
$messages['formincomplete'] = 'Form tam olaraq doldurulmadı';
$messages['noemailwarning'] = 'Xahiş olunur düzgün e-poçt ünvanı daxil edin';
$messages['nonamewarning'] = 'Xahiş olunur bir ad daxil edin';
$messages['nopagesizewarning'] = 'Xahiş olunur bir səhifə ölçüsü daxil edin';
$messages['nosenderwarning'] = 'Zəhmət olmasa, göndərənin e-poçt ünvanını daxil edin';
$messages['norecipientwarning'] = 'Xahiş olunur ən az bir qəbul edən göstərin';
$messages['nosubjectwarning'] = '"Mövzu" daxil edilməmişdir. İndi bir mövzu daxil etmək istəyirsinizmi?';
$messages['nobodywarning'] = 'Məktubu boş olaraq göndər?';
$messages['notsentwarning'] = 'Məktub göndərilmədi. Məktubunuzu ləğv etmək istəyirsinizmi?';
$messages['noldapserver'] = 'Xahiş olunur axtarmaq üçün bir Ldap server seçin';
$messages['nocontactsreturned'] = 'Əlaqə tapılmadı';
$messages['nosearchname'] = 'Xahiş olunur bir ad və ya e-poçt ünvanı daxil edin';
$messages['searchsuccessful'] = '$nr məktub tapıldı';
$messages['searchnomatch'] = 'Axtardığınıza uyğun heç bir nəticə tapılmadı';
$messages['searching'] = 'Axtarılır...';
$messages['checking'] = 'Yoxlanılır...';
$messages['nospellerrors'] = 'Qrammatik səhv tapılmadı';
$messages['folderdeleted'] = 'Qovluq uğurlu olaraq silindi';
$messages['deletedsuccessfully'] = 'Silindi';
$messages['converting'] = 'Mesajın formalandırılması prosesi gedir..';
$messages['messageopenerror'] = 'Mesajın serverdən yüklənilməsi mümkün olmadı';
$messages['fileuploaderror'] = 'Fayl yüklənməsi uğursuz oldu';
$messages['filesizeerror'] = 'Yüklənilən faylın ölçüsü $size çoxdur';
$messages['copysuccess'] = '$nr ünvan nüsxələndi';
$messages['copyerror'] = 'Heç bir ünvanı nüsxələmək mümkün olmadı';
$messages['sourceisreadonly'] = 'Ünvan qaynağı tam oxunar vəziyyətdə';
$messages['errorsavingcontact'] = 'Əlaqə ünvanını yaddaşa salmaq mümkün olmadı';
$messages['movingmessage'] = 'Məktubun yeri dəyişdirilir';
$messages['receiptsent'] = 'Oxuma receipt-i uğurlu olaraq göndərildi';
$messages['errorsendingreceipt'] = 'Receipt göndərmək mümkün olmadı';
$messages['nodeletelastidentity'] = 'Siz bu eyniliyi silə bilməzsiniz.';
$messages['addsubfolderhint'] = 'Bu qovluq seçilmiş qovluqda alt qovluq olaraq yaradıldı';
$messages['forbiddencharacter'] = 'Qovluq adında qadağan olunmuş xarakter(lər) var';
$messages['selectimportfile'] = 'Zəhmət olmasa, yüklənilən faylı seç';
$messages['addresswriterror'] = 'Seçilmiş ünvan kitabçası yazılmayandır';
$messages['importwait'] = 'İdxal, gözləyin...';
$messages['importerror'] = 'İdxal alınmadı! Yüklənilən fayl vCard fayla uyğun deyil.';
$messages['importconfirm'] = '<b>$inserted ünvanlar müvəffəqiyyətlə idxal edildi, mövcud daxil edilən $skipped atla</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'Əməliyyata icazə verilmir!';
$messages['nofromaddress'] = 'Seçilmiş eynilikdə e-poçt ünvanı axtarılır';
$messages['editorwarning'] = 'Adi mətn redaktoruna keçid, bütün mətn formatlarının itkisinə gətirəcək. Davam edim?';

?>
