<?php

/*
+-----------------------------------------------------------------------+
| language/cy_GB/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2008, RoundQube Dev. - Switzerland                      |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Dafydd Tomos <l10n@da.fydd.org>                               |
+-----------------------------------------------------------------------+

*/

$labels = array();
$labels['welcome'] = 'Croeso i $product';
$labels['username'] = 'Enw defnyddiwr';
$labels['password'] = 'Cyfrinair';
$labels['server'] = 'Gweinydd';
$labels['login'] = 'Mewngofnodi';
$labels['logout'] = 'Allgofnodi';
$labels['mail'] = 'E-bost';
$labels['settings'] = 'Gosodiadau Personol';
$labels['addressbook'] = 'Llyfr Cyfeiriadau';
$labels['inbox'] = 'Mewnflwch';
$labels['drafts'] = 'Drafftiau';
$labels['sent'] = 'Danfonwyd';
$labels['trash'] = 'Sbwriel';
$labels['junk'] = 'Sothach';
$labels['subject'] = 'Pwnc';
$labels['from'] = 'Anfonwr';
$labels['to'] = 'Derbyniwr';
$labels['cc'] = 'Copi';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Ateb-I';
$labels['date'] = 'Dyddiad';
$labels['size'] = 'Maint';
$labels['priority'] = 'Blaenoriaeth';
$labels['organization'] = 'Enw\'r Sefydliad';
$labels['reply-to'] = 'Ateb-I';
$labels['mailboxlist'] = 'Ffolderi';
$labels['messagesfromto'] = 'Negeseuon $from i $to o $count';
$labels['messagenrof'] = 'Neges $nr o $count';
$labels['moveto'] = 'Symud i...';
$labels['download'] = 'Llwytho lawr';
$labels['filename'] = 'Enw ffeil';
$labels['filesize'] = 'Maint ffeil';
$labels['preferhtml'] = 'Dangos HTML';
$labels['htmlmessage'] = 'Neges HTML';
$labels['prettydate'] = 'Dyddiadau pert';
$labels['addtoaddressbook'] = 'Ychwanegu i\'r llyfr cyfeiriadau';
$labels['sun'] = 'Sul';
$labels['mon'] = 'Llun';
$labels['tue'] = 'Maw';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Iau';
$labels['fri'] = 'Gwe';
$labels['sat'] = 'Sad';
$labels['sunday'] = 'Dydd Sul';
$labels['monday'] = 'Dydd Llun';
$labels['tuesday'] = 'Dydd Mawrth';
$labels['wednesday'] = 'Dydd Mercher';
$labels['thursday'] = 'Dydd Iau';
$labels['friday'] = 'Dydd Gwener';
$labels['saturday'] = 'Dydd Sadwrn';
$labels['jan'] = 'Ion';
$labels['feb'] = 'Chwe';
$labels['mar'] = 'Maw';
$labels['apr'] = 'Ebr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Meh';
$labels['jul'] = 'Gor';
$labels['aug'] = 'Aws';
$labels['sep'] = 'Med';
$labels['oct'] = 'Hyd';
$labels['nov'] = 'Tach';
$labels['dec'] = 'Rhag';
$labels['longjan'] = 'Ionawr';
$labels['longfeb'] = 'Chwefror';
$labels['longmar'] = 'Mawrth';
$labels['longapr'] = 'Ebrill';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Mehefin';
$labels['longjul'] = 'Gorffennaf';
$labels['longaug'] = 'Awst';
$labels['longsep'] = 'Medi';
$labels['longoct'] = 'Hydref';
$labels['longnov'] = 'Tachwedd';
$labels['longdec'] = 'Rhagfyr';
$labels['today'] = 'Heddiw';
$labels['checkmail'] = 'Edrych am negeseuon newydd';
$labels['writenewmessage'] = 'Creu neges newydd';
$labels['replytomessage'] = 'Ymateb i\'r anfonwr';
$labels['replytoallmessage'] = 'Ymateb i\'r anfonwr a phob derbyniwr';
$labels['forwardmessage'] = 'Danfon y neges ymlaen';
$labels['deletemessage'] = 'Dileu\'r neges';
$labels['movemessagetotrash'] = 'Symud y neges i\'r sbwriel';
$labels['printmessage'] = 'Argraffu\'r neges';
$labels['previousmessage'] = 'Dangos y neges flaenorol';
$labels['previousmessages'] = 'Dangos y set o negeseuon blaenorol';
$labels['firstmessage'] = 'Dangos y neges gyntaf';
$labels['firstmessages'] = 'Dangos y set gyntaf o negeseuon';
$labels['nextmessage'] = 'Dangos y neges nesaf';
$labels['nextmessages'] = 'Dangos y set nesaf o negesuoon';
$labels['lastmessage'] = 'Dangos y neges olaf';
$labels['lastmessages'] = 'Dangos y set olaf o negeseuon';
$labels['backtolist'] = 'Nôl i\'r rhestr o negeseuon';
$labels['viewsource'] = 'Edrych ar y ffynhonnell';
$labels['markmessages'] = 'Nodi\'r negeseuon';
$labels['markread'] = 'Wedi eu darllen';
$labels['markunread'] = 'Heb eu darllen';
$labels['markflagged'] = 'Wedi eu fflagio';
$labels['markunflagged'] = 'Heb eu fflagio';
$labels['select'] = 'Dewis';
$labels['all'] = 'Popeth';
$labels['none'] = 'Dim byd';
$labels['unread'] = 'Heb eu darllen';
$labels['flagged'] = 'Nodwyd';
$labels['unanswered'] = 'Heb ei ateb';
$labels['filter'] = 'Hidlo';
$labels['compact'] = 'Crynhoi';
$labels['empty'] = 'Gwagio';
$labels['purge'] = 'Glanhau';
$labels['quota'] = 'Defnydd ';
$labels['unknown'] = 'anhysbys';
$labels['unlimited'] = 'diderfyn';
$labels['quicksearch'] = 'Chwiliad cyflym';
$labels['resetsearch'] = 'Ail-osod chwiliad';
$labels['openinextwin'] = 'Agor mewn ffenest newydd';
$labels['compose'] = 'Ysgrifennu neges';
$labels['savemessage'] = 'Cadw\'r drafft hwn';
$labels['sendmessage'] = 'Danfon nawr';
$labels['addattachment'] = 'Atodi ffeil';
$labels['charset'] = 'Set nodiau';
$labels['editortype'] = 'Math golygydd';
$labels['returnreceipt'] = 'Cadarnhau derbyn';
$labels['checkspelling'] = 'Gwirio sillafu';
$labels['resumeediting'] = 'Ail-ddechrau golygu';
$labels['revertto'] = 'Dychwelyd i';
$labels['attachments'] = 'Atodiadau';
$labels['upload'] = 'Llwytho fyny';
$labels['close'] = 'Cau';
$labels['low'] = 'Isel';
$labels['lowest'] = 'Isaf';
$labels['normal'] = 'Cyffredin';
$labels['high'] = 'Uchel';
$labels['highest'] = 'Uchaf';
$labels['nosubject'] = '(dim pwnc)';
$labels['showimages'] = 'Dangos lluniau';
$labels['alwaysshow'] = 'Dangos lluniau bob amser o $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Testun plaen';
$labels['savesentmessagein'] = 'Cadw negeseuon a ddanfonir yn';
$labels['dontsave'] = 'peidio cadw';
$labels['maxuploadsize'] = 'Y maint ffeil uchaf a ganiateir yw $size';
$labels['addcc'] = 'Ychwanegu Cc';
$labels['addbcc'] = 'Ychwanegu Bcc';
$labels['addreplyto'] = 'Ychwanegu Ateb-I';
$labels['mdnrequest'] = 'Mae anfonwr y neges hwn wedi gofyn am hysbysiad eich bod wedi darllen y neges. Hoffech chi hysbysu\'r anfonwr?';
$labels['receiptread'] = 'Cadarnhad Derbyn (darllenwyd)';
$labels['yourmessage'] = 'Mae hwn yn gadarnhad o dderbyn eich neges';
$labels['receiptnote'] = 'Nodyn: Mae\'r cadarnhad hwn yn cydnabod fod y neges wedi ei ddangos ar gyfrifiadur y derbynnydd. \'Does dim sicrwydd fod y derbynydd wedi darllen neu ddeall cynnwys y neges.';
$labels['name'] = 'Enw ddangosir';
$labels['firstname'] = 'Enw cyntaf';
$labels['surname'] = 'Enw olaf';
$labels['email'] = 'E-bost';
$labels['addcontact'] = 'Ychwanegu cyswllt newydd';
$labels['editcontact'] = 'Golygu cyswllt';
$labels['edit'] = 'Golygu';
$labels['cancel'] = 'Canslo';
$labels['save'] = 'Cadw';
$labels['delete'] = 'Dileu';
$labels['newcontact'] = 'Creu cerdyn cyswllt newydd';
$labels['deletecontact'] = 'Dileu y cysylltiadau a ddewiswyd';
$labels['composeto'] = 'Ysgrifennu neges at';
$labels['contactsfromto'] = 'Cysylltiadau $from i $to o $count';
$labels['print'] = 'Argraffu';
$labels['export'] = 'Allforio';
$labels['exportvcards'] = 'Allforio cysylltiadau mewn fformat vCard';
$labels['previouspage'] = 'Dangos y set flaenorol';
$labels['firstpage'] = 'Dangos y set gyntaf';
$labels['nextpage'] = 'Dangos y set nesaf';
$labels['lastpage'] = 'Dangos y set olaf';
$labels['groups'] = 'Grwpiau';
$labels['personaladrbook'] = 'Cyfeiriadau Personol';
$labels['import'] = 'Mewnforio';
$labels['importcontacts'] = 'Mewnforio cysylltiadau';
$labels['importfromfile'] = 'Mewnforio o ffeil:';
$labels['importreplace'] = 'Dileu y llyfr cyfeiriadau cyfan wrth lwytho';
$labels['importtext'] = 'Fe allwch chi lwytho fyny cysylltiadau o lyfr cyfeiriadau sy\'n bodoli yn barod. Ar hyn o bryd rydyn\' ni\'n cefnogi mewnforio cyfeiriadau yn y fformat <a href="http://en.wikipedia.org/wiki/VCard">vCard</a>.';
$labels['done'] = 'Wedi gorffen';
$labels['settingsfor'] = 'Gosodiadau ar gyfer';
$labels['preferences'] = 'Dewisiadau';
$labels['userpreferences'] = 'Dewisiadau\'r defnyddiwr';
$labels['editpreferences'] = 'Golygu dewisiadau\'r defnyddiwr';
$labels['identities'] = 'Personoliaethau';
$labels['manageidentities'] = 'Rheoli personoliaethau ar gyfer y cyfri hwn';
$labels['newidentity'] = 'Personoliaeth newydd';
$labels['newitem'] = 'Eitem newydd';
$labels['edititem'] = 'Golygu eitem';
$labels['setdefault'] = 'Rhagosod';
$labels['autodetect'] = 'Awto';
$labels['language'] = 'Iaith';
$labels['timezone'] = 'Parth amser';
$labels['pagesize'] = 'Rhesi ar bob tudalen';
$labels['signature'] = 'Llofnod';
$labels['dstactive'] = 'Amser arbed golau ddydd';
$labels['htmleditor'] = 'Ysgrifennu negeseuon HTML';
$labels['htmlsignature'] = 'Llofnod HTML';
$labels['previewpane'] = 'Dangos ffenest rhagolwg';
$labels['skin'] = 'Croen rhyngwyneb';
$labels['logoutclear'] = 'Clirio\'r Sbwriel wrth allgofnodi';
$labels['logoutcompact'] = 'Crynhoi\'r Mewnflwch wrth allgofnodi';
$labels['uisettings'] = 'Rhyngwyneb Defnyddiwr';
$labels['serversettings'] = 'Gosodiadau Gweinydd';
$labels['mailboxview'] = 'Ymddangosiad y Blychau';
$labels['mdnrequests'] = 'Hysbysiadau anfonwr';
$labels['askuser'] = 'gofyn i\'r defnyddiwr';
$labels['autosend'] = 'danfon yn awtomatig';
$labels['ignore'] = 'anwybyddu';
$labels['readwhendeleted'] = 'Nodi\'r neges fel darllenwyd wrth ddileu';
$labels['flagfordeletion'] = 'Fflagio\'r neges i\'w ddileu yn hytrach na dileu yn syth';
$labels['skipdeleted'] = 'Peidio dangos negesuon wedi ei dileu';
$labels['showremoteimages'] = 'Dangos lluniau o wefannau allanol';
$labels['fromknownsenders'] = 'o ddanfonwyr hysbys';
$labels['always'] = 'bob amser';
$labels['showinlineimages'] = 'Dangos lluniau atodol islaw\'r neges';
$labels['autosavedraft'] = 'Cadw drafft yn awtomatig';
$labels['everynminutes'] = 'bob $n munud';
$labels['keepaliveevery'] = 'bob $n munud';
$labels['keepalive'] = 'Gofyn am negeseuon newydd ymlaen';
$labels['never'] = 'byth';
$labels['messagesdisplaying'] = 'Dangos Negeseuon';
$labels['messagescomposition'] = 'Ysgrifennu Negeseuon';
$labels['mimeparamfolding'] = 'Enw atodiadau';
$labels['2231folding'] = 'RFC 2231 llawn (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 llawn (arall)';
$labels['advancedoptions'] = 'Dewisiadau uwch';
$labels['focusonnewmessage'] = 'Ffocysu\'r porwr ar y neges newydd';
$labels['checkallfolders'] = 'Chwilio pob ffolder am negeseuon newydd';
$labels['folder'] = 'Ffolder';
$labels['folders'] = 'Ffolderi';
$labels['foldername'] = 'Enw ffolder';
$labels['subscribed'] = 'Tanysgrifwyd';
$labels['messagecount'] = 'Negeseuon';
$labels['create'] = 'Creu';
$labels['createfolder'] = 'Creu ffolder newydd';
$labels['rename'] = 'Ailenwi';
$labels['renamefolder'] = 'Ailenwi ffolder';
$labels['deletefolder'] = 'Dileu ffolder';
$labels['managefolders'] = 'Rheoli ffolderi';
$labels['specialfolders'] = 'Ffolderi arbennig';
$labels['sortby'] = 'Trefnu yn ôl';
$labels['sortasc'] = 'Trefn esgynnol';
$labels['sortdesc'] = 'Trefn ddisgynnol';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
