<?php

/*

+-----------------------------------------------------------------------+
| language/tr/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Hasan Cansız <hasancansiz@yahoo.com>                          |
| Author: Gökdeniz Karadağ <gokdenizk@gmail.com>                        |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2194 2008-12-29 18:26:51Z alec $

*/

$labels = array();
$labels['welcome'] = '$product, Hoş Geldiniz';
$labels['username'] = 'Kullanıcı Adı';
$labels['password'] = 'Şifre';
$labels['server'] = 'Sunucu';
$labels['login'] = 'Oturum Aç';
$labels['logout'] = 'Oturumu Kapat';
$labels['mail'] = 'E-Posta';
$labels['settings'] = 'Kişisel Ayarlar';
$labels['addressbook'] = 'Adres Defteri';
$labels['inbox'] = 'Gelen';
$labels['drafts'] = 'Taslaklar';
$labels['sent'] = 'Giden';
$labels['trash'] = 'Çöp';
$labels['junk'] = 'İstenmeyen';
$labels['subject'] = 'Konu';
$labels['from'] = 'Gönderen';
$labels['to'] = 'Alıcı';
$labels['cc'] = 'İlgili Kopyası';
$labels['bcc'] = 'Gizli Kopya';
$labels['replyto'] = 'Yanıtla';
$labels['date'] = 'Tarih';
$labels['size'] = 'Boyut';
$labels['priority'] = 'Öncelik';
$labels['organization'] = 'Kuruluş';
$labels['reply-to'] = 'Yanıtlama Adresi';
$labels['mailboxlist'] = 'Klasörler';
$labels['messagesfromto'] = 'Postalar: $from - $to , Toplam: $count';
$labels['messagenrof'] = 'Posta: $nr / $count';
$labels['moveto'] = 'Buraya taşı...';
$labels['download'] = 'İndir';
$labels['filename'] = 'Dosya Adı';
$labels['filesize'] = 'Dosya Boyutu';
$labels['preferhtml'] = 'HTML görüntüle';
$labels['htmlmessage'] = 'HTML Posta';
$labels['prettydate'] = 'Tarihi kısaltarak göster';
$labels['addtoaddressbook'] = 'Adres Defterine Ekle';
$labels['sun'] = 'Paz';
$labels['mon'] = 'Pzt';
$labels['tue'] = 'Sal';
$labels['wed'] = 'Çar';
$labels['thu'] = 'Per';
$labels['fri'] = 'Cum';
$labels['sat'] = 'Cmt';
$labels['sunday'] = 'Pazar';
$labels['monday'] = 'Pazartesi';
$labels['tuesday'] = 'Salı';
$labels['wednesday'] = 'Çarşamba';
$labels['thursday'] = 'Perşembe';
$labels['friday'] = 'Cuma';
$labels['saturday'] = 'Cumartesi';
$labels['jan'] = 'Oca';
$labels['feb'] = 'Şub';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Nis';
$labels['may'] = 'May';
$labels['jun'] = 'Haz';
$labels['jul'] = 'Tem';
$labels['aug'] = 'Ağu';
$labels['sep'] = 'Eyl';
$labels['oct'] = 'Eki';
$labels['nov'] = 'Kas';
$labels['dec'] = 'Ara';
$labels['longjan'] = 'Ocak';
$labels['longfeb'] = 'Şubat';
$labels['longmar'] = 'Mart';
$labels['longapr'] = 'Nisan';
$labels['longmay'] = 'Mayıs';
$labels['longjun'] = 'Haziran';
$labels['longjul'] = 'Temmuz';
$labels['longaug'] = 'Ağustos';
$labels['longsep'] = 'Eylül';
$labels['longoct'] = 'Ekim';
$labels['longnov'] = 'Kasım';
$labels['longdec'] = 'Aralık';
$labels['today'] = 'Bugün';
$labels['checkmail'] = 'Yeni postaları kontrol et';
$labels['writenewmessage'] = 'Yeni posta oluştur';
$labels['replytomessage'] = 'Gönderene yanıtla';
$labels['replytoallmessage'] = 'Gönderene ve tüm alıcılara yanıtla';
$labels['forwardmessage'] = 'Postayı ilet';
$labels['deletemessage'] = 'Postayı sil';
$labels['movemessagetotrash'] = 'Postayı çöpe taşı';
$labels['printmessage'] = 'Bu postayı yazdır';
$labels['previousmessage'] = 'Önceki postayı göster';
$labels['previousmessages'] = 'Önceki postaları göster';
$labels['firstmessage'] = 'İlk postayı göster';
$labels['firstmessages'] = 'İlk postaları göster';
$labels['nextmessage'] = 'Sonraki postayı göster';
$labels['nextmessages'] = 'Sonraki postaları göster';
$labels['lastmessage'] = 'Son postayı göster';
$labels['lastmessages'] = 'Son postaları göster';
$labels['backtolist'] = 'Posta listesine dön';
$labels['viewsource'] = 'Kaynağı göster';
$labels['markmessages'] = 'Postaları işaretle';
$labels['markread'] = 'okunmuş olarak';
$labels['markunread'] = 'okunmamış olarak';
$labels['markflagged'] = 'işaretli olarak';
$labels['markunflagged'] = 'işaretsiz olarak';
$labels['select'] = 'Seç';
$labels['all'] = 'Hepsini';
$labels['none'] = 'Hiçbirini';
$labels['unread'] = 'Okunmamışları';
$labels['compact'] = 'Sıklaştır';
$labels['empty'] = 'Boşalt';
$labels['purge'] = 'Sil';
$labels['quota'] = 'Disk kullanımı';
$labels['unknown'] = 'bilinmeyen';
$labels['unlimited'] = 'sınırsız';
$labels['quicksearch'] = 'Hızlı arama';
$labels['resetsearch'] = 'Aramayı bitir';
$labels['openinextwin'] = 'Yeni pencerede aç';
$labels['compose'] = 'Yeni posta oluştur';
$labels['savemessage'] = 'Taslak olarak kaydet';
$labels['sendmessage'] = 'Postayı gönder';
$labels['addattachment'] = 'Dosya ekle';
$labels['charset'] = 'Karakter kodlaması';
$labels['editortype'] = 'Düzenleyici';
$labels['returnreceipt'] = 'Alındı onayı';
$labels['checkspelling'] = 'Yazım denetimi yap';
$labels['resumeediting'] = 'Düzenlemeye devam et';
$labels['revertto'] = 'Geri çevir:';
$labels['attachments'] = 'Ekler';
$labels['upload'] = 'Yükle';
$labels['close'] = 'Kapat';
$labels['low'] = 'Düşük';
$labels['lowest'] = 'En Düşük';
$labels['normal'] = 'Normal';
$labels['high'] = 'Yüksek';
$labels['highest'] = 'En yüksek';
$labels['nosubject'] = '(Konu Belirtilmemiş)';
$labels['showimages'] = 'Resimleri göster';
$labels['alwaysshow'] = '$sender tarafından gönderilen resimleri her zaman göster';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Düz metin';
$labels['savesentmessagein'] = 'Gönderileni buraya kaydet';
$labels['dontsave'] = 'kaydetme';
$labels['maxuploadsize'] = 'İzin verilen en büyük dosya boyutu $size';
$labels['addcc'] = 'İlgili kopyası ekle';
$labels['addbcc'] = 'Gizli kopya ekle';
$labels['addreplyto'] = 'Yanıtlama adresi ekle';
$labels['mdnrequest'] = 'Bu postayı gönderen kişi, postayı okuduğunuza dair alındı onayı istedi. Alındı onayını göndermek ister misiniz ?';
$labels['mdnrequests'] = 'Alındı onayları';
$labels['receiptread'] = 'Alındı Onayı (okundu)';
$labels['yourmessage'] = 'Bu, postanız için alındı onayıdır';
$labels['receiptnote'] = 'Not: Bu alındı onayı sadece postanızın alıcının bilgisayarında gösterildiğini belirtir. Alıcının posta içeriğini okuduğunu veya anladığını garantilemez.';
$labels['name'] = 'Görüntülenen isim';
$labels['firstname'] = 'Ad';
$labels['surname'] = 'Soyad';
$labels['email'] = 'E-Posta';
$labels['addcontact'] = 'Adres defterine ekle';
$labels['editcontact'] = 'Kişiyi düzenle';
$labels['edit'] = 'Düzenle';
$labels['cancel'] = 'İptal';
$labels['save'] = 'Kaydet';
$labels['delete'] = 'Sil';
$labels['newcontact'] = 'Yeni adres kartı ekle';
$labels['deletecontact'] = 'Seçili kişileri sil';
$labels['composeto'] = 'Seçili kişiye posta gönder';
$labels['contactsfromto'] = 'Kişiler: $from - $to , Toplam: $count';
$labels['print'] = 'Yazdır';
$labels['export'] = 'Dışa aktar';
$labels['exportvcards'] = 'vCard olarak dışa aktar';
$labels['previouspage'] = 'Öncekileri göster';
$labels['firstpage'] = 'İlkini göster';
$labels['nextpage'] = 'Sonrakileri göster';
$labels['lastpage'] = 'Sonuncuyu göster';
$labels['groups'] = 'Gruplar';
$labels['personaladrbook'] = 'Adresler';
$labels['import'] = 'İçe aktar';
$labels['importcontacts'] = 'Kişileri içe aktar';
$labels['importfromfile'] = 'Dosyadan içe aktar:';
$labels['importreplace'] = 'Tüm adres defterinin yerine geçsin';
$labels['importtext'] = 'Mevcut bir adres defterindeki kişileri yükleyebilirsiniz.<br/><a href="http://en.wikipedia.org/wiki/VCard">vCard</a> dosyalarından adresleri içe aktarmayı destekliyoruz.';
$labels['done'] = 'Tamam';
$labels['settingsfor'] = 'Ayarlar';
$labels['preferences'] = 'Tercihler';
$labels['userpreferences'] = 'Kullanıcı tercihleri';
$labels['editpreferences'] = 'Kullanıcı tercihlerini düzenle';
$labels['identities'] = 'Kimlikler';
$labels['manageidentities'] = 'Bu hesap için kimlikleri düzenle';
$labels['newidentity'] = 'Yeni kimlik';
$labels['newitem'] = 'Yeni öğe';
$labels['edititem'] = 'Öğe düzenle';
$labels['setdefault'] = 'Varsayılan olarak ata';
$labels['autodetect'] = 'Otomatik';
$labels['language'] = 'Dil';
$labels['timezone'] = 'Saat dilimi';
$labels['pagesize'] = 'Bir sayfadaki satır sayısı';
$labels['signature'] = 'İmza';
$labels['dstactive'] = 'Yaz saati uygulaması';
$labels['htmleditor'] = 'HTML postaları oluştur';
$labels['htmlsignature'] = 'HTML imza';
$labels['previewpane'] = 'Önizleme panelini göster';
$labels['skin'] = 'Arayüz görünümü';
$labels['logoutclear'] = 'Oturumu kapatınca Çöpü temizle';
$labels['logoutcompact'] = 'Oturumu kapatınca Gelen Kutusunu sıklaştır';
$labels['uisettings'] = 'Kullanıcı Arayüzü';
$labels['serversettings'] = 'Sunucu Ayarları';
$labels['mailboxview'] = 'Posta Kutusu Görünümü';
$labels['askuser'] = 'kullanıcıya sor';
$labels['autosend'] = 'otomatik olarak gönder';
$labels['ignore'] = 'gözardı et';
$labels['readwhendeleted'] = 'Silinen postaları okunmuş olarak işaretle';
$labels['flagfordeletion'] = 'Postaları silmek yerine silinecek olarak işaretle';
$labels['showinlineimages'] = 'Postanın ekindeki resimleri postanın altında göster';
$labels['autosavedraft'] = 'Taslağı otomatik kaydet:';
$labels['everynminutes'] = 'her $n dakikada bir';
$labels['never'] = 'asla';
$labels['messagesdisplaying'] = 'Posta Görüntüleme';
$labels['messagescomposition'] = 'Yeni Posta Oluşturma';
$labels['folder'] = 'Klasör';
$labels['folders'] = 'Klasörler';
$labels['foldername'] = 'Klasör ismi';
$labels['subscribed'] = 'Abonelik';
$labels['messagecount'] = 'Postalar';
$labels['create'] = 'Oluştur';
$labels['createfolder'] = 'Yeni klasör oluştur';
$labels['rename'] = 'Yeniden adlandır';
$labels['renamefolder'] = 'Klasörü yeniden adlandır';
$labels['deletefolder'] = 'Klasörü sil';
$labels['managefolders'] = 'Klasörleri düzenle';
$labels['specialfolders'] = 'Özel klasörler';
$labels['sortby'] = 'Sırala';
$labels['sortasc'] = 'Artarak';
$labels['sortdesc'] = 'Azalarak';
$labels['filter'] = 'Süzgeç';
$labels['always'] = 'her zaman'; 
$labels['fromknownsenders'] = 'bilinen göndericilerden';
$labels['showremoteimages'] = 'Uzaktan yüklenen resimleri göster';
$labels['checkallfolders'] = 'Tüm klasörlerdeki yeni postaları denetle';
$labels['flagged'] = 'İşaretlenmiş'; 
$labels['unanswered'] = 'Yanıtlanmamış';
$labels['keepaliveevery']  = 'her $n dakikada bir'; 
$labels['keepalive']  = 'Yeni postaları denetle:';
$labels['focusonnewmessage'] = 'Yeni posta geldiğinde web tarayıcı penceresine odaklan.';
$labels['skipdeleted'] = 'Silinmiş postaları gösterme';

$labels['B'] = 'B'; 
$labels['KB'] = 'KB'; 
$labels['MB'] = 'MB'; 
$labels['GB'] = 'GB'; 

$labels['mimeparamfolding'] = 'Eklenti isimleri';
$labels['2231folding'] = 'Tam RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Tam RFC 2047 (diğer)';
$labels['advancedoptions'] = 'Gelişmiş seçenekler';

?>
