<?php

/*

 +-----------------------------------------------------------------------+
 | language/el/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Jim Deves <jim@cobaltblue.gr>                                 |
 |         John Economou <hsoc@irc.gr>                                   |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1160 2008-03-01 15:32:44Z yllar $

*/

$labels = array();
$labels['welcome'] = 'Καλώς ήρθατε στο $product';
$labels['username'] = 'Όνομα Χρήστη';
$labels['password'] = 'Κωδικός Πρόσβασης';
$labels['server'] = 'Διακομιστής';
$labels['login'] = 'Είσοδος';
$labels['logout'] = 'Έξοδος';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Προσωπικές Ρυθμίσεις';
$labels['addressbook'] = 'Βιβλίο Διευθύνσεων';
$labels['inbox'] = 'Εισερχόμενα';
$labels['drafts'] = 'Πρόχειρα';
$labels['sent'] = 'Απεσταλμένα';
$labels['trash'] = 'Κάδος';
$labels['junk'] = 'Junk';
$labels['subject'] = 'Θέμα';
$labels['from'] = 'Αποστολέας';
$labels['to'] = 'Παραλήπτης';
$labels['cc'] = 'Αντίγραφο';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Απάντηση σε';
$labels['date'] = 'Ημ/νία';
$labels['size'] = 'Μέγεθος';
$labels['priority'] = 'Πρoτεραιότητα';
$labels['organization'] = 'Οργανισμός';
$labels['reply-to'] = 'Απάντηση σε';
$labels['mailboxlist'] = 'Φάκελοι';
$labels['messagesfromto'] = 'Μηνύματα $from από $to έως $count';
$labels['messagenrof'] = 'Μήνυμα $nr από $count';
$labels['moveto'] = 'μετακίνηση σε...';
$labels['download'] = 'κατέβασμα';
$labels['filename'] = 'Όνομα αρχείου';
$labels['filesize'] = 'Μέγεθος αρχείου';
$labels['preferhtml'] = 'Προτίμηση HTML';
$labels['htmlmessage'] = 'Μήνυμα HTML';
$labels['prettydate'] = 'Όμορφη ημ/νία';
$labels['addtoaddressbook'] = 'Προσθήκη στο Βιβλίο Διευθύνσεων';
$labels['sun'] = 'Κυρ';
$labels['mon'] = 'Δευτ';
$labels['tue'] = 'Τρι';
$labels['wed'] = 'Τετ';
$labels['thu'] = 'Πεμ';
$labels['fri'] = 'Παρ';
$labels['sat'] = 'Σαβ';
$labels['sunday'] = 'Κυριακή';
$labels['monday'] = 'Δευτέρα';
$labels['tuesday'] = 'Τρίτη';
$labels['wednesday'] = 'Τετάρτη';
$labels['thursday'] = 'Πέμπτη';
$labels['friday'] = 'Παρασκευή';
$labels['saturday'] = 'Σάββατο';
$labels['today'] = 'Σήμερα';
$labels['checkmail'] = 'Έλεγχος για νέα μηνύματα';
$labels['writenewmessage'] = 'Δημιουργία νέου μηνύματος';
$labels['replytomessage'] = 'Απάντηση';
$labels['replytoallmessage'] = 'Απάντηση στον αποστολέα και όλους τους παραλήπτες';
$labels['forwardmessage'] = 'Προώθηση μηνύματος';
$labels['deletemessage'] = 'Διαγραφή μηνύματος';
$labels['movemessagetotrash'] = 'Μετακίνηση μηνύματος στον Κάδο';
$labels['printmessage'] = 'Εκτύπωση';
$labels['previousmessage'] = 'Εμφάνιση προηγούμενου μηνύματος';
$labels['previousmessages'] = 'Εμφάνιση προηγούμενης ομάδας μηνυμάτων';
$labels['firstmessage'] = 'Εμφάνιση πρώτου μυνήματος';
$labels['firstmessages'] = 'Εμφάνιση πρώτης ομάδας μηνυμάτων';
$labels['nextmessage'] = 'Εμφάνιση επόμενου μηνύματος';
$labels['nextmessages'] = 'Εμφάνιση επόμενης ομάδας μηνυμάτων';
$labels['lastmessage'] = 'Εμφάνιση τελευταίου μηνύματος';
$labels['lastmessages'] = 'Εμφάνιση τελευταίας ομάδας μηνυμάτων';
$labels['backtolist'] = 'Επιστροφή στη λίστα μηνυμάτων';
$labels['viewsource'] = 'Προβολή πηγαίου κώδικα';
$labels['markmessages'] = 'Σήμανση μηνυμάτων';
$labels['markread'] = 'ως αναγνωσμένα';
$labels['markunread'] = 'ως μη-αναγνωσμένα';
$labels['select'] = 'Επιλογή';
$labels['all'] = 'Όλα';
$labels['none'] = 'Κανένα';
$labels['unread'] = 'Μη αναγνωσμένα';
$labels['compact'] = 'Συμπίεση';
$labels['empty'] = '’δειασμα';
$labels['purge'] = 'Καθάρισμα';
$labels['quota'] = 'Χρήση δίσκου';
$labels['unknown'] = 'άγνωστο';
$labels['unlimited'] = 'απεριόριστο';
$labels['quicksearch'] = 'Γρήγορη Εύρεση';
$labels['resetsearch'] = 'Επαναφορά Εύρεσης';
$labels['compose'] = 'Συγγραφή μηνύματος';
$labels['savemessage'] = 'Αποθήκευση ως πρόχειρου';
$labels['sendmessage'] = 'Αποστολή μηνύματος τώρα';
$labels['addattachment'] = 'Επισύναψη αρχείου';
$labels['charset'] = 'Charset';
$labels['editortype'] = 'Είδος επεξεργαστή κειμένου';
$labels['returnreceipt'] = 'Αναφορά Παράδοσης';
$labels['checkspelling'] = 'Έλεγχος ορθογραφίας';
$labels['resumeediting'] = 'Συνέχιση επεξεργασίας';
$labels['revertto'] = 'Επαναφορά σε';
$labels['attachments'] = 'Επισυνημένα';
$labels['upload'] = 'Ανέβασμα';
$labels['close'] = 'Κλείσιμο';
$labels['low'] = 'Χαμηλή';
$labels['lowest'] = 'Χαμηλότερη';
$labels['normal'] = 'Κανονική';
$labels['high'] = 'Υψηλή';
$labels['highest'] = 'Υψηλότερη';
$labels['nosubject'] = '(κανένα θέμα)';
$labels['showimages'] = 'Εμφάνιση εικόνων';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Απλό κείμενο';
$labels['addcc'] = 'Προσθήκη Cc';
$labels['addbcc'] = 'Προσθήκη Bcc';
$labels['addreplyto'] = 'Προσθήκη Απάντηση-Σε';
$labels['mdnrequest'] = 'Ο αποστολέας του μηνύματος έχει ζητήσει να ενημερωθεί όταν διαβάσετε αυτό το μήνυμα. Επιθυμείτε να ενημερώστε τον αποστολέα;';
$labels['receiptread'] = 'Αναφορά (ανάγνωσης)';
$labels['yourmessage'] = 'Αυτό είναι μια Αναφορά για το μήνυμά σας';
$labels['receiptnote'] = 'Σημείωση: Αυτή η αναφορά επιβεβαιώνει μόνο ότι το μήνυμα εμφανίστηκε μόνο στον υπολογιστή του παραλήπτη. Δεν επιβεβαιώνει ότι ο παραλήπτης έχει διαβάσει ή έχει κατανοήσει το περιεχόμενο του μηνύματος.';
$labels['name'] = 'Εμφανιζόμενο όνομα';
$labels['firstname'] = 'Όνομα';
$labels['surname'] = 'Επώνυμο';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Προσθήκη επιλεγμένης επαφής στο Βιβλίο Διευθύνσεων';
$labels['editcontact'] = 'Επεξεργασία επαφής';
$labels['edit'] = 'Επεξεργασία';
$labels['cancel'] = 'Ακύρωση';
$labels['save'] = 'Αποθήκευση';
$labels['delete'] = 'Διαγραφή';
$labels['newcontact'] = 'Δημιουργία νέας καρτέλας επαφής';
$labels['deletecontact'] = 'Διαγραφή επιλεγμένων επαφών';
$labels['composeto'] = 'Σύνθεση μηνύματος προς';
$labels['contactsfromto'] = 'Επαφή $from από $to έως $count';
$labels['print'] = 'Εκτύπωση';
$labels['export'] = 'Εξαγωγή';
$labels['previouspage'] = 'Εμφάνιση προηγούμενης σελίδας';
$labels['firstpage'] = 'Εμφάνιση πρώτης σελίδας';
$labels['nextpage'] = 'Εμφάνιση επόμενης σελίδας';
$labels['lastpage'] = 'Εμφάνιση τελευταίας σελίδας';
$labels['groups'] = 'Ομάδες';
$labels['personaladrbook'] = 'Προσωπικό Βιβλίο Διευθύνσεων';
$labels['settingsfor'] = 'Ρυθμίσεις για';
$labels['preferences'] = 'Προτιμήσεις';
$labels['userpreferences'] = 'Προτιμήσεις χρήστη';
$labels['editpreferences'] = 'Επεξεργασία προτιμήσεων χρήστη';
$labels['identities'] = 'Ταυτότητες';
$labels['manageidentities'] = 'Διαχείριση ταυτοτήτων για το λογαριασμό αυτό';
$labels['newidentity'] = 'Νέα ταυτότητα';
$labels['newitem'] = 'Νέο αντικείμενο';
$labels['edititem'] = 'Επεξεργασία αντικειμένου';
$labels['setdefault'] = 'Ορισμός ως προεπιλογή';
$labels['language'] = 'Γλώσσα';
$labels['timezone'] = 'Περιοχή ώρας';
$labels['pagesize'] = 'Γραμμές ανά σελίδα';
$labels['signature'] = 'Υπογραφή';
$labels['dstactive'] = 'Daylight savings';
$labels['htmleditor'] = 'Σύνθεση HTML μηνύματος';
$labels['htmlsignature'] = 'Υπογραφή HTML';
$labels['previewpane'] = 'Εμφάνιση προηγούμενου παραθύρου';
$labels['autosavedraft'] = 'Αυτόματη προχείρου';
$labels['everynminutes'] = 'κάθε $n λεπτά';
$labels['never'] = 'ποτέ';
$labels['folder'] = 'Φάκελος';
$labels['folders'] = 'Φάκελοι';
$labels['foldername'] = 'Όνομα φακέλου';
$labels['subscribed'] = 'Εγγραφή';
$labels['messagecount'] = 'Μηνύματα';
$labels['create'] = 'Δημιουργία';
$labels['createfolder'] = 'Δημιουργία νέου φακέλου';
$labels['rename'] = 'Μετονομασία';
$labels['renamefolder'] = 'Μετονομασία φακέλου';
$labels['deletefolder'] = 'Διαγραφή φακέλου';
$labels['managefolders'] = 'Διαχείριση φακέλων';
$labels['sortby'] = 'Ταξινόμηση κατά';
$labels['sortasc'] = 'Αύξουσα ταξινόμηση';
$labels['sortdesc'] = 'Φθίνουσα ταξινόμηση';

?>