<?php

/*

+-----------------------------------------------------------------------+
| language/sl/messages.inc                                              |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Andrej Sossi <asossi@dotcom.ts.it>                            |
|         Andrej Mocilnik <amocilnik@dotcom.ts.it>                      |
+-----------------------------------------------------------------------+

@version $Id: messages.inc 1109 2008-02-17 20:22:05Z thomasb $

*/

$messages = array();
$messages['loginfailed'] = 'Prijava neuspešna';
$messages['cookiesdisabled'] = 'Vaš brskalnik nima omogočenih piškotov';
$messages['sessionerror'] = 'Vaša seja je napačna oz. potekla';
$messages['imaperror'] = 'Povezava na IMAP strežnik neuspešna';
$messages['nomessagesfound'] = 'Ni sporočil';
$messages['loggedout'] = 'Uspešno ste zaključili sejo. Nasvidenje!';
$messages['mailboxempty'] = 'Nabiralnik je prazen';
$messages['loading'] = 'Nalagam...';
$messages['loadingdata'] = 'Nalagam podatke...';
$messages['checkingmail'] = 'Iščem nova sporočila...';
$messages['sendingmessage'] = 'Pošiljam sporočilo...';
$messages['messagesent'] = 'Sporočilo uspešno poslano';
$messages['savingmessage'] = 'Shranjujem sporočilo';
$messages['messagesaved'] = 'Sporočilo shranjeno v osnutke';
$messages['successfullysaved'] = 'Uspešno shranjeno';
$messages['addedsuccessfully'] = 'Vizitka uspešno dodana';
$messages['contactexists'] = 'Vizitka s tem e-naslovom že obstaja!';
$messages['blockedimages'] = 'Zaradi vaše varnosti slike v tem sporočilu niso prikazane.';
$messages['encryptedmessage'] = 'To je zaščiteno sporočilo, na žalost ne more biti prikazano. Oprostite!';
$messages['nocontactsfound'] = 'Ne najdem nobene vizitke';
$messages['contactnotfound'] = 'Ne najdem iskane vizitke';
$messages['sendingfailed'] = 'Pošiljanje sporočila neuspešno';
$messages['errorsaving'] = 'Pri shranjevanju je prišlo do napake';
$messages['errormoving'] = 'Ne morem premakniti sporočila';
$messages['errordeleting'] = 'Ne morem izbrisati sporočila';
$messages['deletecontactconfirm'] = 'Želite zbrisati izbrane vizitke?';
$messages['deletemessagesconfirm'] = 'Želite zbrisati izbrana sporočila?';
$messages['deletefolderconfirm'] = 'Želite zbrisati to mapo?';
$messages['purgefolderconfirm'] = 'Želite zbrisati vsa sporočila v tej mapi?';
$messages['formincomplete'] = 'Obrazec ni bil izpolnjen v celoti';
$messages['noemailwarning'] = 'Prosim vpišite veljaven e-naslov';
$messages['nonamewarning'] = 'Prosim vpišite ime';
$messages['nopagesizewarning'] = 'Prosim vpišite velikost strani';
$messages['norecipientwarning'] = 'Prosim vpišite vsaj enega naslovnika';
$messages['nosubjectwarning'] = 'Polje "Naslov" je prazno. Ali ga želite vpisati zdaj?';
$messages['nobodywarning'] = 'Pošlji to sporočilo brez besedila?';
$messages['notsentwarning'] = 'Sporočilo ni bilo poslano. Želite opustiti vaše sporočilo?';
$messages['noldapserver'] = 'Prosim izberite ldap strežnik za iskanje';
$messages['nocontactsreturned'] = 'Ne najdem vizitk';
$messages['nosearchname'] = 'Prosim vpišite ime ali e-naslov stika';
$messages['searchsuccessful'] = 'Število dobljenih sporočil: $nr';
$messages['searchnomatch'] = 'Iskanje ni doprineslo nobenega rezultata';
$messages['searching'] = 'Iščem...';
$messages['checking'] = 'Previrjam...';
$messages['nospellerrors'] = 'Ni pravopisnih napak';
$messages['folderdeleted'] = 'Mapa uspešno zbrisana';
$messages['deletedsuccessfully'] = 'Uspešno zbrisano';
$messages['converting'] = 'Brišem obogatitev besedila...';
$messages['messageopenerror'] = 'Neuspešno nalaganje sporočila s stežnika';
$messages['fileuploaderror'] = 'Neuspešno nalaganje datoteke';
$messages['filesizeerror'] = 'Naložena datoteka presega maksimalno velikost $size';
$messages['copysuccess'] = 'Število prepisanih naslovov: $nr';
$messages['copyerror'] = 'Ne morem prepisati nobenega naslova';
$messages['sourceisreadonly'] = 'Izvirnik naslova je samo berljiv';
$messages['errorsavingcontact'] = 'Ne morem shraniti vizitke';
$messages['movingmessage'] = 'Premakni besedilo...';
$messages['receiptsent'] = 'Potrdilo o prebranem sporočilu je bilo uspešno poslano';
$messages['errorsendingreceipt'] = 'Nemogoče poslati potrdilo o prebranem sporočilu';
$messages['nodeletelastidentity'] = 'Nemogoče zbrisati identitete. Ta je edina, ki imate.';
$messages['addsubfolderhint'] = 'Mapa bo narejena kot podmapa trenutno izbrane mape';

?>
