<?php

/*

+-----------------------------------------------------------------------+
| language/id_ID/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Putu Arya Sabda Wijaya <klunxer@gmail.com>                    |
+-----------------------------------------------------------------------+

@version $Id$

*/

$labels = array();
$labels['welcome'] = 'Selamat datang di $product';
$labels['username'] = 'Username';
$labels['password'] = 'Password';
$labels['server'] = 'Server';
$labels['login'] = 'Masuk';
$labels['logout'] = 'Keluar';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Pengaturan Pribadi';
$labels['addressbook'] = 'Buku Alamat';
$labels['inbox'] = 'Kotak Masuk';
$labels['drafts'] = 'Daftar tunggu';
$labels['sent'] = 'Terkirim';
$labels['trash'] = 'Item-itenm tergapus';
$labels['junk'] = 'Sampah';
$labels['subject'] = 'Judul';
$labels['from'] = 'Pengirim';
$labels['to'] = 'Penerima';
$labels['cc'] = 'Lampiran';
$labels['bcc'] = 'Lampiran tersembunyi';
$labels['replyto'] = 'Balas kepada';
$labels['date'] = 'Tangal';
$labels['size'] = 'Ukuran';
$labels['priority'] = 'Prioritas';
$labels['organization'] = 'Organisasi';
$labels['reply-to'] = 'Balas kepada';
$labels['mailboxlist'] = 'Map-map';
$labels['messagesfromto'] = 'Pesan $from kepada $to sebanyak $count';
$labels['messagenrof'] = 'Pesan $nr sebanyak $count';
$labels['moveto'] = 'dipindahkan...';
$labels['download'] = 'unduh';
$labels['filename'] = 'Nama berkas';
$labels['filesize'] = 'Ukuran berkas';
$labels['preferhtml'] = 'Lebih suka HTML';
$labels['htmlmessage'] = 'Pesan HTML';
$labels['prettydate'] = 'Tanggal cantik';
$labels['addtoaddressbook'] = 'Tambahkan ke buku tamu';
$labels['sun'] = 'Min';
$labels['mon'] = 'Sen';
$labels['tue'] = 'Sel';
$labels['wed'] = 'Rab';
$labels['thu'] = 'Kam';
$labels['fri'] = 'Jum';
$labels['sat'] = 'Sab';
$labels['sunday'] = 'Minggu';
$labels['monday'] = 'Senin';
$labels['tuesday'] = 'Selasa';
$labels['wednesday'] = 'Rabu';
$labels['thursday'] = 'Kamis';
$labels['friday'] = 'Jumat';
$labels['saturday'] = 'Sabtu';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Mei';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Ags';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Des';
$labels['longjan'] = 'Januari';
$labels['longfeb'] = 'Februari';
$labels['longmar'] = 'Maret';
$labels['longapr'] = 'April';
$labels['longmay'] = 'Mei';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'Juli';
$labels['longaug'] = 'Agustus';
$labels['longsep'] = 'Spetember';
$labels['longoct'] = 'Oktober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'Desember';
$labels['today'] = 'Hari ini';
$labels['checkmail'] = 'Periksa pesan baru';
$labels['writenewmessage'] = 'Buat pesan baru';
$labels['replytomessage'] = 'Balas pesan';
$labels['replytoallmessage'] = 'balas ke pengirim dan semua penerima';
$labels['forwardmessage'] = 'Teruskan pesan';
$labels['deletemessage'] = 'Pindahkan pesan ke tong sampah';
$labels['movemessagetotrash'] = 'Pindahkan pesan ke tong sampah';
$labels['printmessage'] = 'cetak pesan ini';
$labels['previousmessage'] = 'Perlihatkan pesan sebelumnya';
$labels['previousmessages'] = 'Perlihatkan kumpulan pesan-pesan sebelumnya';
$labels['firstmessage'] = 'Perlihatkan pesan pertama';
$labels['firstmessages'] = 'Perlihatkan kumpulan pesan pertama';
$labels['nextmessage'] = 'Perlihatkan pesan berikutnya';
$labels['nextmessages'] = 'Perlihatkan kumpulan pesan-pesan berikutnya';
$labels['lastmessage'] = 'Perlihatkan pesan terakhir';
$labels['lastmessages'] = 'Perlihatkan kumpulan pesan terkahir';
$labels['backtolist'] = 'Kembali ke daftar pesan';
$labels['viewsource'] = 'Perlihatkan kode sumber';
$labels['markmessages'] = 'Tandai Pesan';
$labels['markread'] = 'Terbaca';
$labels['markunread'] = 'Belum Terbaca';
$labels['markflagged'] = 'Sudah ditandai';
$labels['markunflagged'] = 'Belum ditandai';
$labels['select'] = 'Pilih';
$labels['all'] = 'Semua';
$labels['none'] = 'Tidak satupun';
$labels['unread'] = 'Belum terbaca';
$labels['compact'] = 'Ramping';
$labels['empty'] = 'Kosong';
$labels['purge'] = 'Kosongkan';
$labels['quota'] = 'Penggunaan kandar';
$labels['unknown'] = 'Tidak dikenal';
$labels['unlimited'] = 'Tidak terbatas';
$labels['quicksearch'] = 'Pencarian cepat';
$labels['resetsearch'] = 'Atur ulang pencarian';
$labels['compose'] = 'Tulis sebuah pesan';
$labels['savemessage'] = 'Simpan daftar tunggu ini';
$labels['sendmessage'] = 'Kirim pesan sekarang';
$labels['addattachment'] = 'Sisipkan sebuah berkas';
$labels['charset'] = 'set karakter';
$labels['editortype'] = 'Tipe editor';
$labels['returnreceipt'] = 'Kembalikan penerima';
$labels['checkspelling'] = 'Pemeriksaan ejaan';
$labels['resumeediting'] = 'Lanjutkan mengedit';
$labels['revertto'] = 'Balik ke';
$labels['attachments'] = 'Sisispan';
$labels['upload'] = 'unggah';
$labels['close'] = 'Tutup';
$labels['low'] = 'Rendah';
$labels['lowest'] = 'Terrendah';
$labels['normal'] = 'Normal';
$labels['high'] = 'Tinggi';
$labels['highest'] = 'tertinggi';
$labels['nosubject'] = '(tanpa judul)';
$labels['showimages'] = 'Tampilkan gambar';
$labels['alwaysshow'] = 'Selalu tampilkan gambar dari $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Text murni';
$labels['savesentmessagein'] = 'Simpan pesan terkirim di';
$labels['dontsave'] = 'Jangan disimpan';
$labels['addcc'] = 'Tambah Cc';
$labels['addbcc'] = 'Tambah Bcc';
$labels['addreplyto'] = 'Tambah Balas Ke';
$labels['mdnrequest'] = 'Pengirim pesan ini telah meminta untuk diberitahu ketika Anda membaca pesan ini. Apakah anda ingin memberitahu pengirim?';
$labels['receiptread'] = 'Tanda Terima (baca)';
$labels['yourmessage'] = 'Ini adalah Tanda Terima untuk pesan Anda';
$labels['receiptnote'] = 'Catatan: Tanda Terima ini hanya mengesahkan bahwa pesan telah diperlihatkan pada komputer penerima. Tidak ada jaminan bahwa penerima telah membaca atau mengerti isi pesan.';
$labels['name'] = 'Tampilkan nama';
$labels['firstname'] = 'Nama depan';
$labels['surname'] = 'Nama belakang';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Tambah kontak baru';
$labels['editcontact'] = 'Ubah kontak';
$labels['edit'] = 'Ubah';
$labels['cancel'] = 'Batal';
$labels['save'] = 'Simpan';
$labels['delete'] = 'Hapus';
$labels['newcontact'] = 'Buat kartu kontak baru';
$labels['deletecontact'] = 'Hapus kontak terpilih';
$labels['composeto'] = 'Tulis surat kepada';
$labels['contactsfromto'] = 'Kontak $from kepada $to sebanyak $count';
$labels['print'] = 'Cetak';
$labels['export'] = 'Ekspor';
$labels['previouspage'] = 'Perlihatkan kumpulan sebelumnya';
$labels['firstpage'] = 'Perlihatkan kumpulan pertama';
$labels['nextpage'] = 'Perlihatkan kumpulan selanjutnya';
$labels['lastpage'] = 'Perlihatkan kumpulan terakhir';
$labels['groups'] = 'Kelompok';
$labels['personaladrbook'] = 'Alamat personal';
$labels['settingsfor'] = 'Pengaturan untuk';
$labels['preferences'] = 'Pilihan';
$labels['userpreferences'] = 'Pilihan pengguna';
$labels['editpreferences'] = 'Ubah pilihan pengguna';
$labels['identities'] = 'Identitas';
$labels['manageidentities'] = 'Atur identitas untuk akun ini';
$labels['newidentity'] = 'Identitas baru';
$labels['newitem'] = 'Item baru';
$labels['edititem'] = 'Ubah item';
$labels['setdefault'] = 'Pengaturan Awal';
$labels['language'] = 'Bahasa';
$labels['timezone'] = 'Daerah Waktu';
$labels['pagesize'] = 'Baris per halaman';
$labels['signature'] = 'Tanda tangan';
$labels['dstactive'] = 'Waktu Musim Panas';
$labels['htmleditor'] = 'Tulis pesan HTML';
$labels['htmlsignature'] = 'Tandatangan HTML';
$labels['previewpane'] = 'Perlihatkan tempat melihat';
$labels['skin'] = 'Tampilan antarmuka';
$labels['logoutclear'] = 'Bersihkan Tong Sampah saat keluar';
$labels['logoutcompact'] = 'Mampatkan Kotak Masuk saat keluar';
$labels['uisettings'] = 'Antarmuka pengguna';
$labels['serversettings'] = 'Pengaturan Server';
$labels['mailboxview'] = 'Tampilan Kotak Surat';
$labels['mdnrequests'] = 'Pemberitahuan pada pengirim';
$labels['askuser'] = 'tanya si pengguna';
$labels['autosend'] = 'kirim otomatis';
$labels['ignore'] = 'acuhkan';
$labels['readwhendeleted'] = 'Tandai pesan sebagai terbaca saat dihapus';
$labels['flagfordeletion'] = 'Tandai pesan untuk penghapusan daripada dihapus';
$labels['showinlineimages'] = 'Tampilkan gambar terlampir dibawah pesan';
$labels['autosavedraft'] = 'Otomatis menyimpan pesan tertunda';
$labels['everynminutes'] = 'setiap $n menit';
$labels['never'] = 'tidak pernah';
$labels['messagesdisplaying'] = 'Penampilan Pesan';
$labels['messagescomposition'] = 'Pengaturan Pesan';
$labels['folder'] = 'Map';
$labels['folders'] = 'Map-map';
$labels['foldername'] = 'Nama map';
$labels['subscribed'] = 'Subscribed';
$labels['messagecount'] = 'Pesan-pesan';
$labels['create'] = 'Buat';
$labels['createfolder'] = 'Buat map baru';
$labels['rename'] = 'Namai ulang';
$labels['renamefolder'] = 'Namai ulang map';
$labels['deletefolder'] = 'Hapus map';
$labels['managefolders'] = 'Atur map';
$labels['specialfolders'] = 'Map Khusus';
$labels['sortby'] = 'Urut berdasarkan';
$labels['sortasc'] = 'Urut menaik';
$labels['sortdesc'] = 'Urut menurun';

?>
