<?php

/*

 +-----------------------------------------------------------------------+
 | language/ge/messages.inc                                              |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Zaza Zviadadze <zviadadze@gmail.com>                          |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 842 2007-10-20 13:55:02Z  zaza $

*/

$messages = array();
$messages['loginfailed'] = 'შესვლა შეუძლებელია';
$messages['cookiesdisabled'] = 'თქვენი ბროუზერი კუკიებს არ პასუხობს';
$messages['sessionerror'] = 'თქვენი სესია არის მცდარი ან ვადაგასული';
$messages['imaperror'] = 'IMAP სერვერთან დაკავშირება შეუძლებელია';
$messages['nomessagesfound'] = 'არ არის ახალი შეტყობინება';
$messages['loggedout'] = 'წარმატებით დაიხურა თქვენი სესია';
$messages['mailboxempty'] = 'საფოსტო ყუთი ცარიელია';
$messages['loading'] = 'იტვირთება...';
$messages['loadingdata'] = 'მონაცემების ჩატვირთვა...';
$messages['checkingmail'] = 'ახალი შეტყობინების ნახვა';
$messages['sendingmessage'] = 'შეტყობინების გაგზავნა';
$messages['messagesent'] = 'შეტყობინება გაიგზავნა წარმატებით';
$messages['savingmessage'] = 'შეტყობინების შენახვა...';
$messages['messagesaved'] = 'შეტყობინების დროებით შენახვა';
$messages['successfullysaved'] = 'წარმატებით შეინახა';
$messages['addedsuccessfully'] = 'კონტაქტი წარმატებით დაემატა მისამართებში';
$messages['contactexists'] = 'კონტაქტი ამ მისამართზე უკვე არსებობს';
$messages['blockedimages'] = 'უსაფრთხოების მიზნით სურათების ჩვენება შეზღუდულია';
$messages['encryptedmessage'] = 'შეტყობინება დაშიფრულია და სამწუხაროდ ჩვენება შეუძლებელია';
$messages['nocontactsfound'] = 'კონტაქტი ვერ მოიძებნა';
$messages['contactnotfound'] = 'მოთხოვნილი კონტაქტი ვერ მოიძებნა';
$messages['sendingfailed'] = 'შეტყობინება ვერ გაიგზავნა';
$messages['errorsaving'] = 'შენახვის დროს მოხდა შეცდომა';
$messages['errormoving'] = 'შეტყობინების გადატანა შეუძლებელია';
$messages['errordeleting'] = 'შეტყობინების წაშლა შეუძლებელია';
$messages['deletecontactconfirm'] = 'ნამდვილად გსურთ მონიშნული კონტაქტების წაშლა?';
$messages['deletemessagesconfirm'] = 'ნამდვილად გსურთ მონიშნული შეტყობინებების წაშლა?';
$messages['deletefolderconfirm'] = 'ნამდვილად გსურთ ამ საქაღალდის წაშლა?';
$messages['purgefolderconfirm'] = 'ნამდვილად გსურთ ყველა შეტყობინების წაშლა აღნიშნულ საქაღალდეში?';
$messages['formincomplete'] = 'ყველა ველი არ არის შევსებული';
$messages['noemailwarning'] = 'მიუთითეთ სწორი ელ–ფოსტის მისამართი';
$messages['nonamewarning'] = 'მიუთითეთ სახელი';
$messages['nopagesizewarning'] = 'მიუთითეთ ფურცლის ზომა';
$messages['norecipientwarning'] = 'მიუთითეთ მიმღები';
$messages['nosubjectwarning'] = 'გსურთ თუ არა შეტყობინების გაგზავნა უსათაუროდ?';
$messages['nobodywarning'] = 'გსურთ თუ არა შეტყობინების გაგზავნა უტექსტოდ?';
$messages['notsentwarning'] = 'შეტყობინება ვერ იქნა გაგზავნილი. გსურთ თუ არა გზავნილის გაუქმება?';
$messages['noldapserver'] = 'მიუთითეთ LDAP სერვერი ძიებისთვის';
$messages['nocontactsreturned'] = 'კონტაქტები ვერ მოძებნა';
$messages['nosearchname'] = 'მიუთითეთ სახელი ან ელ–ფოსტის მისამართი';
$messages['searchsuccessful'] = '$nr შეტყობინეა მოიძებნა';
$messages['searchnomatch'] = 'შეტყობინება ვერ მოიძებნა';
$messages['searching'] = 'ძიება...';
$messages['checking'] = 'შემოწმება...';
$messages['nospellerrors'] = 'ორთოგრაფიული შეცდომა არ არის';
$messages['folderdeleted'] = 'საქაღალდე წარმატებით წაიშალა';
$messages['deletedsuccessfully'] = 'წარმატებით წაიშალა';
$messages['converting'] = 'შეტყობინების ფორმატირების გაუქმება...';
$messages['messageopenerror'] = 'შეტყობინება ვერ ჩაიტვირთა სერვერიდან';
$messages['fileuploaderror'] = 'ფაილი ვერ აიტვირთა';
$messages['filesizeerror'] = 'ატვირთული ფაილის ზომა მეტია დასაშვებ ფაილის მაქსიმალურ ზომაზე ($size)';
$messages['copysuccess'] = 'წარმატებით დაკოპირდა $nr მისამართი';
$messages['copyerror'] = 'ვერცერთი მისამართი ვერ დაკოპირდა';
$messages['sourceisreadonly'] = 'აღნიშნული მისამართის მხოლოდ წაკითხვაა შესაძლებელი';
$messages['errorsavingcontact'] = 'საკონტაქტო მისამართის შენახვა შეუძლებელია';
$messages['movingmessage'] = 'შეტყობინების გადატანა...';
$messages['receiptsent'] = 'წარმატებით გაიგზავნა';
$messages['errorsendingreceipt'] = 'არ გაიგზავნა';
$messages['nodeletelastidentity'] = 'წაშლა შეუძლებელია, ის თქვენთვის ერთადერთია';
$messages['addsubfolderhint'] = 'საქაღალდე შეიქმნება როგორც ქვესაქაღალდე მონიშნულ საქაღალდეში';

?>
