<?php

/*

+-----------------------------------------------------------------------+
| language/sk/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Marek Kutnar <marek19@zmail.sk>                               |
|         Lukas Kraic  <lukas.kraic@truni.sk>                           |
|         Peter Mann   <peter.mann@tuke.sk>                             |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Vitajte v $product';
$labels['username'] = 'Prihlasovacie meno';
$labels['password'] = 'Heslo';
$labels['server'] = 'Server';
$labels['login'] = 'Prihlásiť';
$labels['logout'] = 'Odhlásiť';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Osobné nastavenia';
$labels['addressbook'] = 'Adresár';
$labels['inbox'] = 'Doručená pošta';
$labels['drafts'] = 'Rozpísané';
$labels['sent'] = 'Odoslané';
$labels['trash'] = 'Kôš';
$labels['junk'] = 'Nevyžiadaná pošta';
$labels['subject'] = 'Predmet';
$labels['from'] = 'Odosielateľ';
$labels['to'] = 'Adresát';
$labels['cc'] = 'Kópia';
$labels['bcc'] = 'Tajná kópia';
$labels['replyto'] = 'Odpovedať na';
$labels['date'] = 'Dátum';
$labels['size'] = 'Veľkosť';
$labels['priority'] = 'Priorita';
$labels['organization'] = 'Organizácia';
$labels['reply-to'] = 'Odpovedať na';
$labels['mailboxlist'] = 'Adresár';
$labels['messagesfromto'] = 'Správy od $from do $to z $count';
$labels['messagenrof'] = 'Správa $nr z $count';
$labels['moveto'] = 'presunúť do...';
$labels['download'] = 'stiahnuť';
$labels['filename'] = 'Meno súboru';
$labels['filesize'] = 'Veľkosť súboru';
$labels['preferhtml'] = 'Uprednostniť HTML zobrazenie';
$labels['htmlmessage'] = 'HTML správa';
$labels['prettydate'] = 'Krajší dátum';
$labels['addtoaddressbook'] = 'Pridať do adresára';
$labels['sun'] = 'Ne';
$labels['mon'] = 'Po';
$labels['tue'] = 'Ut';
$labels['wed'] = 'St';
$labels['thu'] = 'Št';
$labels['fri'] = 'Pi';
$labels['sat'] = 'So';
$labels['sunday'] = 'Nedeľa';
$labels['monday'] = 'Pondelok';
$labels['tuesday'] = 'Utorok';
$labels['wednesday'] = 'Streda';
$labels['thursday'] = 'Štvrtok';
$labels['friday'] = 'Piatok';
$labels['saturday'] = 'Sobota';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Máj';
$labels['jun'] = 'Jún';
$labels['jul'] = 'Júl';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Január';
$labels['longfeb'] = 'Február';
$labels['longmar'] = 'Marec';
$labels['longapr'] = 'Apríl';
$labels['longmay'] = 'Máj';
$labels['longjun'] = 'Jún';
$labels['longjul'] = 'Júl';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Október';
$labels['longnov'] = 'November';
$labels['longdec'] = 'December';
$labels['today'] = 'Dnes';
$labels['checkmail'] = 'Skontrolovať nové správy';
$labels['writenewmessage'] = 'Vytvoriť novú správu';
$labels['replytomessage'] = 'Odpovedať';
$labels['replytoallmessage'] = 'Odpovedať všetkým';
$labels['forwardmessage'] = 'Poslať ďalej';
$labels['deletemessage'] = 'Zmazať správu';
$labels['movemessagetotrash'] = 'Presunúť správu do koša';
$labels['printmessage'] = 'Vytlačiť správu';
$labels['previousmessage'] = 'Zobraziť predchádzajúcu správu';
$labels['previousmessages'] = 'Zobraziť predchádzajúcu stránku správ';
$labels['firstmessage'] = 'Zobraziť prvú správu';
$labels['firstmessages'] = 'Zobraziť prvú stránku správ';
$labels['nextmessage'] = 'Zobraziť ďalšiu správu';
$labels['nextmessages'] = 'Zobraziť ďalšiu stránku správ';
$labels['lastmessage'] = 'Zobraziť poslednú správu';
$labels['lastmessages'] = 'Zobraziť poslednú stránku správ';
$labels['backtolist'] = 'Späť na zoznam správ';
$labels['viewsource'] = 'Ukázať zdroj správy';
$labels['markmessages'] = 'Označiť správy';
$labels['markread'] = 'Ako prečítané';
$labels['markunread'] = 'Ako neprečítané';
$labels['markflagged'] = 'Ako označené';
$labels['markunflagged'] = 'Ako neoznačené';
$labels['select'] = 'Výber';
$labels['all'] = 'Všetky';
$labels['none'] = 'Žiadne';
$labels['unread'] = 'Neprečítané';
$labels['compact'] = 'Zhustiť priečinok';
$labels['empty'] = 'Prázdne';
$labels['purge'] = 'Vyprázdniť';
$labels['quota'] = 'Zaplnenie schránky';
$labels['unknown'] = 'neznáme';
$labels['unlimited'] = 'neobmedzené';
$labels['quicksearch'] = 'Rýchle vyhľadávanie';
$labels['resetsearch'] = 'Vyčistiť vyhľadávanie';
$labels['openinextwin'] = 'Otvoriť v novom okne';
$labels['compose'] = 'Vytvoriť správu';
$labels['savemessage'] = 'Uložiť do rozpísaných';
$labels['sendmessage'] = 'Odoslať správu';
$labels['addattachment'] = 'Pridať prílohu';
$labels['charset'] = 'Znaková sada';
$labels['editortype'] = 'Typ editora';
$labels['returnreceipt'] = 'Potvrdenie o doručení';
$labels['checkspelling'] = 'Skontrolovať pravopis';
$labels['resumeediting'] = 'Pokračovať v úpravách';
$labels['revertto'] = 'Vrátiť sa na';
$labels['attachments'] = 'Prílohy';
$labels['upload'] = 'Nahrať';
$labels['close'] = 'Zatvoriť';
$labels['low'] = 'Nízka';
$labels['lowest'] = 'Najnižšia';
$labels['normal'] = 'Normálna';
$labels['high'] = 'Vysoká';
$labels['highest'] = 'Najvyššia';
$labels['nosubject'] = '(bez predmetu)';
$labels['showimages'] = 'Ukázať obrázky';
$labels['alwaysshow'] = 'Vždy zobraziť obrázky od $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Čistý text';
$labels['savesentmessagein'] = 'Ukladať odoslané správy do';
$labels['dontsave'] = 'Neukladať';
$labels['maxuploadsize'] = 'Maximálna povolená veľkosť súboru je $size';
$labels['addcc'] = 'Pridať kópiu';
$labels['addbcc'] = 'Pridať skrytú kopiu';
$labels['addreplyto'] = 'Pridať odpoveď';
$labels['mdnrequest'] = 'Odosielateľ tejto správy chce byť upozornený na to, že ste správu obdržali. Chcete potvrdiť prijatie správy?';
$labels['receiptread'] = 'Potvrdenie o prijatí správy';
$labels['yourmessage'] = 'Toto je potvrdenie o prijatí Vašej správy';
$labels['receiptnote'] = 'Poznámka: Toto potvrdenie negarantuje, že správa bola príjemcom prečítaná a porozumel jej obsahu.';
$labels['name'] = 'Celé meno';
$labels['firstname'] = 'Meno';
$labels['surname'] = 'Priezvisko';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Pridať nový kontakt';
$labels['editcontact'] = 'Upraviť kontakt';
$labels['edit'] = 'Upraviť';
$labels['cancel'] = 'Zrušiť';
$labels['save'] = 'Uložiť';
$labels['delete'] = 'Zmazať';
$labels['newcontact'] = 'Vytvoriť nový kontakt';
$labels['deletecontact'] = 'Zmazať zvolené kontakty';
$labels['composeto'] = 'Vytvoriť správu pre';
$labels['contactsfromto'] = 'Kontakty od $from do $to z $count';
$labels['print'] = 'Tlač';
$labels['export'] = 'Export';
$labels['exportvcards'] = 'Exportovať kontakty vo formáte vCard';
$labels['previouspage'] = 'Predchádzajúca stránka';
$labels['firstpage'] = 'Prvá stránka';
$labels['nextpage'] = 'Nasledujúca stránka';
$labels['lastpage'] = 'Posledná stránka';
$labels['groups'] = 'Skupiny';
$labels['personaladrbook'] = 'Osobné adresy';
$labels['import'] = 'Import';
$labels['importcontacts'] = 'Importovať kontakty';
$labels['importfromfile'] = 'Importovať zo súboru:';
$labels['importreplace'] = 'Nahradiť celý zoznam kontaktov';
$labels['importtext'] = 'Môžete nahrať kontakty z existujúcich adresárov. Podporujeme import adries vo formáte vCard.';
$labels['done'] = 'Hotovo';
$labels['settingsfor'] = 'Nastavenia pre';
$labels['preferences'] = 'Vlastnosti';
$labels['userpreferences'] = 'Používateľské nastavenia';
$labels['editpreferences'] = 'Upraviť používateľské nastavenia';
$labels['identities'] = 'Profily';
$labels['manageidentities'] = 'Spravovať profily pre tento účet';
$labels['newidentity'] = 'Nový profil';
$labels['newitem'] = 'Nová položka';
$labels['edititem'] = 'Upraviť položku';
$labels['setdefault'] = 'Obnoviť pôvodné';
$labels['autodetect'] = 'Automaticky';
$labels['language'] = 'Jazyk';
$labels['timezone'] = 'Časová zóna';
$labels['pagesize'] = 'Riadky na stránku';
$labels['signature'] = 'Podpis';
$labels['dstactive'] = 'Letný čas';
$labels['htmleditor'] = 'Vytvoriť HTML správu';
$labels['htmlsignature'] = 'HTML podpis';
$labels['previewpane'] = 'Ukázať náhľad';
$labels['skin'] = 'Vzhľad';
$labels['logoutclear'] = 'Vyprázdniť kôš pri odhlásení';
$labels['logoutcompact'] = 'Zhustiť priečinok Doručená pošta pri odhlásení';
$labels['uisettings'] = 'Používateľské rozhranie';
$labels['serversettings'] = 'Nastavenia servera';
$labels['mailboxview'] = 'Pohľad na schránku';
$labels['mdnrequests'] = 'Upozornenia odosielateľovi';
$labels['askuser'] = 'spýtať sa používateľa';
$labels['autosend'] = 'poslať automaticky';
$labels['ignore'] = 'ignorovať';
$labels['readwhendeleted'] = 'Označiť správu ';
$labels['flagfordeletion'] = 'Pri odstránení správy iba označiť správu ako odstránenú';
$labels['skipdeleted'] = 'Nezobrazovať zmazané správy';
$labels['showinlineimages'] = 'Zobraziť pripojené obrázky pod správou';
$labels['autosavedraft'] = 'Automaticky uložiť koncept';
$labels['everynminutes'] = 'každých $n minút';
$labels['keepalive'] = 'Kontrolovať nové správy';
$labels['never'] = 'nikdy';
$labels['messagesdisplaying'] = 'Zobrazovanie správ';
$labels['messagescomposition'] = 'Vytváranie správ';
$labels['mimeparamfolding'] = 'Názvy príloh';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (other)';
$labels['advancedoptions'] = 'Rozšírené nastavenia';
$labels['folder'] = 'Priečinok';
$labels['folders'] = 'Priečinky';
$labels['foldername'] = 'Názov priečinku';
$labels['subscribed'] = 'Prihlásený k odberu';
$labels['messagecount'] = 'Počet správ';
$labels['create'] = 'Vytvoriť';
$labels['createfolder'] = 'Vytvor nový priečinok';
$labels['rename'] = 'Premenovať';
$labels['renamefolder'] = 'Premenovať priečinok';
$labels['deletefolder'] = 'Zmazať priečinok';
$labels['managefolders'] = 'Spravovať priečinky';
$labels['specialfolders'] = 'Špeciálne priečinky';
$labels['sortby'] = 'Triediť podľa';
$labels['sortasc'] = 'Triediť vzostupne';
$labels['sortdesc'] = 'Triediť zostupne';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
