<?php

/*

 +-----------------------------------------------------------------------+
 | localization/kr/labels.inc                                            |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: lordmiss <lordmiss@lordmiss.com>                              |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 560 2007-05-17 15:01:26Z thomasb $

*/

$labels['welcome'] = '$product에 오신 것을 환영합니다';
$labels['welcome'] = '$product에 오신 것을 환영합니다';
$labels['username'] = '사용자명';
$labels['password'] = '비밀번호';
$labels['server'] = '서버';
$labels['login'] = '로그인';
$labels['logout'] = '로그아웃';
$labels['mail'] = '이메일';
$labels['settings'] = '개인 설정';
$labels['addressbook'] = '주소록';
$labels['inbox'] = '받은편지함';
$labels['drafts'] = '임시저장';
$labels['sent'] = '보낸편지함';
$labels['trash'] = '휴지통';
$labels['junk'] = '정크메일';
$labels['subject'] = '제목';
$labels['from'] = '보내는 사람';
$labels['to'] = '받는 사람';
$labels['cc'] = '참조';
$labels['bcc'] = '숨은 참조';
$labels['replyto'] = '회신 주소';
$labels['date'] = '날짜';
$labels['size'] = '크기';
$labels['priority'] = '우선순위';
$labels['organization'] = '기관';
$labels['reply-to'] = '회신 주소';
$labels['mailboxlist'] = '폴더';
$labels['messagesfromto'] = '$from 이 $to에게 보낸 메시지 $count 개';
$labels['messagenrof'] = '메시지 $count 개 중 $nr 개';
$labels['moveto'] = '이동...';
$labels['download'] = '다운로드';
$labels['filename'] = '파일 이름';
$labels['filesize'] = '파일 크기';
$labels['preferhtml'] = 'HTML 보이기';
$labels['htmlmessage'] = 'HTML 메시지';
$labels['prettydate'] = '날짜 형식';
$labels['addtoaddressbook'] = '주소록에 추가';
$labels['sun'] = '일';
$labels['mon'] = '월';
$labels['tue'] = '화';
$labels['wed'] = '수';
$labels['thu'] = '목';
$labels['fri'] = '금';
$labels['sat'] = '토';
$labels['sunday'] = '일요일';
$labels['monday'] = '월요일';
$labels['tuesday'] = '화요일';
$labels['wednesday'] = '수요일';
$labels['thursday'] = '목요일';
$labels['friday'] = '금요일';
$labels['saturday'] = '토요일';
$labels['today'] = '오늘';
$labels['checkmail'] = '새 메일 확인';
$labels['writenewmessage'] = '새 메일 작성';
$labels['replytomessage'] = '회신 작성';
$labels['replytoallmessage'] = '보낸이와 모든 수신자에게 회신';
$labels['forwardmessage'] = '메일 전달';
$labels['deletemessage'] = '메일 삭제';
$labels['movemessagetotrash'] = '메일 휴지통으로 이동';
$labels['printmessage'] = '메일 인쇄';
$labels['previousmessage'] = '이전 메일 보기';
$labels['previousmessages'] = '이전 메일 세트 보기';
$labels['firstmessage'] = '처음 메일 보기';
$labels['firstmessages'] = '처음 메일 세트 보기';
$labels['nextmessage'] = '다음 메일 보기';
$labels['nextmessages'] = '다음 메일 세트 보기';
$labels['lastmessage'] = '마지막 메일 보기';
$labels['lastmessages'] = '마지막 메일 세트 보기';
$labels['backtolist'] = '메일 목록으로';
$labels['viewsource'] = '소스 보기';
$labels['markmessages'] = '메시지 표시';
$labels['markread'] = '읽은 것으로';
$labels['markunread'] = '읽지 않은 것으로';
$labels['select'] = '선택';
$labels['all'] = '모두';
$labels['none'] = '없음';
$labels['unread'] = '읽지 않음';
$labels['compact'] = '간단하게';
$labels['empty'] = '비우기';
$labels['purge'] = '삭제';
$labels['quota'] = '디스크 사용';
$labels['unknown'] = '알수 없음';
$labels['unlimited'] = '제한 없음';
$labels['quicksearch'] = '빨리 찾기';
$labels['resetsearch'] = '찾기 리셋';
$labels['compose'] = '메일 쓰기';
$labels['savemessage'] = '드래프트 저장';
$labels['sendmessage'] = '메일 지금 보냄';
$labels['addattachment'] = '파일 첨부';
$labels['charset'] = '문자셋';
$labels['editortype'] = '편집기 형태';
$labels['returnreceipt'] = '수신 확인';
$labels['checkspelling'] = '스펠링 체크';
$labels['resumeediting'] = '편집 계속';
$labels['revertto'] = '돌아감';
$labels['attachments'] = '첨부 파일';
$labels['upload'] = '업로드';
$labels['close'] = '닫기';
$labels['low'] = '낮음';
$labels['lowest'] = '가장 낮음';
$labels['normal'] = '보통';
$labels['high'] = '높음';
$labels['highest'] = '가장 높음';
$labels['nosubject'] = '(제목 없음)';
$labels['showimages'] = '이미지 표시';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = '일반 텍스트';
$labels['addcc'] = '참조 넣기';
$labels['addbcc'] = '숨은참조 넣기';
$labels['addreplyto'] = '회신주소 넣기';
$labels['mdnrequest'] = '이 메시지를 보낸 분이 읽음 확인 요청을 했습니다. 확인할까요?';
$labels['receiptread'] = '읽음 확인 보내기';
$labels['yourmessage'] = '당신의 메시지를 읽었습니다.';
$labels['receiptnote'] = '주의: 이 확인은 이 메시지가 수신자의 컴퓨터에 표시된 것만을 의미합니다. 수신자가 반드시 이 메일을 읽거나 이해했다는 것은 아닙니다.';
$labels['name'] = '표시 이름';
$labels['firstname'] = '이름';
$labels['surname'] = '성';
$labels['email'] = '이메일';
$labels['addcontact'] = '새 연락처 추가';
$labels['editcontact'] = '연락처 편집';
$labels['edit'] = '편집';
$labels['cancel'] = '취소';
$labels['save'] = '저장';
$labels['delete'] = '삭제';
$labels['newcontact'] = '새 연락처 카드 만들기';
$labels['deletecontact'] = '선택한 연락처 삭제';
$labels['composeto'] = '새 메일 작성';
$labels['contactsfromto'] = '$from 에서 $to 로의 연락처 $count 개';
$labels['print'] = '인쇄';
$labels['export'] = '내보내기';
$labels['previouspage'] = '이전 세트 보기';
$labels['firstpage'] = '처음 세트 보기';
$labels['nextpage'] = '다음 세트 보기';
$labels['lastpage'] = '마지막 세트 보기';
$labels['groups'] = '그룹';
$labels['personaladrbook'] = '개인 주소';
$labels['settingsfor'] = '설정';
$labels['preferences'] = '환경 설정';
$labels['userpreferences'] = '사용자 환경';
$labels['editpreferences'] = '사용자 환경 편집';
$labels['identities'] = '신원';
$labels['manageidentities'] = '이 계정의 신원 관리';
$labels['newidentity'] = '새 신원';
$labels['newitem'] = '새 아이템';
$labels['edititem'] = '아이템 편집';
$labels['setdefault'] = '기본으로 설정';
$labels['language'] = '언어';
$labels['timezone'] = '시간대';
$labels['pagesize'] = '페이지당 줄 수';
$labels['signature'] = '서명';
$labels['dstactive'] = '서머타임';
$labels['htmleditor'] = 'HTML 메일 쓰기';
$labels['htmlsignature'] = 'HTML 서명';
$labels['previewpane'] = '이전 구역 보기';
$labels['autosavedraft'] = '드래프트 자동 저장';
$labels['everynminutes'] = '$n 분마다';
$labels['never'] = '하지 않음';
$labels['folder'] = '폴더';
$labels['folders'] = '폴더';
$labels['foldername'] = '폴더 이름';
$labels['subscribed'] = '가입됨';
$labels['messagecount'] = '메시지';
$labels['create'] = '만들기';
$labels['createfolder'] = '새 폴더 만들기';
$labels['rename'] = '이름 바꾸기';
$labels['renamefolder'] = '폴더 이름 바꾸기';
$labels['deletefolder'] = '폴더 지우기';
$labels['managefolders'] = '폴더 관리';
$labels['sortby'] = '정렬';
$labels['sortasc'] = '오름차순으로 정렬';
$labels['sortdesc'] = '내림차순으로 정렬';

?>