<?php

/*

+-----------------------------------------------------------------------+
| language/az_AZ/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Orkhan Guliyev, OUR Technology, LLC.<office@ourtechnology.net>|
+-----------------------------------------------------------------------+

*/

$labels = array();
$labels['welcome'] = '$product \-a xoş gəldiniz';
$labels['username'] = 'İstifadəçi Adı';
$labels['password'] = 'Şifrə';
$labels['server'] = 'Server';
$labels['login'] = 'Daxil ol';
$labels['logout'] = 'Çıxış';
$labels['mail'] = 'E-Poçt';
$labels['settings'] = 'Şəxsi Nizamlamalar';
$labels['addressbook'] = 'Ünvan Kitabçası';
$labels['inbox'] = 'Gələnlər';
$labels['drafts'] = 'Qaralamalar';
$labels['sent'] = 'Göndərilənlər';
$labels['trash'] = 'Zibil qutusu';
$labels['junk'] = 'Lazımsızlar(spam)';
$labels['subject'] = 'Mövzu';
$labels['from'] = 'Göndərən';
$labels['to'] = 'Kimə';
$labels['cc'] = 'Surət';
$labels['bcc'] = 'BCC';
$labels['replyto'] = 'Cavabların Göndəriləcəyi Ünvan';
$labels['date'] = 'Tarix';
$labels['size'] = 'Ölçü';
$labels['priority'] = 'Vacib';
$labels['organization'] = 'Quruluş';
$labels['reply-to'] = 'Cavabların Göndəriləcəyi Ünvan';
$labels['mailboxlist'] = 'Qovluqlar';
$labels['messagesfromto'] = '$count Mesajın $from - $to Arasındakı Mesajlar';
$labels['messagenrof'] = '$count Mesajın $nr .';
$labels['moveto'] = 'buraya daşı...';
$labels['download'] = 'Endir';
$labels['filename'] = 'Fayl Adı';
$labels['filesize'] = 'Fayl Ölçüsü';
$labels['preferhtml'] = 'HTML göstərməyi dəstəklə';
$labels['htmlmessage'] = 'HTML Mesaj';
$labels['prettydate'] = 'Tarixi qısaltaraq göstər';
$labels['addtoaddressbook'] = 'Ünvan Kitabçasına Əlavə Et';
$labels['sun'] = 'B';
$labels['mon'] = 'Be';
$labels['tue'] = 'Ç';
$labels['wed'] = 'Ça';
$labels['thu'] = 'C';
$labels['fri'] = 'Ca';
$labels['sat'] = 'Ş';
$labels['sunday'] = 'Bazar';
$labels['monday'] = 'Bazar ertəsi';
$labels['tuesday'] = 'Çərçənbə';
$labels['wednesday'] = 'Çərşənbə axşam';
$labels['thursday'] = 'Cümə';
$labels['friday'] = 'Cümə axşam';
$labels['saturday'] = 'Şənbə';
$labels['jan'] = 'yan';
$labels['feb'] = 'fev';
$labels['mar'] = 'mar';
$labels['apr'] = 'apr';
$labels['may'] = 'may';
$labels['jun'] = 'iyn';
$labels['jul'] = 'iyl';
$labels['aug'] = 'avq';
$labels['sep'] = 'sen';
$labels['oct'] = 'okt';
$labels['nov'] = 'noy';
$labels['dec'] = 'dek';
$labels['longjan'] = 'yanvar';
$labels['longfeb'] = 'fevral';
$labels['longmar'] = 'mart';
$labels['longapr'] = 'aprel';
$labels['longmay'] = 'may';
$labels['longjun'] = 'iyun';
$labels['longjul'] = 'iyul';
$labels['longaug'] = 'avqust';
$labels['longsep'] = 'sentyabr';
$labels['longoct'] = 'oktyabr';
$labels['longnov'] = 'noyabr';
$labels['longdec'] = 'dekabr';
$labels['today'] = 'Bu gün';
$labels['checkmail'] = 'Yeni məktub olub-olmadığını yoxla';
$labels['writenewmessage'] = 'Məktub yaz';
$labels['replytomessage'] = 'Məktuba cavab yaz';
$labels['replytoallmessage'] = 'Bu məktubun göndərildiyi hər kəsə cavab yaz';
$labels['forwardmessage'] = 'Məktubu başqa ünvana göndər';
$labels['deletemessage'] = 'Məktubu sil';
$labels['movemessagetotrash'] = 'Zibil Qutusuna At';
$labels['printmessage'] = 'Çap et';
$labels['previousmessage'] = 'Əvvəlki məktubu göstər';
$labels['previousmessages'] = 'Əvvəlki məktubları göstər';
$labels['firstmessage'] = 'İlk məktubu göstər';
$labels['firstmessages'] = 'İlk məktubları göstər';
$labels['nextmessage'] = 'Sonrakı məktubu göstər';
$labels['nextmessages'] = 'Sonrakı məktubları göstər';
$labels['lastmessage'] = 'Son məktubu göstər';
$labels['lastmessages'] = 'Son məktubları göstər';
$labels['backtolist'] = 'Poçt qutusuna qayıt';
$labels['viewsource'] = 'Qaynağı göstər';
$labels['markmessages'] = 'Məktubları qeyd et';
$labels['markread'] = 'Oxunmuş kimi';
$labels['markunread'] = 'Oxunmamış kimi';
$labels['markflagged'] = 'Qeydə alındı';
$labels['markunflagged'] = 'Qeyddən çıxdı';
$labels['select'] = 'Seç';
$labels['all'] = 'Hamısı';
$labels['none'] = 'Heç biri';
$labels['unread'] = 'Oxunmamış';
$labels['flagged'] = 'İşarəli';
$labels['unanswered'] = 'Cavabsız';
$labels['filter'] = 'Süzgəc';
$labels['compact'] = 'Yığcam';
$labels['empty'] = 'Boşalt';
$labels['purge'] = 'Sil';
$labels['quota'] = 'Disk istifadəsi';
$labels['unknown'] = 'bilinməyən';
$labels['unlimited'] = 'limitsiz';
$labels['quicksearch'] = 'Sürətli axtarış';
$labels['resetsearch'] = 'Axtarışı yenilə';
$labels['openinextwin'] = 'Yeni pəncərədə aç';
$labels['compose'] = 'Yeni məktub yaz';
$labels['savemessage'] = 'Qaralama olaraq məktubu saxla';
$labels['sendmessage'] = 'Məktubu göndər';
$labels['addattachment'] = 'Fayl əlavə et';
$labels['charset'] = 'Xarakter seti';
$labels['editortype'] = 'Düzənləyici tipi';
$labels['returnreceipt'] = 'Return receipt';
$labels['checkspelling'] = 'Qrammatika alətini aktiv et';
$labels['resumeediting'] = 'Redaktə etməyə davam et';
$labels['revertto'] = 'Revert to';
$labels['attachments'] = 'Əlavələr';
$labels['upload'] = 'Yüklə';
$labels['close'] = 'Bağla';
$labels['low'] = 'Alçaq';
$labels['lowest'] = 'Çox alçaq';
$labels['normal'] = 'Normal';
$labels['high'] = 'Yüksək';
$labels['highest'] = 'Çox yüksək';
$labels['nosubject'] = '(Mövzu Yoxdur)';
$labels['showimages'] = 'Qrafikləri göstər';
$labels['alwaysshow'] = 'Həmişə göstər';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Düz metn';
$labels['savesentmessagein'] = 'Göndərilmiş məktubu saxla...';
$labels['dontsave'] = 'Saxlama';
$labels['maxuploadsize'] = 'Maksimal hədd $size qədərdir';
$labels['addcc'] = 'CC əlavə et';
$labels['addbcc'] = 'BCC əlavə et';
$labels['addreplyto'] = 'Reply-To əlavə et';
$labels['mdnrequest'] = 'Məktubu göndərən məktubu oxuduğunuzu bilmək istəyir. Bu barədə ona məlumat verilsin?';
$labels['receiptread'] = 'Return Receipt';
$labels['yourmessage'] = 'Bu sizin məktubunuz üçün Return Receipt-dir';
$labels['receiptnote'] = 'Bu receipt yalnız təsdiq edir ki, məlumat alanın kompüterində göstərildi. Heç bir zəmanət yoxdur - hansı ki, alan oxumuşdur və ya məlumatın içindəkilərini başa düşmüşdür.';
$labels['name'] = 'Adı göstər';
$labels['firstname'] = 'Ad';
$labels['surname'] = 'Soyad';
$labels['email'] = 'E-Poçt';
$labels['addcontact'] = 'Seçiləni ünvan kitabçasına əlavə et';
$labels['editcontact'] = 'Əlaqəni redaktə et';
$labels['edit'] = 'Redaktə et';
$labels['cancel'] = 'Ləğv et';
$labels['save'] = 'Saxla';
$labels['delete'] = 'Sil';
$labels['newcontact'] = 'Yeni əlaqə Kartı Əlavə et';
$labels['deletecontact'] = 'Seçilən əlaqələri sil';
$labels['composeto'] = 'Seçilən əlaqəyə məktub göndər';
$labels['contactsfromto'] = '$count Əlaqənin $from - $to arası ';
$labels['print'] = 'Çap et';
$labels['export'] = 'İxrac et';
$labels['exportvcards'] = 'Əlaqələri vCards formatına ixrac et';
$labels['previouspage'] = 'Əvvəlki səhifə';
$labels['firstpage'] = 'İlk səhifə';
$labels['nextpage'] = 'Sonrakı səhifə';
$labels['lastpage'] = 'Son səhifə';
$labels['groups'] = 'Qruplar';
$labels['personaladrbook'] = 'Ünvanlar';
$labels['import'] = 'İdxal';
$labels['importcontacts'] = 'Əlaqələrin idxalı';
$labels['importfromfile'] = 'Fayldan idxal:';
$labels['importreplace'] = 'Daxil edilən ünvan kitabçasını dəyiş';
$labels['importtext'] = 'Əlaqələri mövcud ünvan kitabçasından yüklə. Biz hal-hazırda vCard data formatından ünvanların idxalını dəstəkləyirik.';
$labels['done'] = 'Bitdi';
$labels['settingsfor'] = 'Nizamlamalar';
$labels['preferences'] = 'Seçimlər';
$labels['userpreferences'] = 'İstifadəçi seçimləri';
$labels['editpreferences'] = 'İstifadəçi seçimlərini redaktə et';
$labels['identities'] = 'Kimliklər';
$labels['manageidentities'] = 'Bu hesab üçün kimlikləri redaktə et';
$labels['newidentity'] = 'Yeni kimlik';
$labels['newitem'] = 'Yeni etiket';
$labels['edititem'] = 'Etiket redaktə et';
$labels['setdefault'] = 'Fərz edilən olaraq nizamla';
$labels['autodetect'] = 'Avto';
$labels['language'] = 'Dil';
$labels['timezone'] = 'Saat qurşağı';
$labels['pagesize'] = 'Bir səhifədə neçə məktub göstərilsin';
$labels['signature'] = 'İmza';
$labels['dstactive'] = 'Yay vaxt;';
$labels['htmleditor'] = 'HTML redaktorda mesaj redaktə et';
$labels['htmlsignature'] = 'HTML imza';
$labels['previewpane'] = 'İlk paneli göstər';
$labels['skin'] = 'İnterfeys stili';
$labels['logoutclear'] = 'Poçtdan çıxış vaxtı zibil qutusu təmizlənsin';
$labels['logoutcompact'] = 'Poçtdan çıxış vaxtı gələnlər yığcam olunsun';
$labels['uisettings'] = 'İstifadəçi İnterfeysi';
$labels['serversettings'] = 'Server Nizamlamalrı';
$labels['mailboxview'] = 'Poçt qutusunu göstər';
$labels['mdnrequests'] = 'Göndərən bildirişləri';
$labels['askuser'] = 'istifadəçini soruş';
$labels['autosend'] = 'avtomatik göndər';
$labels['ignore'] = 'iqnor';
$labels['readwhendeleted'] = 'Məktubu siləndə oxunmuş kimi qeyd et';
$labels['flagfordeletion'] = 'Silinmə üçün bayraq';
$labels['skipdeleted'] = 'Silinmiş məktubları göstərmə';
$labels['showremoteimages'] = 'Uzaq fəaliyyətdəki şəkilləri göstər';
$labels['fromknownsenders'] = 'bilinən göndərilənlərdən';
$labels['always'] = 'hər zaman';
$labels['showinlineimages'] = 'Əlavə olunmuş qrafikləri məktubun aşağısında göstər';
$labels['autosavedraft'] = 'Qaralamanı avtomatik olaraq yaddaşda saxla';
$labels['everynminutes'] = 'hər $n dəqiqədə bir';
$labels['keepaliveevery'] = 'hər $n dəqiqə(lər)';
$labels['keepalive'] = 'Yeni məktubları burada yoxlayın:';
$labels['never'] = 'heç bir zaman';
$labels['messagesdisplaying'] = 'Məktubların göstərilməsi';
$labels['messagescomposition'] = 'Məktubların yazılması';
$labels['mimeparamfolding'] = 'Bərkidilən adlan';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (other)';
$labels['advancedoptions'] = 'Geniş xüsusiyyətlər';
$labels['focusonnewmessage'] = 'Yeni məktubda mərkəzi səyyah pəncərəsi';
$labels['checkallfolders'] = 'Qovluqları yeni məktublar üçün yoxlayın';
$labels['folder'] = 'Qovluq';
$labels['folders'] = 'Qovluqlar';
$labels['foldername'] = 'Qovluq adı';
$labels['subscribed'] = 'Görüləbilinən';
$labels['messagecount'] = 'Məktublar';
$labels['create'] = 'Yani Yarat';
$labels['createfolder'] = 'Yeni qovluq yarat';
$labels['rename'] = 'Yenidən adlandır';
$labels['renamefolder'] = 'Qovluğu yenidən adlandır';
$labels['deletefolder'] = 'Qovluğu sil';
$labels['managefolders'] = 'Qovluqlarla iş';
$labels['specialfolders'] = 'Xüsusi qovluqlar';
$labels['sortby'] = 'Sırala';
$labels['sortasc'] = 'Azdan çoxa';
$labels['sortdesc'] = 'Çoxdan aza';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
