<?
/*

 +-----------------------------------------------------------------------+
 | language/si/messages.inc                                              |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Melanga Dissanayake <Melanga.Dissanayake@pabcbank.com>        |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$messages = array();
$messages['loginfailed'] = 'ඇතුල්වීම අසාර්ථකයි';
$messages['cookiesdisabled'] = 'ඔබේ බෞසරය කුකී බාර ගන්නේ නැත';
$messages['sessionerror'] = 'ඔබේ වාරය අවලංගු හෝ කාලය ඉකුත් වී ඇත';
$messages['imaperror'] = 'IMAP සම්බන්ධතාවය අසාර්ථකයි';
$messages['nomessagesfound'] = 'ලියුම් පෙට්ටියේ පනිවුඩ නැත';
$messages['loggedout'] = 'ඔබගේ වාරය සාර්ථකව අවසන් විය. අයුබොවන්!';
$messages['mailboxempty'] = 'ලියුම් පෙට්ටිය හිස්';
$messages['loading'] = 'පූරනය...';
$messages['loadingdata'] = 'දත්ත පූරනය...';
$messages['checkingmail'] = 'අලුත් පනිවුඩ පරීක්ෂා කිරීම...';
$messages['sendingmessage'] = 'පනිවුඩය යැවීම...';
$messages['messagesent'] = 'පනිවුඩය සාර්ථකව යවන ලදී';
$messages['savingmessage'] = 'පනිවුඩය තැන්පත් කීරීම...';
$messages['messagesaved'] = 'පනිවුඩය කටු සටහනේ තැන්පත් විය';
$messages['successfullysaved'] = 'සාර්ථකව තැන්පත විය';
$messages['addedsuccessfully'] = 'ලිපිනය සාර්ථකව ලිපින පොතට එකතු කරන ලදී';
$messages['contactexists'] = 'ඉහත ලිපිනය සහිත විද්යුත් තැපැල් ලිපිනයක් ලිපින පොතේ ඇත';
$messages['blockedimages'] = 'ඔබගෙ පොද්ගලිකත්වය හේතුවෙන්, දුරස්ථ රූප අවහිර කර ඇත.';
$messages['encryptedmessage'] = 'මෙම පනිවුඩය රහස් කේතනය කර ඇති බැවින් පෙන්විය නොහැක. සමාවන්න!';
$messages['nocontactsfound'] = 'ලිපින සොයා ගත නොහැක';
$messages['contactnotfound'] = 'ඉල්ලූ ලිපිනය සොයාගත නොහැක';
$messages['sendingfailed'] = 'පනිවුඩය යැවීම අසාර්ථකයි';
$messages['errorsaving'] = 'පනිවුඩය තැන්පත් කීරීමේදී දොෂයක් සිදු විය';
$messages['errormoving'] = 'පනිවුඩය ගෙන යාමට නොහැක';
$messages['errordeleting'] = 'පනිවුඩය මකා දැමීමට නොහැක';
$messages['deletecontactconfirm'] = 'තෝරා ඇති ලිපින ඔබට මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['deletemessagesconfirm'] = 'තෝරා ඇත පනිවුඩ ඔබට මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['deletefolderconfirm'] = 'ෆෝල්ඩරය මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['purgefolderconfirm'] = 'මෙම ෆෝල්ඩරයේ ඇති සියලුම පනිවුඩ ඔබට මකා දැමීමට සැබවින්ම වුවමනාද?';
$messages['formincomplete'] = 'පෝරමය සම්පූර්ණයෙන් පුරවා නොමැත';
$messages['noemailwarning'] = 'කරුණාකර වලංගු විද්යුත් තැපැල් ලිපිනයක් ඇතුලත් කරන්න';
$messages['nonamewarning'] = 'කරුණාකර නම ඇතුලත් කරන්න';
$messages['nopagesizewarning'] = 'කරුණාකර පිටුවේ ප්රමානය ඇතුලත් කරන්න';
$messages['norecipientwarning'] = 'කරුණාකර යටත් පිරිසෙයින් එක් ලබන්නෙකු හෝ ඇතුලත් කරන්න';
$messages['nosubjectwarning'] = '"මාතෘකාව" හිස්. මාතෘකාවක් අතුලත් කිරීමට ඔබ කැමතිද?';
$messages['nobodywarning'] = 'මෙම හිස් පනිවුඩය යවන්නද?';
$messages['notsentwarning'] = 'පනිවුඩය යැවීමට නොහැකි විය. ඔබට එය බැහැර කිරීමට වුවමනාද?';
$messages['noldapserver'] = 'සෙවුම සඳහා කරුණාකර ldap සම්බන්ධතාවයක් තෝරා ගන්න';
$messages['nocontactsreturned'] = 'ලිපින/ය සොයා ගත නොහැක';
$messages['nosearchname'] = 'කරුණාකර ලිපිනයෙහි නම හෝ විද්යුත් තැපැල් ලිපිනය ඇතුලත් කරන්න';
$messages['searchsuccessful'] = '$nr පනිවුඩය හමු විය';
$messages['searchnomatch'] = 'සෙවුමට අදාල ගැලපීමක් නොමැත';
$messages['searching'] = 'සොයමින් පවතී...';
$messages['checking'] = 'පිරික්සමින් පවතී...';
$messages['nospellerrors'] = 'වියාකරන දොෂ නොමැත';
$messages['folderdeleted'] = 'ෆෝල්ඩරය සාර්ථකව මකා දමන ලදී';
$messages['deletedsuccessfully'] = 'සාර්ථකව මකා දමන ලදී';
$messages['converting'] = 'පනිවුඩයෙන් ආකෘතීකරණය ඉවත් කිරීම';
$messages['messageopenerror'] = 'පනිවුඩය පූරනය කිරීමට නොහැක';
$messages['fileuploaderror'] = 'ගොනුව ඇතුලත් කිරීමට නොහැක';
$messages['filesizeerror'] = 'ඇතුලත් කල ගොනුවෙ ප්රමාණය උපරිම අගය $size ඉක්මවා ඇත';
$messages['copysuccess'] = '$nr ලිපිනය සාර්ථකව පිටපත් කරන ලදී';
$messages['copyerror'] = 'කවර ලිපිනයක්වත් හෝ පිටපත් කල නොහැක';
$messages['sourceisreadonly'] = 'මෙම ලිපින මූලාශ්රය කියවීම සඳහා පමනි';
$messages['errorsavingcontact'] = 'ලිපිනය තැන්පත් කීරීමට නොහැක';
$messages['movingmessage'] = 'පනිවුඩය ගෙනයමින් පවතී...';
$messages['receiptsent'] = 'කියවීම් භාර ගැනීම සාර්ථකව යවන ලදී';
$messages['errorsendingreceipt'] = 'කියවීම් භාර ගැනීම යැවීමට නොහැක';
$messages['nodeletelastidentity'] = 'අවසාන අනන්‍යතාවය මකා දැමිය නොහැක';
$messages['addsubfolderhint'] = 'ෆෝල්ඩරය දැනට තෝරාගෙන ඇති ෆෝල්ඩරයෙහි අනු ෆෝල්ඩරයක් ලෙස සෑදේ';

?>