<?php

/*

 +-----------------------------------------------------------------------+
 | language/bs_BA/messages.inc                                           |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Begzudin Omerovic <Begzudin.Omerovic@gmail.com>               |
 +-----------------------------------------------------------------------+

 @version $Id: messages.inc 950 2008-01-04 08:04:53Z tomekp $

*/

$messages = array();
$messages['loginfailed']  = 'Prijava neuspješna';
$messages['cookiesdisabled'] = 'Vaš pretraživač ne podržava kolačiće (cookies)';
$messages['sessionerror'] = 'Sesija nije validna ili je istekla';
$messages['imaperror'] = 'Neuspješna konekcija na IMAP server';
$messages['nomessagesfound'] = 'Nema poruka u sandučetu';
$messages['loggedout'] = 'Uspješno ste se odjavili.';
$messages['mailboxempty'] = 'Sanduče je prazno';
$messages['loading'] = 'Učitavanje...';
$messages['loadingdata'] = 'Učitavanje podataka...';
$messages['checkingmail'] = 'Provjera novih poruka u toku...';
$messages['sendingmessage'] = 'Poruka se šalje...';
$messages['messagesent'] = 'Poruka je uspješno poslana';
$messages['savingmessage'] = 'Poruka se snima...';
$messages['messagesaved'] = 'Poruka uspješno sačuvana u \'Drafts\'';
$messages['successfullysaved'] = 'Snimanje uspješno obavljeno';
$messages['addedsuccessfully'] = 'Kontakt uspješno dodat u imenik';
$messages['contactexists'] = 'Kontakt sa ovom e-mail adresom već postoji u imeniku';
$messages['blockedimages'] = 'Zbog zaštite privatnosti, slike sa drugih servera su blokirane.';
$messages['encryptedmessage'] = 'Ova poruka je šifrovana pa se ne može prikazati';
$messages['nocontactsfound'] = 'Imenik je prazan';
$messages['sendingfailed'] = 'Greška pri slanju poruke';
$messages['errorsaving'] = 'Greška pri snimanju';
$messages['errormoving'] = 'Greška pri premještanju poruke';
$messages['errordeleting'] = 'Greška pri brisanju poruke';
$messages['deletecontactconfirm']  = 'Da li želite da obrišete izabrane kontakte?';
$messages['deletemessagesconfirm'] = 'Da li stvarno želite izbrisati poruku(e)?';
$messages['deletefolderconfirm']  = 'Da li zaista želite da obrišete ovu fasciklu?';
$messages['purgefolderconfirm']  = 'Da li zaista želite da obrišete sve poruke u fascikli?';
$messages['formincomplete'] = 'Forma nije u cijelosti popunjena';
$messages['noemailwarning'] = 'Unesite ispravnu e-mail adresu';
$messages['nonamewarning']  = 'Unesite ime';
$messages['nopagesizewarning'] = 'Unesite veličinu stranice';
$messages['norecipientwarning'] = 'Unesite primaoca / primaoce (ZA)';
$messages['nosubjectwarning']  = 'Polje \'Naslov\' je prazno. Želite li da unesete naslov poruke?';
$messages['nobodywarning'] = 'Da li želite da pošaljete poruku bez teksta?';
$messages['notsentwarning'] = 'Poruka nije poslana. Da li želite da odbacite ovu poruku?';
$messages['noldapserver'] = 'Unesite LDAP server za pretragu';
$messages['nocontactsreturned'] = 'Nije pronađen ni jedan kontakt';
$messages['nosearchname'] = 'Unesite ime ili e-mail adresu';
$messages['searchsuccessful'] = 'Broj pronađenih poruka: $nr';
$messages['searchnomatch'] = 'Tražena fraza nije pronađena ni u jednoj poruci';
$messages['searching'] = 'Pretraga u toku...';
$messages['checking'] = 'Provjera u toku...';
$messages['nospellerrors'] = 'Nije pronađena ni jedna pravopisna greška';
$messages['folderdeleted'] = 'Fascikla uspješno obrisana';
$messages['deletedsuccessfully'] = 'Uspješno izbrisano';
$messages['converting'] = 'Vračeno formatiranje iz poruke ...';
$messages['messageopenerror'] = 'Nije učitana poruka sa servera';

?>