<?php

/*

 +-----------------------------------------------------------------------+
 | language/ro/labels.inc                                                |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Daniel Anechitoaie - danieLs <daniels@safereaction.ro>        |
 |         Ispas Dorin <dorinxp2004@yahoo.com>                           |
 +-----------------------------------------------------------------------+

 @version $Id: labels.inc 1149 2008-02-28 19:52:09Z thomasb $

*/

$labels = array();
$labels['welcome'] = 'Bine ati venit la $product';
$labels['username'] = 'Utilizator';
$labels['password'] = 'Parola';
$labels['server'] = 'Server';
$labels['login'] = 'Autentificare';
$labels['logout'] = 'Deconectare';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Setari Personale';
$labels['addressbook'] = 'Agenda';
$labels['inbox'] = 'Primite';
$labels['drafts'] = 'Ciorne';
$labels['sent'] = 'Trimise';
$labels['trash'] = 'Gunoi';
$labels['junk'] = 'Junk';
$labels['subject'] = 'Subiect';
$labels['from'] = 'Expeditor';
$labels['to'] = 'Destinatar';
$labels['cc'] = 'Copie';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Raspunde-La';
$labels['date'] = 'Data';
$labels['size'] = 'Marime';
$labels['priority'] = 'Prioritate';
$labels['organization'] = 'Organizatie';
$labels['reply-to'] = 'Raspunde-La';
$labels['mailboxlist'] = 'Dosare';
$labels['messagesfromto'] = 'Mesaje de la $from pana la $to din $count';
$labels['messagenrof'] = '$nr mesaje din $count';
$labels['moveto'] = 'muta in...';
$labels['download'] = 'descarca';
$labels['filename'] = 'Nume fisier';
$labels['filesize'] = 'Marime fisier';
$labels['preferhtml'] = 'Prefer HTML';
$labels['htmlmessage'] = 'Mesaj HTML';
$labels['prettydate'] = 'Data formatata';
$labels['addtoaddressbook'] = 'Adauga in agenda';
$labels['sun'] = 'Dum';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mie';
$labels['thu'] = 'Joi';
$labels['fri'] = 'Vin';
$labels['sat'] = 'Sam';
$labels['sunday'] = 'Duminica';
$labels['monday'] = 'Luni';
$labels['tuesday'] = 'Marti';
$labels['wednesday'] = 'Miercuri';
$labels['thursday'] = 'Joi';
$labels['friday'] = 'Vineri';
$labels['saturday'] = 'Sambata';
$labels['today'] = 'Astazi';
$labels['checkmail'] = 'Verifica pentru mesaje noi';
$labels['writenewmessage'] = 'Creaza mesaj nou';
$labels['replytomessage'] = 'Raspunde la mesaj';
$labels['replytoallmessage'] = 'Raspunde la toti';
$labels['forwardmessage'] = 'Trimite mesajul mai departe';
$labels['deletemessage'] = 'Trimite mesajul la gunoi';
$labels['movemessagetotrash'] = 'Muta mesajul la gunoi';
$labels['printmessage'] = 'Listeaza mesajul';
$labels['previousmessage'] = 'Afiseaza mesajul anterior';
$labels['previousmessages'] = 'Afiseaza setul anterior de mesaje';
$labels['firstmessage'] = 'Afiseaza primul mesaj';
$labels['firstmessages'] = 'Afiseaza primul set de mesaje';
$labels['nextmessage'] = 'Afiseaza urmatorul mesaj';
$labels['nextmessages'] = 'Afiseaza setul urmator de mesaje';
$labels['lastmessage'] = 'Afiseaza ultimul mesaj';
$labels['lastmessages'] = 'Afiseaza ultimul set de mesaje';
$labels['backtolist'] = 'Inapoi la lista cu mesaje';
$labels['viewsource'] = 'Afiseaza sursa';
$labels['markmessages'] = 'Marcheaza mesajele';
$labels['markread'] = 'Ca citit';
$labels['markunread'] = 'Ca necitit';
$labels['select'] = 'Selecteaza';
$labels['all'] = 'Toate';
$labels['none'] = 'Nici unul';
$labels['unread'] = 'Necitite';
$labels['compact'] = 'Compreseaza';
$labels['empty'] = 'Goleste';
$labels['purge'] = 'Curata';
$labels['quota'] = 'Spatiu folosit';
$labels['unknown'] = 'necunoscut';
$labels['unlimited'] = 'nelimitat';
$labels['quicksearch'] = 'Cautare rapida';
$labels['resetsearch'] = 'Resetare cautare';
$labels['compose'] = 'Compune mesaj';
$labels['savemessage'] = 'Salveaza aceasta ciorna';
$labels['sendmessage'] = 'Trimite mesaj';
$labels['addattachment'] = 'Ataseaza fisier';
$labels['charset'] = 'Set de caractere';
$labels['editortype'] = 'Tip de editor';
$labels['returnreceipt'] = 'Returneaza confirmare';
$labels['checkspelling'] = 'Verifica ortografie';
$labels['resumeediting'] = 'Reia editarea';
$labels['revertto'] = 'Revina la';
$labels['attachments'] = 'Atasamente';
$labels['upload'] = 'Incarca';
$labels['close'] = 'Inchide';
$labels['low'] = 'Mica';
$labels['lowest'] = 'Cea mai mica';
$labels['normal'] = 'Normala';
$labels['high'] = 'Mare';
$labels['highest'] = 'Cea mai mare';
$labels['nosubject'] = '(fara subiect)';
$labels['showimages'] = 'Afiseaza imagini';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Text simplu';
$labels['addcc'] = 'Adauga Cc';
$labels['addbcc'] = 'Adauga Bcc';
$labels['addreplyto'] = 'Adauga Raspunde-La';
$labels['mdnrequest'] = 'Expeditorul acestui mesaj a solicitat sa fie notificat la cititrea mesajului. Doriti sa notificati expeditorul?';
$labels['receiptread'] = 'Returneaza confirmare (citit)';
$labels['yourmessage'] = 'Aceasta este o confirmare a mesajului dumneavoastra.';
$labels['receiptnote'] = 'Nota: Aceasta confirmare doar va informeaza ca mesajul a fost afisat pe calculatorul destinatarului. Nu este nici o garantie ca destinatarul a citit sau a inteles continutul mesajului.';
$labels['name'] = 'Nume de afisat';
$labels['firstname'] = 'Nume';
$labels['surname'] = 'Prenume';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Adauga contactul selectat in agenda';
$labels['editcontact'] = 'Modifica contact';
$labels['edit'] = 'Editeaza';
$labels['cancel'] = 'Renunta';
$labels['save'] = 'Salveaza';
$labels['delete'] = 'Sterge';
$labels['newcontact'] = 'Creaza contact nou';
$labels['deletecontact'] = 'Sterge contactul selectat';
$labels['composeto'] = 'Compune e-mail pentru';
$labels['contactsfromto'] = 'Contacte de la $from pana la $to din $count';
$labels['print'] = 'Listeaza';
$labels['export'] = 'Exporta';
$labels['previouspage'] = 'Pagina anterioara';
$labels['firstpage'] = 'Arata primul set';
$labels['nextpage'] = 'Pagina urmatoare';
$labels['lastpage'] = 'Arata ultimul set';
$labels['groups'] = 'Grupuri';
$labels['personaladrbook'] = 'Adrese personale';
$labels['settingsfor'] = 'Setari pentru';
$labels['preferences'] = 'Preferinte';
$labels['userpreferences'] = 'Preferinte utilizator';
$labels['editpreferences'] = 'Modifica preferinte utilizator';
$labels['identities'] = 'Identitati';
$labels['manageidentities'] = 'Administreaza identitati pentru acest cont';
$labels['newidentity'] = 'Identitate noua';
$labels['newitem'] = 'Item nou';
$labels['edititem'] = 'Editeaza item';
$labels['setdefault'] = 'Seteaza implicit';
$labels['language'] = 'Limba';
$labels['timezone'] = 'Fus orar';
$labels['pagesize'] = 'Randuri pe pagina';
$labels['signature'] = 'Semnatura';
$labels['dstactive'] = 'Daylight savings';
$labels['htmleditor'] = 'Scrie mesaje HTML';
$labels['htmlsignature'] = 'Semnatura HTML';
$labels['previewpane'] = 'Arata preview';
$labels['autosavedraft'] = 'Salveaza ciorna automat';
$labels['everynminutes'] = 'fiecare $n minute';
$labels['never'] = 'niciodata';
$labels['folder'] = 'Dosar';
$labels['folders'] = 'Dosare';
$labels['foldername'] = 'Nume dosar';
$labels['subscribed'] = 'Inscris';
$labels['messagecount'] = 'Mesaje';
$labels['create'] = 'Creaza';
$labels['createfolder'] = 'Creaza dosar nou';
$labels['rename'] = 'Redenumeste';
$labels['renamefolder'] = 'Redenumeste dosar';
$labels['deletefolder'] = 'Sterge dosar';
$labels['managefolders'] = 'Administreaza dosare';
$labels['sortby'] = 'Sorteaza dupa';
$labels['sortasc'] = 'Sorteaza ascendent';
$labels['sortdesc'] = 'Sorteaza descendent';

?>