<?php

/*

+-----------------------------------------------------------------------+
| language/bg/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Todor Dragnev <todor.dragnev@gmail.com>  			|
|	  Nickolay Bunev <just4nick@gmail.com>				|
+-----------------------------------------------------------------------+

@version $Id$

*/

$labels = array();
$labels['welcome'] = 'Добре дошли в $product';
$labels['username'] = 'Потребител';
$labels['password'] = 'Парола';
$labels['server'] = 'Сървър';
$labels['login'] = 'Вход';
$labels['logout'] = 'Изход';
$labels['mail'] = 'Кутия';
$labels['settings'] = 'Настройки';
$labels['addressbook'] = 'Книга с адреси';
$labels['inbox'] = 'Входящи';
$labels['drafts'] = 'Чернови';
$labels['sent'] = 'Изпратени';
$labels['trash'] = 'Кошче';
$labels['junk'] = 'Спам';
$labels['subject'] = 'Заглавие';
$labels['from'] = 'От';
$labels['to'] = 'Получател';
$labels['cc'] = 'Копие до';
$labels['bcc'] = 'Скрито копие до';
$labels['replyto'] = 'Отговор до';
$labels['date'] = 'Дата';
$labels['size'] = 'Размер';
$labels['priority'] = 'Приоритет';
$labels['organization'] = 'Организация';
$labels['reply-to'] = 'Отговор до';
$labels['mailboxlist'] = 'Папки';
$labels['messagesfromto'] = 'Съобщения $from до $to от $count';
$labels['messagenrof'] = 'Съобщение $nr от $count';
$labels['moveto'] = 'Премести в...';
$labels['download'] = 'Изтегли';
$labels['filename'] = 'Име на файла';
$labels['filesize'] = 'Размер на файла';
$labels['preferhtml'] = 'Показвай първо HTML версия';
$labels['htmlmessage'] = 'HTML съобщение';
$labels['prettydate'] = 'Кратки дати';
$labels['addtoaddressbook'] = 'Добави в адресната книга';
$labels['sun'] = 'Нед';
$labels['mon'] = 'Пон';
$labels['tue'] = 'Вто';
$labels['wed'] = 'Сря';
$labels['thu'] = 'Чет';
$labels['fri'] = 'Пет';
$labels['sat'] = 'Съб';
$labels['sunday'] = 'Неделя';
$labels['monday'] = 'Понеделник';
$labels['tuesday'] = 'Вторник';
$labels['wednesday'] = 'Сряда';
$labels['thursday'] = 'Четвъртък';
$labels['friday'] = 'Петък';
$labels['saturday'] = 'Събота';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'May';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Oct';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Януари';
$labels['longfeb'] = 'Февруари';
$labels['longmar'] = 'Март';
$labels['longapr'] = 'Април';
$labels['longmay'] = 'Май';
$labels['longjun'] = 'Юни';
$labels['longjul'] = 'Юли';
$labels['longaug'] = 'Август';
$labels['longsep'] = 'Септември';
$labels['longoct'] = 'Октомври';
$labels['longnov'] = 'Ноември';
$labels['longdec'] = 'Декември';
$labels['today'] = 'Днес';
$labels['checkmail'] = 'Провери за нови писма';
$labels['writenewmessage'] = 'Създай ново писмо';
$labels['replytomessage'] = 'Отговори на писмото';
$labels['replytoallmessage'] = 'Отговори до изпращача и всички получатели';
$labels['forwardmessage'] = 'Препрати писмото';
$labels['deletemessage'] = 'Изтрий писмото';
$labels['movemessagetotrash'] = 'Премести писмото в кошчето';
$labels['printmessage'] = 'Разпечатай писмото';
$labels['previousmessage'] = 'Предишно писмо';
$labels['previousmessages'] = 'Предишна страница';
$labels['firstmessage'] = 'Първо писмо';
$labels['firstmessages'] = 'Първа страница';
$labels['nextmessage'] = 'Следващо писмо';
$labels['nextmessages'] = 'Следваща страница';
$labels['lastmessage'] = 'Последно писмо';
$labels['lastmessages'] = 'Последна страница';
$labels['backtolist'] = 'Обратно към списъка';
$labels['viewsource'] = 'Виж кода';
$labels['markmessages'] = 'Маркирай писмата';
$labels['markread'] = 'Като прочетени';
$labels['markunread'] = 'Като нови';
$labels['markflagged'] = 'Като отбелязани';
$labels['markunflagged'] = 'Като неотбелязани';
$labels['select'] = 'Избери';
$labels['all'] = 'Всички';
$labels['none'] = 'Нищо';
$labels['unread'] = 'Нови';
$labels['compact'] = 'Свий';
$labels['empty'] = 'Изпразни';
$labels['purge'] = 'Изчисти';
$labels['quota'] = 'Използвано място';
$labels['unknown'] = 'няма информация';
$labels['unlimited'] = 'няма ограничение';
$labels['quicksearch'] = 'Бързо търсене';
$labels['resetsearch'] = 'Изчисти търсенето и покажи всички писма';
$labels['openinextwin'] = 'Отвори в нов прозорец';
$labels['compose'] = 'Ново писмо';
$labels['savemessage'] = 'Запиши в Чернови';
$labels['sendmessage'] = 'Изпрати писмото';
$labels['addattachment'] = 'Прикачи файл';
$labels['charset'] = 'Кодировка';
$labels['editortype'] = 'Вид редактор';
$labels['returnreceipt'] = 'Обратна разписка';
$labels['checkspelling'] = 'Провери правописа';
$labels['resumeediting'] = 'Продължи черновата';
$labels['revertto'] = 'Върни се към';
$labels['attachments'] = 'Прикачени файлове';
$labels['upload'] = 'Качи';
$labels['close'] = 'Затвори';
$labels['low'] = 'Нисък';
$labels['lowest'] = '*';
$labels['normal'] = 'Нормален';
$labels['high'] = 'Висок';
$labels['highest'] = '*****';
$labels['nosubject'] = '(няма заглавие)';
$labels['showimages'] = 'Показвай изображения';
$labels['alwaysshow'] = 'Винаги показвай изображения от $ ';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'текстов';
$labels['savesentmessagein'] = 'Запази съобщението в';
$labels['dontsave'] = 'Не съхранявай';
$labels['maxuploadsize'] = 'Максимално позволенa големина в $size';
$labels['addcc'] = 'Копие до';
$labels['addbcc'] = 'Скрито копие до';
$labels['addreplyto'] = 'Отговор на';
$labels['mdnrequest'] = 'Подателят на писмото е пожелал да бъде уведомен, че сте го прочели. Желаете ли да изпратите обратна разписка?';
$labels['receiptread'] = 'Обратна разписка (прочетено)';
$labels['yourmessage'] = 'Това е обратна разписка за писмото Ви';
$labels['receiptnote'] = 'Забележка: Тази разписка потвърждава само, че писмото е било показано на компютъра на получателят. Няма никаква гаранция, че получателят е прочел и/или разбрал съдържанието на писмото.';
$labels['name'] = 'Кратко име';
$labels['firstname'] = 'Име';
$labels['surname'] = 'Фамилия';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Добави';
$labels['editcontact'] = 'Редактирай';
$labels['edit'] = 'Редактирай';
$labels['cancel'] = 'Отказ';
$labels['save'] = 'Запиши';
$labels['delete'] = 'Изтрий';
$labels['newcontact'] = 'Нов контакт';
$labels['deletecontact'] = 'Изтрий маркираните контакти';
$labels['composeto'] = 'Напиши писмо до';
$labels['contactsfromto'] = 'Контакти $from до $to от $count';
$labels['print'] = 'Разпечатай';
$labels['export'] = 'Изнасяне';
$labels['exportvcards'] = 'Изнасяне във vCard формат';
$labels['previouspage'] = 'Предна страница';
$labels['firstpage'] = 'Първа страница';
$labels['nextpage'] = 'Следваща страница';
$labels['lastpage'] = 'Последна страница';
$labels['groups'] = 'Групи';
$labels['personaladrbook'] = 'Лични адреси';
$labels['import'] = 'Внасяне';
$labels['importcontacts'] = 'Внасяне';
$labels['importfromfile'] = 'Внасяне от файл';
$labels['importreplace'] = 'Замени цялата книга с адреси';
$labels['importtext'] = 'Можете да внесете контакти от съществуваща книга с адреси. В момента поддържане внасянето на адреси от vCard формат за данни.';
$labels['done'] = 'Извършено';
$labels['settingsfor'] = 'Настройки за';
$labels['preferences'] = 'Настройки';
$labels['userpreferences'] = 'Потребителски настройки';
$labels['editpreferences'] = 'Редактирай потребителските настройки';
$labels['identities'] = 'Самоличност';
$labels['manageidentities'] = 'Промяна на самоличностите за този акаунт';
$labels['newidentity'] = 'Нова самоличност';
$labels['newitem'] = 'Нова самоличност';
$labels['edititem'] = 'Редактиране на самоличност';
$labels['setdefault'] = 'По подразбиране';
$labels['autodetect'] = 'Автоматично';
$labels['language'] = 'Език';
$labels['timezone'] = 'Часова зона';
$labels['pagesize'] = 'Редове на страница';
$labels['signature'] = 'Подпис';
$labels['dstactive'] = 'Маркирай при лятно време';
$labels['htmleditor'] = 'Писане на съобщениe като HTML';
$labels['htmlsignature'] = 'HTML подпис';
$labels['previewpane'] = 'Панел за преглед';
$labels['skin'] = 'Смяна изгледа на интерфейса';
$labels['logoutclear'] = 'Изчисти кошчето при изход';
$labels['logoutcompact'] = 'Упллътни Входящи при изход';
$labels['uisettings'] = 'Потребителски интерфейс';
$labels['serversettings'] = 'Настройки на сървъра';
$labels['mailboxview'] = 'Преглед на Кутия';
$labels['mdnrequests'] = 'Уведомление на изпращача';
$labels['askuser'] = 'Питай';
$labels['autosend'] = 'Изпрати автоматично';
$labels['ignore'] = 'Отхвърли';
$labels['readwhendeleted'] = 'Отбележи като прочетено при изтриване';
$labels['flagfordeletion'] = 'Отбележи съобщението за изтриване';
$labels['skipdeleted'] = 'Не показвай изтритите съобщения';
$labels['showinlineimages'] = 'Покажи прикачените изображения след съобщението';
$labels['autosavedraft'] = 'Автоматично записвай чернова';
$labels['everynminutes'] = 'всеки $n минути';
$labels['keepaliveevery'] = 'всеки $n минути';
$labels['keepalive'] = 'Проверявай за нови съобщения при';
$labels['never'] = 'никога';
$labels['messagesdisplaying'] = 'Показване на събщенията';
$labels['messagescomposition'] = 'Писане на съобщения';
$labels['mimeparamfolding'] = 'Добавяне име на прикрепените файлове';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (други)';
$labels['advancedoptions'] = 'Настройки за напреднали';
$labels['folder'] = 'Папка';
$labels['folders'] = 'Папки';
$labels['foldername'] = 'Име на папката';
$labels['subscribed'] = 'Използвай';
$labels['messagecount'] = 'Писма';
$labels['create'] = 'Създай';
$labels['createfolder'] = 'Направи нова папка';
$labels['rename'] = 'Преименувай';
$labels['renamefolder'] = 'Преименувай папката';
$labels['deletefolder'] = 'Изтрий';
$labels['managefolders'] = 'Настройки на папките';
$labels['specialfolders'] = 'Служебни папки';
$labels['sortby'] = 'Сортирай по';
$labels['sortasc'] = 'Сортирай възходящо';
$labels['sortdesc'] = 'Сортирай низходящо';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
