<?php

/*

+-----------------------------------------------------------------------+
| language/id_ID/messages.inc                                           |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Putu Arya Sabda Wijaya <klunxer@gmail.com>                    |
+-----------------------------------------------------------------------+

@version $Id$

*/

$messages = array();
$messages['loginfailed'] = 'Gagal masuk';
$messages['cookiesdisabled'] = 'Browser Anda tidak menerima cookies';
$messages['sessionerror'] = 'Session Anda invalid atau kadaluwarsa';
$messages['imaperror'] = 'Koneksi ke IMAP server gagal';
$messages['nomessagesfound'] = 'Surat tidak ditemukan di kotak masuk ini';
$messages['loggedout'] = 'Anda berhasil mengakhiri session. Selamat Tinggal!';
$messages['mailboxempty'] = 'Kotak masuk kosong';
$messages['loading'] = 'Loading...';
$messages['loadingdata'] = 'Loading data...';
$messages['checkingmail'] = 'Memeriksa pesan baru...';
$messages['sendingmessage'] = 'Mengirim pesan...';
$messages['messagesent'] = 'Pesan terkirim';
$messages['savingmessage'] = 'Menyimpan pesan...';
$messages['messagesaved'] = 'MMenyimpan pesan ke daftar tunggu';
$messages['successfullysaved'] = 'Berhasil disimpan';
$messages['addedsuccessfully'] = 'Kontak berhasil ditambahkan ke buku alamat';
$messages['contactexists'] = 'Konatk dengan alamat e-mail ini sudah ada';
$messages['blockedimages'] = 'Untuk melindungi privasi Anda, gambar-gambar diluar server diblok pada pesan ini.';
$messages['encryptedmessage'] = 'Pesan ini terenkripsi dan tidak bisa ditampilkan. Maaf!';
$messages['nocontactsfound'] = 'Kontak tidak ditemukan';
$messages['contactnotfound'] = 'Kontak yang diminta tidak ditemukan';
$messages['sendingfailed'] = 'Pengiriman pesan gagal';
$messages['errorsavingsent'] = 'Error ketika menyimpan pesan terkirim';
$messages['errorsaving'] = 'Error ketika menyimpan';
$messages['errormoving'] = 'Pesan tidak bisa dipindahkan';
$messages['errordeleting'] = 'Pesan tidak bisa dihapus';
$messages['deletecontactconfirm'] = 'Apakah anda yakin untuk menghapus kontak terpilih?';
$messages['deletemessagesconfirm'] = 'Yakin menghapus pesan terpilih?';
$messages['deletefolderconfirm'] = 'Apakah anda benar-benar ingin menghapus map ini?';
$messages['purgefolderconfirm'] = 'Yakin menghapus semua pesan pada map ini?';
$messages['formincomplete'] = 'Blangko tidak terisi semua';
$messages['noemailwarning'] = 'Tolong masukkan alamat email yang valid';
$messages['nonamewarning'] = 'Tolong masukkan nama';
$messages['nopagesizewarning'] = 'Tolong masukkan ukuran halaman';
$messages['norecipientwarning'] = 'Tolong masukkan sedikitnya satu penerima';
$messages['nosubjectwarning'] = '"Judul" kosong. Isi judul sekarang?';
$messages['nobodywarning'] = 'Kirim pesan ini tanpa teks?';
$messages['notsentwarning'] = 'Pesan belum terkirim. Buang pesan Anda?';
$messages['noldapserver'] = 'Tolong pilih server LDAP untuk pencarian';
$messages['nocontactsreturned'] = 'Kontak kosong';
$messages['nosearchname'] = 'Tolong masukkan nama kontak atau alamat email';
$messages['searchsuccessful'] = '$nr pesan ditemukan';
$messages['searchnomatch'] = 'Pencarian kosong';
$messages['searching'] = 'Mencari...';
$messages['checking'] = 'Memeriksa...';
$messages['nospellerrors'] = 'Tidak ditemkan kesalahan ejaan';
$messages['folderdeleted'] = 'Map berhasil dihapus';
$messages['deletedsuccessfully'] = 'Berhasil dihapus';
$messages['converting'] = 'Mengembalikan pesan ke format awal...';
$messages['messageopenerror'] = 'Tidak dapat mengambil pesan dari server';
$messages['fileuploaderror'] = 'Gagal mengunggah berkas';
$messages['filesizeerror'] = 'Berkas terunggah mencapai ukuran maksimal dari $size';
$messages['copysuccess'] = 'Berhasil menyalin $nr alamat';
$messages['copyerror'] = 'Tidak bisa menyalin alamat manapun';
$messages['sourceisreadonly'] = 'Sumber dari alamat ini hanya dapat dibaca';
$messages['errorsavingcontact'] = 'Tidak bisa menyimpan alamat kontak';
$messages['movingmessage'] = 'Memindahkan pesan...';
$messages['receiptsent'] = 'Berhasil mengirim pemberitahuan tanda terima telah terbaca';
$messages['errorsendingreceipt'] = 'Tidak dapat mengirim tanda terima';
$messages['nodeletelastidentity'] = 'Anda tidak bida mengapus identitas ini, ini identitas yang terakhir';
$messages['addsubfolderhint'] = 'Folder ini akan dibuat sebagai subfolder pada folder yang terpilih';
$messages['forbiddencharacter'] = 'Nama folder mengandung karakter terlarang';

?>
