<?php

/*

 +-----------------------------------------------------------------------+
 | language/se/messages.inc                                              |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Fredrik Nygren <f.nygren@gmail.com>                           |
 |         Andreas Henriksson <andreas@fatal.se>						 |
 |		   Jonas Näsholm <hostmaster@bitfuse.net>                        |
 +-----------------------------------------------------------------------+

 @version $Id: messages.inc 1143 2008-02-26 20:50:10Z yllar $

*/

$messages = array();
$messages['loginfailed'] = 'Inloggningen misslyckades';
$messages['cookiesdisabled'] = 'Din webbläsare accepterar inte cookies';
$messages['sessionerror'] = 'Din inloggning är felaktig eller har gått ut';
$messages['imaperror'] = 'Kontakt med IMAP-servern misslyckades';
$messages['nomessagesfound'] = 'Inga meddelanden';
$messages['loggedout'] = 'Du är utloggad. Välkommen åter!';
$messages['mailboxempty'] = 'Mappen är tom';
$messages['loading'] = 'Laddar...';
$messages['loadingdata'] = 'Laddar data...';
$messages['checkingmail'] = 'Letar efter nya meddelanden...';
$messages['sendingmessage'] = 'Skickar meddelande...';
$messages['messagesent'] = 'Meddelandet har skickats';
$messages['savingmessage'] = 'Sparar meddelande...';
$messages['messagesaved'] = 'Meddelande sparades till utkast';
$messages['successfullysaved'] = 'Sparat';
$messages['addedsuccessfully'] = 'Kontakten har lagts till i adressboken';
$messages['contactexists'] = 'En kontakt med den här adressen finns redan';
$messages['blockedimages'] = 'För att skydda dig är bilder blockerade.';
$messages['encryptedmessage'] = 'Meddelandet är krypterat och kan tyvärr inte visas.';
$messages['nocontactsfound'] = 'Inga kontakter hittades';
$messages['contactnotfound'] = 'Den efterfrågade kontanten hittades inte';
$messages['sendingfailed'] = 'Meddelandet kunde inte skickas';
$messages['errorsaving'] = 'Ett fel uppstod när meddelandet sparades';
$messages['errormoving'] = 'Meddelandet kunde inte flyttas';
$messages['errordeleting'] = 'Meddelandet kunde inte raderas';
$messages['deletecontactconfirm'] = 'Vill du verkligen radera valda kontakter?';
$messages['deletemessagesconfirm'] = 'Vill du verkligen ta bort valda meddelanden?';
$messages['deletefolderconfirm'] = 'Vill du verkligen radera den här mappen?';
$messages['purgefolderconfirm'] = 'Vill du verkligen radera alla meddelanden i den här mappen?';
$messages['formincomplete'] = 'Formuläret var inte ifyllt i sin helhet';
$messages['noemailwarning'] = 'Vänligen ange en giltig adress';
$messages['nonamewarning'] = 'Vänligen ange ett namn';
$messages['nopagesizewarning'] = 'Vänligen ange en sidstorlek';
$messages['norecipientwarning'] = 'Vänligen ange minst en mottagare';
$messages['nosubjectwarning'] = 'Ämnesfältet är tomt. Vill du lägga till något nu?';
$messages['nobodywarning'] = 'Skicka det här meddelandet utan text?';
$messages['notsentwarning'] = 'Meddelande har inte skickats. Vill du avbryta meddelandet?';
$messages['noldapserver'] = 'Vänligen ange en LDAP-server att söka';
$messages['nocontactsreturned'] = 'Inga kontakter hittades';
$messages['nosearchname'] = 'Vänligen ange ett kontaktnamn eller en adress';
$messages['searchsuccessful'] = '$nr meddelanden hittades';
$messages['searchnomatch'] = 'Sökningen returnerade inga träffar';
$messages['searching'] = 'Söker...';
$messages['checking'] = 'Kontrollerar...';
$messages['nospellerrors'] = 'Inget stavfel hittades';
$messages['folderdeleted'] = 'Mappen raderades';
$messages['deletedsuccessfully'] = 'Lyckad borttagning';
$messages['converting'] = 'Tar bort formatering från meddelande...';
$messages['messageopenerror'] = 'Kunde inte ladda meddelande från servern';
$messages['fileuploaderror'] = 'Filuppladdning misslyckades';
$messages['filesizeerror'] = 'Den uppladdade filen överstiger maxstorleken $size';
$messages['copysuccess'] = 'Lyckad kopiering av $nr adresser';
$messages['copyerror'] = 'Kunde inte kopiera några adresser';
$messages['sourceisreadonly'] = 'Denna adresskälla är skrivskyddad';
$messages['errorsavingcontact'] = 'Kunde inte spara kontakt-adressen';
$messages['movingmessage'] = 'Flyttar meddelande...';
$messages['receiptsent'] = 'Ett läskvitto har skickats';
$messages['errorsendingreceipt'] = 'Kunde inte skicka läskvittot';
$messages['nodeletelastidentity'] = 'Du kan inte radera den här identiteten, det är din sista.';
$messages['addsubfolderhint'] = 'Den här mappen kommer att skapas som en underkatalog till den valda';

?>