<?php

/*

+-----------------------------------------------------------------------+
| language/it/labels.inc                                                |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Andrej Mocilnik <amocilnik@dotcom.ts.it>                      |
|         Yusef Maali <contact@yusefmaali.net>                          |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2115 2008-12-04 10:21:34Z alec $

*/

$labels = array();
$labels['welcome'] = 'Benvenuto in $product';
$labels['username'] = 'Utente';
$labels['password'] = 'Password';
$labels['server'] = 'Server';
$labels['login'] = 'Entra';
$labels['logout'] = 'Esci';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Impostazioni';
$labels['addressbook'] = 'Rubrica';
$labels['inbox'] = 'Posta in arrivo';
$labels['drafts'] = 'Bozze';
$labels['sent'] = 'Inviata';
$labels['trash'] = 'Cestino';
$labels['junk'] = 'Spam';
$labels['subject'] = 'Oggetto';
$labels['from'] = 'Mittente';
$labels['to'] = 'Destinatario';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Ccn';
$labels['replyto'] = 'Rispondi a';
$labels['date'] = 'Data';
$labels['size'] = 'Dimensione';
$labels['priority'] = 'Priorità';
$labels['organization'] = 'Società';
$labels['reply-to'] = 'Rispondi a';
$labels['mailboxlist'] = 'Cartelle';
$labels['messagesfromto'] = 'Messaggi da $from a $to di $count';
$labels['messagenrof'] = 'Messaggio $nr di $count';
$labels['moveto'] = 'Sposta in...';
$labels['download'] = 'Download';
$labels['filename'] = 'Nome file';
$labels['filesize'] = 'Dimensione file';
$labels['preferhtml'] = 'Mostra HTML';
$labels['htmlmessage'] = 'Messaggio HTML';
$labels['prettydate'] = 'Date più leggibili';
$labels['addtoaddressbook'] = 'Aggiungi alla rubrica';
$labels['sun'] = 'Dom';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Gio';
$labels['fri'] = 'Ven';
$labels['sat'] = 'Sab';
$labels['sunday'] = 'Domenica';
$labels['monday'] = 'Lunedì';
$labels['tuesday'] = 'Martedì';
$labels['wednesday'] = 'Mercoledì';
$labels['thursday'] = 'Giovedì';
$labels['friday'] = 'Venerdì';
$labels['saturday'] = 'Sabato';
$labels['jan'] = 'Gen';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Mag';
$labels['jun'] = 'Giu';
$labels['jul'] = 'Lug';
$labels['aug'] = 'Ago';
$labels['sep'] = 'Set';
$labels['oct'] = 'Ott';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dic';
$labels['longjan'] = 'Gennaio';
$labels['longfeb'] = 'Febbraio';
$labels['longmar'] = 'Marzo';
$labels['longapr'] = 'Aprile';
$labels['longmay'] = 'Maggio';
$labels['longjun'] = 'Giugno';
$labels['longjul'] = 'Luglio';
$labels['longaug'] = 'Agosto';
$labels['longsep'] = 'Settembre';
$labels['longoct'] = 'Ottobre';
$labels['longnov'] = 'Novembre';
$labels['longdec'] = 'Dicembre';
$labels['today'] = 'Oggi';
$labels['checkmail'] = 'Controlla nuovi messaggi';
$labels['writenewmessage'] = 'Scrivi un nuovo messaggio';
$labels['replytomessage'] = 'Rispondi al mittente';
$labels['replytoallmessage'] = 'Rispondi a tutti';
$labels['forwardmessage'] = 'Inoltra il messaggio';
$labels['deletemessage'] = 'Elimina il messaggio';
$labels['movemessagetotrash'] = 'Sposta il messaggio nel cestino';
$labels['printmessage'] = 'Stampa il messaggio';
$labels['previousmessage'] = 'Visualizza il messaggio precedente';
$labels['previousmessages'] = 'Visualizza messaggi precedenti';
$labels['firstmessage'] = 'Visualizza il primo messaggio';
$labels['firstmessages'] = 'Visualizza il primo set di messaggi';
$labels['nextmessage'] = 'Visualizza il messaggio successivo';
$labels['nextmessages'] = 'Visualizza messaggi successivi';
$labels['lastmessage'] = 'Visualizza l\'ultimo messaggio';
$labels['lastmessages'] = 'Visualizza l\'ultimo set di messaggi';
$labels['backtolist'] = 'Torna alla lista messaggi';
$labels['viewsource'] = 'Visualizza sorgente messaggio';
$labels['markmessages'] = 'Marca i messaggi';
$labels['markread'] = 'Letti';
$labels['markunread'] = 'Non letti';
$labels['markflagged'] = 'Contrassegnati';
$labels['markunflagged'] = 'Non contrassegnati';
$labels['select'] = 'Seleziona';
$labels['all'] = 'Tutti';
$labels['none'] = 'Nessuno';
$labels['unread'] = 'Non letti';
$labels['compact'] = 'Compatta';
$labels['empty'] = 'Svuota';
$labels['purge'] = 'Pulisci';
$labels['quota'] = 'Spazio utilizzato';
$labels['unknown'] = 'sconosciuto';
$labels['unlimited'] = 'illimitato';
$labels['quicksearch'] = 'Ricerca veloce';
$labels['resetsearch'] = 'Annulla ricerca';
$labels['openinextwin'] = 'Apri in una nuova finestra';
$labels['compose'] = 'Scrivi un messaggio';
$labels['savemessage'] = 'Salva come bozza';
$labels['sendmessage'] = 'Invia il messaggio adesso';
$labels['addattachment'] = 'Allega un file';
$labels['charset'] = 'Set di caratteri';
$labels['editortype'] = 'Tipo editor';
$labels['returnreceipt'] = 'Ricevuta di ritorno';
$labels['checkspelling'] = 'Controlla ortografia';
$labels['resumeediting'] = 'Torna al messaggio';
$labels['revertto'] = 'Ripristina';
$labels['attachments'] = 'Allegati';
$labels['upload'] = 'Aggiungi';
$labels['close'] = 'Chiudi';
$labels['low'] = 'Bassa';
$labels['lowest'] = 'Molto bassa';
$labels['normal'] = 'Normale';
$labels['high'] = 'Alta';
$labels['highest'] = 'Molto alta';
$labels['nosubject'] = '(nessun oggetto)';
$labels['showimages'] = 'Visualizza immagini';
$labels['alwaysshow'] = 'Mostra sempre immagini da $sender';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Testo semplice';
$labels['savesentmessagein'] = 'Salva messaggi inviati in';
$labels['dontsave'] = 'non salvare';
$labels['maxuploadsize'] = 'La dimensione massima consentita è $size';
$labels['addcc'] = 'Aggiungi Cc';
$labels['addbcc'] = 'Aggiungi Bcc';
$labels['addreplyto'] = 'Aggiungi Rispondi a';
$labels['mdnrequest'] = 'Il mittente ha richiesto di ricevere una notifica dell\'avvenuta lettura del messaggio. Si desidera inviare tale notifica?';
$labels['receiptread'] = 'Ricevuta di ritorno (letto)';
$labels['yourmessage'] = 'Questa è la ricevuta di ritorno del mesaggio inviato';
$labels['receiptnote'] = 'Nota: questa Ricevuta di ritorno attesta solamente che il messaggio è stato visualizzato nel computer del destinatario. Non c\'è pertanto alcuna garanzia che il destinatario abbia letto o compreso il suo contenuto.';
$labels['name'] = 'Nome visualizzato';
$labels['firstname'] = 'Nome';
$labels['surname'] = 'Cognome';
$labels['email'] = 'E-Mail';
$labels['addcontact'] = 'Aggiungi contatto alla rubrica';
$labels['editcontact'] = 'Modifica contatto';
$labels['edit'] = 'Modifica';
$labels['cancel'] = 'Annulla';
$labels['save'] = 'Salva';
$labels['delete'] = 'Elimina';
$labels['newcontact'] = 'Crea un nuovo contatto';
$labels['deletecontact'] = 'Elimina i contatti selezionati';
$labels['composeto'] = 'Invia email a';
$labels['contactsfromto'] = 'Contatti da $from a $to di $count';
$labels['print'] = 'Stampa';
$labels['export'] = 'Esporta';
$labels['exportvcards'] = 'Esporta i contatti in formato vCard';
$labels['previouspage'] = 'Pagina precedente';
$labels['firstpage'] = 'Prima pagina';
$labels['nextpage'] = 'Pagina successiva';
$labels['lastpage'] = 'Ultima pagina';
$labels['groups'] = 'Gruppi';
$labels['personaladrbook'] = 'Rubrica Personale';
$labels['import'] = 'Importa';
$labels['importcontacts'] = 'Importa contatti';
$labels['importfromfile'] = 'Importa da file:';
$labels['importreplace'] = 'Sostituisci l\'intera rubrica';
$labels['importtext'] = 'Puoi caricare i contatti da una rubrica esistente.Al momento è supportata l\'importazione dei contatti dal formato vCard.';
$labels['done'] = 'Fatto';
$labels['settingsfor'] = 'Impostazioni per ';
$labels['preferences'] = 'Preferenze';
$labels['userpreferences'] = 'Preferenze utente';
$labels['editpreferences'] = 'Modifica le preferenze per l\'utente';
$labels['identities'] = 'Identità';
$labels['manageidentities'] = 'Gestisci le identità per questo account';
$labels['newidentity'] = 'Nuova identità';
$labels['newitem'] = 'Nuovo elemento';
$labels['edititem'] = 'Modifica elemento';
$labels['setdefault'] = 'Imposta predefinita';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Lingua';
$labels['timezone'] = 'Fuso orario';
$labels['pagesize'] = 'Righe per pagina';
$labels['signature'] = 'Firma';
$labels['dstactive'] = 'Gestione ora legale / ora solare';
$labels['htmleditor'] = 'Scrivi i messaggi in HTML';
$labels['htmlsignature'] = 'Firma in HTML';
$labels['previewpane'] = 'Mostra l\'anteprima';
$labels['skin'] = 'Tema interfaccia';
$labels['logoutclear'] = 'Svuota il Cestino all\'uscita';
$labels['logoutcompact'] = 'Compatta la Posta In Arrivo all\'uscita';
$labels['uisettings'] = 'Interfaccia Utente';
$labels['serversettings'] = 'Impostazioni Server';
$labels['mailboxview'] = 'Vista Messaggi';
$labels['mdnrequests'] = 'Notifiche Lettura';
$labels['askuser'] = 'chiedi all\'utente';
$labels['autosend'] = 'invia automaticamente';
$labels['ignore'] = 'ignora';
$labels['readwhendeleted'] = 'Segna il messaggio come letto all\'eliminazione';
$labels['flagfordeletion'] = 'Segna il messaggio per l\'eliminazione invece che eliminare';
$labels['skipdeleted'] = 'Non mostrare messaggi eliminati';
$labels['showinlineimages'] = 'Mostra immagini allegate sotto il messaggio';
$labels['autosavedraft'] = 'Salva le bozze automaticamente';
$labels['everynminutes'] = 'ogni $n minuti';
$labels['keepaliveevery'] = 'ogni $n minuto(i)';
$labels['keepalive'] = 'Verificare la presenza di nuovi messaggi su';
$labels['never'] = 'mai';
$labels['messagesdisplaying'] = 'Visualizzazione Messaggi';
$labels['messagescomposition'] = 'Composizione Messaggi';
$labels['mimeparamfolding'] = 'Nomi allegati';
$labels['2231folding'] = 'RFC 2231 completo (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 completo (altri)';
$labels['advancedoptions'] = 'Opzioni avanzate';
$labels['focusonnewmessage'] = 'Finestra del browser sul nuovo messaggio';
$labels['folder'] = 'Cartella';
$labels['folders'] = 'Cartelle';
$labels['foldername'] = 'Nome cartella';
$labels['subscribed'] = 'Sottoscritta';
$labels['messagecount'] = 'Messaggi';
$labels['create'] = 'Crea';
$labels['createfolder'] = 'Crea nuova cartella';
$labels['rename'] = 'Rinomina';
$labels['renamefolder'] = 'Rinomina cartella';
$labels['deletefolder'] = 'Cancella cartella';
$labels['managefolders'] = 'Gestione cartelle';
$labels['specialfolders'] = 'Cartelle Speciali';
$labels['sortby'] = 'Ordina per';
$labels['sortasc'] = 'Ordinamento crescente';
$labels['sortdesc'] = 'Ordinamento decrescente';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
