<?php

/*

+-----------------------------------------------------------------------+
| localization/zh_CN/labels.inc                                         |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Xue zhong sheng <xue.zhongsheng@gmail.com>                    |
|         Zhang Huang bin <michaelbibby@gmail.com>                      |
+-----------------------------------------------------------------------+

@version $Id: labels.inc 2151 2008-12-14 21:37:19Z yllar $

*/

$labels = array();
$labels['welcome'] = '欢迎使用 $product';
$labels['username'] = '用户名';
$labels['password'] = '密码';
$labels['server'] = '服务器';
$labels['login'] = '登录';
$labels['logout'] = '注销';
$labels['mail'] = '电子邮件';
$labels['settings'] = '邮箱设置';
$labels['addressbook'] = '通讯录';
$labels['inbox'] = '收件箱';
$labels['drafts'] = '草稿箱';
$labels['sent'] = '已发送邮件';
$labels['trash'] = '回收站';
$labels['junk'] = '垃圾邮件';
$labels['subject'] = '主题';
$labels['from'] = '发件人';
$labels['to'] = '收件人';
$labels['cc'] = '抄送';
$labels['bcc'] = '密送';
$labels['replyto'] = '回复至';
$labels['date'] = '日期';
$labels['size'] = '大小';
$labels['priority'] = '优先级';
$labels['organization'] = '组织';
$labels['reply-to'] = '回复至';
$labels['mailboxlist'] = '邮件夹';
$labels['messagesfromto'] = '第 $from 到 $to，共 $count 封邮件';
$labels['messagenrof'] = '第 $nr 封邮件，共 $count 封';
$labels['moveto'] = '移动到';
$labels['download'] = '下载';
$labels['filename'] = '文件名';
$labels['filesize'] = '文件大小';
$labels['preferhtml'] = '以 HTML 格式显示';
$labels['htmlmessage'] = 'HTML 邮件';
$labels['prettydate'] = '短日期格式';
$labels['addtoaddressbook'] = '添加到通讯录';
$labels['sun'] = '日';
$labels['mon'] = '一';
$labels['tue'] = '二';
$labels['wed'] = '三';
$labels['thu'] = '四';
$labels['fri'] = '五';
$labels['sat'] = '六';
$labels['sunday'] = '星期日';
$labels['monday'] = '星期一';
$labels['tuesday'] = '星期二';
$labels['wednesday'] = '星期三';
$labels['thursday'] = '星期四';
$labels['friday'] = '星期五';
$labels['saturday'] = '星期六';
$labels['jan'] = '一月';
$labels['feb'] = '二月';
$labels['mar'] = '三月';
$labels['apr'] = '四月';
$labels['may'] = '五月';
$labels['jun'] = '六月';
$labels['jul'] = '七月';
$labels['aug'] = '八月';
$labels['sep'] = '九月';
$labels['oct'] = '十月';
$labels['nov'] = '十一月';
$labels['dec'] = '十二月';
$labels['longjan'] = '一月';
$labels['longfeb'] = '二月';
$labels['longmar'] = '三月';
$labels['longapr'] = '四月';
$labels['longmay'] = '五月';
$labels['longjun'] = '六月';
$labels['longjul'] = '七月';
$labels['longaug'] = '八月';
$labels['longsep'] = '九月';
$labels['longoct'] = '十月';
$labels['longnov'] = '十一月';
$labels['longdec'] = '十二月';
$labels['today'] = '今日';
$labels['checkmail'] = '收取新邮件';
$labels['writenewmessage'] = '写新邮件';
$labels['replytomessage'] = '回复发件人';
$labels['replytoallmessage'] = '全部回复';
$labels['forwardmessage'] = '转发邮件';
$labels['deletemessage'] = '删除邮件';
$labels['movemessagetotrash'] = '移动邮件到回收站';
$labels['printmessage'] = '打印邮件';
$labels['previousmessage'] = '显示上一封邮件';
$labels['previousmessages'] = '上一页';
$labels['firstmessage'] = '显示第一封邮件';
$labels['firstmessages'] = '第一页';
$labels['nextmessage'] = '下一封';
$labels['nextmessages'] = '下一页';
$labels['lastmessage'] = '最后一封';
$labels['lastmessages'] = '最后一页';
$labels['backtolist'] = '返回邮件列表';
$labels['viewsource'] = '显示邮件源文件';
$labels['markmessages'] = '标记邮件';
$labels['markread'] = '已读';
$labels['markunread'] = '未读';
$labels['markflagged'] = '已标记';
$labels['markunflagged'] = '未标记';
$labels['select'] = '选择';
$labels['all'] = '全部';
$labels['none'] = '无';
$labels['unread'] = '未读';
$labels['flagged'] = '已标记';
$labels['unanswered'] = '未回复';
$labels['filter'] = '过滤';
$labels['compact'] = '压缩';
$labels['empty'] = '清空';
$labels['purge'] = '清除';
$labels['quota'] = '邮箱容量';
$labels['unknown'] = '未知';
$labels['unlimited'] = '无限制';
$labels['quicksearch'] = '快速查找';
$labels['resetsearch'] = '清空查找内容';
$labels['openinextwin'] = '在新窗口中打开';
$labels['compose'] = '写新邮件';
$labels['savemessage'] = '保存为草稿';
$labels['sendmessage'] = '立即发送';
$labels['addattachment'] = '添加附件';
$labels['charset'] = '字符集';
$labels['editortype'] = '编辑器类型';
$labels['returnreceipt'] = '邮件回执';
$labels['checkspelling'] = '拼写检查';
$labels['resumeediting'] = '重新编辑';
$labels['revertto'] = '恢复至';
$labels['attachments'] = '附件';
$labels['upload'] = '上传';
$labels['close'] = '关闭';
$labels['low'] = '低';
$labels['lowest'] = '最低';
$labels['normal'] = '普通';
$labels['high'] = '高';
$labels['highest'] = '最高';
$labels['nosubject'] = '（无主题）';
$labels['showimages'] = '显示图片';
$labels['alwaysshow'] = '总是在来自 $sender 的邮件中显示图片';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = '纯文本';
$labels['savesentmessagein'] = '将已发送邮件保存到';
$labels['dontsave'] = '不保存';
$labels['maxuploadsize'] = '允许的最大文件大小是 $size';
$labels['addcc'] = '添加抄送';
$labels['addbcc'] = '添加密送';
$labels['addreplyto'] = '添加回复';
$labels['mdnrequest'] = '发件人要求在您阅读这封邮件时发送通知。您是否希望通知发件人？';
$labels['receiptread'] = '发送回执（已读）';
$labels['yourmessage'] = '这是您的邮件回执';
$labels['receiptnote'] = '注意：回执只表示邮件在收件人的电脑上被打开过，不表示收件人已经阅读或已理解邮件的内容。';
$labels['name'] = '显示名称';
$labels['firstname'] = '名字';
$labels['surname'] = '姓氏';
$labels['email'] = '邮件地址';
$labels['addcontact'] = '添加联系人';
$labels['editcontact'] = '修改联系人';
$labels['edit'] = '编辑';
$labels['cancel'] = '取消';
$labels['save'] = '保存';
$labels['delete'] = '删除';
$labels['newcontact'] = '新建联系人';
$labels['deletecontact'] = '删除选中的联系人';
$labels['composeto'] = '写信给';
$labels['contactsfromto'] = '第 $from 到 $to 个联系人，共 $count 个';
$labels['print'] = '打印';
$labels['export'] = '导出';
$labels['exportvcards'] = '以 vCard 格式导出联系人';
$labels['previouspage'] = '上一页';
$labels['firstpage'] = '第一页';
$labels['nextpage'] = '下一页';
$labels['lastpage'] = '最后一页';
$labels['groups'] = '分组';
$labels['personaladrbook'] = '个人住址';
$labels['import'] = '导入';
$labels['importcontacts'] = '导入联系人';
$labels['importfromfile'] = '从文件导入';
$labels['importreplace'] = '替换整个地址簿';
$labels['importtext'] = '你可以从已有的地址簿导入联系人。目前支持从 vCard 数据格式导入地址簿。';
$labels['done'] = '完成';
$labels['settingsfor'] = '设置';
$labels['preferences'] = '偏好设置';
$labels['userpreferences'] = '个人偏好';
$labels['editpreferences'] = '修改个人偏好';
$labels['identities'] = '发邮件的身份';
$labels['manageidentities'] = '管理此账号的身份';
$labels['newidentity'] = '添加身份';
$labels['newitem'] = '添加条目';
$labels['edititem'] = '修改条目';
$labels['setdefault'] = '设为默认';
$labels['autodetect'] = '自动';
$labels['language'] = '语言';
$labels['timezone'] = '时区';
$labels['pagesize'] = '每页显示的邮件数量';
$labels['signature'] = '签名';
$labels['dstactive'] = '夏令时';
$labels['htmleditor'] = '使用 HTML 编辑器';
$labels['htmlsignature'] = '使用 HTML 签名';
$labels['previewpane'] = '显示预览窗口';
$labels['skin'] = '界面皮肤';
$labels['logoutclear'] = '退出时清空回收站';
$labels['logoutcompact'] = '退出时压缩收件箱';
$labels['uisettings'] = '用户界面';
$labels['serversettings'] = '服务器设置';
$labels['mailboxview'] = '邮箱查看方式';
$labels['mdnrequests'] = '发件人通知';
$labels['askuser'] = '询问用户';
$labels['autosend'] = '自动发送';
$labels['ignore'] = '忽略';
$labels['readwhendeleted'] = '删除后标记为已读';
$labels['flagfordeletion'] = '标记邮件为已删除而不是实际删除';
$labels['skipdeleted'] = '不显示标记为已删除的邮件';
$labels['showremoteimages'] = '显示内嵌的图片';
$labels['fromknownsenders'] = '来自未知的发件人';
$labels['always'] = '总是';
$labels['showinlineimages'] = '在邮件下方显示附件中的图片';
$labels['autosavedraft'] = '自动保存到草稿箱';
$labels['everynminutes'] = '第 $n 分钟';
$labels['keepaliveevery'] = '每隔 $n 分钟';
$labels['keepalive'] = '检查新邮件';
$labels['never'] = '从不';
$labels['messagesdisplaying'] = '邮件显示设置';
$labels['messagescomposition'] = '写邮件';
$labels['mimeparamfolding'] = '附件名';
$labels['2231folding'] = '完整的 RFC 2231（Thunderbird）';
$labels['miscfolding'] = 'RFC 2047/2232（MS Outlook）';
$labels['2047folding'] = '完整的 RFC 2047（其它）';
$labels['advancedoptions'] = '高级选项';
$labels['focusonnewmessage'] = '新邮件到达时将窗口提升为焦点窗口';
$labels['checkallfolders'] = '检查所有邮件夹里的新邮件';
$labels['folder'] = '邮件夹';
$labels['folders'] = '邮件夹';
$labels['foldername'] = '邮件夹名称';
$labels['subscribed'] = '已订阅';
$labels['messagecount'] = '邮件数量';
$labels['create'] = '建立';
$labels['createfolder'] = '建立新邮件夹';
$labels['rename'] = '重命名';
$labels['renamefolder'] = '重命名邮件夹';
$labels['deletefolder'] = '删除邮件夹';
$labels['managefolders'] = '管理邮件夹';
$labels['specialfolders'] = '指定邮件夹';
$labels['sortby'] = '排序';
$labels['sortasc'] = '递增排序';
$labels['sortdesc'] = '递减排序';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';

?>
