-- MySQL dump 10.11
--
-- Host: localhost    Database: ccccmoor_rc01
-- ------------------------------------------------------
-- Server version	5.0.75-community-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `cache`
--

DROP TABLE IF EXISTS `cache`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `cache` (
  `cache_id` int(10) unsigned NOT NULL auto_increment,
  `cache_key` varchar(128) character set ascii NOT NULL,
  `created` datetime NOT NULL default '0000-00-00 00:00:00',
  `data` longtext NOT NULL,
  `user_id` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`cache_id`),
  KEY `created_index` (`created`),
  KEY `user_cache_index` (`user_id`,`cache_key`),
  CONSTRAINT `user_id_fk_cache` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=18 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `cache`
--

LOCK TABLES `cache` WRITE;
/*!40000 ALTER TABLE `cache` DISABLE KEYS */;
INSERT INTO `cache` VALUES (10,'IMAP.messagecount','2009-02-24 12:46:34','a:1:{s:5:\"INBOX\";a:2:{s:3:\"ALL\";i:4;s:6:\"UNSEEN\";i:0;}}',3),(17,'IMAP.mailboxes','2009-02-24 12:46:04','a:3:{i:0;s:5:\"INBOX\";i:1;s:12:\"INBOX.Drafts\";i:2;s:17:\"INBOX.Junk E-mail\";}',3);
/*!40000 ALTER TABLE `cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `contacts`
--

DROP TABLE IF EXISTS `contacts`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `contacts` (
  `contact_id` int(10) unsigned NOT NULL auto_increment,
  `changed` datetime NOT NULL default '0000-00-00 00:00:00',
  `del` tinyint(1) NOT NULL default '0',
  `name` varchar(128) NOT NULL,
  `email` varchar(128) NOT NULL,
  `firstname` varchar(128) NOT NULL,
  `surname` varchar(128) NOT NULL,
  `vcard` text,
  `user_id` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`contact_id`),
  KEY `user_id_fk_contacts` (`user_id`),
  CONSTRAINT `user_id_fk_contacts` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `contacts`
--

LOCK TABLES `contacts` WRITE;
/*!40000 ALTER TABLE `contacts` DISABLE KEYS */;
INSERT INTO `contacts` VALUES (1,'2009-02-23 20:40:44',0,'David C. Cook','weborders@davidccook.com','','',NULL,3);
/*!40000 ALTER TABLE `contacts` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `identities`
--

DROP TABLE IF EXISTS `identities`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `identities` (
  `identity_id` int(10) unsigned NOT NULL auto_increment,
  `del` tinyint(1) NOT NULL default '0',
  `standard` tinyint(1) NOT NULL default '0',
  `name` varchar(128) NOT NULL,
  `organization` varchar(128) NOT NULL default '',
  `email` varchar(128) NOT NULL,
  `reply-to` varchar(128) NOT NULL default '',
  `bcc` varchar(128) NOT NULL default '',
  `signature` text,
  `html_signature` tinyint(1) NOT NULL default '0',
  `user_id` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`identity_id`),
  KEY `user_id_fk_identities` (`user_id`),
  CONSTRAINT `user_id_fk_identities` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `identities`
--

LOCK TABLES `identities` WRITE;
/*!40000 ALTER TABLE `identities` DISABLE KEYS */;
INSERT INTO `identities` VALUES (1,0,1,'Christian Education Department','Columbia Chinese Christian Church','ce@ccccmo.org','','','',0,1),(2,0,1,'ccccmoor','','ccccmoor@mail.ccccmo.org','','',NULL,0,2),(3,0,1,'','','office@ccccmo.org','','',NULL,0,3);
/*!40000 ALTER TABLE `identities` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `messages`
--

DROP TABLE IF EXISTS `messages`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `messages` (
  `message_id` int(11) unsigned NOT NULL auto_increment,
  `user_id` int(10) unsigned NOT NULL default '0',
  `del` tinyint(1) NOT NULL default '0',
  `cache_key` varchar(128) character set ascii NOT NULL,
  `created` datetime NOT NULL default '0000-00-00 00:00:00',
  `idx` int(11) unsigned NOT NULL default '0',
  `uid` int(11) unsigned NOT NULL default '0',
  `subject` varchar(255) NOT NULL,
  `from` varchar(255) NOT NULL,
  `to` varchar(255) NOT NULL,
  `cc` varchar(255) NOT NULL,
  `date` datetime NOT NULL default '0000-00-00 00:00:00',
  `size` int(11) unsigned NOT NULL default '0',
  `headers` text NOT NULL,
  `structure` text,
  PRIMARY KEY  (`message_id`),
  UNIQUE KEY `uniqueness` (`user_id`,`cache_key`,`uid`),
  KEY `created_index` (`created`),
  CONSTRAINT `user_id_fk_messages` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `messages`
--

LOCK TABLES `messages` WRITE;
/*!40000 ALTER TABLE `messages` DISABLE KEYS */;
INSERT INTO `messages` VALUES (11,3,0,'INBOX.msg','2009-02-24 12:44:34',1,1,'David C. Cook - Thanks for Your Order','David C. Cook <weborders@davidccook.com>','office@ccccmo.org','','2009-02-12 23:01:35',15322,'O:14:\"iilBasicHeader\":31:{s:2:\"id\";s:1:\"1\";s:3:\"uid\";s:1:\"1\";s:7:\"subject\";s:37:\"David C. Cook - Thanks for Your Order\";s:4:\"from\";s:42:\"\"David C. Cook\" <weborders@davidccook.com>\";s:2:\"to\";s:17:\"office@ccccmo.org\";s:2:\"cc\";N;s:7:\"replyto\";s:42:\"\"David C. Cook\" <weborders@davidccook.com>\";s:11:\"in_reply_to\";N;s:4:\"date\";s:37:\"Thu, 12 Feb 2009 16:01:35 -0700 (MST)\";s:9:\"messageID\";s:50:\"<33210122.1234479695922.JavaMail.SYSTEM@ccmsrvmx1>\";s:4:\"size\";s:5:\"15322\";s:8:\"encoding\";N;s:7:\"charset\";N;s:5:\"ctype\";s:21:\"multipart/alternative\";s:5:\"flags\";a:1:{i:0;s:4:\"Seen\";}s:9:\"timestamp\";i:1234504895;s:1:\"f\";N;s:12:\"internaldate\";s:20:\"12-Feb-2009 16:01:37\";s:10:\"references\";N;s:8:\"priority\";N;s:6:\"mdn_to\";N;s:8:\"mdn_sent\";b:0;s:8:\"is_draft\";b:0;s:4:\"seen\";b:1;s:7:\"deleted\";b:0;s:6:\"recent\";b:0;s:8:\"answered\";b:0;s:9:\"forwarded\";b:0;s:4:\"junk\";b:0;s:7:\"flagged\";b:0;s:9:\"structure\";N;}',NULL),(12,3,0,'INBOX.msg','2009-02-24 12:44:34',2,2,'David C. Cook - Thanks for Feedback','David C. Cook <feedback@davidccook.com>','office@ccccmo.org','','2009-02-24 03:48:50',6615,'O:14:\"iilBasicHeader\":31:{s:2:\"id\";s:1:\"2\";s:3:\"uid\";s:1:\"2\";s:7:\"subject\";s:35:\"David C. Cook - Thanks for Feedback\";s:4:\"from\";s:41:\"\"David C. Cook\" <feedback@davidccook.com>\";s:2:\"to\";s:17:\"office@ccccmo.org\";s:2:\"cc\";N;s:7:\"replyto\";s:17:\"office@ccccmo.org\";s:11:\"in_reply_to\";N;s:4:\"date\";s:37:\"Mon, 23 Feb 2009 20:48:50 -0700 (MST)\";s:9:\"messageID\";s:50:\"<32749671.1235447330184.JavaMail.SYSTEM@ccmsrvmx1>\";s:4:\"size\";s:4:\"6615\";s:8:\"encoding\";N;s:7:\"charset\";N;s:5:\"ctype\";s:21:\"multipart/alternative\";s:5:\"flags\";a:1:{i:0;s:4:\"Seen\";}s:9:\"timestamp\";i:1235472530;s:1:\"f\";N;s:12:\"internaldate\";s:20:\"23-Feb-2009 20:48:51\";s:10:\"references\";N;s:8:\"priority\";N;s:6:\"mdn_to\";N;s:8:\"mdn_sent\";b:0;s:8:\"is_draft\";b:0;s:4:\"seen\";b:1;s:7:\"deleted\";b:0;s:6:\"recent\";b:0;s:8:\"answered\";b:0;s:9:\"forwarded\";b:0;s:4:\"junk\";b:0;s:7:\"flagged\";b:0;s:9:\"structure\";N;}',NULL),(13,3,0,'INBOX.msg','2009-02-24 12:44:34',3,3,'RE: Website - Order Status Inquiry','Feedback <Feedback@davidccook.com>','office@ccccmo.org <office@ccccmo.org>','','2009-02-24 16:09:04',45856,'O:14:\"iilBasicHeader\":31:{s:2:\"id\";s:1:\"3\";s:3:\"uid\";s:1:\"3\";s:7:\"subject\";s:34:\"RE: Website - Order Status Inquiry\";s:4:\"from\";s:34:\"Feedback <Feedback@davidccook.com>\";s:2:\"to\";s:39:\"\"office@ccccmo.org\" <office@ccccmo.org>\";s:2:\"cc\";N;s:7:\"replyto\";N;s:11:\"in_reply_to\";s:48:\"30610202.1235447330168.JavaMail.SYSTEM@ccmsrvmx1\";s:4:\"date\";s:31:\"Tue, 24 Feb 2009 09:09:04 -0700\";s:9:\"messageID\";s:64:\"<C0708FAE54CE084A82C46F4D86039B704C2E5F4F15@DCC-MAIL2.dcc.local>\";s:4:\"size\";s:5:\"45856\";s:8:\"encoding\";N;s:7:\"charset\";N;s:5:\"ctype\";s:17:\"multipart/related\";s:5:\"flags\";a:1:{i:0;s:4:\"Seen\";}s:9:\"timestamp\";i:1235516944;s:1:\"f\";N;s:12:\"internaldate\";s:20:\"24-Feb-2009 09:09:09\";s:10:\"references\";s:50:\"<30610202.1235447330168.JavaMail.SYSTEM@ccmsrvmx1>\";s:8:\"priority\";N;s:6:\"mdn_to\";N;s:8:\"mdn_sent\";b:0;s:8:\"is_draft\";b:0;s:4:\"seen\";b:1;s:7:\"deleted\";b:0;s:6:\"recent\";b:0;s:8:\"answered\";b:0;s:9:\"forwarded\";b:0;s:4:\"junk\";b:0;s:7:\"flagged\";b:0;s:9:\"structure\";N;}',NULL),(14,3,0,'INBOX.msg','2009-02-24 12:44:34',4,4,'Test','Liu, Tony C.H. <LiuC@missouri.edu>','<office@ccccmo.org>','','2009-02-24 19:43:11',4240,'O:14:\"iilBasicHeader\":31:{s:2:\"id\";s:1:\"4\";s:3:\"uid\";s:1:\"4\";s:7:\"subject\";s:4:\"Test\";s:4:\"from\";s:36:\"\"Liu, Tony C.H.\" <LiuC@missouri.edu>\";s:2:\"to\";s:19:\"<office@ccccmo.org>\";s:2:\"cc\";N;s:7:\"replyto\";N;s:11:\"in_reply_to\";N;s:4:\"date\";s:31:\"Tue, 24 Feb 2009 13:43:11 -0600\";s:9:\"messageID\";s:69:\"<4C4EF6D1A570C24FA0B5466B7BB00C20068ED7F8@UM-XMAIL04.um.umsystem.edu>\";s:4:\"size\";s:4:\"4240\";s:8:\"encoding\";N;s:7:\"charset\";N;s:5:\"ctype\";s:21:\"multipart/alternative\";s:5:\"flags\";a:1:{i:0;s:4:\"Seen\";}s:9:\"timestamp\";i:1235529791;s:1:\"f\";N;s:12:\"internaldate\";s:20:\"24-Feb-2009 12:43:13\";s:10:\"references\";N;s:8:\"priority\";N;s:6:\"mdn_to\";N;s:8:\"mdn_sent\";b:0;s:8:\"is_draft\";b:0;s:4:\"seen\";b:1;s:7:\"deleted\";b:0;s:6:\"recent\";b:0;s:8:\"answered\";b:0;s:9:\"forwarded\";b:0;s:4:\"junk\";b:0;s:7:\"flagged\";b:0;s:9:\"structure\";N;}',NULL);
/*!40000 ALTER TABLE `messages` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `session`
--

DROP TABLE IF EXISTS `session`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `session` (
  `sess_id` varchar(40) NOT NULL,
  `created` datetime NOT NULL default '0000-00-00 00:00:00',
  `changed` datetime NOT NULL default '0000-00-00 00:00:00',
  `ip` varchar(40) NOT NULL,
  `vars` text NOT NULL,
  PRIMARY KEY  (`sess_id`),
  KEY `changed_index` (`changed`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `session`
--

LOCK TABLES `session` WRITE;
/*!40000 ALTER TABLE `session` DISABLE KEYS */;
INSERT INTO `session` VALUES ('51fb5d958e8a3c8a6ed176bb5729828a','2009-02-24 12:43:25','2009-02-24 13:00:47','128.206.65.175','language|s:5:\"en_US\";auth_time|i:1235504821;temp|b:1;task|s:8:\"settings\";');
/*!40000 ALTER TABLE `session` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS `users`;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
CREATE TABLE `users` (
  `user_id` int(10) unsigned NOT NULL auto_increment,
  `username` varchar(128) NOT NULL,
  `mail_host` varchar(128) NOT NULL,
  `alias` varchar(128) NOT NULL,
  `created` datetime NOT NULL default '0000-00-00 00:00:00',
  `last_login` datetime NOT NULL default '0000-00-00 00:00:00',
  `language` varchar(5) default NULL,
  `preferences` text,
  PRIMARY KEY  (`user_id`),
  KEY `username_index` (`username`),
  KEY `alias_index` (`alias`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8;
SET character_set_client = @saved_cs_client;

--
-- Dumping data for table `users`
--

LOCK TABLES `users` WRITE;
/*!40000 ALTER TABLE `users` DISABLE KEYS */;
INSERT INTO `users` VALUES (1,'ce@ccccmo.org','mail.ccccmo.org','','2008-12-30 19:29:40','2009-02-10 08:43:38','en_US',NULL),(2,'ccccmoor','mail.ccccmo.org','','2009-02-10 08:38:50','2009-02-10 08:38:50','en_US',NULL),(3,'office@ccccmo.org','mail.ccccmo.org','','2009-02-20 21:38:24','2009-02-24 12:43:25','en_US','a:6:{s:8:\"timezone\";d:-6;s:11:\"drafts_mbox\";s:6:\"Drafts\";s:9:\"sent_mbox\";s:0:\"\";s:9:\"junk_mbox\";s:11:\"Junk E-mail\";s:10:\"trash_mbox\";s:0:\"\";s:20:\"default_imap_folders\";a:3:{i:0;s:5:\"INBOX\";i:1;s:6:\"Drafts\";i:2;s:11:\"Junk E-mail\";}}');
/*!40000 ALTER TABLE `users` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2009-03-15 19:00:30
