<?php

/*

 +-----------------------------------------------------------------------+
 | language/sq_AL/messages.inc                                           |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Dashamir Hoxha <dhoxha@albaniaonline.net>                     |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$messages = array();
$messages['loginfailed'] = 'Hyrja dështoi';
$messages['cookiesdisabled'] = 'Shfletuesi juaj nuk i pranon sheqerkat';
$messages['sessionerror'] = 'Sesioni juaj është i pavlefshëm ose i ka kaluar afati';
$messages['imaperror'] = 'Lidhja me serverin IMAP dështoi';
$messages['nomessagesfound'] = 'Nuk ka mesazhe në këtë kuti postare';
$messages['loggedout'] = 'Sesionin e mbyllët me sukses. Mirupafshim!';
$messages['mailboxempty'] = 'Kutia postare është bosh';
$messages['loading'] = 'Po ngarkohet...';
$messages['loadingdata'] = 'Po ngarkohen të dhëna...';
$messages['checkingmail'] = 'Po shoh për mesazhe të reja...';
$messages['sendingmessage'] = 'Po dërgoj mesazhin...';
$messages['messagesent'] = 'Mesazhi u dërgua me sukses';
$messages['savingmessage'] = 'Po ruaj mesazhin...';
$messages['messagesaved'] = 'Mesazhi u ruajt te kutia Drafte';
$messages['successfullysaved'] = 'U ruajt me sukses';
$messages['addedsuccessfully'] = 'Kontakti u shtua me sukses në librin e adresave';
$messages['contactexists'] = 'Këtë adresë e-mail e ka një kontakt tjetër';
$messages['blockedimages'] = 'Për të mbrojtur fshehtësinë tuaj, imazhet e largëta të këtij mesazhi janë bllokuar.';
$messages['encryptedmessage'] = 'Ky është një mesazh i koduar dhe nuk mund te shfaqet. Më vjen keq!';
$messages['nocontactsfound'] = 'Nuk ka kontakte';
$messages['contactnotfound'] = 'Kontakti që kërkoni nuk gjendet';
$messages['sendingfailed'] = 'Dërgimi i mesazhit dështoi';
$messages['errorsaving'] = 'Pati nje problem gjatë ruajtjes';
$messages['errormoving'] = 'Nuk e lëviza dot mesazhin';
$messages['errordeleting'] = 'Nuk e fshiva dot mesazhin';
$messages['deletecontactconfirm'] = 'Me të vërtetë doni ti fshini kontaktet e zgjedhura?';
$messages['deletemessagesconfirm'] = 'Me të vërtetë doni ti fshini mesazhet e zgjedhura?';
$messages['deletefolderconfirm'] = 'Me të vërtetë doni ta fshini këtë kuti?';
$messages['purgefolderconfirm'] = 'Me të vërtetë doni ti fshini të gjitha mesazhet në këtë kuti?';
$messages['formincomplete'] = 'Formulari nuk ishte i gjithi i plotësuar';
$messages['noemailwarning'] = 'Ju lutem jepni një adresë email të rregullt';
$messages['nonamewarning'] = 'Ju lutem jepni një emër';
$messages['nopagesizewarning'] = 'Ju lutem jepni nje madhësi për faqen';
$messages['norecipientwarning'] = 'Ju lutem shënoni të paktën një marrës';
$messages['nosubjectwarning'] = 'Fusha e temës është bosh. Dëshironi të shënoni një temë tani?';
$messages['nobodywarning'] = 'Ta dërgoj mesazhin pa tekst?';
$messages['notsentwarning'] = 'Mesazhi nuk u dërgua. Doni ta hidhni poshtë mesazhin?';
$messages['noldapserver'] = 'Ju lutem jepni një server ldap për të kërkuar';
$messages['nocontactsreturned'] = 'Nuk gjeta kontakte';
$messages['nosearchname'] = 'Ju lutem jepni një adresë email ose një emër kontakti';
$messages['searchsuccessful'] = 'U gjetën $nr mesazhe';
$messages['searchnomatch'] = 'Kërkimi nuk gjeti gjë';
$messages['searching'] = 'Po kërkoj...';
$messages['checking'] = 'Po kontrolloj...';
$messages['nospellerrors'] = 'Nuk u gjetën gabime';
$messages['folderdeleted'] = 'Kutia u fshi me sukses';
$messages['deletedsuccessfully'] = 'U fshi me sukses';
$messages['converting'] = 'Po i heq formatimin mesazhit...';
$messages['messageopenerror'] = 'Nuk marr dot mesazhe nga serveri';
$messages['fileuploaderror'] = 'Ngarkimi i skedarit dështoi';
$messages['filesizeerror'] = 'Skedari i ngarkuar e kalon madhësinë kufi prej $size';
$messages['copysuccess'] = 'U kopjuan me sukses $nr adresa';
$messages['copyerror'] = 'Nuk munda të kopjoj adresat';
$messages['sourceisreadonly'] = 'Ky burim adrese është vetëm i lexueshëm';
$messages['errorsavingcontact'] = 'Nuk e ruajta dot adresën e kontaktit';
$messages['movingmessage'] = 'Po lëviz mesazhin...';
$messages['receiptsent'] = 'U dërgua me sukses një njoftim leximi';
$messages['errorsendingreceipt'] = 'Nuk mund të dërgohet njoftimi';
$messages['nodeletelastidentity'] = 'Ju nuk mund ta fshini këtë identitet sepse nuk ju ka mbetur tjetër.';
$messages['addsubfolderhint'] = 'Kjo kuti do të krijohet si një nënkuti e asaj që është e zgjedhur';

?>
