<?php

/*

 +-----------------------------------------------------------------------+
 | language/ro/messages.inc                                              |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Daniel Anechitoaie - danieLs <daniels@safereaction.ro>        |
 |         Ispas Dorin <dorinxp2004@yahoo.com>                           |
 +-----------------------------------------------------------------------+

 @version $Id: messages.inc 1149 2008-02-28 19:52:09Z thomasb $

*/

$messages = array();
$messages['loginfailed'] = 'Autentificare esuata';
$messages['cookiesdisabled'] = 'Browserul dumneavoastra nu accepta cookies';
$messages['sessionerror'] = 'Sesiunea dumneavoastra este invalida sau a expirat';
$messages['imaperror'] = 'Conectarea la serverul IMAP a esuat';
$messages['nomessagesfound'] = 'Nu a fost gasit nici un mesaj in aceasta casuta postala';
$messages['loggedout'] = 'Sesiune incheiata cu succes. La revedere!';
$messages['mailboxempty'] = 'Casuta postala este goala';
$messages['loading'] = 'Se incarca...';
$messages['loadingdata'] = 'Se incarca informatiile...';
$messages['checkingmail'] = 'Verifica pentru mesaje noi...';
$messages['sendingmessage'] = 'Trimitere mesaj...';
$messages['messagesent'] = 'Mesajul a fost trimis cu succes!';
$messages['savingmessage'] = 'Salvare mesaj...';
$messages['messagesaved'] = 'Mesajul a fost salvat in Ciorne';
$messages['successfullysaved'] = 'Salvarea s-a efectuat cu succes';
$messages['addedsuccessfully'] = 'Contactul a fost adaugat cu succes in agenda';
$messages['contactexists'] = 'Mai exista un contact cu aceasta adresa de e-mail';
$messages['blockedimages'] = 'Pentru a va proteja intimitatea imaginile externe au fost blocate.';
$messages['encryptedmessage'] = 'Acesta este un mesaj criptat si nu poate fi afisat. Ne pare rau.';
$messages['nocontactsfound'] = 'Nu s-a gasit nici un contact';
$messages['contactnotfound'] = 'Contactul solicitat nu a fost gasit.';
$messages['sendingfailed'] = 'Nu s-a reusit trimiterea mesajului';
$messages['errorsaving'] = 'A intervenit o eroare in timp ce se efectua salvarea';
$messages['errormoving'] = 'Nu s-a putut muta mesajul';
$messages['errordeleting'] = 'Nu s-a putut sterge mesajul';
$messages['deletecontactconfirm'] = 'Sunteti sigur ca doriti sa stergeti contactul(ele) selectate?';
$messages['deletemessagesconfirm'] = 'Chiar doriti sa stergeti mesajele selectate ?';
$messages['deletefolderconfirm'] = 'Sunteti sigur ca doriti sa stergeti acest dosar?';
$messages['purgefolderconfirm'] = 'Sunteti sigur ca doriti sa stergeti toate mesajele din acest dosar?';
$messages['formincomplete'] = 'Formularul nu a fost completat corect';
$messages['noemailwarning'] = 'Va rugam introduceti o adresa de e-mail valida';
$messages['nonamewarning'] = 'Va rugam introduceti un nume';
$messages['nopagesizewarning'] = 'Va rugam introduceti marimea paginii';
$messages['norecipientwarning'] = 'Va rugam introduceti cel putin un destinatar';
$messages['nosubjectwarning'] = 'Mesajul nu are subiect. Vreti sa introduceti unul acum?';
$messages['nobodywarning'] = 'Trimiteti acest mesaj fara text?';
$messages['notsentwarning'] = 'Mesajul nu a fost trimis. Vreti sa renuntatati la el?';
$messages['noldapserver'] = 'Va rugam alegeti un server ldap pentru cautare';
$messages['nocontactsreturned'] = 'Nu s-a gasit nici un contact';
$messages['nosearchname'] = 'Va rugam introduceti un nume de contact sau adresa de e-mail';
$messages['searchsuccessful'] = '$nr mesaje gasite';
$messages['searchnomatch'] = 'Cautarea nu a returnat nici un rezultat';
$messages['searching'] = 'Se cauta...';
$messages['checking'] = 'Se verifica...';
$messages['nospellerrors'] = 'Nu s-a gasit nicio greseala de ortografie';
$messages['folderdeleted'] = 'Dosarul a fost sters cu succes';
$messages['deletedsuccessfully'] = 'Mesaj sters cu succes !';
$messages['converting'] = 'Resetez mesajul la parametrii initiali';
$messages['messageopenerror'] = 'Nu am putut incarca mesajul din server';
$messages['fileuploaderror'] = 'Incarcarea pe server a esuat';
$messages['filesizeerror'] = 'Fisierul incarcat depaseste marimea de $size';
$messages['copysuccess'] = 'Am copiat cu succes $nr de adrese';
$messages['copyerror'] = 'Nu am putut copia nici o adresa';
$messages['sourceisreadonly'] = 'Sursa adrese este "read-only"(se poate doar citi)';
$messages['errorsavingcontact'] = 'Nu am putut salva adresa de contact';
$messages['movingmessage'] = 'Mutare mesaj....';
$messages['receiptsent'] = 'Confirmarea a fost trimisa cu succes';
$messages['errorsendingreceipt'] = 'Confirmarea nu a putut fi trimisa';
$messages['nodeletelastidentity'] = 'Nu putesti sterge aceasta identitate, este ultima.';
$messages['addsubfolderhint'] = 'Acest dosar va fi creat ca subdosar al celui selectat.';

?>