<?php

/*
+-----------------------------------------------------------------------+
| language/gl_ES/messages.inc                                           |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author:    David Garabana Barro <david garabana com>                  |
+-----------------------------------------------------------------------+

*/

$messages = array();
$messages['loginfailed'] = 'Fallou o acceso';
$messages['cookiesdisabled'] = 'O seu navegador non acepta galletas';
$messages['sessionerror'] = 'A súa sesión non é válida ou expirou';
$messages['imaperror'] = 'Fallou a conexión co servidor IMAP';
$messages['nomessagesfound'] = 'Non se atoparon mensaxes nesta caixa de correo';
$messages['loggedout'] = 'Rematou correctamente a súa sesión. Ata logo!';
$messages['mailboxempty'] = 'A caixa de correo está vacía';
$messages['loading'] = 'Cargando...';
$messages['loadingdata'] = 'Cargando datos...';
$messages['checkingmail'] = 'Á procura de novas mensaxes...';
$messages['sendingmessage'] = 'Enviando mensaxe...';
$messages['messagesent'] = 'A mensaxe enviouse correctamente';
$messages['savingmessage'] = 'Gardando mensaxe...';
$messages['messagesaved'] = 'A mensaxe gardouse en "Borradores"';
$messages['successfullysaved'] = 'Gardada correctamente';
$messages['addedsuccessfully'] = 'O contacto engadiuse correctamente ao caderno de enderezos';
$messages['contactexists'] = 'Xa existe un contacto con este enderezo de correo electrónico';
$messages['blockedimages'] = 'Estanse a bloquear as imaxes remotas para protexer a súa privacidade';
$messages['encryptedmessage'] = 'Síntoo!. Non se pode amosar a mensaxe porque está cifrada';
$messages['nocontactsfound'] = 'Non se atoparon contactos';
$messages['contactnotfound'] = 'Non se atopou o contacto solicitado';
$messages['sendingfailed'] = 'Fallou o envío da mensaxe';
$messages['senttooquickly'] = 'Por favor, espere $sec segundos antes de enviar esta mensaxe';
$messages['errorsavingsent'] = 'Ocurriu un erro mentres se gardaba a mensaxe enviada';
$messages['errorsaving'] = 'Ocurriu un erro mentres se gardaba';
$messages['errormoving'] = 'Non puiden mover a mensaxe';
$messages['errordeleting'] = 'Non puiden eliminar a mensaxe';
$messages['deletecontactconfirm'] = 'Quere eliminar o(s) contacto(s) seleccionados?';
$messages['deletemessagesconfirm'] = 'Quere eliminar a(s) mensaxe(s) seleccionadas?';
$messages['deletefolderconfirm'] = 'Quere eliminar este cartafol?';
$messages['purgefolderconfirm'] = 'Quere eliminar tódalas mensaxes neste cartafol?';
$messages['foldercreating'] = 'Creando o cartafol...';
$messages['folderdeleting'] = 'Eliminando o cartafol...';
$messages['folderrenaming'] = 'Renomeando o cartafol...';
$messages['foldermoving'] = 'Movendo o cartafol...';
$messages['formincomplete'] = 'Non se cumprimentou completamente o formulario';
$messages['noemailwarning'] = 'Por favor, introduza un enderezo de correo electrónico válido';
$messages['nonamewarning'] = 'Por favor, introduza un nome';
$messages['nopagesizewarning'] = 'Por favor, introduza un tamaño de páxina';
$messages['nosenderwarning'] = 'Por favor, introduza o enderezo de correo electrónico do remitente';
$messages['norecipientwarning'] = 'Por favor, introduza polo menos un destinatario';
$messages['nosubjectwarning'] = 'O campo "Asunto" está baleiro. Quere introducir un?';
$messages['nobodywarning'] = 'Quere enviar esta mensaxe sen texto?';
$messages['notsentwarning'] = 'A mensaxe non se enviou. Quere descartala?';
$messages['noldapserver'] = 'Por favor, elixa un servidor LDAP para buscar';
$messages['nocontactsreturned'] = 'Non se atoparon contactos';
$messages['nosearchname'] = 'Por favor, introduza un contacto ou un enderezo de correo electrónico';
$messages['searchsuccessful'] = 'Atopáronse $nr mensaxes';
$messages['searchnomatch'] = 'A busca non atopou coincidencias';
$messages['searching'] = 'Buscando...';
$messages['checking'] = 'Comprobando...';
$messages['nospellerrors'] = 'Non hai erros ortográficos';
$messages['folderdeleted'] = 'Eliminouse correctamente o cartafol';
$messages['deletedsuccessfully'] = 'Eliminouse correctamente';
$messages['converting'] = 'Eliminando o formato da mensaxe...';
$messages['messageopenerror'] = 'Non puiden cargar a mensaxe desde o servidor';
$messages['fileuploaderror'] = 'Fallou a carga do ficheiro';
$messages['filesizeerror'] = 'O ficheiro cargado é máis grande que o tamaño máximo de $size';
$messages['copysuccess'] = 'Copiáronse correctamente $nr enderezos';
$messages['copyerror'] = 'Non puiden copiar ningún enderezo';
$messages['sourceisreadonly'] = 'A orixe é de só lectura';
$messages['errorsavingcontact'] = 'Non puiden gardar o contacto';
$messages['movingmessage'] = 'Movendo mensaxe...';
$messages['receiptsent'] = 'A notificación de disposición enviouse correctamente';
$messages['errorsendingreceipt'] = 'Non se puido enviar a notificación de disposición';
$messages['nodeletelastidentity'] = 'Non pode eliminar esta identidade, é a última';
$messages['addsubfolderhint'] = 'Este cartafol vaise crear coma un subcartafol do seleccionado';
$messages['forbiddencharacter'] = 'O nome do cartafol contén un carácter non válido';
$messages['selectimportfile'] = 'Por favor, escolla un ficheiro para cargar';
$messages['addresswriterror'] = 'Non se pode escribir no caderno de enderezos que escolleu';
$messages['importwait'] = 'Estou a importar. Por favor, agarde...';
$messages['importerror'] = 'Fallou a importación! O ficheiro que cargou non é un vCard correcto.';
$messages['importconfirm'] = '<b>Importáronse correctamente $inserted contactos. Ignoráronse $skipped contactos que xa existían</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'Operación non permitida';
$messages['nofromaddress'] = 'Falta o enderezo de correo electrónico na identidade que escolleu';

?>
