<?php

/*

 +-----------------------------------------------------------------------+
 | language/th_TH/labels.inc                                             |
 |                                                                       |
 | Language file of the RoundCube Webmail client                         |
 | Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
 | Licensed under the GNU GPL                                            |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Wiraphan Treeratphan <webmaster@modoeye.com>                  |
 +-----------------------------------------------------------------------+

 @version $Id$

*/

$labels = array();
$labels['welcome'] = 'ยินดีต้อนรับสู่ $product';
$labels['username'] = 'บัญชีผู้ใช้';
$labels['password'] = 'รหัสผ่าน';
$labels['server'] = 'เซิร์ฟเวอร์';
$labels['login'] = 'เข้าสู่ระบบ';
$labels['logout'] = 'ออกจากระบบ';
$labels['mail'] = 'อีเมล์';
$labels['settings'] = 'ปรับแต่งค่าส่วนตัว';
$labels['addressbook'] = 'สมุดรายชื่อ';
$labels['inbox'] = 'กล่องขาเข้า';
$labels['drafts'] = 'กล่องจดหมายร่าง';
$labels['sent'] = 'กล่องขาออก';
$labels['trash'] = 'ถังขยะ';
$labels['junk'] = 'กล่องจดหมายขยะ';
$labels['spam'] = 'กล่องจดหมายขยะ';
$labels['subject'] = 'หัวจดหมาย';
$labels['from'] = 'ผู้ส่ง';
$labels['to'] = 'ผู้รับ';
$labels['cc'] = 'คัดลอก';
$labels['bcc'] = 'แอบสำเนาถึง';
$labels['replyto'] = 'ตอบกลับ';
$labels['date'] = 'วันที่';
$labels['size'] = 'ขนาด';
$labels['priority'] = 'ระดับความสำคัญ';
$labels['organization'] = 'องค์กร';
$labels['reply-to'] = 'ตอบกลับ';
$labels['mailboxlist'] = 'กล่องจดหมาย';
$labels['messagesfromto'] = 'จดหมายจาก $from ถึง $to จำนวน $count ฉบับ';
$labels['messagenrof'] = 'จดหมายฉบับที่ $nr จาก $count ฉบับ';
$labels['moveto'] = 'ย้ายไป...';
$labels['download'] = 'ดาวน์โหลด';
$labels['filename'] = 'ชื่อไฟล์';
$labels['filesize'] = 'ขนาดไฟล์';
$labels['preferhtml'] = 'อ่านแบบ HTML';
$labels['htmlmessage'] = 'จดหมาย HTML';
$labels['prettydate'] = 'แสดงวันที่แบบย่อ';
$labels['addtoaddressbook'] = 'บันทึกในสมุดรายชื่อ';
$labels['sun'] = 'อ';
$labels['mon'] = 'จ';
$labels['tue'] = 'อ';
$labels['wed'] = 'พ';
$labels['thu'] = 'พฤ';
$labels['fri'] = 'ศ';
$labels['sat'] = 'ส';
$labels['sunday'] = 'วันอาทิตย์';
$labels['monday'] = 'วันจันทร์';
$labels['tuesday'] = 'วันอังคาร';
$labels['wednesday'] = 'วันพุธ';
$labels['thursday'] = 'วันพฤหัสบดี';
$labels['friday'] = 'วันศุกร์';
$labels['saturday'] = 'วันเสาร์';
$labels['today'] = 'วันนี้';
$labels['checkmail'] = 'ตรวจสอบจดหมายใหม่';
$labels['writenewmessage'] = 'สร้างจดหมายใหม่';
$labels['replytomessage'] = 'ตอบกลับจดหมาย';
$labels['replytoallmessage'] = 'ตอบกลับถึงทุกคนในจดหมาย';
$labels['forwardmessage'] = 'ส่งต่อจดหมาย';
$labels['deletemessage'] = 'ลบจดหมาย';
$labels['printmessage'] = 'พิมพ์จดหมาย';
$labels['previousmessage'] = 'แสดงจดหมายฉบับที่แล้ว';
$labels['previousmessages'] = 'จดหมายฉบับก่อนหน้า';
$labels['firstmessage'] = 'แสดงจดหมายฉบับแรก';
$labels['nextmessage'] = 'แสดงจดหมายฉบับต่อไป';
$labels['nextmessages'] = 'จดหมายฉบับถัดไป';
$labels['lastmessage'] = 'แสดงจดหมายฉบับล่าสุด';
$labels['backtolist'] = 'กลับไปยังรายการจดหมาย';
$labels['viewsource'] = 'แสดง source';
$labels['select'] = 'เลือก';
$labels['all'] = 'ทั้งหมด';
$labels['none'] = 'ไม่เลือก';
$labels['unread'] = 'จดหมายที่ไม่ได้อ่าน';
$labels['compact'] = 'แบบย่อ';
$labels['empty'] = 'ว่างเปล่า';
$labels['purge'] = 'ลบทั้งหมด';
$labels['quota'] = 'พื้นที่ใช้งาน';
$labels['unknown'] = 'ไม่ทราบ';
$labels['unlimited'] = 'ไม่จำกัด';
$labels['quicksearch'] = 'ค้นหาแบบด่วน';
$labels['resetsearch'] = 'ล้างการค้นหา';
$labels['compose'] = 'เขียนจดหมายใหม่';
$labels['savemessage'] = 'บันทึกฉบับร่าง';
$labels['sendmessage'] = 'ส่งจดหมาย';
$labels['addattachment'] = 'แนบไฟล์';
$labels['charset'] = 'Charset';
$labels['returnreceipt'] = 'ตอบกลับผู้รับ';
$labels['checkspelling'] = 'ตรวจสอบคำผิด';
$labels['resumeediting'] = 'แก้ไขต่อ';
$labels['revertto'] = 'ย้นกลับไปยัง';
$labels['attachments'] = 'ไฟล์แนบ';
$labels['upload'] = 'อัพโหลด';
$labels['close'] = 'ปิด';
$labels['low'] = 'ต่ำ';
$labels['lowest'] = 'ต่ำสุด';
$labels['normal'] = 'ปกติ';
$labels['high'] = 'สูง';
$labels['highest'] = 'สูงสุด';
$labels['nosubject'] = '(ไม่มีหัวข้อ)';
$labels['showimages'] = 'แสดงรูป';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Plain text';
$labels['name'] = 'ชื่อแสดง';
$labels['firstname'] = 'ชื่อ';
$labels['surname'] = 'สกุล';
$labels['email'] = 'อีเมล์';
$labels['addcontact'] = 'เพิ่มรายชื่อ';
$labels['editcontact'] = 'แก้ไขรายชื่อ';
$labels['edit'] = 'แก้ไข';
$labels['cancel'] = 'ยกเลิก';
$labels['save'] = 'บันทึก';
$labels['delete'] = 'ลบ';
$labels['newcontact'] = 'สร้างรายชื่อใหม่';
$labels['deletecontact'] = 'ลบรายชื่อที่เลือก';
$labels['composeto'] = 'เขียนจดหมายถึง';
$labels['contactsfromto'] = 'รายชื่อ $from ถึง $to จำนวน $count';
$labels['print'] = 'พิมพ์';
$labels['export'] = 'ส่งออก';
$labels['previouspage'] = 'หน้าที่แล้ว';
$labels['nextpage'] = 'หน้าถัดไป';
$labels['settingsfor'] = 'ตั้งค่าสำหรับ';
$labels['preferences'] = 'ปรับแต่ง';
$labels['userpreferences'] = 'ข้อมูลส่วนตัว';
$labels['editpreferences'] = 'แก้ไขข้อมูลส่วนตัว';
$labels['identities'] = 'ชื่อแสดงตัว';
$labels['manageidentities'] = 'จัดการชื่อแสดงตัวสำหรับรายชื่อนี้';
$labels['newidentity'] = 'ชื่อแสดงตัวใหม่';
$labels['newitem'] = 'New item';
$labels['edititem'] = 'Edit item';
$labels['setdefault'] = 'ตั้งเป็นค่าใช้งาน';
$labels['language'] = 'ภาษา';
$labels['timezone'] = 'เขตเวลา';
$labels['pagesize'] = 'จำนวนจดหมายต่อหน้า';
$labels['signature'] = 'ลายมือชื่อ';
$labels['dstactive'] = 'Daylight savings';
$labels['htmleditor'] = 'เขียนจดหมายแบบ HTML';
$labels['htmlsignature'] = 'ลายมือชื่อแบบ HTML';
$labels['previewpane'] = 'แสดงหน้าต่างตัวอย่างแสดงผล';
$labels['autosavedraft'] = 'บันทึกเป็นจดหมายร่างอัตโนมัติ';
$labels['everynminutes'] = 'ทุกๆ $n นาที';
$labels['never'] = 'ไม่ใช้';
$labels['folder'] = 'กล่องจดหมาย';
$labels['folders'] = 'กล่องจดหมาย';
$labels['foldername'] = 'ชื่อกล่องจดหมาย';
$labels['subscribed'] = 'ลงชื่อ';
$labels['create'] = 'สร้าง';
$labels['createfolder'] = 'สร้างกล่องจดหมาย';
$labels['rename'] = 'เปลื่ยนชื่อ';
$labels['renamefolder'] = 'เปลี่ยนชื่อกล่องจดหมาย';
$labels['deletefolder'] = 'ลบกล่องจดหมาย';
$labels['managefolders'] = 'จัดการกล่องจดหมาย';
$labels['sortby'] = 'เรียงตาม';
$labels['sortasc'] = 'เรียงจากหน้าไปหลัง';
$labels['sortdesc'] = 'เรียงจากหลังไปหน้า';

?>