<?php

/*

+-----------------------------------------------------------------------+
| language/lt_LT/messages.inc                                           |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Martynas Bendorius <martynas@evanet.lt>                       |
+-----------------------------------------------------------------------+

@version $Id: messages.inc 2184 2008-12-21 09:30:25Z yllar $

*/

$messages = array();
$messages['loginfailed'] = 'Prisijungti nepavyko';
$messages['cookiesdisabled'] = 'Jūsų naršyklė nepriima slapukų';
$messages['sessionerror'] = 'Jūsų sesija negaliojanti';
$messages['imaperror'] = 'Nepavyko prisijungti prie IMAP serverio';
$messages['nomessagesfound'] = 'Šioje pašto dėžutėje laiškų nėra ';
$messages['loggedout'] = 'Jus sėkmingai atsijungėte. Viso gero!';
$messages['mailboxempty'] = 'Pašto dėžutė tuščia';
$messages['loading'] = 'Įkeliama...';
$messages['loadingdata'] = 'Įkeliami duomenys...';
$messages['checkingmail'] = 'Tikrinama ar nėra naujų pranešimų...';
$messages['sendingmessage'] = 'Siunčiamas laiškas...';
$messages['messagesent'] = 'Laiškas sėkmingai nusiųstas';
$messages['savingmessage'] = 'Išsaugomas laiškas...';
$messages['messagesaved'] = 'Laiškas išsaugotas į Juodraščius';
$messages['successfullysaved'] = 'Sėkmingai išsaugota';
$messages['addedsuccessfully'] = 'Kontaktas sėkmingai įtrauktas į adresų knygą';
$messages['contactexists'] = 'Kontaktas, turintis šį el. pašto adresą, jau egzistuoja';
$messages['blockedimages'] = 'Saugant jūsų privatumą su laišku neatsiųsti paveikslėliai nerodomi';
$messages['encryptedmessage'] = 'Apgailestaujame, tačiau šis laiškas užšifruotas ir negali būti parodytas.';
$messages['nocontactsfound'] = 'Kontaktų nerasta';
$messages['contactnotfound'] = 'Reikalautas kontaktas nerastas';
$messages['sendingfailed'] = 'Laiško išsiųsti nepavyko';
$messages['senttooquickly'] = 'Jūs turite palaukti $sec sek., kad galėtumėte išsiųsti laišką';
$messages['errorsavingsent'] = 'Išsaugant išsiųstą laišką įvyko klaida';
$messages['errorsaving'] = 'Išsaugant įvyko klaida';
$messages['errormoving'] = 'Laiško perkelti nepavyko';
$messages['errordeleting'] = 'Laiško ištrinti nepavyko';
$messages['deletecontactconfirm'] = 'Ar jūs tikrai norite ištrinti pasirinktą(-us) kontaktą(-us)?';
$messages['deletemessagesconfirm'] = 'Ar jūs tikrai norite ištrinti pasirinktą(-us) žinutę(-es)?';
$messages['deletefolderconfirm'] = 'Ar jūs tikrai norite ištrinti šį aplanką?';
$messages['purgefolderconfirm'] = 'Ar jūs tikrai norite ištrinti visus laiškus, esančius šiame aplanke?';
$messages['foldercreating'] = 'Aplankas kuriamas...';
$messages['folderdeleting'] = 'Aplankas pašalinamas...';
$messages['folderrenaming'] = 'Aplankas pervardinamas...';
$messages['foldermoving'] = 'Aplankas perkeliamas...';
$messages['formincomplete'] = 'Šios formos laukai yra nepilnai užpildyti';
$messages['noemailwarning'] = 'Prašome įvesti teisingą el. pašto adresą';
$messages['nonamewarning'] = 'Prašome įvesti vardą';
$messages['nopagesizewarning'] = 'Prašome įvesti puslapio dydį';
$messages['nosenderwarning'] = 'Prašome įvesti siuntėjo el. pašto adresą';
$messages['norecipientwarning'] = 'Prašome įvesti bent vieną gavėją';
$messages['nosubjectwarning'] = 'Temos laukelis tuščias. Ar norite temą įvesti dabar?';
$messages['nobodywarning'] = 'Išsiųsti šį laišką be teksto?';
$messages['notsentwarning'] = 'Laiškas neišsiųstas. Ar jūs tikrai norite jo atsikratyti?';
$messages['noldapserver'] = 'Prašome pasirinkti LDAP serverį paieškai';
$messages['nocontactsreturned'] = 'Kontaktas(-ai) nerastas(-i)';
$messages['nosearchname'] = 'Prašom įvesti vardą arba el. pašto adresą';
$messages['searchsuccessful'] = 'Surasta $nr žinučių';
$messages['searchnomatch'] = 'Rezultatų nerasta';
$messages['searching'] = 'Ieškoma...';
$messages['checking'] = 'Tikrinama...';
$messages['nospellerrors'] = 'Rašybos klaidų nerasta';
$messages['folderdeleted'] = 'Aplankas sėkmingai ištrintas';
$messages['deletedsuccessfully'] = 'Sėkmingai ištrintas';
$messages['converting'] = 'Pašalinamas laiško formatavimas...';
$messages['messageopenerror'] = 'Nepavyko įkelti laišką iš serverio';
$messages['fileuploaderror'] = 'Nepavyko įkelti bylos';
$messages['filesizeerror'] = 'Įkelta byla viršija maksimalų vietos limitą — $size';
$messages['copysuccess'] = 'Sėkmingai nukopijuoti $nr adresai';
$messages['copyerror'] = 'Adresų kopijuoti negalima';
$messages['sourceisreadonly'] = 'Šis adreso šaltinis yra tik skaitymui';
$messages['errorsavingcontact'] = 'Kontakto adreso išsaugoti negalima';
$messages['movingmessage'] = 'Perkeliamas laiškas...';
$messages['receiptsent'] = 'Sėkmingai išsiųstas laiško perskaitymo patvirtinimas';
$messages['errorsendingreceipt'] = 'Nepavyko išsiųsti laiško perskaitymo patvirtinimo';
$messages['nodeletelastidentity'] = 'Jūs negalite ištrinti šios tapatybės, kadangi ji yra vienintelė likusi.';
$messages['addsubfolderhint'] = 'Šis aplankas bus sukurtas kaip poaplankis, kurį esate pažymėjęs';
$messages['forbiddencharacter'] = 'Aplanko pavadinimas turi neleistinų simbolių';
$messages['selectimportfile'] = 'Prašome pasirinkti bylą įkėlimui';
$messages['addresswriterror'] = 'Pasirinkta adresų knyga nėra įrašoma';
$messages['importwait'] = 'Importuojama, prašome palaukti...';
$messages['importerror'] = 'Importavimas nepavyko! Įkelta byla nėra vCard formato.';
$messages['importconfirm'] = '<b>Sėkmingai importuoti $inserted kontaktai, $skipped egzistuojančių įrašų praleista</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'Operacija neleistina!';
$messages['nofromaddress'] = 'Nerastas el. pašto adresas pasirinktoje tapatybėje';
$messages['editorwarning'] = 'Pereinant tik į teksto redagavimą visas formatavimas bus prarastas. Ar tikrai norite vykdyti užklausą?';

?>
