<?php

/*
+-----------------------------------------------------------------------+
| language/he_IL/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2005-2008, RoundCube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Moshe Leibovitch  <moish@mln.co.il>                           |
| Updates: Noor Dawod <noor@comrax.com>                                 |
| Updates: Moshe Leibovitch  <moish@mln.co.il>  06122008                |
+-----------------------------------------------------------------------+
*/

$labels = array();
$labels['welcome'] = 'ברוך בואך אל $product';
$labels['username'] = 'שם משתמש';
$labels['password'] = 'סיסמה';
$labels['server'] = 'שרת';
$labels['login'] = 'כניסה';
$labels['logout'] = 'יציאה';
$labels['mail'] = 'רשימת הודעות';
$labels['settings'] = 'הגדרות אישיות';
$labels['addressbook'] = 'פנקס כתובות';
$labels['inbox'] = 'נכנס';
$labels['drafts'] = 'טיוטות';
$labels['sent'] = 'נשלח';
$labels['trash'] = 'אשפה';
$labels['junk'] = 'זבל';
$labels['subject'] = 'נושא';
$labels['from'] = 'השולח';
$labels['to'] = 'הנמען';
$labels['cc'] = 'לידיעה';
$labels['bcc'] = 'מכותב מוסתר';
$labels['replyto'] = 'כתובת למענה';
$labels['date'] = 'תאריך';
$labels['size'] = 'גודל';
$labels['priority'] = 'עדיפות';
$labels['organization'] = 'ארגון';
$labels['reply-to'] = 'כתובת למענה';
$labels['mailboxlist'] = 'תיקים';
$labels['messagesfromto'] = 'הודעות $from עד $to מתוך $count';
$labels['messagenrof'] = 'הודעה $nr מתוך $count';
$labels['moveto'] = 'תיוק ב...';
$labels['download'] = 'הורדה';
$labels['filename'] = 'שם קובץ';
$labels['filesize'] = 'גודל קובץ';
$labels['preferhtml'] = 'הצגת HTML';
$labels['htmlmessage'] = 'תוכן HTML';
$labels['prettydate'] = 'תאריכים מעוצבים';
$labels['addtoaddressbook'] = 'הוספה לפנקס כתובות';
$labels['sun'] = 'יום א';
$labels['mon'] = 'יום ב';
$labels['tue'] = 'יום ג';
$labels['wed'] = 'יום ד';
$labels['thu'] = 'יום ה';
$labels['fri'] = 'יום ו';
$labels['sat'] = 'יום ש';
$labels['sunday'] = 'ראשון';
$labels['monday'] = 'שני';
$labels['tuesday'] = 'שלישי';
$labels['wednesday'] = 'רביעי';
$labels['thursday'] = 'חמישי';
$labels['friday'] = 'ששי';
$labels['saturday'] = 'שבת';
$labels['jan'] = 'ינו';
$labels['feb'] = 'פבר';
$labels['mar'] = 'מרץ';
$labels['apr'] = 'אפר';
$labels['may'] = 'מאי';
$labels['jun'] = 'יונ';
$labels['jul'] = 'יול';
$labels['aug'] = 'אוג';
$labels['sep'] = 'ספט';
$labels['oct'] = 'אוק';
$labels['nov'] = 'נוב';
$labels['dec'] = 'דצמ';
$labels['longjan'] = 'ינואר';
$labels['longfeb'] = 'פברואר';
$labels['longmar'] = 'מרץ';
$labels['longapr'] = 'אפריל';
$labels['longmay'] = 'מאי';
$labels['longjun'] = 'יוני';
$labels['longjul'] = 'יולי';
$labels['longaug'] = 'אוגוסט';
$labels['longsep'] = 'ספטמבר';
$labels['longoct'] = 'אוקטובר';
$labels['longnov'] = 'נובמבר';
$labels['longdec'] = 'דצמבר';
$labels['today'] = 'היום';
$labels['checkmail'] = 'משיכת הודעות חדשות';
$labels['writenewmessage'] = 'יצירת הודעה חדשה';
$labels['replytomessage'] = 'מענה לשולח';
$labels['replytoallmessage'] = 'מענה לשולח ולכל הנמענים';
$labels['forwardmessage'] = 'העבר הודעה';
$labels['deletemessage'] = 'מחיקה';
$labels['movemessagetotrash'] = 'השלכה לאשפה';
$labels['printmessage'] = 'הדפסה';
$labels['previousmessage'] = 'הצגת הודעה קודמת';
$labels['previousmessages'] = 'הצגת קבוצה קודמת של הודעות';
$labels['firstmessage'] = 'הצגת ההודעה הראשונה';
$labels['firstmessages'] = 'הצגת הקבוצה הראשונה של ההודעות';
$labels['nextmessage'] = 'הצגת ההודעה הבאה';
$labels['nextmessages'] = 'הצגת קבוצה נוספת של הודעות';
$labels['lastmessage'] = 'הצגת ההודעה האחרונה';
$labels['lastmessages'] = 'הצגת הקבוצה האחרונה של ההודעות';
$labels['backtolist'] = 'חזרה אל רשימת ההודעות';
$labels['viewsource'] = 'הצגת קוד מקור';
$labels['markmessages'] = 'סימון הודעות';
$labels['markread'] = 'כנקראו';
$labels['markunread'] = 'כלא נקראו';
$labels['markflagged'] = 'כמסומן';
$labels['markunflagged'] = 'כלא מסומן';
$labels['select'] = 'בחירה';
$labels['all'] = 'הכל';
$labels['none'] = 'כלום';
$labels['unread'] = 'לא נקראו';
$labels['flagged'] = 'מסומן';
$labels['unanswered'] = 'לא נענה';
$labels['filter'] = 'סינון';
$labels['compact'] = 'פינוי שטח לא מנוצל';
$labels['empty'] = 'ריקון';
$labels['purge'] = 'מחיקה';
$labels['quota'] = 'ניצול קיבולת';
$labels['unknown'] = 'לא ידוע';
$labels['unlimited'] = 'ללא הגבלה';
$labels['quicksearch'] = 'חיפוש מהיר';
$labels['resetsearch'] = 'ניקוי תיבת החיפוש';
$labels['openinextwin'] = 'פתיחה בחלון חדש';
$labels['compose'] = 'כתיבת הודעה';
$labels['savemessage'] = 'שמירת טיוטה';
$labels['sendmessage'] = 'משלוח מיידי';
$labels['addattachment'] = 'צירוף קובץ';
$labels['charset'] = 'קידוד';
$labels['editortype'] = 'סוג עורך';
$labels['returnreceipt'] = 'אישור קבלה';
$labels['checkspelling'] = 'בדיקת איות';
$labels['resumeediting'] = 'המשך עריכה';
$labels['revertto'] = 'חזור למצב קודם';
$labels['attachments'] = 'קבצים מצורפים';
$labels['upload'] = 'העלאה';
$labels['close'] = 'סגירה';
$labels['low'] = 'נמוך';
$labels['lowest'] = 'נמוך ביותר';
$labels['normal'] = 'רגיל';
$labels['high'] = 'גבוה';
$labels['highest'] = 'גבוה ביותר';
$labels['nosubject'] = '(ללא נושא)';
$labels['showimages'] = 'הצגת תמונות';
$labels['alwaysshow'] = '$sender תמיד להציג תמונות מאת ';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'ללא עיצוב';
$labels['savesentmessagein'] = 'היכן לשמור ההודעה?';
$labels['dontsave'] = 'ללא שמירה';
$labels['maxuploadsize'] = 'גודל מקסימלי לקובץ הוא  $size';
$labels['addcc'] = 'הוספת מכותב לידיעה';
$labels['addbcc'] = 'הוספת מכותב נסתר';
$labels['addreplyto'] = 'הוספת כתובת למענה';
$labels['mdnrequest'] = 'השולח ביקש לדעת אם ההודעה נקראה. האם להודיע לשולח?';
$labels['receiptread'] = 'אישור קבלה (נקרא)';
$labels['yourmessage'] = 'אישור קבלה להודעתך';
$labels['receiptnote'] = 'הערה: האישור אינו מבטיח שהנמען קרא או הבין את תוכן ההודעה.';
$labels['name'] = 'שם להצגה';
$labels['firstname'] = 'שם פרטי';
$labels['surname'] = 'שם משפחה';
$labels['email'] = 'כתובת דוא"ל';
$labels['addcontact'] = 'הוספת איש קשר';
$labels['editcontact'] = 'עריכת איש קשר';
$labels['edit'] = 'עריכה';
$labels['cancel'] = 'ביטול';
$labels['save'] = 'שמירה';
$labels['delete'] = 'מחיקה';
$labels['newcontact'] = 'איש קשר חדש';
$labels['deletecontact'] = 'מחיקת אנשי קשר מסומנים';
$labels['composeto'] = 'יצירת הודעה אל';
$labels['contactsfromto'] = 'אנשי קשר $from עד $to מתוך $count';
$labels['print'] = 'הדפסה';
$labels['export'] = 'ייצוא';
$labels['exportvcards'] = 'ייצוא אנשי קשר בפורמט  vCard ';
$labels['previouspage'] = 'הצגת הקבוצה הקודמת';
$labels['firstpage'] = 'הצגת הקבוצה הראשונה';
$labels['nextpage'] = 'הצגת הקבוצה הבאה';
$labels['lastpage'] = 'הצגת הקבוצה האחרונה';
$labels['groups'] = 'קבוצות';
$labels['personaladrbook'] = 'כתובות פרטיות';
$labels['import'] = 'ייבוא';
$labels['importcontacts'] = 'ייבוא אנשי קשר';
$labels['importfromfile'] = 'ייבוא מקובץ';
$labels['importreplace'] = 'החלפת כל פנקס הכתובות';
$labels['importtext'] = '<a href="http://en.wikipedia.org/wiki/VCard">vCard</a>  ניתן לייבא אנשי קשר מפנקס כתובות קיים.  אנו תומכים בפורמט';
$labels['done'] = 'בוצע';
$labels['settingsfor'] = 'הגדרות עבור';
$labels['preferences'] = 'העדפות';
$labels['userpreferences'] = 'העדפות משתמש';
$labels['editpreferences'] = 'עריכה של העדפות משתמש';
$labels['identities'] = 'זהויות';
$labels['manageidentities'] = 'ניהול זהויות לחשבון זה';
$labels['newidentity'] = 'זהות חדשה';
$labels['newitem'] = 'רשומה חדשה';
$labels['edititem'] = 'עריכת רשומה';
$labels['setdefault'] = 'קביעה כברירת מחדל';
$labels['autodetect'] = 'אוטומטי';
$labels['language'] = 'שפה';
$labels['timezone'] = 'איזור זמן';
$labels['pagesize'] = 'מספר שורות בדף';
$labels['signature'] = 'חתימה';
$labels['dstactive'] = 'שעון קיץ';
$labels['htmleditor'] = 'יצירת הודעה מעוצבת';
$labels['htmlsignature'] = 'חתימה מעוצבת';
$labels['previewpane'] = 'תצוגה מוקדמת';
$labels['skin'] = 'ערכת מראה';
$labels['logoutclear'] = 'ריקון סל אשפה ביציאה';
$labels['logoutcompact'] = 'פינוי שטח לא מנוצל ביציאה';
$labels['uisettings'] = 'ממשק משתמש';
$labels['serversettings'] = 'הגדרות שרת';
$labels['mailboxview'] = 'הצגת תיבת ההודעות';
$labels['mdnrequests'] = 'משלוח אישור מסירה';
$labels['askuser'] = 'שאל את המשתמש';
$labels['autosend'] = 'שליחה אוטומטית';
$labels['ignore'] = 'התעלם';
$labels['readwhendeleted'] = 'סימון הודעה כנקראה לאחר מחיקה';
$labels['flagfordeletion'] = 'סימון הודעה כמחוקה במקום מחיקה';
$labels['skipdeleted'] = 'הסתרת הודעות שנמחקו';
$labels['showremoteimages'] = 'הצגת תמונות משרת מרוחק בגוף ההודעה';
$labels['fromknownsenders'] = 'משולחים מוכרים';
$labels['always'] = 'תמיד';
$labels['showinlineimages'] = 'הצגת תמונות מצורפות בתחתית ההודעה';
$labels['autosavedraft'] = 'שמירה אוטומטית של טיוטה';
$labels['everynminutes'] = 'כל $n דקות';
$labels['keepaliveevery'] = 'כל $n דקות';
$labels['keepalive'] = 'בדיקת הגעה של הודעות חדשות';
$labels['never'] = 'אף פעם';
$labels['messagesdisplaying'] = 'הצגת הודעות';
$labels['messagescomposition'] = 'כתיבת הודעות';
$labels['mimeparamfolding'] = 'שמות קבצים מצורפים';
$labels['2231folding'] = 'תאימות מלאה 2231 תאנדרבירד';
$labels['miscfolding'] = 'תאימות 2047/2231 אאוטלוק';
$labels['2047folding'] = 'תאימות מלאה 2047 אחרים';
$labels['advancedoptions'] = 'הגדרות נוספות';
$labels['focusonnewmessage'] = 'מיקוד הסמן על החלון עם ההודעה החדשה';
$labels['checkallfolders'] = 'בדיקת הודעות חדשות בכל התיקים';
$labels['folder'] = 'תיק';
$labels['folders'] = 'תיקים';
$labels['foldername'] = 'שם תיק';
$labels['subscribed'] = 'מנוי';
$labels['messagecount'] = 'הודעות';
$labels['create'] = 'יצירה';
$labels['createfolder'] = 'יצירת תיק חדש';
$labels['rename'] = 'שינוי שם';
$labels['renamefolder'] = 'שינוי שם תיק';
$labels['deletefolder'] = 'מחיקת תיק';
$labels['managefolders'] = 'ניהול תיקים';
$labels['specialfolders'] = 'תיקים מיוחדים';
$labels['sortby'] = 'מיון לפי';
$labels['sortasc'] = 'מיון בסדר עולה';
$labels['sortdesc'] = 'מיון בסדר יורד';
$labels['B'] = 'בייט';
$labels['KB'] = 'ק"ב';
$labels['MB'] = 'מ"ב';
$labels['GB'] = 'ג"ב';

?>
